import { type BrowserSharedCookie } from '../../../../../../models/browserSharedCookie';
import { type BrowserSite } from '../../../../../../models/browserSite';
import { type BrowserSiteList } from '../../../../../../models/browserSiteList';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createPublishPostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoPublishPostRequestBody;
export declare function deserializeIntoPublishPostRequestBody(publishPostRequestBody?: PublishPostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export interface PublishPostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The revision property
     */
    revision?: string;
    /**
     * The sharedCookies property
     */
    sharedCookies?: BrowserSharedCookie[];
    /**
     * The sites property
     */
    sites?: BrowserSite[];
}
export declare function serializePublishPostRequestBody(writer: SerializationWriter, publishPostRequestBody?: PublishPostRequestBody | undefined): void;
/**
 * Provides operations to call the publish method.
 */
export declare class PublishRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new PublishRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Publish the specified browserSiteList for devices to download.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BrowserSiteList
     * @see {@link https://learn.microsoft.com/graph/api/browsersitelist-publish?view=graph-rest-1.0|Find more info here}
     */
    post(body: PublishPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<BrowserSiteList | undefined>;
    /**
     * Publish the specified browserSiteList for devices to download.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: PublishPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a publishRequestBuilder
     */
    withUrl(rawUrl: string): PublishRequestBuilder;
}
