import { type BrowserSharedCookieCollectionResponse } from '../../../../../../models/';
import { type BrowserSharedCookie } from '../../../../../../models/browserSharedCookie';
import { CountRequestBuilder } from './count/';
import { BrowserSharedCookieItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SharedCookiesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the sharedCookies property of the microsoft.graph.browserSiteList entity.
 */
export declare class SharedCookiesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the sharedCookies property of the microsoft.graph.browserSiteList entity.
     * @param browserSharedCookieId The unique identifier of browserSharedCookie
     * @returns a BrowserSharedCookieItemRequestBuilder
     */
    byBrowserSharedCookieId(browserSharedCookieId: string): BrowserSharedCookieItemRequestBuilder;
    /**
     * Instantiates a new SharedCookiesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the browserSharedCookie objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BrowserSharedCookieCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/browsersitelist-list-sharedcookies?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SharedCookiesRequestBuilderGetQueryParameters> | undefined): Promise<BrowserSharedCookieCollectionResponse | undefined>;
    /**
     * Create a new browserSharedCookie object in a browserSiteList.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BrowserSharedCookie
     * @see {@link https://learn.microsoft.com/graph/api/browsersitelist-post-sharedcookies?view=graph-rest-1.0|Find more info here}
     */
    post(body: BrowserSharedCookie, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<BrowserSharedCookie | undefined>;
    /**
     * Get a list of the browserSharedCookie objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SharedCookiesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new browserSharedCookie object in a browserSiteList.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: BrowserSharedCookie, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a sharedCookiesRequestBuilder
     */
    withUrl(rawUrl: string): SharedCookiesRequestBuilder;
}
