import { type BrowserSite } from '../../../../../../../models/browserSite';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface BrowserSiteItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the sites property of the microsoft.graph.browserSiteList entity.
 */
export declare class BrowserSiteItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new BrowserSiteItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete a browserSite from a browserSiteList.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/browsersitelist-delete-sites?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Get a browserSite that resides on a browserSiteList.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BrowserSite
     * @see {@link https://learn.microsoft.com/graph/api/browsersite-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<BrowserSiteItemRequestBuilderGetQueryParameters> | undefined): Promise<BrowserSite | undefined>;
    /**
     * Update the properties of a browserSite object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BrowserSite
     * @see {@link https://learn.microsoft.com/graph/api/browsersite-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: BrowserSite, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<BrowserSite | undefined>;
    /**
     * Delete a browserSite from a browserSiteList.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Get a browserSite that resides on a browserSiteList.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<BrowserSiteItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of a browserSite object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: BrowserSite, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a BrowserSiteItemRequestBuilder
     */
    withUrl(rawUrl: string): BrowserSiteItemRequestBuilder;
}
