import { type PeopleAdminSettings } from '../../models/peopleAdminSettings';
import { ProfileCardPropertiesRequestBuilder } from './profileCardProperties/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface PeopleRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the people property of the microsoft.graph.admin entity.
 */
export declare class PeopleRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the profileCardProperties property of the microsoft.graph.peopleAdminSettings entity.
     */
    get profileCardProperties(): ProfileCardPropertiesRequestBuilder;
    /**
     * Instantiates a new PeopleRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the properties and relationships of a peopleAdminSettings object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PeopleAdminSettings
     * @see {@link https://learn.microsoft.com/graph/api/peopleadminsettings-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<PeopleRequestBuilderGetQueryParameters> | undefined): Promise<PeopleAdminSettings | undefined>;
    /**
     * Update the navigation property people in admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PeopleAdminSettings
     */
    patch(body: PeopleAdminSettings, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<PeopleAdminSettings | undefined>;
    /**
     * Retrieve the properties and relationships of a peopleAdminSettings object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<PeopleRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property people in admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: PeopleAdminSettings, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a peopleRequestBuilder
     */
    withUrl(rawUrl: string): PeopleRequestBuilder;
}
