import { type ServiceHealthIssueCollectionResponse } from '../../../models/';
import { type ServiceHealthIssue } from '../../../models/serviceHealthIssue';
import { CountRequestBuilder } from './count/';
import { ServiceHealthIssueItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface IssuesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the issues property of the microsoft.graph.serviceAnnouncement entity.
 */
export declare class IssuesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the issues property of the microsoft.graph.serviceAnnouncement entity.
     * @param serviceHealthIssueId The unique identifier of serviceHealthIssue
     * @returns a ServiceHealthIssueItemRequestBuilder
     */
    byServiceHealthIssueId(serviceHealthIssueId: string): ServiceHealthIssueItemRequestBuilder;
    /**
     * Instantiates a new IssuesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve serviceHealthIssue resources from the issues navigation property. This operation retrieves information about all service health issues that exist for the tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ServiceHealthIssueCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/serviceannouncement-list-issues?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<IssuesRequestBuilderGetQueryParameters> | undefined): Promise<ServiceHealthIssueCollectionResponse | undefined>;
    /**
     * Create new navigation property to issues for admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ServiceHealthIssue
     */
    post(body: ServiceHealthIssue, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ServiceHealthIssue | undefined>;
    /**
     * Retrieve serviceHealthIssue resources from the issues navigation property. This operation retrieves information about all service health issues that exist for the tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<IssuesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to issues for admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ServiceHealthIssue, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a issuesRequestBuilder
     */
    withUrl(rawUrl: string): IssuesRequestBuilder;
}
