"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ArchiveRequestBuilder = exports.serializeArchivePostResponse = exports.serializeArchivePostRequestBody = exports.deserializeIntoArchivePostResponse = exports.deserializeIntoArchivePostRequestBody = exports.createArchivePostResponseFromDiscriminatorValue = exports.createArchivePostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createArchivePostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoArchivePostRequestBody;
}
exports.createArchivePostRequestBodyFromDiscriminatorValue = createArchivePostRequestBodyFromDiscriminatorValue;
function createArchivePostResponseFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoArchivePostResponse;
}
exports.createArchivePostResponseFromDiscriminatorValue = createArchivePostResponseFromDiscriminatorValue;
function deserializeIntoArchivePostRequestBody(archivePostRequestBody = {}) {
    return {
        "messageIds": n => { archivePostRequestBody.messageIds = n.getCollectionOfPrimitiveValues(); },
    };
}
exports.deserializeIntoArchivePostRequestBody = deserializeIntoArchivePostRequestBody;
function deserializeIntoArchivePostResponse(archivePostResponse = {}) {
    return {
        "value": n => { archivePostResponse.value = n.getBooleanValue(); },
    };
}
exports.deserializeIntoArchivePostResponse = deserializeIntoArchivePostResponse;
function serializeArchivePostRequestBody(writer, archivePostRequestBody = {}) {
    writer.writeCollectionOfPrimitiveValues("messageIds", archivePostRequestBody.messageIds);
    writer.writeAdditionalData(archivePostRequestBody.additionalData);
}
exports.serializeArchivePostRequestBody = serializeArchivePostRequestBody;
function serializeArchivePostResponse(writer, archivePostResponse = {}) {
    writer.writeBooleanValue("value", archivePostResponse.value);
    writer.writeAdditionalData(archivePostResponse.additionalData);
}
exports.serializeArchivePostResponse = serializeArchivePostResponse;
/**
 * Provides operations to call the archive method.
 */
class ArchiveRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new ArchiveRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/admin/serviceAnnouncement/messages/archive");
    }
    ;
    /**
     * Archive a list of serviceUpdateMessages for the signed in user.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ArchivePostResponse
     * @see {@link https://learn.microsoft.com/graph/api/serviceupdatemessage-archive?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, createArchivePostResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Archive a list of serviceUpdateMessages for the signed in user.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeArchivePostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a archiveRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new ArchiveRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.ArchiveRequestBuilder = ArchiveRequestBuilder;
// tslint:enable
// eslint-enable
