"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FavoriteRequestBuilder = exports.serializeFavoritePostResponse = exports.serializeFavoritePostRequestBody = exports.deserializeIntoFavoritePostResponse = exports.deserializeIntoFavoritePostRequestBody = exports.createFavoritePostResponseFromDiscriminatorValue = exports.createFavoritePostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createFavoritePostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoFavoritePostRequestBody;
}
exports.createFavoritePostRequestBodyFromDiscriminatorValue = createFavoritePostRequestBodyFromDiscriminatorValue;
function createFavoritePostResponseFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoFavoritePostResponse;
}
exports.createFavoritePostResponseFromDiscriminatorValue = createFavoritePostResponseFromDiscriminatorValue;
function deserializeIntoFavoritePostRequestBody(favoritePostRequestBody = {}) {
    return {
        "messageIds": n => { favoritePostRequestBody.messageIds = n.getCollectionOfPrimitiveValues(); },
    };
}
exports.deserializeIntoFavoritePostRequestBody = deserializeIntoFavoritePostRequestBody;
function deserializeIntoFavoritePostResponse(favoritePostResponse = {}) {
    return {
        "value": n => { favoritePostResponse.value = n.getBooleanValue(); },
    };
}
exports.deserializeIntoFavoritePostResponse = deserializeIntoFavoritePostResponse;
function serializeFavoritePostRequestBody(writer, favoritePostRequestBody = {}) {
    writer.writeCollectionOfPrimitiveValues("messageIds", favoritePostRequestBody.messageIds);
    writer.writeAdditionalData(favoritePostRequestBody.additionalData);
}
exports.serializeFavoritePostRequestBody = serializeFavoritePostRequestBody;
function serializeFavoritePostResponse(writer, favoritePostResponse = {}) {
    writer.writeBooleanValue("value", favoritePostResponse.value);
    writer.writeAdditionalData(favoritePostResponse.additionalData);
}
exports.serializeFavoritePostResponse = serializeFavoritePostResponse;
/**
 * Provides operations to call the favorite method.
 */
class FavoriteRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new FavoriteRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/admin/serviceAnnouncement/messages/favorite");
    }
    ;
    /**
     * Change the status of a list of serviceUpdateMessages to favorite for the signed in user.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of FavoritePostResponse
     * @see {@link https://learn.microsoft.com/graph/api/serviceupdatemessage-favorite?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, createFavoritePostResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Change the status of a list of serviceUpdateMessages to favorite for the signed in user.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeFavoritePostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a favoriteRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new FavoriteRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.FavoriteRequestBuilder = FavoriteRequestBuilder;
// tslint:enable
// eslint-enable
