import { type ServiceUpdateMessageCollectionResponse } from '../../../models/';
import { type ServiceUpdateMessage } from '../../../models/serviceUpdateMessage';
import { ArchiveRequestBuilder } from './archive/';
import { CountRequestBuilder } from './count/';
import { FavoriteRequestBuilder } from './favorite/';
import { ServiceUpdateMessageItemRequestBuilder } from './item/';
import { MarkReadRequestBuilder } from './markRead/';
import { MarkUnreadRequestBuilder } from './markUnread/';
import { UnarchiveRequestBuilder } from './unarchive/';
import { UnfavoriteRequestBuilder } from './unfavorite/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface MessagesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the messages property of the microsoft.graph.serviceAnnouncement entity.
 */
export declare class MessagesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the archive method.
     */
    get archive(): ArchiveRequestBuilder;
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to call the favorite method.
     */
    get favorite(): FavoriteRequestBuilder;
    /**
     * Provides operations to call the markRead method.
     */
    get markRead(): MarkReadRequestBuilder;
    /**
     * Provides operations to call the markUnread method.
     */
    get markUnread(): MarkUnreadRequestBuilder;
    /**
     * Provides operations to call the unarchive method.
     */
    get unarchive(): UnarchiveRequestBuilder;
    /**
     * Provides operations to call the unfavorite method.
     */
    get unfavorite(): UnfavoriteRequestBuilder;
    /**
     * Provides operations to manage the messages property of the microsoft.graph.serviceAnnouncement entity.
     * @param serviceUpdateMessageId The unique identifier of serviceUpdateMessage
     * @returns a ServiceUpdateMessageItemRequestBuilder
     */
    byServiceUpdateMessageId(serviceUpdateMessageId: string): ServiceUpdateMessageItemRequestBuilder;
    /**
     * Instantiates a new MessagesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the serviceUpdateMessage resources from the messages navigation property. This operation retrieves all service update messages that exist for the tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ServiceUpdateMessageCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/serviceannouncement-list-messages?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<MessagesRequestBuilderGetQueryParameters> | undefined): Promise<ServiceUpdateMessageCollectionResponse | undefined>;
    /**
     * Create new navigation property to messages for admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ServiceUpdateMessage
     */
    post(body: ServiceUpdateMessage, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ServiceUpdateMessage | undefined>;
    /**
     * Retrieve the serviceUpdateMessage resources from the messages navigation property. This operation retrieves all service update messages that exist for the tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<MessagesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to messages for admin
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ServiceUpdateMessage, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a messagesRequestBuilder
     */
    withUrl(rawUrl: string): MessagesRequestBuilder;
}
