"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MarkReadRequestBuilder = exports.serializeMarkReadPostResponse = exports.serializeMarkReadPostRequestBody = exports.deserializeIntoMarkReadPostResponse = exports.deserializeIntoMarkReadPostRequestBody = exports.createMarkReadPostResponseFromDiscriminatorValue = exports.createMarkReadPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createMarkReadPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoMarkReadPostRequestBody;
}
exports.createMarkReadPostRequestBodyFromDiscriminatorValue = createMarkReadPostRequestBodyFromDiscriminatorValue;
function createMarkReadPostResponseFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoMarkReadPostResponse;
}
exports.createMarkReadPostResponseFromDiscriminatorValue = createMarkReadPostResponseFromDiscriminatorValue;
function deserializeIntoMarkReadPostRequestBody(markReadPostRequestBody = {}) {
    return {
        "messageIds": n => { markReadPostRequestBody.messageIds = n.getCollectionOfPrimitiveValues(); },
    };
}
exports.deserializeIntoMarkReadPostRequestBody = deserializeIntoMarkReadPostRequestBody;
function deserializeIntoMarkReadPostResponse(markReadPostResponse = {}) {
    return {
        "value": n => { markReadPostResponse.value = n.getBooleanValue(); },
    };
}
exports.deserializeIntoMarkReadPostResponse = deserializeIntoMarkReadPostResponse;
function serializeMarkReadPostRequestBody(writer, markReadPostRequestBody = {}) {
    writer.writeCollectionOfPrimitiveValues("messageIds", markReadPostRequestBody.messageIds);
    writer.writeAdditionalData(markReadPostRequestBody.additionalData);
}
exports.serializeMarkReadPostRequestBody = serializeMarkReadPostRequestBody;
function serializeMarkReadPostResponse(writer, markReadPostResponse = {}) {
    writer.writeBooleanValue("value", markReadPostResponse.value);
    writer.writeAdditionalData(markReadPostResponse.additionalData);
}
exports.serializeMarkReadPostResponse = serializeMarkReadPostResponse;
/**
 * Provides operations to call the markRead method.
 */
class MarkReadRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new MarkReadRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/admin/serviceAnnouncement/messages/markRead");
    }
    ;
    /**
     * Mark a list of serviceUpdateMessages as read for the signed in user.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MarkReadPostResponse
     * @see {@link https://learn.microsoft.com/graph/api/serviceupdatemessage-markread?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, createMarkReadPostResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Mark a list of serviceUpdateMessages as read for the signed in user.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeMarkReadPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a markReadRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new MarkReadRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.MarkReadRequestBuilder = MarkReadRequestBuilder;
// tslint:enable
// eslint-enable
