"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnarchiveRequestBuilder = exports.serializeUnarchivePostResponse = exports.serializeUnarchivePostRequestBody = exports.deserializeIntoUnarchivePostResponse = exports.deserializeIntoUnarchivePostRequestBody = exports.createUnarchivePostResponseFromDiscriminatorValue = exports.createUnarchivePostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createUnarchivePostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoUnarchivePostRequestBody;
}
exports.createUnarchivePostRequestBodyFromDiscriminatorValue = createUnarchivePostRequestBodyFromDiscriminatorValue;
function createUnarchivePostResponseFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoUnarchivePostResponse;
}
exports.createUnarchivePostResponseFromDiscriminatorValue = createUnarchivePostResponseFromDiscriminatorValue;
function deserializeIntoUnarchivePostRequestBody(unarchivePostRequestBody = {}) {
    return {
        "messageIds": n => { unarchivePostRequestBody.messageIds = n.getCollectionOfPrimitiveValues(); },
    };
}
exports.deserializeIntoUnarchivePostRequestBody = deserializeIntoUnarchivePostRequestBody;
function deserializeIntoUnarchivePostResponse(unarchivePostResponse = {}) {
    return {
        "value": n => { unarchivePostResponse.value = n.getBooleanValue(); },
    };
}
exports.deserializeIntoUnarchivePostResponse = deserializeIntoUnarchivePostResponse;
function serializeUnarchivePostRequestBody(writer, unarchivePostRequestBody = {}) {
    writer.writeCollectionOfPrimitiveValues("messageIds", unarchivePostRequestBody.messageIds);
    writer.writeAdditionalData(unarchivePostRequestBody.additionalData);
}
exports.serializeUnarchivePostRequestBody = serializeUnarchivePostRequestBody;
function serializeUnarchivePostResponse(writer, unarchivePostResponse = {}) {
    writer.writeBooleanValue("value", unarchivePostResponse.value);
    writer.writeAdditionalData(unarchivePostResponse.additionalData);
}
exports.serializeUnarchivePostResponse = serializeUnarchivePostResponse;
/**
 * Provides operations to call the unarchive method.
 */
class UnarchiveRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new UnarchiveRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/admin/serviceAnnouncement/messages/unarchive");
    }
    ;
    /**
     * Unarchive a list of serviceUpdateMessages for the signed in user.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UnarchivePostResponse
     * @see {@link https://learn.microsoft.com/graph/api/serviceupdatemessage-unarchive?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, createUnarchivePostResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Unarchive a list of serviceUpdateMessages for the signed in user.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeUnarchivePostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a unarchiveRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new UnarchiveRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.UnarchiveRequestBuilder = UnarchiveRequestBuilder;
// tslint:enable
// eslint-enable
