"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnfavoriteRequestBuilder = exports.serializeUnfavoritePostResponse = exports.serializeUnfavoritePostRequestBody = exports.deserializeIntoUnfavoritePostResponse = exports.deserializeIntoUnfavoritePostRequestBody = exports.createUnfavoritePostResponseFromDiscriminatorValue = exports.createUnfavoritePostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createUnfavoritePostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoUnfavoritePostRequestBody;
}
exports.createUnfavoritePostRequestBodyFromDiscriminatorValue = createUnfavoritePostRequestBodyFromDiscriminatorValue;
function createUnfavoritePostResponseFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoUnfavoritePostResponse;
}
exports.createUnfavoritePostResponseFromDiscriminatorValue = createUnfavoritePostResponseFromDiscriminatorValue;
function deserializeIntoUnfavoritePostRequestBody(unfavoritePostRequestBody = {}) {
    return {
        "messageIds": n => { unfavoritePostRequestBody.messageIds = n.getCollectionOfPrimitiveValues(); },
    };
}
exports.deserializeIntoUnfavoritePostRequestBody = deserializeIntoUnfavoritePostRequestBody;
function deserializeIntoUnfavoritePostResponse(unfavoritePostResponse = {}) {
    return {
        "value": n => { unfavoritePostResponse.value = n.getBooleanValue(); },
    };
}
exports.deserializeIntoUnfavoritePostResponse = deserializeIntoUnfavoritePostResponse;
function serializeUnfavoritePostRequestBody(writer, unfavoritePostRequestBody = {}) {
    writer.writeCollectionOfPrimitiveValues("messageIds", unfavoritePostRequestBody.messageIds);
    writer.writeAdditionalData(unfavoritePostRequestBody.additionalData);
}
exports.serializeUnfavoritePostRequestBody = serializeUnfavoritePostRequestBody;
function serializeUnfavoritePostResponse(writer, unfavoritePostResponse = {}) {
    writer.writeBooleanValue("value", unfavoritePostResponse.value);
    writer.writeAdditionalData(unfavoritePostResponse.additionalData);
}
exports.serializeUnfavoritePostResponse = serializeUnfavoritePostResponse;
/**
 * Provides operations to call the unfavorite method.
 */
class UnfavoriteRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new UnfavoriteRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/admin/serviceAnnouncement/messages/unfavorite");
    }
    ;
    /**
     * Remove the favorite status of serviceUpdateMessages for the signed in user.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UnfavoritePostResponse
     * @see {@link https://learn.microsoft.com/graph/api/serviceupdatemessage-unfavorite?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, createUnfavoritePostResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Remove the favorite status of serviceUpdateMessages for the signed in user.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeUnfavoritePostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a unfavoriteRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new UnfavoriteRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.UnfavoriteRequestBuilder = UnfavoriteRequestBuilder;
// tslint:enable
// eslint-enable
