import { type AgreementFileLocalizationCollectionResponse } from '../../../models/';
import { type AgreementFileLocalization } from '../../../models/agreementFileLocalization';
import { CountRequestBuilder } from './count/';
import { AgreementFileLocalizationItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface FilesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the files property of the microsoft.graph.agreement entity.
 */
export declare class FilesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the files property of the microsoft.graph.agreement entity.
     * @param agreementFileLocalizationId The unique identifier of agreementFileLocalization
     * @returns a AgreementFileLocalizationItemRequestBuilder
     */
    byAgreementFileLocalizationId(agreementFileLocalizationId: string): AgreementFileLocalizationItemRequestBuilder;
    /**
     * Instantiates a new FilesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * PDFs linked to this agreement. This property is in the process of being deprecated. Use the  file property instead. Supports $expand.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AgreementFileLocalizationCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<FilesRequestBuilderGetQueryParameters> | undefined): Promise<AgreementFileLocalizationCollectionResponse | undefined>;
    /**
     * Create a new localized agreement file.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AgreementFileLocalization
     * @see {@link https://learn.microsoft.com/graph/api/agreement-post-files?view=graph-rest-1.0|Find more info here}
     */
    post(body: AgreementFileLocalization, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AgreementFileLocalization | undefined>;
    /**
     * PDFs linked to this agreement. This property is in the process of being deprecated. Use the  file property instead. Supports $expand.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<FilesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new localized agreement file.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AgreementFileLocalization, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a filesRequestBuilder
     */
    withUrl(rawUrl: string): FilesRequestBuilder;
}
