import { type ExtensionPropertyCollectionResponse } from '../../../models/';
import { type ExtensionProperty } from '../../../models/extensionProperty';
import { CountRequestBuilder } from './count/';
import { ExtensionPropertyItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ExtensionPropertiesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the extensionProperties property of the microsoft.graph.application entity.
 */
export declare class ExtensionPropertiesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the extensionProperties property of the microsoft.graph.application entity.
     * @param extensionPropertyId The unique identifier of extensionProperty
     * @returns a ExtensionPropertyItemRequestBuilder
     */
    byExtensionPropertyId(extensionPropertyId: string): ExtensionPropertyItemRequestBuilder;
    /**
     * Instantiates a new ExtensionPropertiesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the list of directory extension definitions, represented by extensionProperty objects on an application.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ExtensionPropertyCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/application-list-extensionproperty?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ExtensionPropertiesRequestBuilderGetQueryParameters> | undefined): Promise<ExtensionPropertyCollectionResponse | undefined>;
    /**
     * Create a new directory extension definition, represented by an extensionProperty object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ExtensionProperty
     * @see {@link https://learn.microsoft.com/graph/api/application-post-extensionproperty?view=graph-rest-1.0|Find more info here}
     */
    post(body: ExtensionProperty, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ExtensionProperty | undefined>;
    /**
     * Retrieve the list of directory extension definitions, represented by extensionProperty objects on an application.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ExtensionPropertiesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new directory extension definition, represented by an extensionProperty object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ExtensionProperty, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a extensionPropertiesRequestBuilder
     */
    withUrl(rawUrl: string): ExtensionPropertiesRequestBuilder;
}
