import { type FederatedIdentityCredential } from '../../../../models/federatedIdentityCredential';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface FederatedIdentityCredentialItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the federatedIdentityCredentials property of the microsoft.graph.application entity.
 */
export declare class FederatedIdentityCredentialItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new FederatedIdentityCredentialItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete a federatedIdentityCredential object from an application.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/federatedidentitycredential-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of a federatedIdentityCredential object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of FederatedIdentityCredential
     * @see {@link https://learn.microsoft.com/graph/api/federatedidentitycredential-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<FederatedIdentityCredentialItemRequestBuilderGetQueryParameters> | undefined): Promise<FederatedIdentityCredential | undefined>;
    /**
     * Update the properties of a federatedIdentityCredential object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of FederatedIdentityCredential
     * @see {@link https://learn.microsoft.com/graph/api/federatedidentitycredential-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: FederatedIdentityCredential, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<FederatedIdentityCredential | undefined>;
    /**
     * Delete a federatedIdentityCredential object from an application.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of a federatedIdentityCredential object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<FederatedIdentityCredentialItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of a federatedIdentityCredential object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: FederatedIdentityCredential, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a FederatedIdentityCredentialItemRequestBuilder
     */
    withUrl(rawUrl: string): FederatedIdentityCredentialItemRequestBuilder;
}
