import { type Application } from '../../models/application';
import { AddKeyRequestBuilder } from './addKey/';
import { AddPasswordRequestBuilder } from './addPassword/';
import { AppManagementPoliciesRequestBuilder } from './appManagementPolicies/';
import { CheckMemberGroupsRequestBuilder } from './checkMemberGroups/';
import { CheckMemberObjectsRequestBuilder } from './checkMemberObjects/';
import { CreatedOnBehalfOfRequestBuilder } from './createdOnBehalfOf/';
import { ExtensionPropertiesRequestBuilder } from './extensionProperties/';
import { FederatedIdentityCredentialsRequestBuilder } from './federatedIdentityCredentials/';
import { GetMemberGroupsRequestBuilder } from './getMemberGroups/';
import { GetMemberObjectsRequestBuilder } from './getMemberObjects/';
import { HomeRealmDiscoveryPoliciesRequestBuilder } from './homeRealmDiscoveryPolicies/';
import { LogoRequestBuilder } from './logo/';
import { OwnersRequestBuilder } from './owners/';
import { RemoveKeyRequestBuilder } from './removeKey/';
import { RemovePasswordRequestBuilder } from './removePassword/';
import { RestoreRequestBuilder } from './restore/';
import { SetVerifiedPublisherRequestBuilder } from './setVerifiedPublisher/';
import { SynchronizationRequestBuilder } from './synchronization/';
import { TokenIssuancePoliciesRequestBuilder } from './tokenIssuancePolicies/';
import { TokenLifetimePoliciesRequestBuilder } from './tokenLifetimePolicies/';
import { UnsetVerifiedPublisherRequestBuilder } from './unsetVerifiedPublisher/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ApplicationItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the collection of application entities.
 */
export declare class ApplicationItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the addKey method.
     */
    get addKey(): AddKeyRequestBuilder;
    /**
     * Provides operations to call the addPassword method.
     */
    get addPassword(): AddPasswordRequestBuilder;
    /**
     * Provides operations to manage the appManagementPolicies property of the microsoft.graph.application entity.
     */
    get appManagementPolicies(): AppManagementPoliciesRequestBuilder;
    /**
     * Provides operations to call the checkMemberGroups method.
     */
    get checkMemberGroups(): CheckMemberGroupsRequestBuilder;
    /**
     * Provides operations to call the checkMemberObjects method.
     */
    get checkMemberObjects(): CheckMemberObjectsRequestBuilder;
    /**
     * Provides operations to manage the createdOnBehalfOf property of the microsoft.graph.application entity.
     */
    get createdOnBehalfOf(): CreatedOnBehalfOfRequestBuilder;
    /**
     * Provides operations to manage the extensionProperties property of the microsoft.graph.application entity.
     */
    get extensionProperties(): ExtensionPropertiesRequestBuilder;
    /**
     * Provides operations to manage the federatedIdentityCredentials property of the microsoft.graph.application entity.
     */
    get federatedIdentityCredentials(): FederatedIdentityCredentialsRequestBuilder;
    /**
     * Provides operations to call the getMemberGroups method.
     */
    get getMemberGroups(): GetMemberGroupsRequestBuilder;
    /**
     * Provides operations to call the getMemberObjects method.
     */
    get getMemberObjects(): GetMemberObjectsRequestBuilder;
    /**
     * Provides operations to manage the homeRealmDiscoveryPolicies property of the microsoft.graph.application entity.
     */
    get homeRealmDiscoveryPolicies(): HomeRealmDiscoveryPoliciesRequestBuilder;
    /**
     * Provides operations to manage the media for the application entity.
     */
    get logo(): LogoRequestBuilder;
    /**
     * Provides operations to manage the owners property of the microsoft.graph.application entity.
     */
    get owners(): OwnersRequestBuilder;
    /**
     * Provides operations to call the removeKey method.
     */
    get removeKey(): RemoveKeyRequestBuilder;
    /**
     * Provides operations to call the removePassword method.
     */
    get removePassword(): RemovePasswordRequestBuilder;
    /**
     * Provides operations to call the restore method.
     */
    get restore(): RestoreRequestBuilder;
    /**
     * Provides operations to call the setVerifiedPublisher method.
     */
    get setVerifiedPublisher(): SetVerifiedPublisherRequestBuilder;
    /**
     * Provides operations to manage the synchronization property of the microsoft.graph.application entity.
     */
    get synchronization(): SynchronizationRequestBuilder;
    /**
     * Provides operations to manage the tokenIssuancePolicies property of the microsoft.graph.application entity.
     */
    get tokenIssuancePolicies(): TokenIssuancePoliciesRequestBuilder;
    /**
     * Provides operations to manage the tokenLifetimePolicies property of the microsoft.graph.application entity.
     */
    get tokenLifetimePolicies(): TokenLifetimePoliciesRequestBuilder;
    /**
     * Provides operations to call the unsetVerifiedPublisher method.
     */
    get unsetVerifiedPublisher(): UnsetVerifiedPublisherRequestBuilder;
    /**
     * Instantiates a new ApplicationItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete an application object. When deleted, apps are moved to a temporary container and can be restored within 30 days. After that time, they are permanently deleted.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/application-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Get the properties and relationships of an application object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Application
     * @see {@link https://learn.microsoft.com/graph/api/application-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ApplicationItemRequestBuilderGetQueryParameters> | undefined): Promise<Application | undefined>;
    /**
     * Update the properties of an application object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Application
     * @see {@link https://learn.microsoft.com/graph/api/application-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: Application, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Application | undefined>;
    /**
     * Delete an application object. When deleted, apps are moved to a temporary container and can be restored within 30 days. After that time, they are permanently deleted.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Get the properties and relationships of an application object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ApplicationItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of an application object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Application, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ApplicationItemRequestBuilder
     */
    withUrl(rawUrl: string): ApplicationItemRequestBuilder;
}
