import { type Synchronization } from '../../../models/synchronization';
import { AcquireAccessTokenRequestBuilder } from './acquireAccessToken/';
import { JobsRequestBuilder } from './jobs/';
import { SecretsRequestBuilder } from './secrets/';
import { TemplatesRequestBuilder } from './templates/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SynchronizationRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the synchronization property of the microsoft.graph.application entity.
 */
export declare class SynchronizationRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the acquireAccessToken method.
     */
    get acquireAccessToken(): AcquireAccessTokenRequestBuilder;
    /**
     * Provides operations to manage the jobs property of the microsoft.graph.synchronization entity.
     */
    get jobs(): JobsRequestBuilder;
    /**
     * The secrets property
     */
    get secrets(): SecretsRequestBuilder;
    /**
     * Provides operations to manage the templates property of the microsoft.graph.synchronization entity.
     */
    get templates(): TemplatesRequestBuilder;
    /**
     * Instantiates a new SynchronizationRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property synchronization for applications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Represents the capability for Microsoft Entra identity synchronization through the Microsoft Graph API.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Synchronization
     */
    get(requestConfiguration?: RequestConfiguration<SynchronizationRequestBuilderGetQueryParameters> | undefined): Promise<Synchronization | undefined>;
    /**
     * Update the navigation property synchronization in applications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Synchronization
     */
    put(body: Synchronization, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Synchronization | undefined>;
    /**
     * Delete navigation property synchronization for applications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Represents the capability for Microsoft Entra identity synchronization through the Microsoft Graph API.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SynchronizationRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property synchronization in applications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPutRequestInformation(body: Synchronization, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a synchronizationRequestBuilder
     */
    withUrl(rawUrl: string): SynchronizationRequestBuilder;
}
