"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SynchronizationJobItemRequestBuilder = void 0;
const oDataError_1 = require("../../../../../models/oDataErrors/oDataError");
const synchronizationJob_1 = require("../../../../../models/synchronizationJob");
const pause_1 = require("./pause/");
const provisionOnDemand_1 = require("./provisionOnDemand/");
const restart_1 = require("./restart/");
const schema_1 = require("./schema/");
const start_1 = require("./start/");
const validateCredentials_1 = require("./validateCredentials/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the jobs property of the microsoft.graph.synchronization entity.
 */
class SynchronizationJobItemRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to call the pause method.
     */
    get pause() {
        return new pause_1.PauseRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the provisionOnDemand method.
     */
    get provisionOnDemand() {
        return new provisionOnDemand_1.ProvisionOnDemandRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the restart method.
     */
    get restart() {
        return new restart_1.RestartRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the schema property of the microsoft.graph.synchronizationJob entity.
     */
    get schema() {
        return new schema_1.SchemaRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the start method.
     */
    get start() {
        return new start_1.StartRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the validateCredentials method.
     */
    get validateCredentials() {
        return new validateCredentials_1.ValidateCredentialsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new SynchronizationJobItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/applications/{application%2Did}/synchronization/jobs/{synchronizationJob%2Did}{?%24select,%24expand}");
    }
    ;
    /**
     * Stop the synchronization job, and permanently delete all the state associated with it. Synchronized accounts are left as-is.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/synchronization-synchronizationjob-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration) {
        const requestInfo = this.toDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Retrieve the existing synchronization job and its properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SynchronizationJob
     * @see {@link https://learn.microsoft.com/graph/api/synchronization-synchronizationjob-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, synchronizationJob_1.createSynchronizationJobFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Update the navigation property jobs in applications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SynchronizationJob
     */
    patch(body, requestConfiguration) {
        const requestInfo = this.toPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, synchronizationJob_1.createSynchronizationJobFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Stop the synchronization job, and permanently delete all the state associated with it. Synchronized accounts are left as-is.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.DELETE, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Retrieve the existing synchronization job and its properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, synchronizationJobItemRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property jobs in applications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.PATCH, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, synchronizationJob_1.serializeSynchronizationJob);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a SynchronizationJobItemRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new SynchronizationJobItemRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.SynchronizationJobItemRequestBuilder = SynchronizationJobItemRequestBuilder;
const synchronizationJobItemRequestBuilderGetQueryParametersMapper = {
    "expand": "%24expand",
    "select": "%24select",
};
// tslint:enable
// eslint-enable
