import { type DirectoryDefinitionCollectionResponse } from '../../../../../../../models/';
import { type DirectoryDefinition } from '../../../../../../../models/directoryDefinition';
import { CountRequestBuilder } from './count/';
import { DirectoryDefinitionItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DirectoriesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the directories property of the microsoft.graph.synchronizationSchema entity.
 */
export declare class DirectoriesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the directories property of the microsoft.graph.synchronizationSchema entity.
     * @param directoryDefinitionId The unique identifier of directoryDefinition
     * @returns a DirectoryDefinitionItemRequestBuilder
     */
    byDirectoryDefinitionId(directoryDefinitionId: string): DirectoryDefinitionItemRequestBuilder;
    /**
     * Instantiates a new DirectoriesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Contains the collection of directories and all of their objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DirectoryDefinitionCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<DirectoriesRequestBuilderGetQueryParameters> | undefined): Promise<DirectoryDefinitionCollectionResponse | undefined>;
    /**
     * Create new navigation property to directories for applications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DirectoryDefinition
     */
    post(body: DirectoryDefinition, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DirectoryDefinition | undefined>;
    /**
     * Contains the collection of directories and all of their objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DirectoriesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to directories for applications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DirectoryDefinition, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a directoriesRequestBuilder
     */
    withUrl(rawUrl: string): DirectoriesRequestBuilder;
}
