import { type TokenIssuancePolicyCollectionResponse } from '../../../models/';
import { CountRequestBuilder } from './count/';
import { TokenIssuancePolicyItemRequestBuilder } from './item/';
import { RefRequestBuilder } from './ref/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface TokenIssuancePoliciesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the tokenIssuancePolicies property of the microsoft.graph.application entity.
 */
export declare class TokenIssuancePoliciesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the collection of application entities.
     */
    get ref(): RefRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.tokenIssuancePolicies.item collection
     * @param tokenIssuancePolicyId Unique identifier of the item
     * @returns a TokenIssuancePolicyItemRequestBuilder
     */
    byTokenIssuancePolicyId(tokenIssuancePolicyId: string): TokenIssuancePolicyItemRequestBuilder;
    /**
     * Instantiates a new TokenIssuancePoliciesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List the tokenIssuancePolicy objects that are assigned to an application.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TokenIssuancePolicyCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/application-list-tokenissuancepolicies?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<TokenIssuancePoliciesRequestBuilderGetQueryParameters> | undefined): Promise<TokenIssuancePolicyCollectionResponse | undefined>;
    /**
     * List the tokenIssuancePolicy objects that are assigned to an application.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<TokenIssuancePoliciesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a tokenIssuancePoliciesRequestBuilder
     */
    withUrl(rawUrl: string): TokenIssuancePoliciesRequestBuilder;
}
