import { type ProvisioningObjectSummaryCollectionResponse } from '../../models/';
import { type ProvisioningObjectSummary } from '../../models/provisioningObjectSummary';
import { CountRequestBuilder } from './count/';
import { ProvisioningObjectSummaryItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ProvisioningRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the provisioning property of the microsoft.graph.auditLogRoot entity.
 */
export declare class ProvisioningRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the provisioning property of the microsoft.graph.auditLogRoot entity.
     * @param provisioningObjectSummaryId The unique identifier of provisioningObjectSummary
     * @returns a ProvisioningObjectSummaryItemRequestBuilder
     */
    byProvisioningObjectSummaryId(provisioningObjectSummaryId: string): ProvisioningObjectSummaryItemRequestBuilder;
    /**
     * Instantiates a new ProvisioningRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get all provisioning events that occurred in your tenant, such as the deletion of a group in a target application or the creation of a user when provisioning user accounts from your HR system.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ProvisioningObjectSummaryCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/provisioningobjectsummary-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ProvisioningRequestBuilderGetQueryParameters> | undefined): Promise<ProvisioningObjectSummaryCollectionResponse | undefined>;
    /**
     * Create new navigation property to provisioning for auditLogs
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ProvisioningObjectSummary
     */
    post(body: ProvisioningObjectSummary, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ProvisioningObjectSummary | undefined>;
    /**
     * Get all provisioning events that occurred in your tenant, such as the deletion of a group in a target application or the creation of a user when provisioning user accounts from your HR system.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ProvisioningRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to provisioning for auditLogs
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ProvisioningObjectSummary, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a provisioningRequestBuilder
     */
    withUrl(rawUrl: string): ProvisioningRequestBuilder;
}
