import { type CertificateBasedAuthConfigurationCollectionResponse } from '../models/';
import { type CertificateBasedAuthConfiguration } from '../models/certificateBasedAuthConfiguration';
import { CountRequestBuilder } from './count/';
import { CertificateBasedAuthConfigurationItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface CertificateBasedAuthConfigurationRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the collection of certificateBasedAuthConfiguration entities.
 */
export declare class CertificateBasedAuthConfigurationRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the collection of certificateBasedAuthConfiguration entities.
     * @param certificateBasedAuthConfigurationId The unique identifier of certificateBasedAuthConfiguration
     * @returns a CertificateBasedAuthConfigurationItemRequestBuilder
     */
    byCertificateBasedAuthConfigurationId(certificateBasedAuthConfigurationId: string): CertificateBasedAuthConfigurationItemRequestBuilder;
    /**
     * Instantiates a new CertificateBasedAuthConfigurationRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get entities from certificateBasedAuthConfiguration
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of CertificateBasedAuthConfigurationCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<CertificateBasedAuthConfigurationRequestBuilderGetQueryParameters> | undefined): Promise<CertificateBasedAuthConfigurationCollectionResponse | undefined>;
    /**
     * Add new entity to certificateBasedAuthConfiguration
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of CertificateBasedAuthConfiguration
     */
    post(body: CertificateBasedAuthConfiguration, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<CertificateBasedAuthConfiguration | undefined>;
    /**
     * Get entities from certificateBasedAuthConfiguration
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<CertificateBasedAuthConfigurationRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Add new entity to certificateBasedAuthConfiguration
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: CertificateBasedAuthConfiguration, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a certificateBasedAuthConfigurationRequestBuilder
     */
    withUrl(rawUrl: string): CertificateBasedAuthConfigurationRequestBuilder;
}
