import { type ChatCollectionResponse } from '../models/';
import { type Chat } from '../models/chat';
import { CountRequestBuilder } from './count/';
import { GetAllMessagesRequestBuilder } from './getAllMessages/';
import { ChatItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ChatsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the collection of chat entities.
 */
export declare class ChatsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to call the getAllMessages method.
     */
    get getAllMessages(): GetAllMessagesRequestBuilder;
    /**
     * Provides operations to manage the collection of chat entities.
     * @param chatId The unique identifier of chat
     * @returns a ChatItemRequestBuilder
     */
    byChatId(chatId: string): ChatItemRequestBuilder;
    /**
     * Instantiates a new ChatsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the list of chats that the user is part of. This method supports federation. When a user ID is provided, the calling application must belong to the same tenant that the user belongs to.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ChatCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/chat-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ChatsRequestBuilderGetQueryParameters> | undefined): Promise<ChatCollectionResponse | undefined>;
    /**
     * Create a new chat object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Chat
     * @see {@link https://learn.microsoft.com/graph/api/chat-post?view=graph-rest-1.0|Find more info here}
     */
    post(body: Chat, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Chat | undefined>;
    /**
     * Retrieve the list of chats that the user is part of. This method supports federation. When a user ID is provided, the calling application must belong to the same tenant that the user belongs to.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ChatsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new chat object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: Chat, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a chatsRequestBuilder
     */
    withUrl(rawUrl: string): ChatsRequestBuilder;
}
