import { type ItemBody } from '../../../models/itemBody';
import { type KeyValuePair } from '../../../models/keyValuePair';
import { type TeamworkActivityTopic } from '../../../models/teamworkActivityTopic';
import { type TeamworkNotificationRecipient } from '../../../models/teamworkNotificationRecipient';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createSendActivityNotificationPostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoSendActivityNotificationPostRequestBody;
export declare function deserializeIntoSendActivityNotificationPostRequestBody(sendActivityNotificationPostRequestBody?: SendActivityNotificationPostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export interface SendActivityNotificationPostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * The activityType property
     */
    activityType?: string;
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The chainId property
     */
    chainId?: number;
    /**
     * The previewText property
     */
    previewText?: ItemBody;
    /**
     * The recipient property
     */
    recipient?: TeamworkNotificationRecipient;
    /**
     * The templateParameters property
     */
    templateParameters?: KeyValuePair[];
    /**
     * The topic property
     */
    topic?: TeamworkActivityTopic;
}
export declare function serializeSendActivityNotificationPostRequestBody(writer: SerializationWriter, sendActivityNotificationPostRequestBody?: SendActivityNotificationPostRequestBody | undefined): void;
/**
 * Provides operations to call the sendActivityNotification method.
 */
export declare class SendActivityNotificationRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new SendActivityNotificationRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Send an activity feed notification in scope of a chat. For more details about sending notifications and the requirements for doing so, see sending Teams activity notifications.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/chat-sendactivitynotification?view=graph-rest-1.0|Find more info here}
     */
    post(body: SendActivityNotificationPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Send an activity feed notification in scope of a chat. For more details about sending notifications and the requirements for doing so, see sending Teams activity notifications.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: SendActivityNotificationPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a sendActivityNotificationRequestBuilder
     */
    withUrl(rawUrl: string): SendActivityNotificationRequestBuilder;
}
