import { type TeamsTabCollectionResponse } from '../../../models/';
import { type TeamsTab } from '../../../models/teamsTab';
import { CountRequestBuilder } from './count/';
import { TeamsTabItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface TabsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the tabs property of the microsoft.graph.chat entity.
 */
export declare class TabsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the tabs property of the microsoft.graph.chat entity.
     * @param teamsTabId The unique identifier of teamsTab
     * @returns a TeamsTabItemRequestBuilder
     */
    byTeamsTabId(teamsTabId: string): TeamsTabItemRequestBuilder;
    /**
     * Instantiates a new TabsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the list of tabs in the specified chat.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TeamsTabCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/chat-list-tabs?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<TabsRequestBuilderGetQueryParameters> | undefined): Promise<TeamsTabCollectionResponse | undefined>;
    /**
     * Add (pin) a tab to the specified chat. The corresponding app must already be installed in the chat.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TeamsTab
     * @see {@link https://learn.microsoft.com/graph/api/chat-post-tabs?view=graph-rest-1.0|Find more info here}
     */
    post(body: TeamsTab, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<TeamsTab | undefined>;
    /**
     * Retrieve the list of tabs in the specified chat.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<TabsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Add (pin) a tab to the specified chat. The corresponding app must already be installed in the chat.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: TeamsTab, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a tabsRequestBuilder
     */
    withUrl(rawUrl: string): TabsRequestBuilder;
}
