import { type IncomingCallOptions } from '../../../../models/incomingCallOptions';
import { type MediaConfig } from '../../../../models/mediaConfig';
import { Modality } from '../../../../models/modality';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export interface AnswerPostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * The acceptedModalities property
     */
    acceptedModalities?: Modality[];
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The callbackUri property
     */
    callbackUri?: string;
    /**
     * The callOptions property
     */
    callOptions?: IncomingCallOptions;
    /**
     * The mediaConfig property
     */
    mediaConfig?: MediaConfig;
    /**
     * The participantCapacity property
     */
    participantCapacity?: number;
}
export declare function createAnswerPostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoAnswerPostRequestBody;
export declare function deserializeIntoAnswerPostRequestBody(answerPostRequestBody?: AnswerPostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeAnswerPostRequestBody(writer: SerializationWriter, answerPostRequestBody?: AnswerPostRequestBody | undefined): void;
/**
 * Provides operations to call the answer method.
 */
export declare class AnswerRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new AnswerRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Enable a bot to answer an incoming call. The incoming call request can be an invite from a participant in a group call or a peer-to-peer call. If an invite to a group call is received, the notification will contain the chatInfo and meetingInfo parameters. The bot is expected to answer, reject, or redirect the call before the call times out. The current timeout value is 15 seconds for regular scenarios, and 5 seconds for policy-based recording scenarios.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/call-answer?view=graph-rest-1.0|Find more info here}
     */
    post(body: AnswerPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Enable a bot to answer an incoming call. The incoming call request can be an invite from a participant in a group call or a peer-to-peer call. If an invite to a group call is received, the notification will contain the chatInfo and meetingInfo parameters. The bot is expected to answer, reject, or redirect the call before the call times out. The current timeout value is 15 seconds for regular scenarios, and 5 seconds for policy-based recording scenarios.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AnswerPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a answerRequestBuilder
     */
    withUrl(rawUrl: string): AnswerRequestBuilder;
}
