import { type AudioRoutingGroupCollectionResponse } from '../../../../models/';
import { type AudioRoutingGroup } from '../../../../models/audioRoutingGroup';
import { CountRequestBuilder } from './count/';
import { AudioRoutingGroupItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AudioRoutingGroupsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the audioRoutingGroups property of the microsoft.graph.call entity.
 */
export declare class AudioRoutingGroupsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the audioRoutingGroups property of the microsoft.graph.call entity.
     * @param audioRoutingGroupId The unique identifier of audioRoutingGroup
     * @returns a AudioRoutingGroupItemRequestBuilder
     */
    byAudioRoutingGroupId(audioRoutingGroupId: string): AudioRoutingGroupItemRequestBuilder;
    /**
     * Instantiates a new AudioRoutingGroupsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of audioRoutingGroup objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AudioRoutingGroupCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/call-list-audioroutinggroups?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<AudioRoutingGroupsRequestBuilderGetQueryParameters> | undefined): Promise<AudioRoutingGroupCollectionResponse | undefined>;
    /**
     * Create a new audioRoutingGroup.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AudioRoutingGroup
     * @see {@link https://learn.microsoft.com/graph/api/call-post-audioroutinggroups?view=graph-rest-1.0|Find more info here}
     */
    post(body: AudioRoutingGroup, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AudioRoutingGroup | undefined>;
    /**
     * Retrieve a list of audioRoutingGroup objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AudioRoutingGroupsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new audioRoutingGroup.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AudioRoutingGroup, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a audioRoutingGroupsRequestBuilder
     */
    withUrl(rawUrl: string): AudioRoutingGroupsRequestBuilder;
}
