import { type Call } from '../../../models/call';
import { AddLargeGalleryViewRequestBuilder } from './addLargeGalleryView/';
import { AnswerRequestBuilder } from './answer/';
import { AudioRoutingGroupsRequestBuilder } from './audioRoutingGroups/';
import { CancelMediaProcessingRequestBuilder } from './cancelMediaProcessing/';
import { ChangeScreenSharingRoleRequestBuilder } from './changeScreenSharingRole/';
import { ContentSharingSessionsRequestBuilder } from './contentSharingSessions/';
import { KeepAliveRequestBuilder } from './keepAlive/';
import { MuteRequestBuilder } from './mute/';
import { OperationsRequestBuilder } from './operations/';
import { ParticipantsRequestBuilder } from './participants/';
import { PlayPromptRequestBuilder } from './playPrompt/';
import { RecordResponseRequestBuilder } from './recordResponse/';
import { RedirectRequestBuilder } from './redirect/';
import { RejectRequestBuilder } from './reject/';
import { SubscribeToToneRequestBuilder } from './subscribeToTone/';
import { TransferRequestBuilder } from './transfer/';
import { UnmuteRequestBuilder } from './unmute/';
import { UpdateRecordingStatusRequestBuilder } from './updateRecordingStatus/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface CallItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the calls property of the microsoft.graph.cloudCommunications entity.
 */
export declare class CallItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the addLargeGalleryView method.
     */
    get addLargeGalleryView(): AddLargeGalleryViewRequestBuilder;
    /**
     * Provides operations to call the answer method.
     */
    get answer(): AnswerRequestBuilder;
    /**
     * Provides operations to manage the audioRoutingGroups property of the microsoft.graph.call entity.
     */
    get audioRoutingGroups(): AudioRoutingGroupsRequestBuilder;
    /**
     * Provides operations to call the cancelMediaProcessing method.
     */
    get cancelMediaProcessing(): CancelMediaProcessingRequestBuilder;
    /**
     * Provides operations to call the changeScreenSharingRole method.
     */
    get changeScreenSharingRole(): ChangeScreenSharingRoleRequestBuilder;
    /**
     * Provides operations to manage the contentSharingSessions property of the microsoft.graph.call entity.
     */
    get contentSharingSessions(): ContentSharingSessionsRequestBuilder;
    /**
     * Provides operations to call the keepAlive method.
     */
    get keepAlive(): KeepAliveRequestBuilder;
    /**
     * Provides operations to call the mute method.
     */
    get mute(): MuteRequestBuilder;
    /**
     * Provides operations to manage the operations property of the microsoft.graph.call entity.
     */
    get operations(): OperationsRequestBuilder;
    /**
     * Provides operations to manage the participants property of the microsoft.graph.call entity.
     */
    get participants(): ParticipantsRequestBuilder;
    /**
     * Provides operations to call the playPrompt method.
     */
    get playPrompt(): PlayPromptRequestBuilder;
    /**
     * Provides operations to call the recordResponse method.
     */
    get recordResponse(): RecordResponseRequestBuilder;
    /**
     * Provides operations to call the redirect method.
     */
    get redirect(): RedirectRequestBuilder;
    /**
     * Provides operations to call the reject method.
     */
    get reject(): RejectRequestBuilder;
    /**
     * Provides operations to call the subscribeToTone method.
     */
    get subscribeToTone(): SubscribeToToneRequestBuilder;
    /**
     * Provides operations to call the transfer method.
     */
    get transfer(): TransferRequestBuilder;
    /**
     * Provides operations to call the unmute method.
     */
    get unmute(): UnmuteRequestBuilder;
    /**
     * Provides operations to call the updateRecordingStatus method.
     */
    get updateRecordingStatus(): UpdateRecordingStatusRequestBuilder;
    /**
     * Instantiates a new CallItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete or hang up an active call. For group calls, this will only delete your call leg and the underlying group call will still continue.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/call-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of a call object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Call
     * @see {@link https://learn.microsoft.com/graph/api/call-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<CallItemRequestBuilderGetQueryParameters> | undefined): Promise<Call | undefined>;
    /**
     * Update the navigation property calls in communications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Call
     */
    patch(body: Call, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Call | undefined>;
    /**
     * Delete or hang up an active call. For group calls, this will only delete your call leg and the underlying group call will still continue.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of a call object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<CallItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property calls in communications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Call, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a CallItemRequestBuilder
     */
    withUrl(rawUrl: string): CallItemRequestBuilder;
}
