import { type MuteParticipantOperation } from '../../../../../../models/muteParticipantOperation';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createMutePostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoMutePostRequestBody;
export declare function deserializeIntoMutePostRequestBody(mutePostRequestBody?: MutePostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export interface MutePostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The clientContext property
     */
    clientContext?: string;
}
export declare function serializeMutePostRequestBody(writer: SerializationWriter, mutePostRequestBody?: MutePostRequestBody | undefined): void;
/**
 * Provides operations to call the mute method.
 */
export declare class MuteRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new MuteRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Mute a specific participant in the call. This is a server mute, meaning that the server will drop all audio packets for this participant, even if the participant continues to stream audio. For more information about how to handle mute operations, see muteParticipantOperation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MuteParticipantOperation
     * @see {@link https://learn.microsoft.com/graph/api/participant-mute?view=graph-rest-1.0|Find more info here}
     */
    post(body: MutePostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<MuteParticipantOperation | undefined>;
    /**
     * Mute a specific participant in the call. This is a server mute, meaning that the server will drop all audio packets for this participant, even if the participant continues to stream audio. For more information about how to handle mute operations, see muteParticipantOperation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: MutePostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a muteRequestBuilder
     */
    withUrl(rawUrl: string): MuteRequestBuilder;
}
