"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StartHoldMusicRequestBuilder = exports.serializeStartHoldMusicPostRequestBody = exports.deserializeIntoStartHoldMusicPostRequestBody = exports.createStartHoldMusicPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../../../models/oDataErrors/oDataError");
const prompt_1 = require("../../../../../../models/prompt");
const startHoldMusicOperation_1 = require("../../../../../../models/startHoldMusicOperation");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createStartHoldMusicPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoStartHoldMusicPostRequestBody;
}
exports.createStartHoldMusicPostRequestBodyFromDiscriminatorValue = createStartHoldMusicPostRequestBodyFromDiscriminatorValue;
function deserializeIntoStartHoldMusicPostRequestBody(startHoldMusicPostRequestBody = {}) {
    return {
        "clientContext": n => { startHoldMusicPostRequestBody.clientContext = n.getStringValue(); },
        "customPrompt": n => { startHoldMusicPostRequestBody.customPrompt = n.getObjectValue(prompt_1.createPromptFromDiscriminatorValue); },
    };
}
exports.deserializeIntoStartHoldMusicPostRequestBody = deserializeIntoStartHoldMusicPostRequestBody;
function serializeStartHoldMusicPostRequestBody(writer, startHoldMusicPostRequestBody = {}) {
    writer.writeStringValue("clientContext", startHoldMusicPostRequestBody.clientContext);
    writer.writeObjectValue("customPrompt", startHoldMusicPostRequestBody.customPrompt, prompt_1.serializePrompt);
    writer.writeAdditionalData(startHoldMusicPostRequestBody.additionalData);
}
exports.serializeStartHoldMusicPostRequestBody = serializeStartHoldMusicPostRequestBody;
/**
 * Provides operations to call the startHoldMusic method.
 */
class StartHoldMusicRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new StartHoldMusicRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/communications/calls/{call%2Did}/participants/{participant%2Did}/startHoldMusic");
    }
    ;
    /**
     * Put a participant on hold and play music in the background.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of StartHoldMusicOperation
     * @see {@link https://learn.microsoft.com/graph/api/participant-startholdmusic?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, startHoldMusicOperation_1.createStartHoldMusicOperationFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Put a participant on hold and play music in the background.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeStartHoldMusicPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a startHoldMusicRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new StartHoldMusicRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.StartHoldMusicRequestBuilder = StartHoldMusicRequestBuilder;
// tslint:enable
// eslint-enable
