"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayPromptRequestBuilder = exports.serializePlayPromptPostRequestBody = exports.deserializeIntoPlayPromptPostRequestBody = exports.createPlayPromptPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const playPromptOperation_1 = require("../../../../models/playPromptOperation");
const prompt_1 = require("../../../../models/prompt");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createPlayPromptPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoPlayPromptPostRequestBody;
}
exports.createPlayPromptPostRequestBodyFromDiscriminatorValue = createPlayPromptPostRequestBodyFromDiscriminatorValue;
function deserializeIntoPlayPromptPostRequestBody(playPromptPostRequestBody = {}) {
    return {
        "clientContext": n => { playPromptPostRequestBody.clientContext = n.getStringValue(); },
        "prompts": n => { playPromptPostRequestBody.prompts = n.getCollectionOfObjectValues(prompt_1.createPromptFromDiscriminatorValue); },
    };
}
exports.deserializeIntoPlayPromptPostRequestBody = deserializeIntoPlayPromptPostRequestBody;
function serializePlayPromptPostRequestBody(writer, playPromptPostRequestBody = {}) {
    writer.writeStringValue("clientContext", playPromptPostRequestBody.clientContext);
    writer.writeCollectionOfObjectValues("prompts", playPromptPostRequestBody.prompts, prompt_1.serializePrompt);
    writer.writeAdditionalData(playPromptPostRequestBody.additionalData);
}
exports.serializePlayPromptPostRequestBody = serializePlayPromptPostRequestBody;
/**
 * Provides operations to call the playPrompt method.
 */
class PlayPromptRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new PlayPromptRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/communications/calls/{call%2Did}/playPrompt");
    }
    ;
    /**
     * Play a prompt in the call. For more information about how to handle operations, see commsOperation
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PlayPromptOperation
     * @see {@link https://learn.microsoft.com/graph/api/call-playprompt?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, playPromptOperation_1.createPlayPromptOperationFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Play a prompt in the call. For more information about how to handle operations, see commsOperation
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializePlayPromptPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a playPromptRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new PlayPromptRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.PlayPromptRequestBuilder = PlayPromptRequestBuilder;
// tslint:enable
// eslint-enable
