import { type Prompt } from '../../../../models/prompt';
import { type RecordOperation } from '../../../../models/recordOperation';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createRecordResponsePostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoRecordResponsePostRequestBody;
export declare function deserializeIntoRecordResponsePostRequestBody(recordResponsePostRequestBody?: RecordResponsePostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export interface RecordResponsePostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The bargeInAllowed property
     */
    bargeInAllowed?: boolean;
    /**
     * The clientContext property
     */
    clientContext?: string;
    /**
     * The initialSilenceTimeoutInSeconds property
     */
    initialSilenceTimeoutInSeconds?: number;
    /**
     * The maxRecordDurationInSeconds property
     */
    maxRecordDurationInSeconds?: number;
    /**
     * The maxSilenceTimeoutInSeconds property
     */
    maxSilenceTimeoutInSeconds?: number;
    /**
     * The playBeep property
     */
    playBeep?: boolean;
    /**
     * The prompts property
     */
    prompts?: Prompt[];
    /**
     * The stopTones property
     */
    stopTones?: string[];
}
export declare function serializeRecordResponsePostRequestBody(writer: SerializationWriter, recordResponsePostRequestBody?: RecordResponsePostRequestBody | undefined): void;
/**
 * Provides operations to call the recordResponse method.
 */
export declare class RecordResponseRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new RecordResponseRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Records a short audio response from the caller.A bot can utilize this to capture a voice response from a caller after they are prompted for a response. For further information on how to handle operations, please review commsOperation This action is not intended to record the entire call. The maximum length of recording is 2 minutes. The recording is not saved permanently by the Cloud Communications Platform and is discarded shortly after the call ends. The bot must download the recording promptly after the recording operation finishes by using the recordingLocation value that's given in the completed notification.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RecordOperation
     * @see {@link https://learn.microsoft.com/graph/api/call-record?view=graph-rest-1.0|Find more info here}
     */
    post(body: RecordResponsePostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<RecordOperation | undefined>;
    /**
     * Records a short audio response from the caller.A bot can utilize this to capture a voice response from a caller after they are prompted for a response. For further information on how to handle operations, please review commsOperation This action is not intended to record the entire call. The maximum length of recording is 2 minutes. The recording is not saved permanently by the Cloud Communications Platform and is discarded shortly after the call ends. The bot must download the recording promptly after the recording operation finishes by using the recordingLocation value that's given in the completed notification.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: RecordResponsePostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a recordResponseRequestBuilder
     */
    withUrl(rawUrl: string): RecordResponseRequestBuilder;
}
