"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RecordResponseRequestBuilder = exports.serializeRecordResponsePostRequestBody = exports.deserializeIntoRecordResponsePostRequestBody = exports.createRecordResponsePostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const prompt_1 = require("../../../../models/prompt");
const recordOperation_1 = require("../../../../models/recordOperation");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createRecordResponsePostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoRecordResponsePostRequestBody;
}
exports.createRecordResponsePostRequestBodyFromDiscriminatorValue = createRecordResponsePostRequestBodyFromDiscriminatorValue;
function deserializeIntoRecordResponsePostRequestBody(recordResponsePostRequestBody = {}) {
    return {
        "bargeInAllowed": n => { recordResponsePostRequestBody.bargeInAllowed = n.getBooleanValue(); },
        "clientContext": n => { recordResponsePostRequestBody.clientContext = n.getStringValue(); },
        "initialSilenceTimeoutInSeconds": n => { recordResponsePostRequestBody.initialSilenceTimeoutInSeconds = n.getNumberValue(); },
        "maxRecordDurationInSeconds": n => { recordResponsePostRequestBody.maxRecordDurationInSeconds = n.getNumberValue(); },
        "maxSilenceTimeoutInSeconds": n => { recordResponsePostRequestBody.maxSilenceTimeoutInSeconds = n.getNumberValue(); },
        "playBeep": n => { recordResponsePostRequestBody.playBeep = n.getBooleanValue(); },
        "prompts": n => { recordResponsePostRequestBody.prompts = n.getCollectionOfObjectValues(prompt_1.createPromptFromDiscriminatorValue); },
        "stopTones": n => { recordResponsePostRequestBody.stopTones = n.getCollectionOfPrimitiveValues(); },
    };
}
exports.deserializeIntoRecordResponsePostRequestBody = deserializeIntoRecordResponsePostRequestBody;
function serializeRecordResponsePostRequestBody(writer, recordResponsePostRequestBody = {}) {
    writer.writeBooleanValue("bargeInAllowed", recordResponsePostRequestBody.bargeInAllowed);
    writer.writeStringValue("clientContext", recordResponsePostRequestBody.clientContext);
    writer.writeNumberValue("initialSilenceTimeoutInSeconds", recordResponsePostRequestBody.initialSilenceTimeoutInSeconds);
    writer.writeNumberValue("maxRecordDurationInSeconds", recordResponsePostRequestBody.maxRecordDurationInSeconds);
    writer.writeNumberValue("maxSilenceTimeoutInSeconds", recordResponsePostRequestBody.maxSilenceTimeoutInSeconds);
    writer.writeBooleanValue("playBeep", recordResponsePostRequestBody.playBeep);
    writer.writeCollectionOfObjectValues("prompts", recordResponsePostRequestBody.prompts, prompt_1.serializePrompt);
    writer.writeCollectionOfPrimitiveValues("stopTones", recordResponsePostRequestBody.stopTones);
    writer.writeAdditionalData(recordResponsePostRequestBody.additionalData);
}
exports.serializeRecordResponsePostRequestBody = serializeRecordResponsePostRequestBody;
/**
 * Provides operations to call the recordResponse method.
 */
class RecordResponseRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new RecordResponseRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/communications/calls/{call%2Did}/recordResponse");
    }
    ;
    /**
     * Records a short audio response from the caller.A bot can utilize this to capture a voice response from a caller after they are prompted for a response. For further information on how to handle operations, please review commsOperation This action is not intended to record the entire call. The maximum length of recording is 2 minutes. The recording is not saved permanently by the Cloud Communications Platform and is discarded shortly after the call ends. The bot must download the recording promptly after the recording operation finishes by using the recordingLocation value that's given in the completed notification.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RecordOperation
     * @see {@link https://learn.microsoft.com/graph/api/call-record?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, recordOperation_1.createRecordOperationFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Records a short audio response from the caller.A bot can utilize this to capture a voice response from a caller after they are prompted for a response. For further information on how to handle operations, please review commsOperation This action is not intended to record the entire call. The maximum length of recording is 2 minutes. The recording is not saved permanently by the Cloud Communications Platform and is discarded shortly after the call ends. The bot must download the recording promptly after the recording operation finishes by using the recordingLocation value that's given in the completed notification.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeRecordResponsePostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a recordResponseRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new RecordResponseRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.RecordResponseRequestBuilder = RecordResponseRequestBuilder;
// tslint:enable
// eslint-enable
