"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RejectRequestBuilder = exports.serializeRejectPostRequestBody = exports.deserializeIntoRejectPostRequestBody = exports.createRejectPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const rejectReason_1 = require("../../../../models/rejectReason");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createRejectPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoRejectPostRequestBody;
}
exports.createRejectPostRequestBodyFromDiscriminatorValue = createRejectPostRequestBodyFromDiscriminatorValue;
function deserializeIntoRejectPostRequestBody(rejectPostRequestBody = {}) {
    return {
        "callbackUri": n => { rejectPostRequestBody.callbackUri = n.getStringValue(); },
        "reason": n => { rejectPostRequestBody.reason = n.getEnumValue(rejectReason_1.RejectReason); },
    };
}
exports.deserializeIntoRejectPostRequestBody = deserializeIntoRejectPostRequestBody;
function serializeRejectPostRequestBody(writer, rejectPostRequestBody = {}) {
    writer.writeStringValue("callbackUri", rejectPostRequestBody.callbackUri);
    writer.writeEnumValue("reason", rejectPostRequestBody.reason);
    writer.writeAdditionalData(rejectPostRequestBody.additionalData);
}
exports.serializeRejectPostRequestBody = serializeRejectPostRequestBody;
/**
 * Provides operations to call the reject method.
 */
class RejectRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new RejectRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/communications/calls/{call%2Did}/reject");
    }
    ;
    /**
     * Enable a bot to reject an incoming call. The incoming call request can be an invite from a participant in a group call or a peer-to-peer call. If an invite to a group call is received, the notification will contain the chatInfo and meetingInfo parameters. The bot is expected to answer or reject the call before the call times out. The current timeout value is 15 seconds. This API does not end existing calls that have already been answered. Use delete call to end a call.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/call-reject?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Enable a bot to reject an incoming call. The incoming call request can be an invite from a participant in a group call or a peer-to-peer call. If an invite to a group call is received, the notification will contain the chatInfo and meetingInfo parameters. The bot is expected to answer or reject the call before the call times out. The current timeout value is 15 seconds. This API does not end existing calls that have already been answered. Use delete call to end a call.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeRejectPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a rejectRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new RejectRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.RejectRequestBuilder = RejectRequestBuilder;
// tslint:enable
// eslint-enable
