import { type InvitationParticipantInfo } from '../../../../models/invitationParticipantInfo';
import { type ParticipantInfo } from '../../../../models/participantInfo';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createTransferPostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoTransferPostRequestBody;
export declare function deserializeIntoTransferPostRequestBody(transferPostRequestBody?: TransferPostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeTransferPostRequestBody(writer: SerializationWriter, transferPostRequestBody?: TransferPostRequestBody | undefined): void;
export interface TransferPostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The transferee property
     */
    transferee?: ParticipantInfo;
    /**
     * The transferTarget property
     */
    transferTarget?: InvitationParticipantInfo;
}
/**
 * Provides operations to call the transfer method.
 */
export declare class TransferRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new TransferRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Transfer an active peer-to-peer call or group call. A consultative transfer means that the transferor can inform the person they want to transfer the call to (the transferee), before the transfer is made. This is opposed to transfering the call directly.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/call-transfer?view=graph-rest-1.0|Find more info here}
     */
    post(body: TransferPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Transfer an active peer-to-peer call or group call. A consultative transfer means that the transferor can inform the person they want to transfer the call to (the transferee), before the transfer is made. This is opposed to transfering the call directly.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: TransferPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a transferRequestBuilder
     */
    withUrl(rawUrl: string): TransferRequestBuilder;
}
