import { type UnmuteParticipantOperation } from '../../../../models/unmuteParticipantOperation';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createUnmutePostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoUnmutePostRequestBody;
export declare function deserializeIntoUnmutePostRequestBody(unmutePostRequestBody?: UnmutePostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeUnmutePostRequestBody(writer: SerializationWriter, unmutePostRequestBody?: UnmutePostRequestBody | undefined): void;
export interface UnmutePostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The clientContext property
     */
    clientContext?: string;
}
/**
 * Provides operations to call the unmute method.
 */
export declare class UnmuteRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new UnmuteRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Allow the application to unmute itself. This is a server unmute, meaning that the server will start sending audio packets for this participant to other participants again. For more information about how to handle unmute operations, see unmuteParticipantOperation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UnmuteParticipantOperation
     * @see {@link https://learn.microsoft.com/graph/api/call-unmute?view=graph-rest-1.0|Find more info here}
     */
    post(body: UnmutePostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<UnmuteParticipantOperation | undefined>;
    /**
     * Allow the application to unmute itself. This is a server unmute, meaning that the server will start sending audio packets for this participant to other participants again. For more information about how to handle unmute operations, see unmuteParticipantOperation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: UnmutePostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a unmuteRequestBuilder
     */
    withUrl(rawUrl: string): UnmuteRequestBuilder;
}
