"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnmuteRequestBuilder = exports.serializeUnmutePostRequestBody = exports.deserializeIntoUnmutePostRequestBody = exports.createUnmutePostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const unmuteParticipantOperation_1 = require("../../../../models/unmuteParticipantOperation");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createUnmutePostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoUnmutePostRequestBody;
}
exports.createUnmutePostRequestBodyFromDiscriminatorValue = createUnmutePostRequestBodyFromDiscriminatorValue;
function deserializeIntoUnmutePostRequestBody(unmutePostRequestBody = {}) {
    return {
        "clientContext": n => { unmutePostRequestBody.clientContext = n.getStringValue(); },
    };
}
exports.deserializeIntoUnmutePostRequestBody = deserializeIntoUnmutePostRequestBody;
function serializeUnmutePostRequestBody(writer, unmutePostRequestBody = {}) {
    writer.writeStringValue("clientContext", unmutePostRequestBody.clientContext);
    writer.writeAdditionalData(unmutePostRequestBody.additionalData);
}
exports.serializeUnmutePostRequestBody = serializeUnmutePostRequestBody;
/**
 * Provides operations to call the unmute method.
 */
class UnmuteRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new UnmuteRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/communications/calls/{call%2Did}/unmute");
    }
    ;
    /**
     * Allow the application to unmute itself. This is a server unmute, meaning that the server will start sending audio packets for this participant to other participants again. For more information about how to handle unmute operations, see unmuteParticipantOperation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UnmuteParticipantOperation
     * @see {@link https://learn.microsoft.com/graph/api/call-unmute?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, unmuteParticipantOperation_1.createUnmuteParticipantOperationFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Allow the application to unmute itself. This is a server unmute, meaning that the server will start sending audio packets for this participant to other participants again. For more information about how to handle unmute operations, see unmuteParticipantOperation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeUnmutePostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a unmuteRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new UnmuteRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.UnmuteRequestBuilder = UnmuteRequestBuilder;
// tslint:enable
// eslint-enable
