import { RecordingStatus } from '../../../../models/recordingStatus';
import { type UpdateRecordingStatusOperation } from '../../../../models/updateRecordingStatusOperation';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createUpdateRecordingStatusPostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoUpdateRecordingStatusPostRequestBody;
export declare function deserializeIntoUpdateRecordingStatusPostRequestBody(updateRecordingStatusPostRequestBody?: UpdateRecordingStatusPostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeUpdateRecordingStatusPostRequestBody(writer: SerializationWriter, updateRecordingStatusPostRequestBody?: UpdateRecordingStatusPostRequestBody | undefined): void;
export interface UpdateRecordingStatusPostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The clientContext property
     */
    clientContext?: string;
    /**
     * The status property
     */
    status?: RecordingStatus;
}
/**
 * Provides operations to call the updateRecordingStatus method.
 */
export declare class UpdateRecordingStatusRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new UpdateRecordingStatusRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Update the application's recording status associated with a call. This requires the use of the Teams policy-based recording solution.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UpdateRecordingStatusOperation
     * @see {@link https://learn.microsoft.com/graph/api/call-updaterecordingstatus?view=graph-rest-1.0|Find more info here}
     */
    post(body: UpdateRecordingStatusPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<UpdateRecordingStatusOperation | undefined>;
    /**
     * Update the application's recording status associated with a call. This requires the use of the Teams policy-based recording solution.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: UpdateRecordingStatusPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a updateRecordingStatusRequestBuilder
     */
    withUrl(rawUrl: string): UpdateRecordingStatusRequestBuilder;
}
