"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UpdateRecordingStatusRequestBuilder = exports.serializeUpdateRecordingStatusPostRequestBody = exports.deserializeIntoUpdateRecordingStatusPostRequestBody = exports.createUpdateRecordingStatusPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const recordingStatus_1 = require("../../../../models/recordingStatus");
const updateRecordingStatusOperation_1 = require("../../../../models/updateRecordingStatusOperation");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createUpdateRecordingStatusPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoUpdateRecordingStatusPostRequestBody;
}
exports.createUpdateRecordingStatusPostRequestBodyFromDiscriminatorValue = createUpdateRecordingStatusPostRequestBodyFromDiscriminatorValue;
function deserializeIntoUpdateRecordingStatusPostRequestBody(updateRecordingStatusPostRequestBody = {}) {
    return {
        "clientContext": n => { updateRecordingStatusPostRequestBody.clientContext = n.getStringValue(); },
        "status": n => { updateRecordingStatusPostRequestBody.status = n.getEnumValue(recordingStatus_1.RecordingStatus); },
    };
}
exports.deserializeIntoUpdateRecordingStatusPostRequestBody = deserializeIntoUpdateRecordingStatusPostRequestBody;
function serializeUpdateRecordingStatusPostRequestBody(writer, updateRecordingStatusPostRequestBody = {}) {
    writer.writeStringValue("clientContext", updateRecordingStatusPostRequestBody.clientContext);
    writer.writeEnumValue("status", updateRecordingStatusPostRequestBody.status);
    writer.writeAdditionalData(updateRecordingStatusPostRequestBody.additionalData);
}
exports.serializeUpdateRecordingStatusPostRequestBody = serializeUpdateRecordingStatusPostRequestBody;
/**
 * Provides operations to call the updateRecordingStatus method.
 */
class UpdateRecordingStatusRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new UpdateRecordingStatusRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/communications/calls/{call%2Did}/updateRecordingStatus");
    }
    ;
    /**
     * Update the application's recording status associated with a call. This requires the use of the Teams policy-based recording solution.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UpdateRecordingStatusOperation
     * @see {@link https://learn.microsoft.com/graph/api/call-updaterecordingstatus?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, updateRecordingStatusOperation_1.createUpdateRecordingStatusOperationFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Update the application's recording status associated with a call. This requires the use of the Teams policy-based recording solution.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeUpdateRecordingStatusPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a updateRecordingStatusRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new UpdateRecordingStatusRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.UpdateRecordingStatusRequestBuilder = UpdateRecordingStatusRequestBuilder;
// tslint:enable
// eslint-enable
