"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogTeleconferenceDeviceQualityRequestBuilder = exports.serializeLogTeleconferenceDeviceQualityPostRequestBody = exports.deserializeIntoLogTeleconferenceDeviceQualityPostRequestBody = exports.createLogTeleconferenceDeviceQualityPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const teleconferenceDeviceQuality_1 = require("../../../models/teleconferenceDeviceQuality");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createLogTeleconferenceDeviceQualityPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoLogTeleconferenceDeviceQualityPostRequestBody;
}
exports.createLogTeleconferenceDeviceQualityPostRequestBodyFromDiscriminatorValue = createLogTeleconferenceDeviceQualityPostRequestBodyFromDiscriminatorValue;
function deserializeIntoLogTeleconferenceDeviceQualityPostRequestBody(logTeleconferenceDeviceQualityPostRequestBody = {}) {
    return {
        "quality": n => { logTeleconferenceDeviceQualityPostRequestBody.quality = n.getObjectValue(teleconferenceDeviceQuality_1.createTeleconferenceDeviceQualityFromDiscriminatorValue); },
    };
}
exports.deserializeIntoLogTeleconferenceDeviceQualityPostRequestBody = deserializeIntoLogTeleconferenceDeviceQualityPostRequestBody;
function serializeLogTeleconferenceDeviceQualityPostRequestBody(writer, logTeleconferenceDeviceQualityPostRequestBody = {}) {
    writer.writeObjectValue("quality", logTeleconferenceDeviceQualityPostRequestBody.quality, teleconferenceDeviceQuality_1.serializeTeleconferenceDeviceQuality);
    writer.writeAdditionalData(logTeleconferenceDeviceQualityPostRequestBody.additionalData);
}
exports.serializeLogTeleconferenceDeviceQualityPostRequestBody = serializeLogTeleconferenceDeviceQualityPostRequestBody;
/**
 * Provides operations to call the logTeleconferenceDeviceQuality method.
 */
class LogTeleconferenceDeviceQualityRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new LogTeleconferenceDeviceQualityRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/communications/calls/logTeleconferenceDeviceQuality");
    }
    ;
    /**
     * Log video teleconferencing device quality data. The Cloud Video Interop (CVI) bot represents video teleconferencing (VTC) devices and acts as a back-to-back agent for a VTC device in a conference call. Because a CVI bot is in the middle of the VTC and Microsoft Teams infrastructure as a VTC proxy, it has two media legs. One media leg is between the CVI bot and Teams infrastructure, such as Teams conference server or a Teams client. The other media leg is between the CVI bot and the VTC device.  The third-party partners own the VTC media leg and the Teams infrastructure cannot access the quality data of the third-party call leg.  This method is only for the CVI partners to provide their media quality data.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/call-logteleconferencedevicequality?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Log video teleconferencing device quality data. The Cloud Video Interop (CVI) bot represents video teleconferencing (VTC) devices and acts as a back-to-back agent for a VTC device in a conference call. Because a CVI bot is in the middle of the VTC and Microsoft Teams infrastructure as a VTC proxy, it has two media legs. One media leg is between the CVI bot and Teams infrastructure, such as Teams conference server or a Teams client. The other media leg is between the CVI bot and the VTC device.  The third-party partners own the VTC media leg and the Teams infrastructure cannot access the quality data of the third-party call leg.  This method is only for the CVI partners to provide their media quality data.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeLogTeleconferenceDeviceQualityPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a logTeleconferenceDeviceQualityRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new LogTeleconferenceDeviceQualityRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.LogTeleconferenceDeviceQualityRequestBuilder = LogTeleconferenceDeviceQualityRequestBuilder;
// tslint:enable
// eslint-enable
