import { type CloudCommunications } from '../models/cloudCommunications';
import { CallRecordsRequestBuilder } from './callRecords/';
import { CallsRequestBuilder } from './calls/';
import { GetPresencesByUserIdRequestBuilder } from './getPresencesByUserId/';
import { OnlineMeetingsRequestBuilder } from './onlineMeetings/';
import { PresencesRequestBuilder } from './presences/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface CommunicationsRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the cloudCommunications singleton.
 */
export declare class CommunicationsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the callRecords property of the microsoft.graph.cloudCommunications entity.
     */
    get callRecords(): CallRecordsRequestBuilder;
    /**
     * Provides operations to manage the calls property of the microsoft.graph.cloudCommunications entity.
     */
    get calls(): CallsRequestBuilder;
    /**
     * Provides operations to call the getPresencesByUserId method.
     */
    get getPresencesByUserId(): GetPresencesByUserIdRequestBuilder;
    /**
     * Provides operations to manage the onlineMeetings property of the microsoft.graph.cloudCommunications entity.
     */
    get onlineMeetings(): OnlineMeetingsRequestBuilder;
    /**
     * Provides operations to manage the presences property of the microsoft.graph.cloudCommunications entity.
     */
    get presences(): PresencesRequestBuilder;
    /**
     * Instantiates a new CommunicationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of CloudCommunications
     */
    get(requestConfiguration?: RequestConfiguration<CommunicationsRequestBuilderGetQueryParameters> | undefined): Promise<CloudCommunications | undefined>;
    /**
     * Update communications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of CloudCommunications
     */
    patch(body: CloudCommunications, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<CloudCommunications | undefined>;
    /**
     * Get communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<CommunicationsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update communications
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: CloudCommunications, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a communicationsRequestBuilder
     */
    withUrl(rawUrl: string): CommunicationsRequestBuilder;
}
