import { type Compliance } from '../models/compliance';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ComplianceRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the compliance singleton.
 */
export declare class ComplianceRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new ComplianceRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get compliance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Compliance
     */
    get(requestConfiguration?: RequestConfiguration<ComplianceRequestBuilderGetQueryParameters> | undefined): Promise<Compliance | undefined>;
    /**
     * Update compliance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Compliance
     */
    patch(body: Compliance, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Compliance | undefined>;
    /**
     * Get compliance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ComplianceRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update compliance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Compliance, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a complianceRequestBuilder
     */
    withUrl(rawUrl: string): ComplianceRequestBuilder;
}
