import { type ExternalActivity } from '../../../../../../models/externalConnectors/externalActivity';
import { PerformedByRequestBuilder } from './performedBy/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ExternalActivityItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the activities property of the microsoft.graph.externalConnectors.externalItem entity.
 */
export declare class ExternalActivityItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the performedBy property of the microsoft.graph.externalConnectors.externalActivity entity.
     */
    get performedBy(): PerformedByRequestBuilder;
    /**
     * Instantiates a new ExternalActivityItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property activities for connections
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Returns a list of activities performed on the item. Write-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ExternalActivity
     */
    get(requestConfiguration?: RequestConfiguration<ExternalActivityItemRequestBuilderGetQueryParameters> | undefined): Promise<ExternalActivity | undefined>;
    /**
     * Update the navigation property activities in connections
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ExternalActivity
     */
    patch(body: ExternalActivity, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ExternalActivity | undefined>;
    /**
     * Delete navigation property activities for connections
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a list of activities performed on the item. Write-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ExternalActivityItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property activities in connections
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ExternalActivity, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ExternalActivityItemRequestBuilder
     */
    withUrl(rawUrl: string): ExternalActivityItemRequestBuilder;
}
