import { type DataPolicyOperation } from '../../models/dataPolicyOperation';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DataPolicyOperationItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the collection of dataPolicyOperation entities.
 */
export declare class DataPolicyOperationItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new DataPolicyOperationItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from dataPolicyOperations
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties of a dataPolicyOperation object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DataPolicyOperation
     * @see {@link https://learn.microsoft.com/graph/api/datapolicyoperation-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<DataPolicyOperationItemRequestBuilderGetQueryParameters> | undefined): Promise<DataPolicyOperation | undefined>;
    /**
     * Update entity in dataPolicyOperations
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DataPolicyOperation
     */
    patch(body: DataPolicyOperation, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DataPolicyOperation | undefined>;
    /**
     * Delete entity from dataPolicyOperations
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties of a dataPolicyOperation object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DataPolicyOperationItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update entity in dataPolicyOperations
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: DataPolicyOperation, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a DataPolicyOperationItemRequestBuilder
     */
    withUrl(rawUrl: string): DataPolicyOperationItemRequestBuilder;
}
