import { type DeviceAppManagement } from '../models/deviceAppManagement';
import { AndroidManagedAppProtectionsRequestBuilder } from './androidManagedAppProtections/';
import { DefaultManagedAppProtectionsRequestBuilder } from './defaultManagedAppProtections/';
import { IosManagedAppProtectionsRequestBuilder } from './iosManagedAppProtections/';
import { ManagedAppPoliciesRequestBuilder } from './managedAppPolicies/';
import { ManagedAppRegistrationsRequestBuilder } from './managedAppRegistrations/';
import { ManagedAppStatusesRequestBuilder } from './managedAppStatuses/';
import { ManagedEBooksRequestBuilder } from './managedEBooks/';
import { MdmWindowsInformationProtectionPoliciesRequestBuilder } from './mdmWindowsInformationProtectionPolicies/';
import { MobileAppCategoriesRequestBuilder } from './mobileAppCategories/';
import { MobileAppConfigurationsRequestBuilder } from './mobileAppConfigurations/';
import { MobileAppsRequestBuilder } from './mobileApps/';
import { SyncMicrosoftStoreForBusinessAppsRequestBuilder } from './syncMicrosoftStoreForBusinessApps/';
import { TargetedManagedAppConfigurationsRequestBuilder } from './targetedManagedAppConfigurations/';
import { VppTokensRequestBuilder } from './vppTokens/';
import { WindowsInformationProtectionPoliciesRequestBuilder } from './windowsInformationProtectionPolicies/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DeviceAppManagementRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the deviceAppManagement singleton.
 */
export declare class DeviceAppManagementRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the androidManagedAppProtections property of the microsoft.graph.deviceAppManagement entity.
     */
    get androidManagedAppProtections(): AndroidManagedAppProtectionsRequestBuilder;
    /**
     * Provides operations to manage the defaultManagedAppProtections property of the microsoft.graph.deviceAppManagement entity.
     */
    get defaultManagedAppProtections(): DefaultManagedAppProtectionsRequestBuilder;
    /**
     * Provides operations to manage the iosManagedAppProtections property of the microsoft.graph.deviceAppManagement entity.
     */
    get iosManagedAppProtections(): IosManagedAppProtectionsRequestBuilder;
    /**
     * Provides operations to manage the managedAppPolicies property of the microsoft.graph.deviceAppManagement entity.
     */
    get managedAppPolicies(): ManagedAppPoliciesRequestBuilder;
    /**
     * Provides operations to manage the managedAppRegistrations property of the microsoft.graph.deviceAppManagement entity.
     */
    get managedAppRegistrations(): ManagedAppRegistrationsRequestBuilder;
    /**
     * Provides operations to manage the managedAppStatuses property of the microsoft.graph.deviceAppManagement entity.
     */
    get managedAppStatuses(): ManagedAppStatusesRequestBuilder;
    /**
     * Provides operations to manage the managedEBooks property of the microsoft.graph.deviceAppManagement entity.
     */
    get managedEBooks(): ManagedEBooksRequestBuilder;
    /**
     * Provides operations to manage the mdmWindowsInformationProtectionPolicies property of the microsoft.graph.deviceAppManagement entity.
     */
    get mdmWindowsInformationProtectionPolicies(): MdmWindowsInformationProtectionPoliciesRequestBuilder;
    /**
     * Provides operations to manage the mobileAppCategories property of the microsoft.graph.deviceAppManagement entity.
     */
    get mobileAppCategories(): MobileAppCategoriesRequestBuilder;
    /**
     * Provides operations to manage the mobileAppConfigurations property of the microsoft.graph.deviceAppManagement entity.
     */
    get mobileAppConfigurations(): MobileAppConfigurationsRequestBuilder;
    /**
     * Provides operations to manage the mobileApps property of the microsoft.graph.deviceAppManagement entity.
     */
    get mobileApps(): MobileAppsRequestBuilder;
    /**
     * Provides operations to call the syncMicrosoftStoreForBusinessApps method.
     */
    get syncMicrosoftStoreForBusinessApps(): SyncMicrosoftStoreForBusinessAppsRequestBuilder;
    /**
     * Provides operations to manage the targetedManagedAppConfigurations property of the microsoft.graph.deviceAppManagement entity.
     */
    get targetedManagedAppConfigurations(): TargetedManagedAppConfigurationsRequestBuilder;
    /**
     * Provides operations to manage the vppTokens property of the microsoft.graph.deviceAppManagement entity.
     */
    get vppTokens(): VppTokensRequestBuilder;
    /**
     * Provides operations to manage the windowsInformationProtectionPolicies property of the microsoft.graph.deviceAppManagement entity.
     */
    get windowsInformationProtectionPolicies(): WindowsInformationProtectionPoliciesRequestBuilder;
    /**
     * Instantiates a new DeviceAppManagementRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Read properties and relationships of the deviceAppManagement object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceAppManagement
     * @see {@link https://learn.microsoft.com/graph/api/intune-apps-deviceappmanagement-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<DeviceAppManagementRequestBuilderGetQueryParameters> | undefined): Promise<DeviceAppManagement | undefined>;
    /**
     * Update the properties of a deviceAppManagement object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceAppManagement
     * @see {@link https://learn.microsoft.com/graph/api/intune-unlock-deviceappmanagement-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: DeviceAppManagement, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DeviceAppManagement | undefined>;
    /**
     * Read properties and relationships of the deviceAppManagement object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DeviceAppManagementRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of a deviceAppManagement object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: DeviceAppManagement, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a deviceAppManagementRequestBuilder
     */
    withUrl(rawUrl: string): DeviceAppManagementRequestBuilder;
}
