import { type ManagedMobileApp } from '../../../../../models/managedMobileApp';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ManagedMobileAppItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the apps property of the microsoft.graph.iosManagedAppProtection entity.
 */
export declare class ManagedMobileAppItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new ManagedMobileAppItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Deletes a managedMobileApp.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/intune-mam-managedmobileapp-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read properties and relationships of the managedMobileApp object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedMobileApp
     * @see {@link https://learn.microsoft.com/graph/api/intune-mam-managedmobileapp-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ManagedMobileAppItemRequestBuilderGetQueryParameters> | undefined): Promise<ManagedMobileApp | undefined>;
    /**
     * Update the properties of a managedMobileApp object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedMobileApp
     * @see {@link https://learn.microsoft.com/graph/api/intune-mam-managedmobileapp-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: ManagedMobileApp, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ManagedMobileApp | undefined>;
    /**
     * Deletes a managedMobileApp.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read properties and relationships of the managedMobileApp object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ManagedMobileAppItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of a managedMobileApp object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ManagedMobileApp, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ManagedMobileAppItemRequestBuilder
     */
    withUrl(rawUrl: string): ManagedMobileAppItemRequestBuilder;
}
