import { type ManagedAppPolicyCollectionResponse } from '../../models/';
import { type ManagedAppPolicy } from '../../models/managedAppPolicy';
import { CountRequestBuilder } from './count/';
import { ManagedAppPolicyItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ManagedAppPoliciesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the managedAppPolicies property of the microsoft.graph.deviceAppManagement entity.
 */
export declare class ManagedAppPoliciesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the managedAppPolicies property of the microsoft.graph.deviceAppManagement entity.
     * @param managedAppPolicyId The unique identifier of managedAppPolicy
     * @returns a ManagedAppPolicyItemRequestBuilder
     */
    byManagedAppPolicyId(managedAppPolicyId: string): ManagedAppPolicyItemRequestBuilder;
    /**
     * Instantiates a new ManagedAppPoliciesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the managedAppConfiguration objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedAppPolicyCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-mam-managedappconfiguration-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ManagedAppPoliciesRequestBuilderGetQueryParameters> | undefined): Promise<ManagedAppPolicyCollectionResponse | undefined>;
    /**
     * Create new navigation property to managedAppPolicies for deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedAppPolicy
     */
    post(body: ManagedAppPolicy, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ManagedAppPolicy | undefined>;
    /**
     * List properties and relationships of the managedAppConfiguration objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ManagedAppPoliciesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to managedAppPolicies for deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ManagedAppPolicy, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a managedAppPoliciesRequestBuilder
     */
    withUrl(rawUrl: string): ManagedAppPoliciesRequestBuilder;
}
