import { type ManagedEBookCollectionResponse } from '../../models/';
import { type ManagedEBook } from '../../models/managedEBook';
import { CountRequestBuilder } from './count/';
import { ManagedEBookItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ManagedEBooksRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the managedEBooks property of the microsoft.graph.deviceAppManagement entity.
 */
export declare class ManagedEBooksRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the managedEBooks property of the microsoft.graph.deviceAppManagement entity.
     * @param managedEBookId The unique identifier of managedEBook
     * @returns a ManagedEBookItemRequestBuilder
     */
    byManagedEBookId(managedEBookId: string): ManagedEBookItemRequestBuilder;
    /**
     * Instantiates a new ManagedEBooksRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the iosVppEBook objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedEBookCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-books-iosvppebook-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ManagedEBooksRequestBuilderGetQueryParameters> | undefined): Promise<ManagedEBookCollectionResponse | undefined>;
    /**
     * Create a new iosVppEBook object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedEBook
     * @see {@link https://learn.microsoft.com/graph/api/intune-books-iosvppebook-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: ManagedEBook, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ManagedEBook | undefined>;
    /**
     * List properties and relationships of the iosVppEBook objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ManagedEBooksRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new iosVppEBook object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ManagedEBook, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a managedEBooksRequestBuilder
     */
    withUrl(rawUrl: string): ManagedEBooksRequestBuilder;
}
