import { type ManagedEBook } from '../../../models/managedEBook';
import { AssignRequestBuilder } from './assign/';
import { AssignmentsRequestBuilder } from './assignments/';
import { DeviceStatesRequestBuilder } from './deviceStates/';
import { InstallSummaryRequestBuilder } from './installSummary/';
import { UserStateSummaryRequestBuilder } from './userStateSummary/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ManagedEBookItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the managedEBooks property of the microsoft.graph.deviceAppManagement entity.
 */
export declare class ManagedEBookItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the assign method.
     */
    get assign(): AssignRequestBuilder;
    /**
     * Provides operations to manage the assignments property of the microsoft.graph.managedEBook entity.
     */
    get assignments(): AssignmentsRequestBuilder;
    /**
     * Provides operations to manage the deviceStates property of the microsoft.graph.managedEBook entity.
     */
    get deviceStates(): DeviceStatesRequestBuilder;
    /**
     * Provides operations to manage the installSummary property of the microsoft.graph.managedEBook entity.
     */
    get installSummary(): InstallSummaryRequestBuilder;
    /**
     * Provides operations to manage the userStateSummary property of the microsoft.graph.managedEBook entity.
     */
    get userStateSummary(): UserStateSummaryRequestBuilder;
    /**
     * Instantiates a new ManagedEBookItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Deletes a iosVppEBook.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/intune-books-iosvppebook-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read properties and relationships of the iosVppEBook object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedEBook
     * @see {@link https://learn.microsoft.com/graph/api/intune-books-iosvppebook-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ManagedEBookItemRequestBuilderGetQueryParameters> | undefined): Promise<ManagedEBook | undefined>;
    /**
     * Update the properties of a iosVppEBook object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedEBook
     * @see {@link https://learn.microsoft.com/graph/api/intune-books-iosvppebook-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: ManagedEBook, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ManagedEBook | undefined>;
    /**
     * Deletes a iosVppEBook.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read properties and relationships of the iosVppEBook object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ManagedEBookItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of a iosVppEBook object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ManagedEBook, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ManagedEBookItemRequestBuilder
     */
    withUrl(rawUrl: string): ManagedEBookItemRequestBuilder;
}
