import { type UserInstallStateSummaryCollectionResponse } from '../../../../models/';
import { type UserInstallStateSummary } from '../../../../models/userInstallStateSummary';
import { CountRequestBuilder } from './count/';
import { UserInstallStateSummaryItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface UserStateSummaryRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the userStateSummary property of the microsoft.graph.managedEBook entity.
 */
export declare class UserStateSummaryRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the userStateSummary property of the microsoft.graph.managedEBook entity.
     * @param userInstallStateSummaryId The unique identifier of userInstallStateSummary
     * @returns a UserInstallStateSummaryItemRequestBuilder
     */
    byUserInstallStateSummaryId(userInstallStateSummaryId: string): UserInstallStateSummaryItemRequestBuilder;
    /**
     * Instantiates a new UserStateSummaryRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the userInstallStateSummary objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserInstallStateSummaryCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-books-userinstallstatesummary-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<UserStateSummaryRequestBuilderGetQueryParameters> | undefined): Promise<UserInstallStateSummaryCollectionResponse | undefined>;
    /**
     * Create a new userInstallStateSummary object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserInstallStateSummary
     * @see {@link https://learn.microsoft.com/graph/api/intune-books-userinstallstatesummary-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: UserInstallStateSummary, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<UserInstallStateSummary | undefined>;
    /**
     * List properties and relationships of the userInstallStateSummary objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<UserStateSummaryRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new userInstallStateSummary object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: UserInstallStateSummary, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a userStateSummaryRequestBuilder
     */
    withUrl(rawUrl: string): UserStateSummaryRequestBuilder;
}
