import { type DeviceInstallStateCollectionResponse } from '../../../../../../models/';
import { type DeviceInstallState } from '../../../../../../models/deviceInstallState';
import { CountRequestBuilder } from './count/';
import { DeviceInstallStateItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DeviceStatesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the deviceStates property of the microsoft.graph.userInstallStateSummary entity.
 */
export declare class DeviceStatesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the deviceStates property of the microsoft.graph.userInstallStateSummary entity.
     * @param deviceInstallStateId The unique identifier of deviceInstallState
     * @returns a DeviceInstallStateItemRequestBuilder
     */
    byDeviceInstallStateId(deviceInstallStateId: string): DeviceInstallStateItemRequestBuilder;
    /**
     * Instantiates a new DeviceStatesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The install state of the eBook.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceInstallStateCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<DeviceStatesRequestBuilderGetQueryParameters> | undefined): Promise<DeviceInstallStateCollectionResponse | undefined>;
    /**
     * Create new navigation property to deviceStates for deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceInstallState
     */
    post(body: DeviceInstallState, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DeviceInstallState | undefined>;
    /**
     * The install state of the eBook.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DeviceStatesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to deviceStates for deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DeviceInstallState, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a deviceStatesRequestBuilder
     */
    withUrl(rawUrl: string): DeviceStatesRequestBuilder;
}
