import { type MobileAppCategoryCollectionResponse } from '../../models/';
import { type MobileAppCategory } from '../../models/mobileAppCategory';
import { CountRequestBuilder } from './count/';
import { MobileAppCategoryItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface MobileAppCategoriesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the mobileAppCategories property of the microsoft.graph.deviceAppManagement entity.
 */
export declare class MobileAppCategoriesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the mobileAppCategories property of the microsoft.graph.deviceAppManagement entity.
     * @param mobileAppCategoryId The unique identifier of mobileAppCategory
     * @returns a MobileAppCategoryItemRequestBuilder
     */
    byMobileAppCategoryId(mobileAppCategoryId: string): MobileAppCategoryItemRequestBuilder;
    /**
     * Instantiates a new MobileAppCategoriesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the mobileAppCategory objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MobileAppCategoryCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-apps-mobileappcategory-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<MobileAppCategoriesRequestBuilderGetQueryParameters> | undefined): Promise<MobileAppCategoryCollectionResponse | undefined>;
    /**
     * Create a new mobileAppCategory object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MobileAppCategory
     * @see {@link https://learn.microsoft.com/graph/api/intune-apps-mobileappcategory-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: MobileAppCategory, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<MobileAppCategory | undefined>;
    /**
     * List properties and relationships of the mobileAppCategory objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<MobileAppCategoriesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new mobileAppCategory object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: MobileAppCategory, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a mobileAppCategoriesRequestBuilder
     */
    withUrl(rawUrl: string): MobileAppCategoriesRequestBuilder;
}
