import { type MobileAppCollectionResponse } from '../../models/';
import { type MobileApp } from '../../models/mobileApp';
import { CountRequestBuilder } from './count/';
import { GraphAndroidLobAppRequestBuilder } from './graphAndroidLobApp/';
import { GraphAndroidStoreAppRequestBuilder } from './graphAndroidStoreApp/';
import { GraphIosLobAppRequestBuilder } from './graphIosLobApp/';
import { GraphIosStoreAppRequestBuilder } from './graphIosStoreApp/';
import { GraphIosVppAppRequestBuilder } from './graphIosVppApp/';
import { GraphMacOSDmgAppRequestBuilder } from './graphMacOSDmgApp/';
import { GraphMacOSLobAppRequestBuilder } from './graphMacOSLobApp/';
import { GraphManagedAndroidLobAppRequestBuilder } from './graphManagedAndroidLobApp/';
import { GraphManagedIOSLobAppRequestBuilder } from './graphManagedIOSLobApp/';
import { GraphManagedMobileLobAppRequestBuilder } from './graphManagedMobileLobApp/';
import { GraphMicrosoftStoreForBusinessAppRequestBuilder } from './graphMicrosoftStoreForBusinessApp/';
import { GraphWin32LobAppRequestBuilder } from './graphWin32LobApp/';
import { GraphWindowsAppXRequestBuilder } from './graphWindowsAppX/';
import { GraphWindowsMobileMSIRequestBuilder } from './graphWindowsMobileMSI/';
import { GraphWindowsUniversalAppXRequestBuilder } from './graphWindowsUniversalAppX/';
import { GraphWindowsWebAppRequestBuilder } from './graphWindowsWebApp/';
import { MobileAppItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface MobileAppsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the mobileApps property of the microsoft.graph.deviceAppManagement entity.
 */
export declare class MobileAppsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Casts the previous resource to androidLobApp.
     */
    get graphAndroidLobApp(): GraphAndroidLobAppRequestBuilder;
    /**
     * Casts the previous resource to androidStoreApp.
     */
    get graphAndroidStoreApp(): GraphAndroidStoreAppRequestBuilder;
    /**
     * Casts the previous resource to iosLobApp.
     */
    get graphIosLobApp(): GraphIosLobAppRequestBuilder;
    /**
     * Casts the previous resource to iosStoreApp.
     */
    get graphIosStoreApp(): GraphIosStoreAppRequestBuilder;
    /**
     * Casts the previous resource to iosVppApp.
     */
    get graphIosVppApp(): GraphIosVppAppRequestBuilder;
    /**
     * Casts the previous resource to macOSDmgApp.
     */
    get graphMacOSDmgApp(): GraphMacOSDmgAppRequestBuilder;
    /**
     * Casts the previous resource to macOSLobApp.
     */
    get graphMacOSLobApp(): GraphMacOSLobAppRequestBuilder;
    /**
     * Casts the previous resource to managedAndroidLobApp.
     */
    get graphManagedAndroidLobApp(): GraphManagedAndroidLobAppRequestBuilder;
    /**
     * Casts the previous resource to managedIOSLobApp.
     */
    get graphManagedIOSLobApp(): GraphManagedIOSLobAppRequestBuilder;
    /**
     * Casts the previous resource to managedMobileLobApp.
     */
    get graphManagedMobileLobApp(): GraphManagedMobileLobAppRequestBuilder;
    /**
     * Casts the previous resource to microsoftStoreForBusinessApp.
     */
    get graphMicrosoftStoreForBusinessApp(): GraphMicrosoftStoreForBusinessAppRequestBuilder;
    /**
     * Casts the previous resource to win32LobApp.
     */
    get graphWin32LobApp(): GraphWin32LobAppRequestBuilder;
    /**
     * Casts the previous resource to windowsAppX.
     */
    get graphWindowsAppX(): GraphWindowsAppXRequestBuilder;
    /**
     * Casts the previous resource to windowsMobileMSI.
     */
    get graphWindowsMobileMSI(): GraphWindowsMobileMSIRequestBuilder;
    /**
     * Casts the previous resource to windowsUniversalAppX.
     */
    get graphWindowsUniversalAppX(): GraphWindowsUniversalAppXRequestBuilder;
    /**
     * Casts the previous resource to windowsWebApp.
     */
    get graphWindowsWebApp(): GraphWindowsWebAppRequestBuilder;
    /**
     * Provides operations to manage the mobileApps property of the microsoft.graph.deviceAppManagement entity.
     * @param mobileAppId The unique identifier of mobileApp
     * @returns a MobileAppItemRequestBuilder
     */
    byMobileAppId(mobileAppId: string): MobileAppItemRequestBuilder;
    /**
     * Instantiates a new MobileAppsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the managedIOSStoreApp objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MobileAppCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-apps-managediosstoreapp-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<MobileAppsRequestBuilderGetQueryParameters> | undefined): Promise<MobileAppCollectionResponse | undefined>;
    /**
     * Create a new webApp object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MobileApp
     * @see {@link https://learn.microsoft.com/graph/api/intune-apps-webapp-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: MobileApp, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<MobileApp | undefined>;
    /**
     * List properties and relationships of the managedIOSStoreApp objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<MobileAppsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new webApp object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: MobileApp, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a mobileAppsRequestBuilder
     */
    withUrl(rawUrl: string): MobileAppsRequestBuilder;
}
