"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GraphAndroidLobAppRequestBuilder = void 0;
const androidLobApp_1 = require("../../../../models/androidLobApp");
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const assignments_1 = require("./assignments/");
const categories_1 = require("./categories/");
const contentVersions_1 = require("./contentVersions/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Casts the previous resource to androidLobApp.
 */
class GraphAndroidLobAppRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to manage the assignments property of the microsoft.graph.mobileApp entity.
     */
    get assignments() {
        return new assignments_1.AssignmentsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the categories property of the microsoft.graph.mobileApp entity.
     */
    get categories() {
        return new categories_1.CategoriesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the contentVersions property of the microsoft.graph.mobileLobApp entity.
     */
    get contentVersions() {
        return new contentVersions_1.ContentVersionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new GraphAndroidLobAppRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/deviceAppManagement/mobileApps/{mobileApp%2Did}/graph.androidLobApp{?%24select,%24expand}");
    }
    ;
    /**
     * Get the item of type microsoft.graph.mobileApp as microsoft.graph.androidLobApp
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AndroidLobApp
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, androidLobApp_1.createAndroidLobAppFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Get the item of type microsoft.graph.mobileApp as microsoft.graph.androidLobApp
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, graphAndroidLobAppRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a graphAndroidLobAppRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new GraphAndroidLobAppRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.GraphAndroidLobAppRequestBuilder = GraphAndroidLobAppRequestBuilder;
const graphAndroidLobAppRequestBuilderGetQueryParametersMapper = {
    "expand": "%24expand",
    "select": "%24select",
};
// tslint:enable
// eslint-enable
