import { type MobileAppContentFileCollectionResponse } from '../../../../../../../models/';
import { type MobileAppContentFile } from '../../../../../../../models/mobileAppContentFile';
import { CountRequestBuilder } from './count/';
import { MobileAppContentFileItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface FilesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the files property of the microsoft.graph.mobileAppContent entity.
 */
export declare class FilesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the files property of the microsoft.graph.mobileAppContent entity.
     * @param mobileAppContentFileId The unique identifier of mobileAppContentFile
     * @returns a MobileAppContentFileItemRequestBuilder
     */
    byMobileAppContentFileId(mobileAppContentFileId: string): MobileAppContentFileItemRequestBuilder;
    /**
     * Instantiates a new FilesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The list of files for this app content version.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MobileAppContentFileCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<FilesRequestBuilderGetQueryParameters> | undefined): Promise<MobileAppContentFileCollectionResponse | undefined>;
    /**
     * Create new navigation property to files for deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MobileAppContentFile
     */
    post(body: MobileAppContentFile, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<MobileAppContentFile | undefined>;
    /**
     * The list of files for this app content version.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<FilesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to files for deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: MobileAppContentFile, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a filesRequestBuilder
     */
    withUrl(rawUrl: string): FilesRequestBuilder;
}
