import { type MobileAppContentFile } from '../../../../../../../../models/mobileAppContentFile';
import { CommitRequestBuilder } from './commit/';
import { RenewUploadRequestBuilder } from './renewUpload/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface MobileAppContentFileItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the files property of the microsoft.graph.mobileAppContent entity.
 */
export declare class MobileAppContentFileItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the commit method.
     */
    get commit(): CommitRequestBuilder;
    /**
     * Provides operations to call the renewUpload method.
     */
    get renewUpload(): RenewUploadRequestBuilder;
    /**
     * Instantiates a new MobileAppContentFileItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property files for deviceAppManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * The list of files for this app content version.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MobileAppContentFile
     */
    get(requestConfiguration?: RequestConfiguration<MobileAppContentFileItemRequestBuilderGetQueryParameters> | undefined): Promise<MobileAppContentFile | undefined>;
    /**
     * Update the navigation property files in deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MobileAppContentFile
     */
    patch(body: MobileAppContentFile, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<MobileAppContentFile | undefined>;
    /**
     * Delete navigation property files for deviceAppManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * The list of files for this app content version.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<MobileAppContentFileItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property files in deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: MobileAppContentFile, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a MobileAppContentFileItemRequestBuilder
     */
    withUrl(rawUrl: string): MobileAppContentFileItemRequestBuilder;
}
