import { type MobileContainedAppCollectionResponse } from '../../../../../../../models/';
import { type MobileContainedApp } from '../../../../../../../models/mobileContainedApp';
import { CountRequestBuilder } from './count/';
import { MobileContainedAppItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ContainedAppsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the containedApps property of the microsoft.graph.mobileAppContent entity.
 */
export declare class ContainedAppsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the containedApps property of the microsoft.graph.mobileAppContent entity.
     * @param mobileContainedAppId The unique identifier of mobileContainedApp
     * @returns a MobileContainedAppItemRequestBuilder
     */
    byMobileContainedAppId(mobileContainedAppId: string): MobileContainedAppItemRequestBuilder;
    /**
     * Instantiates a new ContainedAppsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The collection of contained apps in a MobileLobApp acting as a package.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MobileContainedAppCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<ContainedAppsRequestBuilderGetQueryParameters> | undefined): Promise<MobileContainedAppCollectionResponse | undefined>;
    /**
     * Create new navigation property to containedApps for deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MobileContainedApp
     */
    post(body: MobileContainedApp, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<MobileContainedApp | undefined>;
    /**
     * The collection of contained apps in a MobileLobApp acting as a package.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ContainedAppsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to containedApps for deviceAppManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: MobileContainedApp, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a containedAppsRequestBuilder
     */
    withUrl(rawUrl: string): ContainedAppsRequestBuilder;
}
