import { type TargetedManagedAppConfigurationCollectionResponse } from '../../models/';
import { type TargetedManagedAppConfiguration } from '../../models/targetedManagedAppConfiguration';
import { CountRequestBuilder } from './count/';
import { TargetedManagedAppConfigurationItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface TargetedManagedAppConfigurationsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the targetedManagedAppConfigurations property of the microsoft.graph.deviceAppManagement entity.
 */
export declare class TargetedManagedAppConfigurationsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the targetedManagedAppConfigurations property of the microsoft.graph.deviceAppManagement entity.
     * @param targetedManagedAppConfigurationId The unique identifier of targetedManagedAppConfiguration
     * @returns a TargetedManagedAppConfigurationItemRequestBuilder
     */
    byTargetedManagedAppConfigurationId(targetedManagedAppConfigurationId: string): TargetedManagedAppConfigurationItemRequestBuilder;
    /**
     * Instantiates a new TargetedManagedAppConfigurationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the targetedManagedAppConfiguration objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TargetedManagedAppConfigurationCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-mam-targetedmanagedappconfiguration-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<TargetedManagedAppConfigurationsRequestBuilderGetQueryParameters> | undefined): Promise<TargetedManagedAppConfigurationCollectionResponse | undefined>;
    /**
     * Create a new targetedManagedAppConfiguration object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TargetedManagedAppConfiguration
     * @see {@link https://learn.microsoft.com/graph/api/intune-mam-targetedmanagedappconfiguration-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: TargetedManagedAppConfiguration, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<TargetedManagedAppConfiguration | undefined>;
    /**
     * List properties and relationships of the targetedManagedAppConfiguration objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<TargetedManagedAppConfigurationsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new targetedManagedAppConfiguration object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: TargetedManagedAppConfiguration, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a targetedManagedAppConfigurationsRequestBuilder
     */
    withUrl(rawUrl: string): TargetedManagedAppConfigurationsRequestBuilder;
}
