import { type OnPremisesConditionalAccessSettings } from '../../models/onPremisesConditionalAccessSettings';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ConditionalAccessSettingsRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the conditionalAccessSettings property of the microsoft.graph.deviceManagement entity.
 */
export declare class ConditionalAccessSettingsRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new ConditionalAccessSettingsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property conditionalAccessSettings for deviceManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read properties and relationships of the onPremisesConditionalAccessSettings object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OnPremisesConditionalAccessSettings
     * @see {@link https://learn.microsoft.com/graph/api/intune-onboarding-onpremisesconditionalaccesssettings-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ConditionalAccessSettingsRequestBuilderGetQueryParameters> | undefined): Promise<OnPremisesConditionalAccessSettings | undefined>;
    /**
     * Update the properties of a onPremisesConditionalAccessSettings object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OnPremisesConditionalAccessSettings
     * @see {@link https://learn.microsoft.com/graph/api/intune-onboarding-onpremisesconditionalaccesssettings-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: OnPremisesConditionalAccessSettings, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<OnPremisesConditionalAccessSettings | undefined>;
    /**
     * Delete navigation property conditionalAccessSettings for deviceManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read properties and relationships of the onPremisesConditionalAccessSettings object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ConditionalAccessSettingsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of a onPremisesConditionalAccessSettings object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: OnPremisesConditionalAccessSettings, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a conditionalAccessSettingsRequestBuilder
     */
    withUrl(rawUrl: string): ConditionalAccessSettingsRequestBuilder;
}
