import { type DeviceComplianceScheduledActionForRuleCollectionResponse } from '../../../../models/';
import { type DeviceComplianceScheduledActionForRule } from '../../../../models/deviceComplianceScheduledActionForRule';
import { CountRequestBuilder } from './count/';
import { DeviceComplianceScheduledActionForRuleItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ScheduledActionsForRuleRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the scheduledActionsForRule property of the microsoft.graph.deviceCompliancePolicy entity.
 */
export declare class ScheduledActionsForRuleRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the scheduledActionsForRule property of the microsoft.graph.deviceCompliancePolicy entity.
     * @param deviceComplianceScheduledActionForRuleId The unique identifier of deviceComplianceScheduledActionForRule
     * @returns a DeviceComplianceScheduledActionForRuleItemRequestBuilder
     */
    byDeviceComplianceScheduledActionForRuleId(deviceComplianceScheduledActionForRuleId: string): DeviceComplianceScheduledActionForRuleItemRequestBuilder;
    /**
     * Instantiates a new ScheduledActionsForRuleRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the deviceComplianceScheduledActionForRule objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceComplianceScheduledActionForRuleCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-deviceconfig-devicecompliancescheduledactionforrule-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ScheduledActionsForRuleRequestBuilderGetQueryParameters> | undefined): Promise<DeviceComplianceScheduledActionForRuleCollectionResponse | undefined>;
    /**
     * Create a new deviceComplianceScheduledActionForRule object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceComplianceScheduledActionForRule
     * @see {@link https://learn.microsoft.com/graph/api/intune-deviceconfig-devicecompliancescheduledactionforrule-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: DeviceComplianceScheduledActionForRule, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DeviceComplianceScheduledActionForRule | undefined>;
    /**
     * List properties and relationships of the deviceComplianceScheduledActionForRule objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ScheduledActionsForRuleRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new deviceComplianceScheduledActionForRule object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DeviceComplianceScheduledActionForRule, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a scheduledActionsForRuleRequestBuilder
     */
    withUrl(rawUrl: string): ScheduledActionsForRuleRequestBuilder;
}
