import { type DeviceComplianceActionItemCollectionResponse } from '../../../../../../models/';
import { type DeviceComplianceActionItem } from '../../../../../../models/deviceComplianceActionItem';
import { CountRequestBuilder } from './count/';
import { DeviceComplianceActionItemItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ScheduledActionConfigurationsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the scheduledActionConfigurations property of the microsoft.graph.deviceComplianceScheduledActionForRule entity.
 */
export declare class ScheduledActionConfigurationsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the scheduledActionConfigurations property of the microsoft.graph.deviceComplianceScheduledActionForRule entity.
     * @param deviceComplianceActionItemId The unique identifier of deviceComplianceActionItem
     * @returns a DeviceComplianceActionItemItemRequestBuilder
     */
    byDeviceComplianceActionItemId(deviceComplianceActionItemId: string): DeviceComplianceActionItemItemRequestBuilder;
    /**
     * Instantiates a new ScheduledActionConfigurationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the deviceComplianceActionItem objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceComplianceActionItemCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-deviceconfig-devicecomplianceactionitem-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ScheduledActionConfigurationsRequestBuilderGetQueryParameters> | undefined): Promise<DeviceComplianceActionItemCollectionResponse | undefined>;
    /**
     * Create a new deviceComplianceActionItem object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceComplianceActionItem
     * @see {@link https://learn.microsoft.com/graph/api/intune-deviceconfig-devicecomplianceactionitem-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: DeviceComplianceActionItem, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DeviceComplianceActionItem | undefined>;
    /**
     * List properties and relationships of the deviceComplianceActionItem objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ScheduledActionConfigurationsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new deviceComplianceActionItem object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DeviceComplianceActionItem, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a scheduledActionConfigurationsRequestBuilder
     */
    withUrl(rawUrl: string): ScheduledActionConfigurationsRequestBuilder;
}
