import { type DeviceComplianceSettingStateCollectionResponse } from '../../../../models/';
import { type DeviceComplianceSettingState } from '../../../../models/deviceComplianceSettingState';
import { CountRequestBuilder } from './count/';
import { DeviceComplianceSettingStateItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DeviceComplianceSettingStatesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the deviceComplianceSettingStates property of the microsoft.graph.deviceCompliancePolicySettingStateSummary entity.
 */
export declare class DeviceComplianceSettingStatesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the deviceComplianceSettingStates property of the microsoft.graph.deviceCompliancePolicySettingStateSummary entity.
     * @param deviceComplianceSettingStateId The unique identifier of deviceComplianceSettingState
     * @returns a DeviceComplianceSettingStateItemRequestBuilder
     */
    byDeviceComplianceSettingStateId(deviceComplianceSettingStateId: string): DeviceComplianceSettingStateItemRequestBuilder;
    /**
     * Instantiates a new DeviceComplianceSettingStatesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the deviceComplianceSettingState objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceComplianceSettingStateCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-deviceconfig-devicecompliancesettingstate-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<DeviceComplianceSettingStatesRequestBuilderGetQueryParameters> | undefined): Promise<DeviceComplianceSettingStateCollectionResponse | undefined>;
    /**
     * Create a new deviceComplianceSettingState object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceComplianceSettingState
     * @see {@link https://learn.microsoft.com/graph/api/intune-deviceconfig-devicecompliancesettingstate-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: DeviceComplianceSettingState, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DeviceComplianceSettingState | undefined>;
    /**
     * List properties and relationships of the deviceComplianceSettingState objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DeviceComplianceSettingStatesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new deviceComplianceSettingState object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DeviceComplianceSettingState, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a deviceComplianceSettingStatesRequestBuilder
     */
    withUrl(rawUrl: string): DeviceComplianceSettingStatesRequestBuilder;
}
