import { type SettingStateDeviceSummaryCollectionResponse } from '../../../../models/';
import { type SettingStateDeviceSummary } from '../../../../models/settingStateDeviceSummary';
import { CountRequestBuilder } from './count/';
import { SettingStateDeviceSummaryItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DeviceSettingStateSummariesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the deviceSettingStateSummaries property of the microsoft.graph.deviceConfiguration entity.
 */
export declare class DeviceSettingStateSummariesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the deviceSettingStateSummaries property of the microsoft.graph.deviceConfiguration entity.
     * @param settingStateDeviceSummaryId The unique identifier of settingStateDeviceSummary
     * @returns a SettingStateDeviceSummaryItemRequestBuilder
     */
    bySettingStateDeviceSummaryId(settingStateDeviceSummaryId: string): SettingStateDeviceSummaryItemRequestBuilder;
    /**
     * Instantiates a new DeviceSettingStateSummariesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the settingStateDeviceSummary objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SettingStateDeviceSummaryCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-deviceconfig-settingstatedevicesummary-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<DeviceSettingStateSummariesRequestBuilderGetQueryParameters> | undefined): Promise<SettingStateDeviceSummaryCollectionResponse | undefined>;
    /**
     * Create a new settingStateDeviceSummary object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SettingStateDeviceSummary
     * @see {@link https://learn.microsoft.com/graph/api/intune-deviceconfig-settingstatedevicesummary-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: SettingStateDeviceSummary, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<SettingStateDeviceSummary | undefined>;
    /**
     * List properties and relationships of the settingStateDeviceSummary objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DeviceSettingStateSummariesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new settingStateDeviceSummary object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: SettingStateDeviceSummary, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a deviceSettingStateSummariesRequestBuilder
     */
    withUrl(rawUrl: string): DeviceSettingStateSummariesRequestBuilder;
}
