import { type DeviceManagementPartnerCollectionResponse } from '../../models/';
import { type DeviceManagementPartner } from '../../models/deviceManagementPartner';
import { CountRequestBuilder } from './count/';
import { DeviceManagementPartnerItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DeviceManagementPartnersRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the deviceManagementPartners property of the microsoft.graph.deviceManagement entity.
 */
export declare class DeviceManagementPartnersRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the deviceManagementPartners property of the microsoft.graph.deviceManagement entity.
     * @param deviceManagementPartnerId The unique identifier of deviceManagementPartner
     * @returns a DeviceManagementPartnerItemRequestBuilder
     */
    byDeviceManagementPartnerId(deviceManagementPartnerId: string): DeviceManagementPartnerItemRequestBuilder;
    /**
     * Instantiates a new DeviceManagementPartnersRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the deviceManagementPartner objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceManagementPartnerCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-onboarding-devicemanagementpartner-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<DeviceManagementPartnersRequestBuilderGetQueryParameters> | undefined): Promise<DeviceManagementPartnerCollectionResponse | undefined>;
    /**
     * Create a new deviceManagementPartner object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceManagementPartner
     * @see {@link https://learn.microsoft.com/graph/api/intune-onboarding-devicemanagementpartner-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: DeviceManagementPartner, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DeviceManagementPartner | undefined>;
    /**
     * List properties and relationships of the deviceManagementPartner objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DeviceManagementPartnersRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new deviceManagementPartner object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DeviceManagementPartner, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a deviceManagementPartnersRequestBuilder
     */
    withUrl(rawUrl: string): DeviceManagementPartnersRequestBuilder;
}
