import { type DeviceManagementExchangeConnectorCollectionResponse } from '../../models/';
import { type DeviceManagementExchangeConnector } from '../../models/deviceManagementExchangeConnector';
import { CountRequestBuilder } from './count/';
import { DeviceManagementExchangeConnectorItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ExchangeConnectorsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the exchangeConnectors property of the microsoft.graph.deviceManagement entity.
 */
export declare class ExchangeConnectorsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the exchangeConnectors property of the microsoft.graph.deviceManagement entity.
     * @param deviceManagementExchangeConnectorId The unique identifier of deviceManagementExchangeConnector
     * @returns a DeviceManagementExchangeConnectorItemRequestBuilder
     */
    byDeviceManagementExchangeConnectorId(deviceManagementExchangeConnectorId: string): DeviceManagementExchangeConnectorItemRequestBuilder;
    /**
     * Instantiates a new ExchangeConnectorsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the deviceManagementExchangeConnector objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceManagementExchangeConnectorCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-onboarding-devicemanagementexchangeconnector-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ExchangeConnectorsRequestBuilderGetQueryParameters> | undefined): Promise<DeviceManagementExchangeConnectorCollectionResponse | undefined>;
    /**
     * Create a new deviceManagementExchangeConnector object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceManagementExchangeConnector
     * @see {@link https://learn.microsoft.com/graph/api/intune-onboarding-devicemanagementexchangeconnector-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: DeviceManagementExchangeConnector, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DeviceManagementExchangeConnector | undefined>;
    /**
     * List properties and relationships of the deviceManagementExchangeConnector objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ExchangeConnectorsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new deviceManagementExchangeConnector object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DeviceManagementExchangeConnector, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a exchangeConnectorsRequestBuilder
     */
    withUrl(rawUrl: string): ExchangeConnectorsRequestBuilder;
}
