import { type ImportedWindowsAutopilotDeviceIdentityCollectionResponse } from '../../models/';
import { type ImportedWindowsAutopilotDeviceIdentity } from '../../models/importedWindowsAutopilotDeviceIdentity';
import { CountRequestBuilder } from './count/';
import { ImportRequestBuilder } from './importEscaped/';
import { ImportedWindowsAutopilotDeviceIdentityItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ImportedWindowsAutopilotDeviceIdentitiesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the importedWindowsAutopilotDeviceIdentities property of the microsoft.graph.deviceManagement entity.
 */
export declare class ImportedWindowsAutopilotDeviceIdentitiesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to call the import method.
     */
    get importEscaped(): ImportRequestBuilder;
    /**
     * Provides operations to manage the importedWindowsAutopilotDeviceIdentities property of the microsoft.graph.deviceManagement entity.
     * @param importedWindowsAutopilotDeviceIdentityId The unique identifier of importedWindowsAutopilotDeviceIdentity
     * @returns a ImportedWindowsAutopilotDeviceIdentityItemRequestBuilder
     */
    byImportedWindowsAutopilotDeviceIdentityId(importedWindowsAutopilotDeviceIdentityId: string): ImportedWindowsAutopilotDeviceIdentityItemRequestBuilder;
    /**
     * Instantiates a new ImportedWindowsAutopilotDeviceIdentitiesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the importedWindowsAutopilotDeviceIdentity objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ImportedWindowsAutopilotDeviceIdentityCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-enrollment-importedwindowsautopilotdeviceidentity-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ImportedWindowsAutopilotDeviceIdentitiesRequestBuilderGetQueryParameters> | undefined): Promise<ImportedWindowsAutopilotDeviceIdentityCollectionResponse | undefined>;
    /**
     * Create a new importedWindowsAutopilotDeviceIdentity object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ImportedWindowsAutopilotDeviceIdentity
     * @see {@link https://learn.microsoft.com/graph/api/intune-enrollment-importedwindowsautopilotdeviceidentity-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: ImportedWindowsAutopilotDeviceIdentity, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ImportedWindowsAutopilotDeviceIdentity | undefined>;
    /**
     * List properties and relationships of the importedWindowsAutopilotDeviceIdentity objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ImportedWindowsAutopilotDeviceIdentitiesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new importedWindowsAutopilotDeviceIdentity object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ImportedWindowsAutopilotDeviceIdentity, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a importedWindowsAutopilotDeviceIdentitiesRequestBuilder
     */
    withUrl(rawUrl: string): ImportedWindowsAutopilotDeviceIdentitiesRequestBuilder;
}
