import { type IosUpdateDeviceStatusCollectionResponse } from '../../models/';
import { type IosUpdateDeviceStatus } from '../../models/iosUpdateDeviceStatus';
import { CountRequestBuilder } from './count/';
import { IosUpdateDeviceStatusItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface IosUpdateStatusesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the iosUpdateStatuses property of the microsoft.graph.deviceManagement entity.
 */
export declare class IosUpdateStatusesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the iosUpdateStatuses property of the microsoft.graph.deviceManagement entity.
     * @param iosUpdateDeviceStatusId The unique identifier of iosUpdateDeviceStatus
     * @returns a IosUpdateDeviceStatusItemRequestBuilder
     */
    byIosUpdateDeviceStatusId(iosUpdateDeviceStatusId: string): IosUpdateDeviceStatusItemRequestBuilder;
    /**
     * Instantiates a new IosUpdateStatusesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the iosUpdateDeviceStatus objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IosUpdateDeviceStatusCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-deviceconfig-iosupdatedevicestatus-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<IosUpdateStatusesRequestBuilderGetQueryParameters> | undefined): Promise<IosUpdateDeviceStatusCollectionResponse | undefined>;
    /**
     * Create a new iosUpdateDeviceStatus object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IosUpdateDeviceStatus
     * @see {@link https://learn.microsoft.com/graph/api/intune-deviceconfig-iosupdatedevicestatus-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: IosUpdateDeviceStatus, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<IosUpdateDeviceStatus | undefined>;
    /**
     * List properties and relationships of the iosUpdateDeviceStatus objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<IosUpdateStatusesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new iosUpdateDeviceStatus object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: IosUpdateDeviceStatus, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a iosUpdateStatusesRequestBuilder
     */
    withUrl(rawUrl: string): IosUpdateStatusesRequestBuilder;
}
