"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeviceConfigurationStatesRequestBuilder = void 0;
const deviceConfigurationState_1 = require("../../../../models/deviceConfigurationState");
const deviceConfigurationStateCollectionResponse_1 = require("../../../../models/deviceConfigurationStateCollectionResponse");
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const count_1 = require("./count/");
const item_1 = require("./item/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the deviceConfigurationStates property of the microsoft.graph.managedDevice entity.
 */
class DeviceConfigurationStatesRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new count_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the deviceConfigurationStates property of the microsoft.graph.managedDevice entity.
     * @param deviceConfigurationStateId The unique identifier of deviceConfigurationState
     * @returns a DeviceConfigurationStateItemRequestBuilder
     */
    byDeviceConfigurationStateId(deviceConfigurationStateId) {
        if (!deviceConfigurationStateId)
            throw new Error("deviceConfigurationStateId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["deviceConfigurationState%2Did"] = deviceConfigurationStateId;
        return new item_1.DeviceConfigurationStateItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new DeviceConfigurationStatesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/deviceManagement/managedDevices/{managedDevice%2Did}/deviceConfigurationStates{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * Device configuration states for this device.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceConfigurationStateCollectionResponse
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, deviceConfigurationStateCollectionResponse_1.createDeviceConfigurationStateCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Create new navigation property to deviceConfigurationStates for deviceManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceConfigurationState
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, deviceConfigurationState_1.createDeviceConfigurationStateFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Device configuration states for this device.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, deviceConfigurationStatesRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Create new navigation property to deviceConfigurationStates for deviceManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, deviceConfigurationState_1.serializeDeviceConfigurationState);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a deviceConfigurationStatesRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new DeviceConfigurationStatesRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.DeviceConfigurationStatesRequestBuilder = DeviceConfigurationStatesRequestBuilder;
const deviceConfigurationStatesRequestBuilderGetQueryParametersMapper = {
    "count": "%24count",
    "expand": "%24expand",
    "filter": "%24filter",
    "orderby": "%24orderby",
    "search": "%24search",
    "select": "%24select",
    "skip": "%24skip",
    "top": "%24top",
};
// tslint:enable
// eslint-enable
