import { type ManagedDevice } from '../../../models/managedDevice';
import { BypassActivationLockRequestBuilder } from './bypassActivationLock/';
import { CleanWindowsDeviceRequestBuilder } from './cleanWindowsDevice/';
import { DeleteUserFromSharedAppleDeviceRequestBuilder } from './deleteUserFromSharedAppleDevice/';
import { DeviceCategoryRequestBuilder } from './deviceCategory/';
import { DeviceCompliancePolicyStatesRequestBuilder } from './deviceCompliancePolicyStates/';
import { DeviceConfigurationStatesRequestBuilder } from './deviceConfigurationStates/';
import { DisableLostModeRequestBuilder } from './disableLostMode/';
import { LocateDeviceRequestBuilder } from './locateDevice/';
import { LogCollectionRequestsRequestBuilder } from './logCollectionRequests/';
import { LogoutSharedAppleDeviceActiveUserRequestBuilder } from './logoutSharedAppleDeviceActiveUser/';
import { RebootNowRequestBuilder } from './rebootNow/';
import { RecoverPasscodeRequestBuilder } from './recoverPasscode/';
import { RemoteLockRequestBuilder } from './remoteLock/';
import { RequestRemoteAssistanceRequestBuilder } from './requestRemoteAssistance/';
import { ResetPasscodeRequestBuilder } from './resetPasscode/';
import { RetireRequestBuilder } from './retire/';
import { ShutDownRequestBuilder } from './shutDown/';
import { SyncDeviceRequestBuilder } from './syncDevice/';
import { UpdateWindowsDeviceAccountRequestBuilder } from './updateWindowsDeviceAccount/';
import { UsersRequestBuilder } from './users/';
import { WindowsDefenderScanRequestBuilder } from './windowsDefenderScan/';
import { WindowsDefenderUpdateSignaturesRequestBuilder } from './windowsDefenderUpdateSignatures/';
import { WindowsProtectionStateRequestBuilder } from './windowsProtectionState/';
import { WipeRequestBuilder } from './wipe/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ManagedDeviceItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the managedDevices property of the microsoft.graph.deviceManagement entity.
 */
export declare class ManagedDeviceItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the bypassActivationLock method.
     */
    get bypassActivationLock(): BypassActivationLockRequestBuilder;
    /**
     * Provides operations to call the cleanWindowsDevice method.
     */
    get cleanWindowsDevice(): CleanWindowsDeviceRequestBuilder;
    /**
     * Provides operations to call the deleteUserFromSharedAppleDevice method.
     */
    get deleteUserFromSharedAppleDevice(): DeleteUserFromSharedAppleDeviceRequestBuilder;
    /**
     * Provides operations to manage the deviceCategory property of the microsoft.graph.managedDevice entity.
     */
    get deviceCategory(): DeviceCategoryRequestBuilder;
    /**
     * Provides operations to manage the deviceCompliancePolicyStates property of the microsoft.graph.managedDevice entity.
     */
    get deviceCompliancePolicyStates(): DeviceCompliancePolicyStatesRequestBuilder;
    /**
     * Provides operations to manage the deviceConfigurationStates property of the microsoft.graph.managedDevice entity.
     */
    get deviceConfigurationStates(): DeviceConfigurationStatesRequestBuilder;
    /**
     * Provides operations to call the disableLostMode method.
     */
    get disableLostMode(): DisableLostModeRequestBuilder;
    /**
     * Provides operations to call the locateDevice method.
     */
    get locateDevice(): LocateDeviceRequestBuilder;
    /**
     * Provides operations to manage the logCollectionRequests property of the microsoft.graph.managedDevice entity.
     */
    get logCollectionRequests(): LogCollectionRequestsRequestBuilder;
    /**
     * Provides operations to call the logoutSharedAppleDeviceActiveUser method.
     */
    get logoutSharedAppleDeviceActiveUser(): LogoutSharedAppleDeviceActiveUserRequestBuilder;
    /**
     * Provides operations to call the rebootNow method.
     */
    get rebootNow(): RebootNowRequestBuilder;
    /**
     * Provides operations to call the recoverPasscode method.
     */
    get recoverPasscode(): RecoverPasscodeRequestBuilder;
    /**
     * Provides operations to call the remoteLock method.
     */
    get remoteLock(): RemoteLockRequestBuilder;
    /**
     * Provides operations to call the requestRemoteAssistance method.
     */
    get requestRemoteAssistance(): RequestRemoteAssistanceRequestBuilder;
    /**
     * Provides operations to call the resetPasscode method.
     */
    get resetPasscode(): ResetPasscodeRequestBuilder;
    /**
     * Provides operations to call the retire method.
     */
    get retire(): RetireRequestBuilder;
    /**
     * Provides operations to call the shutDown method.
     */
    get shutDown(): ShutDownRequestBuilder;
    /**
     * Provides operations to call the syncDevice method.
     */
    get syncDevice(): SyncDeviceRequestBuilder;
    /**
     * Provides operations to call the updateWindowsDeviceAccount method.
     */
    get updateWindowsDeviceAccount(): UpdateWindowsDeviceAccountRequestBuilder;
    /**
     * Provides operations to manage the users property of the microsoft.graph.managedDevice entity.
     */
    get users(): UsersRequestBuilder;
    /**
     * Provides operations to call the windowsDefenderScan method.
     */
    get windowsDefenderScan(): WindowsDefenderScanRequestBuilder;
    /**
     * Provides operations to call the windowsDefenderUpdateSignatures method.
     */
    get windowsDefenderUpdateSignatures(): WindowsDefenderUpdateSignaturesRequestBuilder;
    /**
     * Provides operations to manage the windowsProtectionState property of the microsoft.graph.managedDevice entity.
     */
    get windowsProtectionState(): WindowsProtectionStateRequestBuilder;
    /**
     * Provides operations to call the wipe method.
     */
    get wipe(): WipeRequestBuilder;
    /**
     * Instantiates a new ManagedDeviceItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Deletes a managedDevice.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-manageddevice-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read properties and relationships of the managedDevice object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedDevice
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-manageddevice-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ManagedDeviceItemRequestBuilderGetQueryParameters> | undefined): Promise<ManagedDevice | undefined>;
    /**
     * Update the properties of a managedDevice object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ManagedDevice
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-manageddevice-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: ManagedDevice, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ManagedDevice | undefined>;
    /**
     * Deletes a managedDevice.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read properties and relationships of the managedDevice object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ManagedDeviceItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of a managedDevice object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ManagedDevice, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ManagedDeviceItemRequestBuilder
     */
    withUrl(rawUrl: string): ManagedDeviceItemRequestBuilder;
}
