import { type DeviceLogCollectionResponseCollectionResponse } from '../../../../models/';
import { type DeviceLogCollectionResponse } from '../../../../models/deviceLogCollectionResponse';
import { CountRequestBuilder } from './count/';
import { DeviceLogCollectionResponseItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface LogCollectionRequestsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the logCollectionRequests property of the microsoft.graph.managedDevice entity.
 */
export declare class LogCollectionRequestsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the logCollectionRequests property of the microsoft.graph.managedDevice entity.
     * @param deviceLogCollectionResponseId The unique identifier of deviceLogCollectionResponse
     * @returns a DeviceLogCollectionResponseItemRequestBuilder
     */
    byDeviceLogCollectionResponseId(deviceLogCollectionResponseId: string): DeviceLogCollectionResponseItemRequestBuilder;
    /**
     * Instantiates a new LogCollectionRequestsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List of log collection requests
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceLogCollectionResponseCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<LogCollectionRequestsRequestBuilderGetQueryParameters> | undefined): Promise<DeviceLogCollectionResponseCollectionResponse | undefined>;
    /**
     * Create new navigation property to logCollectionRequests for deviceManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceLogCollectionResponse
     */
    post(body: DeviceLogCollectionResponse, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DeviceLogCollectionResponse | undefined>;
    /**
     * List of log collection requests
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<LogCollectionRequestsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to logCollectionRequests for deviceManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DeviceLogCollectionResponse, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a logCollectionRequestsRequestBuilder
     */
    withUrl(rawUrl: string): LogCollectionRequestsRequestBuilder;
}
