import { type AppLogCollectionRequestCollectionResponse } from '../../../../models/';
import { type AppLogCollectionRequest } from '../../../../models/appLogCollectionRequest';
import { CountRequestBuilder } from './count/';
import { AppLogCollectionRequestItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AppLogCollectionRequestsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the appLogCollectionRequests property of the microsoft.graph.mobileAppTroubleshootingEvent entity.
 */
export declare class AppLogCollectionRequestsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the appLogCollectionRequests property of the microsoft.graph.mobileAppTroubleshootingEvent entity.
     * @param appLogCollectionRequestId The unique identifier of appLogCollectionRequest
     * @returns a AppLogCollectionRequestItemRequestBuilder
     */
    byAppLogCollectionRequestId(appLogCollectionRequestId: string): AppLogCollectionRequestItemRequestBuilder;
    /**
     * Instantiates a new AppLogCollectionRequestsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the appLogCollectionRequest objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AppLogCollectionRequestCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-applogcollectionrequest-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<AppLogCollectionRequestsRequestBuilderGetQueryParameters> | undefined): Promise<AppLogCollectionRequestCollectionResponse | undefined>;
    /**
     * Create a new appLogCollectionRequest object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AppLogCollectionRequest
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-applogcollectionrequest-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: AppLogCollectionRequest, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AppLogCollectionRequest | undefined>;
    /**
     * List properties and relationships of the appLogCollectionRequest objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AppLogCollectionRequestsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new appLogCollectionRequest object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AppLogCollectionRequest, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a appLogCollectionRequestsRequestBuilder
     */
    withUrl(rawUrl: string): AppLogCollectionRequestsRequestBuilder;
}
