import { type AppLogCollectionRequest } from '../../../../../models/appLogCollectionRequest';
import { CreateDownloadUrlRequestBuilder } from './createDownloadUrl/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AppLogCollectionRequestItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the appLogCollectionRequests property of the microsoft.graph.mobileAppTroubleshootingEvent entity.
 */
export declare class AppLogCollectionRequestItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the createDownloadUrl method.
     */
    get createDownloadUrl(): CreateDownloadUrlRequestBuilder;
    /**
     * Instantiates a new AppLogCollectionRequestItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Deletes a appLogCollectionRequest.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-applogcollectionrequest-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read properties and relationships of the appLogCollectionRequest object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AppLogCollectionRequest
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-applogcollectionrequest-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<AppLogCollectionRequestItemRequestBuilderGetQueryParameters> | undefined): Promise<AppLogCollectionRequest | undefined>;
    /**
     * Update the properties of a appLogCollectionRequest object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AppLogCollectionRequest
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-applogcollectionrequest-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: AppLogCollectionRequest, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AppLogCollectionRequest | undefined>;
    /**
     * Deletes a appLogCollectionRequest.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read properties and relationships of the appLogCollectionRequest object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AppLogCollectionRequestItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of a appLogCollectionRequest object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: AppLogCollectionRequest, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a AppLogCollectionRequestItemRequestBuilder
     */
    withUrl(rawUrl: string): AppLogCollectionRequestItemRequestBuilder;
}
