import { type NotificationMessageTemplateCollectionResponse } from '../../models/';
import { type NotificationMessageTemplate } from '../../models/notificationMessageTemplate';
import { CountRequestBuilder } from './count/';
import { NotificationMessageTemplateItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface NotificationMessageTemplatesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the notificationMessageTemplates property of the microsoft.graph.deviceManagement entity.
 */
export declare class NotificationMessageTemplatesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the notificationMessageTemplates property of the microsoft.graph.deviceManagement entity.
     * @param notificationMessageTemplateId The unique identifier of notificationMessageTemplate
     * @returns a NotificationMessageTemplateItemRequestBuilder
     */
    byNotificationMessageTemplateId(notificationMessageTemplateId: string): NotificationMessageTemplateItemRequestBuilder;
    /**
     * Instantiates a new NotificationMessageTemplatesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the notificationMessageTemplate objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of NotificationMessageTemplateCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-notification-notificationmessagetemplate-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<NotificationMessageTemplatesRequestBuilderGetQueryParameters> | undefined): Promise<NotificationMessageTemplateCollectionResponse | undefined>;
    /**
     * Create a new notificationMessageTemplate object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of NotificationMessageTemplate
     * @see {@link https://learn.microsoft.com/graph/api/intune-notification-notificationmessagetemplate-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: NotificationMessageTemplate, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<NotificationMessageTemplate | undefined>;
    /**
     * List properties and relationships of the notificationMessageTemplate objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<NotificationMessageTemplatesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new notificationMessageTemplate object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: NotificationMessageTemplate, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a notificationMessageTemplatesRequestBuilder
     */
    withUrl(rawUrl: string): NotificationMessageTemplatesRequestBuilder;
}
