import { type LocalizedNotificationMessageCollectionResponse } from '../../../../models/';
import { type LocalizedNotificationMessage } from '../../../../models/localizedNotificationMessage';
import { CountRequestBuilder } from './count/';
import { LocalizedNotificationMessageItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface LocalizedNotificationMessagesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the localizedNotificationMessages property of the microsoft.graph.notificationMessageTemplate entity.
 */
export declare class LocalizedNotificationMessagesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the localizedNotificationMessages property of the microsoft.graph.notificationMessageTemplate entity.
     * @param localizedNotificationMessageId The unique identifier of localizedNotificationMessage
     * @returns a LocalizedNotificationMessageItemRequestBuilder
     */
    byLocalizedNotificationMessageId(localizedNotificationMessageId: string): LocalizedNotificationMessageItemRequestBuilder;
    /**
     * Instantiates a new LocalizedNotificationMessagesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the localizedNotificationMessage objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of LocalizedNotificationMessageCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-notification-localizednotificationmessage-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<LocalizedNotificationMessagesRequestBuilderGetQueryParameters> | undefined): Promise<LocalizedNotificationMessageCollectionResponse | undefined>;
    /**
     * Create a new localizedNotificationMessage object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of LocalizedNotificationMessage
     * @see {@link https://learn.microsoft.com/graph/api/intune-notification-localizednotificationmessage-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: LocalizedNotificationMessage, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<LocalizedNotificationMessage | undefined>;
    /**
     * List properties and relationships of the localizedNotificationMessage objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<LocalizedNotificationMessagesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new localizedNotificationMessage object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: LocalizedNotificationMessage, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a localizedNotificationMessagesRequestBuilder
     */
    withUrl(rawUrl: string): LocalizedNotificationMessagesRequestBuilder;
}
