import { type DeviceManagementExportJobCollectionResponse } from '../../../models/';
import { type DeviceManagementExportJob } from '../../../models/deviceManagementExportJob';
import { CountRequestBuilder } from './count/';
import { DeviceManagementExportJobItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ExportJobsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the exportJobs property of the microsoft.graph.deviceManagementReports entity.
 */
export declare class ExportJobsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the exportJobs property of the microsoft.graph.deviceManagementReports entity.
     * @param deviceManagementExportJobId The unique identifier of deviceManagementExportJob
     * @returns a DeviceManagementExportJobItemRequestBuilder
     */
    byDeviceManagementExportJobId(deviceManagementExportJobId: string): DeviceManagementExportJobItemRequestBuilder;
    /**
     * Instantiates a new ExportJobsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the deviceManagementExportJob objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceManagementExportJobCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-reporting-devicemanagementexportjob-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ExportJobsRequestBuilderGetQueryParameters> | undefined): Promise<DeviceManagementExportJobCollectionResponse | undefined>;
    /**
     * Create a new deviceManagementExportJob object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceManagementExportJob
     * @see {@link https://learn.microsoft.com/graph/api/intune-reporting-devicemanagementexportjob-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: DeviceManagementExportJob, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DeviceManagementExportJob | undefined>;
    /**
     * List properties and relationships of the deviceManagementExportJob objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ExportJobsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new deviceManagementExportJob object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DeviceManagementExportJob, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a exportJobsRequestBuilder
     */
    withUrl(rawUrl: string): ExportJobsRequestBuilder;
}
