import { type RoleAssignment } from '../../../../../models/roleAssignment';
import { RoleDefinitionRequestBuilder } from './roleDefinition/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface RoleAssignmentItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the roleAssignments property of the microsoft.graph.roleDefinition entity.
 */
export declare class RoleAssignmentItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the roleDefinition property of the microsoft.graph.roleAssignment entity.
     */
    get roleDefinition(): RoleDefinitionRequestBuilder;
    /**
     * Instantiates a new RoleAssignmentItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Deletes a roleAssignment.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/intune-rbac-roleassignment-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read properties and relationships of the roleAssignment object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RoleAssignment
     * @see {@link https://learn.microsoft.com/graph/api/intune-rbac-roleassignment-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<RoleAssignmentItemRequestBuilderGetQueryParameters> | undefined): Promise<RoleAssignment | undefined>;
    /**
     * Update the properties of a roleAssignment object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RoleAssignment
     * @see {@link https://learn.microsoft.com/graph/api/intune-rbac-roleassignment-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: RoleAssignment, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<RoleAssignment | undefined>;
    /**
     * Deletes a roleAssignment.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read properties and relationships of the roleAssignment object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<RoleAssignmentItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of a roleAssignment object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: RoleAssignment, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a RoleAssignmentItemRequestBuilder
     */
    withUrl(rawUrl: string): RoleAssignmentItemRequestBuilder;
}
