import { type TermsAndConditionsAcceptanceStatusCollectionResponse } from '../../../../models/';
import { type TermsAndConditionsAcceptanceStatus } from '../../../../models/termsAndConditionsAcceptanceStatus';
import { CountRequestBuilder } from './count/';
import { TermsAndConditionsAcceptanceStatusItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AcceptanceStatusesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the acceptanceStatuses property of the microsoft.graph.termsAndConditions entity.
 */
export declare class AcceptanceStatusesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the acceptanceStatuses property of the microsoft.graph.termsAndConditions entity.
     * @param termsAndConditionsAcceptanceStatusId The unique identifier of termsAndConditionsAcceptanceStatus
     * @returns a TermsAndConditionsAcceptanceStatusItemRequestBuilder
     */
    byTermsAndConditionsAcceptanceStatusId(termsAndConditionsAcceptanceStatusId: string): TermsAndConditionsAcceptanceStatusItemRequestBuilder;
    /**
     * Instantiates a new AcceptanceStatusesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the termsAndConditionsAcceptanceStatus objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TermsAndConditionsAcceptanceStatusCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-companyterms-termsandconditionsacceptancestatus-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<AcceptanceStatusesRequestBuilderGetQueryParameters> | undefined): Promise<TermsAndConditionsAcceptanceStatusCollectionResponse | undefined>;
    /**
     * Create a new termsAndConditionsAcceptanceStatus object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TermsAndConditionsAcceptanceStatus
     * @see {@link https://learn.microsoft.com/graph/api/intune-companyterms-termsandconditionsacceptancestatus-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: TermsAndConditionsAcceptanceStatus, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<TermsAndConditionsAcceptanceStatus | undefined>;
    /**
     * List properties and relationships of the termsAndConditionsAcceptanceStatus objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AcceptanceStatusesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new termsAndConditionsAcceptanceStatus object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: TermsAndConditionsAcceptanceStatus, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a acceptanceStatusesRequestBuilder
     */
    withUrl(rawUrl: string): AcceptanceStatusesRequestBuilder;
}
