import { type UserExperienceAnalyticsMetricCollectionResponse } from '../../../models/';
import { type UserExperienceAnalyticsMetric } from '../../../models/userExperienceAnalyticsMetric';
import { CountRequestBuilder } from './count/';
import { UserExperienceAnalyticsMetricItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface MetricValuesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the metricValues property of the microsoft.graph.userExperienceAnalyticsCategory entity.
 */
export declare class MetricValuesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the metricValues property of the microsoft.graph.userExperienceAnalyticsCategory entity.
     * @param userExperienceAnalyticsMetricId The unique identifier of userExperienceAnalyticsMetric
     * @returns a UserExperienceAnalyticsMetricItemRequestBuilder
     */
    byUserExperienceAnalyticsMetricId(userExperienceAnalyticsMetricId: string): UserExperienceAnalyticsMetricItemRequestBuilder;
    /**
     * Instantiates a new MetricValuesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The metric values for the user experience analytics category. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserExperienceAnalyticsMetricCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<MetricValuesRequestBuilderGetQueryParameters> | undefined): Promise<UserExperienceAnalyticsMetricCollectionResponse | undefined>;
    /**
     * Create new navigation property to metricValues for deviceManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserExperienceAnalyticsMetric
     */
    post(body: UserExperienceAnalyticsMetric, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<UserExperienceAnalyticsMetric | undefined>;
    /**
     * The metric values for the user experience analytics category. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<MetricValuesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to metricValues for deviceManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: UserExperienceAnalyticsMetric, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a metricValuesRequestBuilder
     */
    withUrl(rawUrl: string): MetricValuesRequestBuilder;
}
