import { type UserExperienceAnalyticsDevicePerformanceCollectionResponse } from '../../models/';
import { type UserExperienceAnalyticsDevicePerformance } from '../../models/userExperienceAnalyticsDevicePerformance';
import { CountRequestBuilder } from './count/';
import { UserExperienceAnalyticsDevicePerformanceItemRequestBuilder } from './item/';
import { SummarizeDevicePerformanceDevicesWithSummarizeByRequestBuilder } from './summarizeDevicePerformanceDevicesWithSummarizeBy/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface UserExperienceAnalyticsDevicePerformanceRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the userExperienceAnalyticsDevicePerformance property of the microsoft.graph.deviceManagement entity.
 */
export declare class UserExperienceAnalyticsDevicePerformanceRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the userExperienceAnalyticsDevicePerformance property of the microsoft.graph.deviceManagement entity.
     * @param userExperienceAnalyticsDevicePerformanceId The unique identifier of userExperienceAnalyticsDevicePerformance
     * @returns a UserExperienceAnalyticsDevicePerformanceItemRequestBuilder
     */
    byUserExperienceAnalyticsDevicePerformanceId(userExperienceAnalyticsDevicePerformanceId: string): UserExperienceAnalyticsDevicePerformanceItemRequestBuilder;
    /**
     * Instantiates a new UserExperienceAnalyticsDevicePerformanceRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * User experience analytics device performance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserExperienceAnalyticsDevicePerformanceCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<UserExperienceAnalyticsDevicePerformanceRequestBuilderGetQueryParameters> | undefined): Promise<UserExperienceAnalyticsDevicePerformanceCollectionResponse | undefined>;
    /**
     * Create new navigation property to userExperienceAnalyticsDevicePerformance for deviceManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserExperienceAnalyticsDevicePerformance
     */
    post(body: UserExperienceAnalyticsDevicePerformance, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<UserExperienceAnalyticsDevicePerformance | undefined>;
    /**
     * Provides operations to call the summarizeDevicePerformanceDevices method.
     * @param summarizeBy Usage: summarizeBy='{summarizeBy}'
     * @returns a summarizeDevicePerformanceDevicesWithSummarizeByRequestBuilder
     */
    summarizeDevicePerformanceDevicesWithSummarizeBy(summarizeBy: string | undefined): SummarizeDevicePerformanceDevicesWithSummarizeByRequestBuilder;
    /**
     * User experience analytics device performance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<UserExperienceAnalyticsDevicePerformanceRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to userExperienceAnalyticsDevicePerformance for deviceManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: UserExperienceAnalyticsDevicePerformance, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a userExperienceAnalyticsDevicePerformanceRequestBuilder
     */
    withUrl(rawUrl: string): UserExperienceAnalyticsDevicePerformanceRequestBuilder;
}
