"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DirectoryObjectItemRequestBuilder = void 0;
const directoryObject_1 = require("../../../../models/directoryObject");
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const graphAdministrativeUnit_1 = require("./graphAdministrativeUnit/");
const graphGroup_1 = require("./graphGroup/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the memberOf property of the microsoft.graph.device entity.
 */
class DirectoryObjectItemRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Casts the previous resource to administrativeUnit.
     */
    get graphAdministrativeUnit() {
        return new graphAdministrativeUnit_1.GraphAdministrativeUnitRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Casts the previous resource to group.
     */
    get graphGroup() {
        return new graphGroup_1.GraphGroupRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new DirectoryObjectItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/devices/{device%2Did}/memberOf/{directoryObject%2Did}{?%24select,%24expand}");
    }
    ;
    /**
     * Groups and administrative units that this device is a member of. Read-only. Nullable. Supports $expand.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DirectoryObject
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, directoryObject_1.createDirectoryObjectFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Groups and administrative units that this device is a member of. Read-only. Nullable. Supports $expand.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, directoryObjectItemRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a DirectoryObjectItemRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new DirectoryObjectItemRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.DirectoryObjectItemRequestBuilder = DirectoryObjectItemRequestBuilder;
const directoryObjectItemRequestBuilderGetQueryParametersMapper = {
    "expand": "%24expand",
    "select": "%24select",
};
// tslint:enable
// eslint-enable
