"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RegisteredUsersRequestBuilder = void 0;
const directoryObjectCollectionResponse_1 = require("../../../models/directoryObjectCollectionResponse");
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const count_1 = require("./count/");
const graphAppRoleAssignment_1 = require("./graphAppRoleAssignment/");
const graphEndpoint_1 = require("./graphEndpoint/");
const graphServicePrincipal_1 = require("./graphServicePrincipal/");
const graphUser_1 = require("./graphUser/");
const item_1 = require("./item/");
const ref_1 = require("./ref/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the registeredUsers property of the microsoft.graph.device entity.
 */
class RegisteredUsersRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new count_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Casts the previous resource to appRoleAssignment.
     */
    get graphAppRoleAssignment() {
        return new graphAppRoleAssignment_1.GraphAppRoleAssignmentRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Casts the previous resource to endpoint.
     */
    get graphEndpoint() {
        return new graphEndpoint_1.GraphEndpointRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Casts the previous resource to servicePrincipal.
     */
    get graphServicePrincipal() {
        return new graphServicePrincipal_1.GraphServicePrincipalRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Casts the previous resource to user.
     */
    get graphUser() {
        return new graphUser_1.GraphUserRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the collection of device entities.
     */
    get ref() {
        return new ref_1.RefRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.devices.item.registeredUsers.item collection
     * @param directoryObjectId Unique identifier of the item
     * @returns a DirectoryObjectItemRequestBuilder
     */
    byDirectoryObjectId(directoryObjectId) {
        if (!directoryObjectId)
            throw new Error("directoryObjectId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["directoryObject%2Did"] = directoryObjectId;
        return new item_1.DirectoryObjectItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new RegisteredUsersRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/devices/{device%2Did}/registeredUsers{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * Collection of registered users of the device. For cloud joined devices and registered personal devices, registered users are set to the same value as registered owners at the time of registration. Read-only. Nullable. Supports $expand.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DirectoryObjectCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/device-list-registeredusers?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, directoryObjectCollectionResponse_1.createDirectoryObjectCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Collection of registered users of the device. For cloud joined devices and registered personal devices, registered users are set to the same value as registered owners at the time of registration. Read-only. Nullable. Supports $expand.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, registeredUsersRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a registeredUsersRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new RegisteredUsersRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.RegisteredUsersRequestBuilder = RegisteredUsersRequestBuilder;
const registeredUsersRequestBuilderGetQueryParametersMapper = {
    "count": "%24count",
    "expand": "%24expand",
    "filter": "%24filter",
    "orderby": "%24orderby",
    "search": "%24search",
    "select": "%24select",
    "skip": "%24skip",
    "top": "%24top",
};
// tslint:enable
// eslint-enable
