import { type AllowedValueCollectionResponse } from '../../../../models/';
import { type AllowedValue } from '../../../../models/allowedValue';
import { CountRequestBuilder } from './count/';
import { AllowedValueItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AllowedValuesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the allowedValues property of the microsoft.graph.customSecurityAttributeDefinition entity.
 */
export declare class AllowedValuesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the allowedValues property of the microsoft.graph.customSecurityAttributeDefinition entity.
     * @param allowedValueId The unique identifier of allowedValue
     * @returns a AllowedValueItemRequestBuilder
     */
    byAllowedValueId(allowedValueId: string): AllowedValueItemRequestBuilder;
    /**
     * Instantiates a new AllowedValuesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the allowedValue objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AllowedValueCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/customsecurityattributedefinition-list-allowedvalues?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<AllowedValuesRequestBuilderGetQueryParameters> | undefined): Promise<AllowedValueCollectionResponse | undefined>;
    /**
     * Create a new allowedValue object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AllowedValue
     * @see {@link https://learn.microsoft.com/graph/api/customsecurityattributedefinition-post-allowedvalues?view=graph-rest-1.0|Find more info here}
     */
    post(body: AllowedValue, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AllowedValue | undefined>;
    /**
     * Get a list of the allowedValue objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AllowedValuesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new allowedValue object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AllowedValue, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a allowedValuesRequestBuilder
     */
    withUrl(rawUrl: string): AllowedValuesRequestBuilder;
}
