import { type CustomSecurityAttributeDefinition } from '../../../models/customSecurityAttributeDefinition';
import { AllowedValuesRequestBuilder } from './allowedValues/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface CustomSecurityAttributeDefinitionItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the customSecurityAttributeDefinitions property of the microsoft.graph.directory entity.
 */
export declare class CustomSecurityAttributeDefinitionItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the allowedValues property of the microsoft.graph.customSecurityAttributeDefinition entity.
     */
    get allowedValues(): AllowedValuesRequestBuilder;
    /**
     * Instantiates a new CustomSecurityAttributeDefinitionItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property customSecurityAttributeDefinitions for directory
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of a customSecurityAttributeDefinition object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of CustomSecurityAttributeDefinition
     * @see {@link https://learn.microsoft.com/graph/api/customsecurityattributedefinition-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<CustomSecurityAttributeDefinitionItemRequestBuilderGetQueryParameters> | undefined): Promise<CustomSecurityAttributeDefinition | undefined>;
    /**
     * Update the properties of a customSecurityAttributeDefinition object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of CustomSecurityAttributeDefinition
     * @see {@link https://learn.microsoft.com/graph/api/customsecurityattributedefinition-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: CustomSecurityAttributeDefinition, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<CustomSecurityAttributeDefinition | undefined>;
    /**
     * Delete navigation property customSecurityAttributeDefinitions for directory
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of a customSecurityAttributeDefinition object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<CustomSecurityAttributeDefinitionItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of a customSecurityAttributeDefinition object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: CustomSecurityAttributeDefinition, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a CustomSecurityAttributeDefinitionItemRequestBuilder
     */
    withUrl(rawUrl: string): CustomSecurityAttributeDefinitionItemRequestBuilder;
}
