import { type DeviceLocalCredentialInfoCollectionResponse } from '../../models/';
import { type DeviceLocalCredentialInfo } from '../../models/deviceLocalCredentialInfo';
import { CountRequestBuilder } from './count/';
import { DeviceLocalCredentialInfoItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DeviceLocalCredentialsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the deviceLocalCredentials property of the microsoft.graph.directory entity.
 */
export declare class DeviceLocalCredentialsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the deviceLocalCredentials property of the microsoft.graph.directory entity.
     * @param deviceLocalCredentialInfoId The unique identifier of deviceLocalCredentialInfo
     * @returns a DeviceLocalCredentialInfoItemRequestBuilder
     */
    byDeviceLocalCredentialInfoId(deviceLocalCredentialInfoId: string): DeviceLocalCredentialInfoItemRequestBuilder;
    /**
     * Instantiates a new DeviceLocalCredentialsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the deviceLocalCredentialInfo objects and their properties, excluding the credentials property.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceLocalCredentialInfoCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/directory-list-devicelocalcredentials?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<DeviceLocalCredentialsRequestBuilderGetQueryParameters> | undefined): Promise<DeviceLocalCredentialInfoCollectionResponse | undefined>;
    /**
     * Create new navigation property to deviceLocalCredentials for directory
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceLocalCredentialInfo
     */
    post(body: DeviceLocalCredentialInfo, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DeviceLocalCredentialInfo | undefined>;
    /**
     * Get a list of the deviceLocalCredentialInfo objects and their properties, excluding the credentials property.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DeviceLocalCredentialsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to deviceLocalCredentials for directory
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DeviceLocalCredentialInfo, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a deviceLocalCredentialsRequestBuilder
     */
    withUrl(rawUrl: string): DeviceLocalCredentialsRequestBuilder;
}
