"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeviceLocalCredentialsRequestBuilder = void 0;
const deviceLocalCredentialInfo_1 = require("../../models/deviceLocalCredentialInfo");
const deviceLocalCredentialInfoCollectionResponse_1 = require("../../models/deviceLocalCredentialInfoCollectionResponse");
const oDataError_1 = require("../../models/oDataErrors/oDataError");
const count_1 = require("./count/");
const item_1 = require("./item/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the deviceLocalCredentials property of the microsoft.graph.directory entity.
 */
class DeviceLocalCredentialsRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new count_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the deviceLocalCredentials property of the microsoft.graph.directory entity.
     * @param deviceLocalCredentialInfoId The unique identifier of deviceLocalCredentialInfo
     * @returns a DeviceLocalCredentialInfoItemRequestBuilder
     */
    byDeviceLocalCredentialInfoId(deviceLocalCredentialInfoId) {
        if (!deviceLocalCredentialInfoId)
            throw new Error("deviceLocalCredentialInfoId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["deviceLocalCredentialInfo%2Did"] = deviceLocalCredentialInfoId;
        return new item_1.DeviceLocalCredentialInfoItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new DeviceLocalCredentialsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/directory/deviceLocalCredentials{?%24top,%24search,%24filter,%24count,%24orderby,%24select}");
    }
    ;
    /**
     * Get a list of the deviceLocalCredentialInfo objects and their properties, excluding the credentials property.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceLocalCredentialInfoCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/directory-list-devicelocalcredentials?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, deviceLocalCredentialInfoCollectionResponse_1.createDeviceLocalCredentialInfoCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Create new navigation property to deviceLocalCredentials for directory
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceLocalCredentialInfo
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, deviceLocalCredentialInfo_1.createDeviceLocalCredentialInfoFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Get a list of the deviceLocalCredentialInfo objects and their properties, excluding the credentials property.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, deviceLocalCredentialsRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Create new navigation property to deviceLocalCredentials for directory
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, deviceLocalCredentialInfo_1.serializeDeviceLocalCredentialInfo);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a deviceLocalCredentialsRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new DeviceLocalCredentialsRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.DeviceLocalCredentialsRequestBuilder = DeviceLocalCredentialsRequestBuilder;
const deviceLocalCredentialsRequestBuilderGetQueryParametersMapper = {
    "count": "%24count",
    "filter": "%24filter",
    "orderby": "%24orderby",
    "search": "%24search",
    "select": "%24select",
    "top": "%24top",
};
// tslint:enable
// eslint-enable
