import { type DeviceLocalCredentialInfo } from '../../../models/deviceLocalCredentialInfo';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DeviceLocalCredentialInfoItemRequestBuilderGetQueryParameters {
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the deviceLocalCredentials property of the microsoft.graph.directory entity.
 */
export declare class DeviceLocalCredentialInfoItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new DeviceLocalCredentialInfoItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property deviceLocalCredentials for directory
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties of a deviceLocalCredentialInfo for a specified device object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceLocalCredentialInfo
     * @see {@link https://learn.microsoft.com/graph/api/devicelocalcredentialinfo-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<DeviceLocalCredentialInfoItemRequestBuilderGetQueryParameters> | undefined): Promise<DeviceLocalCredentialInfo | undefined>;
    /**
     * Update the navigation property deviceLocalCredentials in directory
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DeviceLocalCredentialInfo
     */
    patch(body: DeviceLocalCredentialInfo, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DeviceLocalCredentialInfo | undefined>;
    /**
     * Delete navigation property deviceLocalCredentials for directory
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties of a deviceLocalCredentialInfo for a specified device object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DeviceLocalCredentialInfoItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property deviceLocalCredentials in directory
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: DeviceLocalCredentialInfo, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a DeviceLocalCredentialInfoItemRequestBuilder
     */
    withUrl(rawUrl: string): DeviceLocalCredentialInfoItemRequestBuilder;
}
