import { type IdentityProviderBaseCollectionResponse } from '../../models/';
import { type IdentityProviderBase } from '../../models/identityProviderBase';
import { AvailableProviderTypesRequestBuilder } from './availableProviderTypes/';
import { CountRequestBuilder } from './count/';
import { IdentityProviderBaseItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface FederationConfigurationsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the federationConfigurations property of the microsoft.graph.directory entity.
 */
export declare class FederationConfigurationsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the availableProviderTypes method.
     */
    get availableProviderTypes(): AvailableProviderTypesRequestBuilder;
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the federationConfigurations property of the microsoft.graph.directory entity.
     * @param identityProviderBaseId The unique identifier of identityProviderBase
     * @returns a IdentityProviderBaseItemRequestBuilder
     */
    byIdentityProviderBaseId(identityProviderBaseId: string): IdentityProviderBaseItemRequestBuilder;
    /**
     * Instantiates a new FederationConfigurationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Configure domain federation with organizations whose identity provider (IdP) supports either the SAML or WS-Fed protocol.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityProviderBaseCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<FederationConfigurationsRequestBuilderGetQueryParameters> | undefined): Promise<IdentityProviderBaseCollectionResponse | undefined>;
    /**
     * Create new navigation property to federationConfigurations for directory
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityProviderBase
     */
    post(body: IdentityProviderBase, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<IdentityProviderBase | undefined>;
    /**
     * Configure domain federation with organizations whose identity provider (IdP) supports either the SAML or WS-Fed protocol.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<FederationConfigurationsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to federationConfigurations for directory
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: IdentityProviderBase, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a federationConfigurationsRequestBuilder
     */
    withUrl(rawUrl: string): FederationConfigurationsRequestBuilder;
}
