import { type Directory } from '../models/directory';
import { AdministrativeUnitsRequestBuilder } from './administrativeUnits/';
import { AttributeSetsRequestBuilder } from './attributeSets/';
import { CustomSecurityAttributeDefinitionsRequestBuilder } from './customSecurityAttributeDefinitions/';
import { DeletedItemsRequestBuilder } from './deletedItems/';
import { DeviceLocalCredentialsRequestBuilder } from './deviceLocalCredentials/';
import { FederationConfigurationsRequestBuilder } from './federationConfigurations/';
import { OnPremisesSynchronizationRequestBuilder } from './onPremisesSynchronization/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DirectoryRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the directory singleton.
 */
export declare class DirectoryRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the administrativeUnits property of the microsoft.graph.directory entity.
     */
    get administrativeUnits(): AdministrativeUnitsRequestBuilder;
    /**
     * Provides operations to manage the attributeSets property of the microsoft.graph.directory entity.
     */
    get attributeSets(): AttributeSetsRequestBuilder;
    /**
     * Provides operations to manage the customSecurityAttributeDefinitions property of the microsoft.graph.directory entity.
     */
    get customSecurityAttributeDefinitions(): CustomSecurityAttributeDefinitionsRequestBuilder;
    /**
     * Provides operations to manage the deletedItems property of the microsoft.graph.directory entity.
     */
    get deletedItems(): DeletedItemsRequestBuilder;
    /**
     * Provides operations to manage the deviceLocalCredentials property of the microsoft.graph.directory entity.
     */
    get deviceLocalCredentials(): DeviceLocalCredentialsRequestBuilder;
    /**
     * Provides operations to manage the federationConfigurations property of the microsoft.graph.directory entity.
     */
    get federationConfigurations(): FederationConfigurationsRequestBuilder;
    /**
     * Provides operations to manage the onPremisesSynchronization property of the microsoft.graph.directory entity.
     */
    get onPremisesSynchronization(): OnPremisesSynchronizationRequestBuilder;
    /**
     * Instantiates a new DirectoryRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get directory
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Directory
     */
    get(requestConfiguration?: RequestConfiguration<DirectoryRequestBuilderGetQueryParameters> | undefined): Promise<Directory | undefined>;
    /**
     * Update directory
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Directory
     */
    patch(body: Directory, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Directory | undefined>;
    /**
     * Get directory
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DirectoryRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update directory
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Directory, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a directoryRequestBuilder
     */
    withUrl(rawUrl: string): DirectoryRequestBuilder;
}
