import { type InternalDomainFederationCollectionResponse } from '../../../models/';
import { type InternalDomainFederation } from '../../../models/internalDomainFederation';
import { CountRequestBuilder } from './count/';
import { InternalDomainFederationItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface FederationConfigurationRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the federationConfiguration property of the microsoft.graph.domain entity.
 */
export declare class FederationConfigurationRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the federationConfiguration property of the microsoft.graph.domain entity.
     * @param internalDomainFederationId The unique identifier of internalDomainFederation
     * @returns a InternalDomainFederationItemRequestBuilder
     */
    byInternalDomainFederationId(internalDomainFederationId: string): InternalDomainFederationItemRequestBuilder;
    /**
     * Instantiates a new FederationConfigurationRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Read the properties of the internalDomainFederation objects for the domain. This API returns only one object in the collection.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of InternalDomainFederationCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/domain-list-federationconfiguration?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<FederationConfigurationRequestBuilderGetQueryParameters> | undefined): Promise<InternalDomainFederationCollectionResponse | undefined>;
    /**
     * Create a new internalDomainFederation object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of InternalDomainFederation
     * @see {@link https://learn.microsoft.com/graph/api/domain-post-federationconfiguration?view=graph-rest-1.0|Find more info here}
     */
    post(body: InternalDomainFederation, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<InternalDomainFederation | undefined>;
    /**
     * Read the properties of the internalDomainFederation objects for the domain. This API returns only one object in the collection.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<FederationConfigurationRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new internalDomainFederation object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: InternalDomainFederation, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a federationConfigurationRequestBuilder
     */
    withUrl(rawUrl: string): FederationConfigurationRequestBuilder;
}
