"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ForceDeleteRequestBuilder = exports.serializeForceDeletePostRequestBody = exports.deserializeIntoForceDeletePostRequestBody = exports.createForceDeletePostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createForceDeletePostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoForceDeletePostRequestBody;
}
exports.createForceDeletePostRequestBodyFromDiscriminatorValue = createForceDeletePostRequestBodyFromDiscriminatorValue;
function deserializeIntoForceDeletePostRequestBody(forceDeletePostRequestBody = {}) {
    return {
        "disableUserAccounts": n => { forceDeletePostRequestBody.disableUserAccounts = n.getBooleanValue(); },
    };
}
exports.deserializeIntoForceDeletePostRequestBody = deserializeIntoForceDeletePostRequestBody;
function serializeForceDeletePostRequestBody(writer, forceDeletePostRequestBody = {}) {
    writer.writeBooleanValue("disableUserAccounts", forceDeletePostRequestBody.disableUserAccounts);
    writer.writeAdditionalData(forceDeletePostRequestBody.additionalData);
}
exports.serializeForceDeletePostRequestBody = serializeForceDeletePostRequestBody;
/**
 * Provides operations to call the forceDelete method.
 */
class ForceDeleteRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new ForceDeleteRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/domains/{domain%2Did}/forceDelete");
    }
    ;
    /**
     * Deletes a domain using an asynchronous long-running operation. Prior to calling forceDelete, you must update or remove any references to Exchange as the provisioning service. The following actions are performed as part of this operation: After the domain deletion completes, API operations for the deleted domain will return an HTTP 404 status code. To verify deletion of a domain, you can perform a get domain operation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/domain-forcedelete?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Deletes a domain using an asynchronous long-running operation. Prior to calling forceDelete, you must update or remove any references to Exchange as the provisioning service. The following actions are performed as part of this operation: After the domain deletion completes, API operations for the deleted domain will return an HTTP 404 status code. To verify deletion of a domain, you can perform a get domain operation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeForceDeletePostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a forceDeleteRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new ForceDeleteRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.ForceDeleteRequestBuilder = ForceDeleteRequestBuilder;
// tslint:enable
// eslint-enable
