import { type Domain } from '../../models/domain';
import { DomainNameReferencesRequestBuilder } from './domainNameReferences/';
import { FederationConfigurationRequestBuilder } from './federationConfiguration/';
import { ForceDeleteRequestBuilder } from './forceDelete/';
import { PromoteRequestBuilder } from './promote/';
import { ServiceConfigurationRecordsRequestBuilder } from './serviceConfigurationRecords/';
import { VerificationDnsRecordsRequestBuilder } from './verificationDnsRecords/';
import { VerifyRequestBuilder } from './verify/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DomainItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the collection of domain entities.
 */
export declare class DomainItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the domainNameReferences property of the microsoft.graph.domain entity.
     */
    get domainNameReferences(): DomainNameReferencesRequestBuilder;
    /**
     * Provides operations to manage the federationConfiguration property of the microsoft.graph.domain entity.
     */
    get federationConfiguration(): FederationConfigurationRequestBuilder;
    /**
     * Provides operations to call the forceDelete method.
     */
    get forceDelete(): ForceDeleteRequestBuilder;
    /**
     * Provides operations to call the promote method.
     */
    get promote(): PromoteRequestBuilder;
    /**
     * Provides operations to manage the serviceConfigurationRecords property of the microsoft.graph.domain entity.
     */
    get serviceConfigurationRecords(): ServiceConfigurationRecordsRequestBuilder;
    /**
     * Provides operations to manage the verificationDnsRecords property of the microsoft.graph.domain entity.
     */
    get verificationDnsRecords(): VerificationDnsRecordsRequestBuilder;
    /**
     * Provides operations to call the verify method.
     */
    get verify(): VerifyRequestBuilder;
    /**
     * Instantiates a new DomainItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Deletes a domain from a tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/domain-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of domain object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Domain
     * @see {@link https://learn.microsoft.com/graph/api/domain-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<DomainItemRequestBuilderGetQueryParameters> | undefined): Promise<Domain | undefined>;
    /**
     * Update the properties of domain object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Domain
     * @see {@link https://learn.microsoft.com/graph/api/domain-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: Domain, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Domain | undefined>;
    /**
     * Deletes a domain from a tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of domain object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DomainItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of domain object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Domain, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a DomainItemRequestBuilder
     */
    withUrl(rawUrl: string): DomainItemRequestBuilder;
}
