import { type DomainDnsRecordCollectionResponse } from '../../../models/';
import { type DomainDnsRecord } from '../../../models/domainDnsRecord';
import { CountRequestBuilder } from './count/';
import { DomainDnsRecordItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface VerificationDnsRecordsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the verificationDnsRecords property of the microsoft.graph.domain entity.
 */
export declare class VerificationDnsRecordsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the verificationDnsRecords property of the microsoft.graph.domain entity.
     * @param domainDnsRecordId The unique identifier of domainDnsRecord
     * @returns a DomainDnsRecordItemRequestBuilder
     */
    byDomainDnsRecordId(domainDnsRecordId: string): DomainDnsRecordItemRequestBuilder;
    /**
     * Instantiates a new VerificationDnsRecordsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of domainDnsRecord objects. You cannot use an associated domain with your Microsoft Entra tenant until ownership is verified. To verify the ownership of the domain, retrieve the domain verification records and add the details to the zone file of the domain. This can be done through the domain registrar or DNS server configuration. Root domains require verification. For example, contoso.com requires verification. If a root domain is verified, subdomains of the root domain are automatically verified. For example, subdomain.contoso.com is automatically be verified if contoso.com has been verified.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DomainDnsRecordCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/domain-list-verificationdnsrecords?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<VerificationDnsRecordsRequestBuilderGetQueryParameters> | undefined): Promise<DomainDnsRecordCollectionResponse | undefined>;
    /**
     * Create new navigation property to verificationDnsRecords for domains
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DomainDnsRecord
     */
    post(body: DomainDnsRecord, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DomainDnsRecord | undefined>;
    /**
     * Retrieve a list of domainDnsRecord objects. You cannot use an associated domain with your Microsoft Entra tenant until ownership is verified. To verify the ownership of the domain, retrieve the domain verification records and add the details to the zone file of the domain. This can be done through the domain registrar or DNS server configuration. Root domains require verification. For example, contoso.com requires verification. If a root domain is verified, subdomains of the root domain are automatically verified. For example, subdomain.contoso.com is automatically be verified if contoso.com has been verified.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<VerificationDnsRecordsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to verificationDnsRecords for domains
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DomainDnsRecord, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a verificationDnsRecordsRequestBuilder
     */
    withUrl(rawUrl: string): VerificationDnsRecordsRequestBuilder;
}
