import { type DriveCollectionResponse } from '../models/';
import { type Drive } from '../models/drive';
import { DriveItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DrivesRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the collection of drive entities.
 */
export declare class DrivesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the collection of drive entities.
     * @param driveId The unique identifier of drive
     * @returns a DriveItemRequestBuilder
     */
    byDriveId(driveId: string): DriveItemRequestBuilder;
    /**
     * Instantiates a new DrivesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get entities from drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DriveCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<DrivesRequestBuilderGetQueryParameters> | undefined): Promise<DriveCollectionResponse | undefined>;
    /**
     * Add new entity to drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Drive
     */
    post(body: Drive, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Drive | undefined>;
    /**
     * Get entities from drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DrivesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Add new entity to drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: Drive, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a drivesRequestBuilder
     */
    withUrl(rawUrl: string): DrivesRequestBuilder;
}
