"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CheckinRequestBuilder = exports.serializeCheckinPostRequestBody = exports.deserializeIntoCheckinPostRequestBody = exports.createCheckinPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createCheckinPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoCheckinPostRequestBody;
}
exports.createCheckinPostRequestBodyFromDiscriminatorValue = createCheckinPostRequestBodyFromDiscriminatorValue;
function deserializeIntoCheckinPostRequestBody(checkinPostRequestBody = {}) {
    return {
        "checkInAs": n => { checkinPostRequestBody.checkInAs = n.getStringValue(); },
        "comment": n => { checkinPostRequestBody.comment = n.getStringValue(); },
    };
}
exports.deserializeIntoCheckinPostRequestBody = deserializeIntoCheckinPostRequestBody;
function serializeCheckinPostRequestBody(writer, checkinPostRequestBody = {}) {
    writer.writeStringValue("checkInAs", checkinPostRequestBody.checkInAs);
    writer.writeStringValue("comment", checkinPostRequestBody.comment);
    writer.writeAdditionalData(checkinPostRequestBody.additionalData);
}
exports.serializeCheckinPostRequestBody = serializeCheckinPostRequestBody;
/**
 * Provides operations to call the checkin method.
 */
class CheckinRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new CheckinRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/drives/{drive%2Did}/items/{driveItem%2Did}/checkin");
    }
    ;
    /**
     * Check in a checked out driveItem resource, which makes the version of the document available to others.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/driveitem-checkin?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Check in a checked out driveItem resource, which makes the version of the document available to others.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeCheckinPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a checkinRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new CheckinRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.CheckinRequestBuilder = CheckinRequestBuilder;
// tslint:enable
// eslint-enable
