import { type DriveItem } from '../../../../../models/driveItem';
import { type ItemReference } from '../../../../../models/itemReference';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export interface CopyPostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The name property
     */
    name?: string;
    /**
     * The parentReference property
     */
    parentReference?: ItemReference;
}
export declare function createCopyPostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoCopyPostRequestBody;
export declare function deserializeIntoCopyPostRequestBody(copyPostRequestBody?: CopyPostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeCopyPostRequestBody(writer: SerializationWriter, copyPostRequestBody?: CopyPostRequestBody | undefined): void;
/**
 * Provides operations to call the copy method.
 */
export declare class CopyRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new CopyRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Asynchronously creates a copy of an [driveItem][item-resource] (including any children), under a new parent item or with a new name.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DriveItem
     * @see {@link https://learn.microsoft.com/graph/api/driveitem-copy?view=graph-rest-1.0|Find more info here}
     */
    post(body: CopyPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DriveItem | undefined>;
    /**
     * Asynchronously creates a copy of an [driveItem][item-resource] (including any children), under a new parent item or with a new name.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: CopyPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a copyRequestBuilder
     */
    withUrl(rawUrl: string): CopyRequestBuilder;
}
