import { type BaseCollectionPaginationCountResponse } from '../../../../../models/baseCollectionPaginationCountResponse';
import { type DriveRecipient } from '../../../../../models/driveRecipient';
import { type Permission } from '../../../../../models/permission';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createInvitePostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoInvitePostRequestBody;
export declare function createInvitePostResponseFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoInvitePostResponse;
export declare function deserializeIntoInvitePostRequestBody(invitePostRequestBody?: InvitePostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export declare function deserializeIntoInvitePostResponse(invitePostResponse?: InvitePostResponse | undefined): Record<string, (node: ParseNode) => void>;
export interface InvitePostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The expirationDateTime property
     */
    expirationDateTime?: string;
    /**
     * The message property
     */
    message?: string;
    /**
     * The password property
     */
    password?: string;
    /**
     * The recipients property
     */
    recipients?: DriveRecipient[];
    /**
     * The requireSignIn property
     */
    requireSignIn?: boolean;
    /**
     * The retainInheritedPermissions property
     */
    retainInheritedPermissions?: boolean;
    /**
     * The roles property
     */
    roles?: string[];
    /**
     * The sendInvitation property
     */
    sendInvitation?: boolean;
}
export interface InvitePostResponse extends BaseCollectionPaginationCountResponse, Parsable {
    /**
     * The value property
     */
    value?: Permission[];
}
export declare function serializeInvitePostRequestBody(writer: SerializationWriter, invitePostRequestBody?: InvitePostRequestBody | undefined): void;
export declare function serializeInvitePostResponse(writer: SerializationWriter, invitePostResponse?: InvitePostResponse | undefined): void;
/**
 * Provides operations to call the invite method.
 */
export declare class InviteRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new InviteRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Sends a sharing invitation for a driveItem.A sharing invitation provides permissions to the recipients and optionally sends them an email with a [sharing link][].
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of InvitePostResponse
     * @see {@link https://learn.microsoft.com/graph/api/driveitem-invite?view=graph-rest-1.0|Find more info here}
     */
    post(body: InvitePostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<InvitePostResponse | undefined>;
    /**
     * Sends a sharing invitation for a driveItem.A sharing invitation provides permissions to the recipients and optionally sends them an email with a [sharing link][].
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: InvitePostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a inviteRequestBuilder
     */
    withUrl(rawUrl: string): InviteRequestBuilder;
}
