import { type DriveItem } from '../../../../../models/driveItem';
import { type ItemReference } from '../../../../../models/itemReference';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createRestorePostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoRestorePostRequestBody;
export declare function deserializeIntoRestorePostRequestBody(restorePostRequestBody?: RestorePostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export interface RestorePostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The name property
     */
    name?: string;
    /**
     * The parentReference property
     */
    parentReference?: ItemReference;
}
export declare function serializeRestorePostRequestBody(writer: SerializationWriter, restorePostRequestBody?: RestorePostRequestBody | undefined): void;
/**
 * Provides operations to call the restore method.
 */
export declare class RestoreRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new RestoreRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Restore a driveItem that has been deleted and is currently in the recycle bin. NOTE: This functionality is currently only available for OneDrive Personal.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DriveItem
     * @see {@link https://learn.microsoft.com/graph/api/driveitem-restore?view=graph-rest-1.0|Find more info here}
     */
    post(body: RestorePostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DriveItem | undefined>;
    /**
     * Restore a driveItem that has been deleted and is currently in the recycle bin. NOTE: This functionality is currently only available for OneDrive Personal.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: RestorePostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a restoreRequestBuilder
     */
    withUrl(rawUrl: string): RestoreRequestBuilder;
}
