import { type ThumbnailSet } from '../../../../../../models/thumbnailSet';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ThumbnailSetItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the thumbnails property of the microsoft.graph.driveItem entity.
 */
export declare class ThumbnailSetItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new ThumbnailSetItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property thumbnails for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Collection of [thumbnailSet][] objects associated with the item. For more information, see [getting thumbnails][]. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ThumbnailSet
     */
    get(requestConfiguration?: RequestConfiguration<ThumbnailSetItemRequestBuilderGetQueryParameters> | undefined): Promise<ThumbnailSet | undefined>;
    /**
     * Update the navigation property thumbnails in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ThumbnailSet
     */
    patch(body: ThumbnailSet, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ThumbnailSet | undefined>;
    /**
     * Delete navigation property thumbnails for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Collection of [thumbnailSet][] objects associated with the item. For more information, see [getting thumbnails][]. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ThumbnailSetItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property thumbnails in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ThumbnailSet, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ThumbnailSetItemRequestBuilder
     */
    withUrl(rawUrl: string): ThumbnailSetItemRequestBuilder;
}
