import { type DriveItemVersion } from '../../../../../../models/driveItemVersion';
import { ContentRequestBuilder } from './content/';
import { RestoreVersionRequestBuilder } from './restoreVersion/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DriveItemVersionItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the versions property of the microsoft.graph.driveItem entity.
 */
export declare class DriveItemVersionItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the media for the drive entity.
     */
    get content(): ContentRequestBuilder;
    /**
     * Provides operations to call the restoreVersion method.
     */
    get restoreVersion(): RestoreVersionRequestBuilder;
    /**
     * Instantiates a new DriveItemVersionItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property versions for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the metadata for a specific version of a DriveItem.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DriveItemVersion
     * @see {@link https://learn.microsoft.com/graph/api/driveitemversion-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<DriveItemVersionItemRequestBuilderGetQueryParameters> | undefined): Promise<DriveItemVersion | undefined>;
    /**
     * Update the navigation property versions in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DriveItemVersion
     */
    patch(body: DriveItemVersion, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DriveItemVersion | undefined>;
    /**
     * Delete navigation property versions for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the metadata for a specific version of a DriveItem.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DriveItemVersionItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property versions in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: DriveItemVersion, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a DriveItemVersionItemRequestBuilder
     */
    withUrl(rawUrl: string): DriveItemVersionItemRequestBuilder;
}
