import { type WorkbookCommentReplyCollectionResponse } from '../../../../../../../../models/';
import { type WorkbookCommentReply } from '../../../../../../../../models/workbookCommentReply';
import { CountRequestBuilder } from './count/';
import { WorkbookCommentReplyItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface RepliesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the replies property of the microsoft.graph.workbookComment entity.
 */
export declare class RepliesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the replies property of the microsoft.graph.workbookComment entity.
     * @param workbookCommentReplyId The unique identifier of workbookCommentReply
     * @returns a WorkbookCommentReplyItemRequestBuilder
     */
    byWorkbookCommentReplyId(workbookCommentReplyId: string): WorkbookCommentReplyItemRequestBuilder;
    /**
     * Instantiates a new RepliesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the properties and relationships of workbookCommentReply object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookCommentReplyCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<RepliesRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookCommentReplyCollectionResponse | undefined>;
    /**
     * Create new navigation property to replies for drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookCommentReply
     */
    post(body: WorkbookCommentReply, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookCommentReply | undefined>;
    /**
     * Retrieve the properties and relationships of workbookCommentReply object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<RepliesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to replies for drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: WorkbookCommentReply, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a repliesRequestBuilder
     */
    withUrl(rawUrl: string): RepliesRequestBuilder;
}
