"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CreateSessionRequestBuilder = exports.serializeCreateSessionPostRequestBody = exports.deserializeIntoCreateSessionPostRequestBody = exports.createCreateSessionPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../../../models/oDataErrors/oDataError");
const workbookSessionInfo_1 = require("../../../../../../models/workbookSessionInfo");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createCreateSessionPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoCreateSessionPostRequestBody;
}
exports.createCreateSessionPostRequestBodyFromDiscriminatorValue = createCreateSessionPostRequestBodyFromDiscriminatorValue;
function deserializeIntoCreateSessionPostRequestBody(createSessionPostRequestBody = {}) {
    return {
        "persistChanges": n => { createSessionPostRequestBody.persistChanges = n.getBooleanValue(); },
    };
}
exports.deserializeIntoCreateSessionPostRequestBody = deserializeIntoCreateSessionPostRequestBody;
function serializeCreateSessionPostRequestBody(writer, createSessionPostRequestBody = {}) {
    writer.writeBooleanValue("persistChanges", createSessionPostRequestBody.persistChanges);
    writer.writeAdditionalData(createSessionPostRequestBody.additionalData);
}
exports.serializeCreateSessionPostRequestBody = serializeCreateSessionPostRequestBody;
/**
 * Provides operations to call the createSession method.
 */
class CreateSessionRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new CreateSessionRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/drives/{drive%2Did}/items/{driveItem%2Did}/workbook/createSession");
    }
    ;
    /**
     * Create a new workbook session.  Excel APIs can be called in one of two modes:  To represent the session in the API, use the workbook-session-id: {session-id} header.  In some cases, creating a new session requires an indeterminate time to complete. Microsoft Graph also provides a long running operations pattern. This pattern provides a way to poll for creation status updates, without waiting for the creation to complete. The following are the steps:
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookSessionInfo
     * @see {@link https://learn.microsoft.com/graph/api/workbook-createsession?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, workbookSessionInfo_1.createWorkbookSessionInfoFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Create a new workbook session.  Excel APIs can be called in one of two modes:  To represent the session in the API, use the workbook-session-id: {session-id} header.  In some cases, creating a new session requires an indeterminate time to complete. Microsoft Graph also provides a long running operations pattern. This pattern provides a way to poll for creation status updates, without waiting for the creation to complete. The following are the steps:
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeCreateSessionPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a createSessionRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new CreateSessionRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.CreateSessionRequestBuilder = CreateSessionRequestBuilder;
// tslint:enable
// eslint-enable
