import { type Workbook } from '../../../../../models/workbook';
import { ApplicationRequestBuilder } from './application/';
import { CloseSessionRequestBuilder } from './closeSession/';
import { CommentsRequestBuilder } from './comments/';
import { CreateSessionRequestBuilder } from './createSession/';
import { FunctionsRequestBuilder } from './functions/';
import { NamesRequestBuilder } from './names/';
import { OperationsRequestBuilder } from './operations/';
import { RefreshSessionRequestBuilder } from './refreshSession/';
import { SessionInfoResourceWithKeyRequestBuilder } from './sessionInfoResourceWithKey/';
import { TableRowOperationResultWithKeyRequestBuilder } from './tableRowOperationResultWithKey/';
import { TablesRequestBuilder } from './tables/';
import { WorksheetsRequestBuilder } from './worksheets/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface WorkbookRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the workbook property of the microsoft.graph.driveItem entity.
 */
export declare class WorkbookRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the application property of the microsoft.graph.workbook entity.
     */
    get application(): ApplicationRequestBuilder;
    /**
     * Provides operations to call the closeSession method.
     */
    get closeSession(): CloseSessionRequestBuilder;
    /**
     * Provides operations to manage the comments property of the microsoft.graph.workbook entity.
     */
    get comments(): CommentsRequestBuilder;
    /**
     * Provides operations to call the createSession method.
     */
    get createSession(): CreateSessionRequestBuilder;
    /**
     * Provides operations to manage the functions property of the microsoft.graph.workbook entity.
     */
    get functions(): FunctionsRequestBuilder;
    /**
     * Provides operations to manage the names property of the microsoft.graph.workbook entity.
     */
    get names(): NamesRequestBuilder;
    /**
     * Provides operations to manage the operations property of the microsoft.graph.workbook entity.
     */
    get operations(): OperationsRequestBuilder;
    /**
     * Provides operations to call the refreshSession method.
     */
    get refreshSession(): RefreshSessionRequestBuilder;
    /**
     * Provides operations to manage the tables property of the microsoft.graph.workbook entity.
     */
    get tables(): TablesRequestBuilder;
    /**
     * Provides operations to manage the worksheets property of the microsoft.graph.workbook entity.
     */
    get worksheets(): WorksheetsRequestBuilder;
    /**
     * Instantiates a new WorkbookRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property workbook for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * For files that are Excel spreadsheets, access to the workbook API to work with the spreadsheet's contents. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Workbook
     */
    get(requestConfiguration?: RequestConfiguration<WorkbookRequestBuilderGetQueryParameters> | undefined): Promise<Workbook | undefined>;
    /**
     * Update the navigation property workbook in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Workbook
     */
    patch(body: Workbook, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Workbook | undefined>;
    /**
     * Provides operations to call the sessionInfoResource method.
     * @param key Usage: key='{key}'
     * @returns a sessionInfoResourceWithKeyRequestBuilder
     */
    sessionInfoResourceWithKey(key: string | undefined): SessionInfoResourceWithKeyRequestBuilder;
    /**
     * Provides operations to call the tableRowOperationResult method.
     * @param key Usage: key='{key}'
     * @returns a tableRowOperationResultWithKeyRequestBuilder
     */
    tableRowOperationResultWithKey(key: string | undefined): TableRowOperationResultWithKeyRequestBuilder;
    /**
     * Delete navigation property workbook for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * For files that are Excel spreadsheets, access to the workbook API to work with the spreadsheet's contents. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<WorkbookRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property workbook in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Workbook, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a workbookRequestBuilder
     */
    withUrl(rawUrl: string): WorkbookRequestBuilder;
}
