"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FilterRequestBuilder = void 0;
const oDataError_1 = require("../../../../../../../../../../models/oDataErrors/oDataError");
const workbookFilter_1 = require("../../../../../../../../../../models/workbookFilter");
const apply_1 = require("./apply/");
const applyBottomItemsFilter_1 = require("./applyBottomItemsFilter/");
const applyBottomPercentFilter_1 = require("./applyBottomPercentFilter/");
const applyCellColorFilter_1 = require("./applyCellColorFilter/");
const applyCustomFilter_1 = require("./applyCustomFilter/");
const applyDynamicFilter_1 = require("./applyDynamicFilter/");
const applyFontColorFilter_1 = require("./applyFontColorFilter/");
const applyIconFilter_1 = require("./applyIconFilter/");
const applyTopItemsFilter_1 = require("./applyTopItemsFilter/");
const applyTopPercentFilter_1 = require("./applyTopPercentFilter/");
const applyValuesFilter_1 = require("./applyValuesFilter/");
const clear_1 = require("./clear/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the filter property of the microsoft.graph.workbookTableColumn entity.
 */
class FilterRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to call the apply method.
     */
    get apply() {
        return new apply_1.ApplyRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyBottomItemsFilter method.
     */
    get applyBottomItemsFilter() {
        return new applyBottomItemsFilter_1.ApplyBottomItemsFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyBottomPercentFilter method.
     */
    get applyBottomPercentFilter() {
        return new applyBottomPercentFilter_1.ApplyBottomPercentFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyCellColorFilter method.
     */
    get applyCellColorFilter() {
        return new applyCellColorFilter_1.ApplyCellColorFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyCustomFilter method.
     */
    get applyCustomFilter() {
        return new applyCustomFilter_1.ApplyCustomFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyDynamicFilter method.
     */
    get applyDynamicFilter() {
        return new applyDynamicFilter_1.ApplyDynamicFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyFontColorFilter method.
     */
    get applyFontColorFilter() {
        return new applyFontColorFilter_1.ApplyFontColorFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyIconFilter method.
     */
    get applyIconFilter() {
        return new applyIconFilter_1.ApplyIconFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyTopItemsFilter method.
     */
    get applyTopItemsFilter() {
        return new applyTopItemsFilter_1.ApplyTopItemsFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyTopPercentFilter method.
     */
    get applyTopPercentFilter() {
        return new applyTopPercentFilter_1.ApplyTopPercentFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the applyValuesFilter method.
     */
    get applyValuesFilter() {
        return new applyValuesFilter_1.ApplyValuesFilterRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the clear method.
     */
    get clear() {
        return new clear_1.ClearRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new FilterRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/drives/{drive%2Did}/items/{driveItem%2Did}/workbook/tables/{workbookTable%2Did}/columns/{workbookTableColumn%2Did}/filter{?%24select,%24expand}");
    }
    ;
    /**
     * Delete navigation property filter for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration) {
        const requestInfo = this.toDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Retrieve the filter applied to the column. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookFilter
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, workbookFilter_1.createWorkbookFilterFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Update the navigation property filter in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookFilter
     */
    patch(body, requestConfiguration) {
        const requestInfo = this.toPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, workbookFilter_1.createWorkbookFilterFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Delete navigation property filter for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.DELETE, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Retrieve the filter applied to the column. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, filterRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property filter in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.PATCH, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, workbookFilter_1.serializeWorkbookFilter);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a filterRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new FilterRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.FilterRequestBuilder = FilterRequestBuilder;
const filterRequestBuilderGetQueryParametersMapper = {
    "expand": "%24expand",
    "select": "%24select",
};
// tslint:enable
// eslint-enable
