import { type WorkbookTableRow } from '../../../../../../../../../models/workbookTableRow';
import { RangeRequestBuilder } from './range/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface WorkbookTableRowItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the rows property of the microsoft.graph.workbookTable entity.
 */
export declare class WorkbookTableRowItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the range method.
     */
    get range(): RangeRequestBuilder;
    /**
     * Instantiates a new WorkbookTableRowItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Deletes the row from the table.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/tablerow-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of tablerow object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookTableRow
     * @see {@link https://learn.microsoft.com/graph/api/tablerow-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<WorkbookTableRowItemRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookTableRow | undefined>;
    /**
     * Update the properties of tablerow object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookTableRow
     * @see {@link https://learn.microsoft.com/graph/api/tablerow-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: WorkbookTableRow, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookTableRow | undefined>;
    /**
     * Deletes the row from the table.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of tablerow object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<WorkbookTableRowItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of tablerow object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookTableRow, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a WorkbookTableRowItemRequestBuilder
     */
    withUrl(rawUrl: string): WorkbookTableRowItemRequestBuilder;
}
