import { type WorkbookChartCollectionResponse } from '../../../../../../../../models/';
import { type WorkbookChart } from '../../../../../../../../models/workbookChart';
import { AddRequestBuilder } from './add/';
import { CountRequestBuilder } from './count/';
import { WorkbookChartItemRequestBuilder } from './item/';
import { ItemAtWithIndexRequestBuilder } from './itemAtWithIndex/';
import { ItemWithNameRequestBuilder } from './itemWithName/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ChartsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the charts property of the microsoft.graph.workbookWorksheet entity.
 */
export declare class ChartsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the add method.
     */
    get add(): AddRequestBuilder;
    /**
     * Provides operations to call the count method.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the charts property of the microsoft.graph.workbookWorksheet entity.
     * @param workbookChartId The unique identifier of workbookChart
     * @returns a WorkbookChartItemRequestBuilder
     */
    byWorkbookChartId(workbookChartId: string): WorkbookChartItemRequestBuilder;
    /**
     * Instantiates a new ChartsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of chart objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/worksheet-list-charts?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ChartsRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookChartCollectionResponse | undefined>;
    /**
     * Provides operations to call the itemAt method.
     * @param index Usage: index={index}
     * @returns a itemAtWithIndexRequestBuilder
     */
    itemAtWithIndex(index: number | undefined): ItemAtWithIndexRequestBuilder;
    /**
     * Provides operations to call the item method.
     * @param name Usage: name='{name}'
     * @returns a itemWithNameRequestBuilder
     */
    itemWithName(name: string | undefined): ItemWithNameRequestBuilder;
    /**
     * Use this API to create a new Chart.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChart
     * @see {@link https://learn.microsoft.com/graph/api/worksheet-post-charts?view=graph-rest-1.0|Find more info here}
     */
    post(body: WorkbookChart, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookChart | undefined>;
    /**
     * Retrieve a list of chart objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ChartsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Use this API to create a new Chart.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: WorkbookChart, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a chartsRequestBuilder
     */
    withUrl(rawUrl: string): ChartsRequestBuilder;
}
