"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChartsRequestBuilder = void 0;
const oDataError_1 = require("../../../../../../../../models/oDataErrors/oDataError");
const workbookChart_1 = require("../../../../../../../../models/workbookChart");
const workbookChartCollectionResponse_1 = require("../../../../../../../../models/workbookChartCollectionResponse");
const add_1 = require("./add/");
const count_1 = require("./count/");
const item_1 = require("./item/");
const itemAtWithIndex_1 = require("./itemAtWithIndex/");
const itemWithName_1 = require("./itemWithName/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the charts property of the microsoft.graph.workbookWorksheet entity.
 */
class ChartsRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to call the add method.
     */
    get add() {
        return new add_1.AddRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the count method.
     */
    get count() {
        return new count_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the charts property of the microsoft.graph.workbookWorksheet entity.
     * @param workbookChartId The unique identifier of workbookChart
     * @returns a WorkbookChartItemRequestBuilder
     */
    byWorkbookChartId(workbookChartId) {
        if (!workbookChartId)
            throw new Error("workbookChartId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["workbookChart%2Did"] = workbookChartId;
        return new item_1.WorkbookChartItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new ChartsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/drives/{drive%2Did}/items/{driveItem%2Did}/workbook/worksheets/{workbookWorksheet%2Did}/charts{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * Retrieve a list of chart objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/worksheet-list-charts?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, workbookChartCollectionResponse_1.createWorkbookChartCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Provides operations to call the itemAt method.
     * @param index Usage: index={index}
     * @returns a itemAtWithIndexRequestBuilder
     */
    itemAtWithIndex(index) {
        if (!index)
            throw new Error("index cannot be undefined");
        return new itemAtWithIndex_1.ItemAtWithIndexRequestBuilder(this.pathParameters, this.requestAdapter, index);
    }
    ;
    /**
     * Provides operations to call the item method.
     * @param name Usage: name='{name}'
     * @returns a itemWithNameRequestBuilder
     */
    itemWithName(name) {
        if (!name)
            throw new Error("name cannot be undefined");
        return new itemWithName_1.ItemWithNameRequestBuilder(this.pathParameters, this.requestAdapter, name);
    }
    ;
    /**
     * Use this API to create a new Chart.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChart
     * @see {@link https://learn.microsoft.com/graph/api/worksheet-post-charts?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, workbookChart_1.createWorkbookChartFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Retrieve a list of chart objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, chartsRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Use this API to create a new Chart.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, workbookChart_1.serializeWorkbookChart);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a chartsRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new ChartsRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.ChartsRequestBuilder = ChartsRequestBuilder;
const chartsRequestBuilderGetQueryParametersMapper = {
    "count": "%24count",
    "expand": "%24expand",
    "filter": "%24filter",
    "orderby": "%24orderby",
    "search": "%24search",
    "select": "%24select",
    "skip": "%24skip",
    "top": "%24top",
};
// tslint:enable
// eslint-enable
