import { type WorkbookChartAxisTitle } from '../../../../../../../../../../../../models/workbookChartAxisTitle';
import { FormatRequestBuilder } from './format/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface TitleRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the title property of the microsoft.graph.workbookChartAxis entity.
 */
export declare class TitleRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the format property of the microsoft.graph.workbookChartAxisTitle entity.
     */
    get format(): FormatRequestBuilder;
    /**
     * Instantiates a new TitleRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property title for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of chartaxistitle object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartAxisTitle
     * @see {@link https://learn.microsoft.com/graph/api/chartaxistitle-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<TitleRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookChartAxisTitle | undefined>;
    /**
     * Update the properties of chartaxistitle object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartAxisTitle
     * @see {@link https://learn.microsoft.com/graph/api/chartaxistitle-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: WorkbookChartAxisTitle, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookChartAxisTitle | undefined>;
    /**
     * Delete navigation property title for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of chartaxistitle object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<TitleRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of chartaxistitle object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookChartAxisTitle, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a titleRequestBuilder
     */
    withUrl(rawUrl: string): TitleRequestBuilder;
}
