import { type WorkbookChartAxis } from '../../../../../../../../../../../models/workbookChartAxis';
import { FormatRequestBuilder } from './format/';
import { MajorGridlinesRequestBuilder } from './majorGridlines/';
import { MinorGridlinesRequestBuilder } from './minorGridlines/';
import { TitleRequestBuilder } from './title/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ValueAxisRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the valueAxis property of the microsoft.graph.workbookChartAxes entity.
 */
export declare class ValueAxisRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the format property of the microsoft.graph.workbookChartAxis entity.
     */
    get format(): FormatRequestBuilder;
    /**
     * Provides operations to manage the majorGridlines property of the microsoft.graph.workbookChartAxis entity.
     */
    get majorGridlines(): MajorGridlinesRequestBuilder;
    /**
     * Provides operations to manage the minorGridlines property of the microsoft.graph.workbookChartAxis entity.
     */
    get minorGridlines(): MinorGridlinesRequestBuilder;
    /**
     * Provides operations to manage the title property of the microsoft.graph.workbookChartAxis entity.
     */
    get title(): TitleRequestBuilder;
    /**
     * Instantiates a new ValueAxisRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property valueAxis for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of chartaxis object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartAxis
     * @see {@link https://learn.microsoft.com/graph/api/chartaxis-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ValueAxisRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookChartAxis | undefined>;
    /**
     * Update the properties of chartaxis object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartAxis
     * @see {@link https://learn.microsoft.com/graph/api/chartaxis-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: WorkbookChartAxis, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookChartAxis | undefined>;
    /**
     * Delete navigation property valueAxis for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of chartaxis object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ValueAxisRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of chartaxis object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookChartAxis, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a valueAxisRequestBuilder
     */
    withUrl(rawUrl: string): ValueAxisRequestBuilder;
}
