import { type WorkbookChartAreaFormat } from '../../../../../../../../../../models/workbookChartAreaFormat';
import { FillRequestBuilder } from './fill/';
import { FontRequestBuilder } from './font/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface FormatRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the format property of the microsoft.graph.workbookChart entity.
 */
export declare class FormatRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the fill property of the microsoft.graph.workbookChartAreaFormat entity.
     */
    get fill(): FillRequestBuilder;
    /**
     * Provides operations to manage the font property of the microsoft.graph.workbookChartAreaFormat entity.
     */
    get font(): FontRequestBuilder;
    /**
     * Instantiates a new FormatRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property format for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Encapsulates the format properties for the chart area. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartAreaFormat
     */
    get(requestConfiguration?: RequestConfiguration<FormatRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookChartAreaFormat | undefined>;
    /**
     * Update the navigation property format in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartAreaFormat
     */
    patch(body: WorkbookChartAreaFormat, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookChartAreaFormat | undefined>;
    /**
     * Delete navigation property format for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Encapsulates the format properties for the chart area. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<FormatRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property format in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookChartAreaFormat, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a formatRequestBuilder
     */
    withUrl(rawUrl: string): FormatRequestBuilder;
}
