import { type WorkbookChart } from '../../../../../../../../../models/workbookChart';
import { AxesRequestBuilder } from './axes/';
import { DataLabelsRequestBuilder } from './dataLabels/';
import { FormatRequestBuilder } from './format/';
import { ImageRequestBuilder } from './image/';
import { ImageWithWidthRequestBuilder } from './imageWithWidth/';
import { ImageWithWidthWithHeightRequestBuilder } from './imageWithWidthWithHeight/';
import { ImageWithWidthWithHeightWithFittingModeRequestBuilder } from './imageWithWidthWithHeightWithFittingMode/';
import { LegendRequestBuilder } from './legend/';
import { SeriesRequestBuilder } from './series/';
import { SetDataRequestBuilder } from './setData/';
import { SetPositionRequestBuilder } from './setPosition/';
import { TitleRequestBuilder } from './title/';
import { WorksheetRequestBuilder } from './worksheet/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface WorkbookChartItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the charts property of the microsoft.graph.workbookWorksheet entity.
 */
export declare class WorkbookChartItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the axes property of the microsoft.graph.workbookChart entity.
     */
    get axes(): AxesRequestBuilder;
    /**
     * Provides operations to manage the dataLabels property of the microsoft.graph.workbookChart entity.
     */
    get dataLabels(): DataLabelsRequestBuilder;
    /**
     * Provides operations to manage the format property of the microsoft.graph.workbookChart entity.
     */
    get format(): FormatRequestBuilder;
    /**
     * Provides operations to call the image method.
     */
    get image(): ImageRequestBuilder;
    /**
     * Provides operations to manage the legend property of the microsoft.graph.workbookChart entity.
     */
    get legend(): LegendRequestBuilder;
    /**
     * Provides operations to manage the series property of the microsoft.graph.workbookChart entity.
     */
    get series(): SeriesRequestBuilder;
    /**
     * Provides operations to call the setData method.
     */
    get setData(): SetDataRequestBuilder;
    /**
     * Provides operations to call the setPosition method.
     */
    get setPosition(): SetPositionRequestBuilder;
    /**
     * Provides operations to manage the title property of the microsoft.graph.workbookChart entity.
     */
    get title(): TitleRequestBuilder;
    /**
     * Provides operations to manage the worksheet property of the microsoft.graph.workbookChart entity.
     */
    get worksheet(): WorksheetRequestBuilder;
    /**
     * Instantiates a new WorkbookChartItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Deletes the chart object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/chart-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of chart object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChart
     * @see {@link https://learn.microsoft.com/graph/api/chart-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<WorkbookChartItemRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookChart | undefined>;
    /**
     * Provides operations to call the image method.
     * @param width Usage: width={width}
     * @returns a imageWithWidthRequestBuilder
     */
    imageWithWidth(width: number | undefined): ImageWithWidthRequestBuilder;
    /**
     * Provides operations to call the image method.
     * @param height Usage: height={height}
     * @param width Usage: width={width}
     * @returns a imageWithWidthWithHeightRequestBuilder
     */
    imageWithWidthWithHeight(height: number | undefined, width: number | undefined): ImageWithWidthWithHeightRequestBuilder;
    /**
     * Provides operations to call the image method.
     * @param fittingMode Usage: fittingMode='{fittingMode}'
     * @param height Usage: height={height}
     * @param width Usage: width={width}
     * @returns a imageWithWidthWithHeightWithFittingModeRequestBuilder
     */
    imageWithWidthWithHeightWithFittingMode(fittingMode: string | undefined, height: number | undefined, width: number | undefined): ImageWithWidthWithHeightWithFittingModeRequestBuilder;
    /**
     * Update the properties of chart object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChart
     * @see {@link https://learn.microsoft.com/graph/api/chart-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: WorkbookChart, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookChart | undefined>;
    /**
     * Deletes the chart object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of chart object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<WorkbookChartItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of chart object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookChart, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a WorkbookChartItemRequestBuilder
     */
    withUrl(rawUrl: string): WorkbookChartItemRequestBuilder;
}
