import { type WorkbookChartFill } from '../../../../../../../../../../../../models/workbookChartFill';
import { ClearRequestBuilder } from './clear/';
import { SetSolidColorRequestBuilder } from './setSolidColor/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface FillRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the fill property of the microsoft.graph.workbookChartLegendFormat entity.
 */
export declare class FillRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the clear method.
     */
    get clear(): ClearRequestBuilder;
    /**
     * Provides operations to call the setSolidColor method.
     */
    get setSolidColor(): SetSolidColorRequestBuilder;
    /**
     * Instantiates a new FillRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property fill for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Represents the fill format of an object, which includes background formating information. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartFill
     */
    get(requestConfiguration?: RequestConfiguration<FillRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookChartFill | undefined>;
    /**
     * Update the navigation property fill in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartFill
     */
    patch(body: WorkbookChartFill, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookChartFill | undefined>;
    /**
     * Delete navigation property fill for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Represents the fill format of an object, which includes background formating information. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<FillRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property fill in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookChartFill, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a fillRequestBuilder
     */
    withUrl(rawUrl: string): FillRequestBuilder;
}
