import { type WorkbookChartSeriesCollectionResponse } from '../../../../../../../../../../models/';
import { type WorkbookChartSeries } from '../../../../../../../../../../models/workbookChartSeries';
import { CountRequestBuilder } from './count/';
import { WorkbookChartSeriesItemRequestBuilder } from './item/';
import { ItemAtWithIndexRequestBuilder } from './itemAtWithIndex/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SeriesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the series property of the microsoft.graph.workbookChart entity.
 */
export declare class SeriesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the count method.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the series property of the microsoft.graph.workbookChart entity.
     * @param workbookChartSeriesId The unique identifier of workbookChartSeries
     * @returns a WorkbookChartSeriesItemRequestBuilder
     */
    byWorkbookChartSeriesId(workbookChartSeriesId: string): WorkbookChartSeriesItemRequestBuilder;
    /**
     * Instantiates a new SeriesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of chartseries objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartSeriesCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/chartseries-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SeriesRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookChartSeriesCollectionResponse | undefined>;
    /**
     * Provides operations to call the itemAt method.
     * @param index Usage: index={index}
     * @returns a itemAtWithIndexRequestBuilder
     */
    itemAtWithIndex(index: number | undefined): ItemAtWithIndexRequestBuilder;
    /**
     * Use this API to create a new ChartSeries.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartSeries
     * @see {@link https://learn.microsoft.com/graph/api/chart-post-series?view=graph-rest-1.0|Find more info here}
     */
    post(body: WorkbookChartSeries, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookChartSeries | undefined>;
    /**
     * Retrieve a list of chartseries objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SeriesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Use this API to create a new ChartSeries.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: WorkbookChartSeries, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a seriesRequestBuilder
     */
    withUrl(rawUrl: string): SeriesRequestBuilder;
}
