import { type WorkbookChartSeries } from '../../../../../../../../../../../models/workbookChartSeries';
import { FormatRequestBuilder } from './format/';
import { PointsRequestBuilder } from './points/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface WorkbookChartSeriesItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the series property of the microsoft.graph.workbookChart entity.
 */
export declare class WorkbookChartSeriesItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the format property of the microsoft.graph.workbookChartSeries entity.
     */
    get format(): FormatRequestBuilder;
    /**
     * Provides operations to manage the points property of the microsoft.graph.workbookChartSeries entity.
     */
    get points(): PointsRequestBuilder;
    /**
     * Instantiates a new WorkbookChartSeriesItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property series for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of chartseries object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartSeries
     * @see {@link https://learn.microsoft.com/graph/api/chartseries-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<WorkbookChartSeriesItemRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookChartSeries | undefined>;
    /**
     * Update the properties of chartseries object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartSeries
     * @see {@link https://learn.microsoft.com/graph/api/chartseries-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: WorkbookChartSeries, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookChartSeries | undefined>;
    /**
     * Delete navigation property series for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of chartseries object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<WorkbookChartSeriesItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of chartseries object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookChartSeries, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a WorkbookChartSeriesItemRequestBuilder
     */
    withUrl(rawUrl: string): WorkbookChartSeriesItemRequestBuilder;
}
