import { type WorkbookChartPointCollectionResponse } from '../../../../../../../../../../../../models/';
import { type WorkbookChartPoint } from '../../../../../../../../../../../../models/workbookChartPoint';
import { CountRequestBuilder } from './count/';
import { WorkbookChartPointItemRequestBuilder } from './item/';
import { ItemAtWithIndexRequestBuilder } from './itemAtWithIndex/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface PointsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the points property of the microsoft.graph.workbookChartSeries entity.
 */
export declare class PointsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the count method.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the points property of the microsoft.graph.workbookChartSeries entity.
     * @param workbookChartPointId The unique identifier of workbookChartPoint
     * @returns a WorkbookChartPointItemRequestBuilder
     */
    byWorkbookChartPointId(workbookChartPointId: string): WorkbookChartPointItemRequestBuilder;
    /**
     * Instantiates a new PointsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of chartpoints objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartPointCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/chartseries-list-points?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<PointsRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookChartPointCollectionResponse | undefined>;
    /**
     * Provides operations to call the itemAt method.
     * @param index Usage: index={index}
     * @returns a itemAtWithIndexRequestBuilder
     */
    itemAtWithIndex(index: number | undefined): ItemAtWithIndexRequestBuilder;
    /**
     * Use this API to create a new ChartPoints.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartPoint
     * @see {@link https://learn.microsoft.com/graph/api/chartseries-post-points?view=graph-rest-1.0|Find more info here}
     */
    post(body: WorkbookChartPoint, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookChartPoint | undefined>;
    /**
     * Retrieve a list of chartpoints objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<PointsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Use this API to create a new ChartPoints.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: WorkbookChartPoint, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a pointsRequestBuilder
     */
    withUrl(rawUrl: string): PointsRequestBuilder;
}
