import { type WorkbookChartPoint } from '../../../../../../../../../../../../../models/workbookChartPoint';
import { FormatRequestBuilder } from './format/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface WorkbookChartPointItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the points property of the microsoft.graph.workbookChartSeries entity.
 */
export declare class WorkbookChartPointItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the format property of the microsoft.graph.workbookChartPoint entity.
     */
    get format(): FormatRequestBuilder;
    /**
     * Instantiates a new WorkbookChartPointItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property points for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of chartpoint object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartPoint
     * @see {@link https://learn.microsoft.com/graph/api/chartpoint-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<WorkbookChartPointItemRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookChartPoint | undefined>;
    /**
     * Update the navigation property points in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChartPoint
     */
    patch(body: WorkbookChartPoint, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookChartPoint | undefined>;
    /**
     * Delete navigation property points for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of chartpoint object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<WorkbookChartPointItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property points in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookChartPoint, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a WorkbookChartPointItemRequestBuilder
     */
    withUrl(rawUrl: string): WorkbookChartPointItemRequestBuilder;
}
