import { type WorkbookWorksheet } from '../../../../../../../models/workbookWorksheet';
import { CellWithRowWithColumnRequestBuilder } from './cellWithRowWithColumn/';
import { ChartsRequestBuilder } from './charts/';
import { NamesRequestBuilder } from './names/';
import { PivotTablesRequestBuilder } from './pivotTables/';
import { ProtectionRequestBuilder } from './protection/';
import { RangeRequestBuilder } from './range/';
import { RangeWithAddressRequestBuilder } from './rangeWithAddress/';
import { TablesRequestBuilder } from './tables/';
import { UsedRangeRequestBuilder } from './usedRange/';
import { UsedRangeWithValuesOnlyRequestBuilder } from './usedRangeWithValuesOnly/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface WorkbookWorksheetItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the worksheets property of the microsoft.graph.workbook entity.
 */
export declare class WorkbookWorksheetItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the charts property of the microsoft.graph.workbookWorksheet entity.
     */
    get charts(): ChartsRequestBuilder;
    /**
     * Provides operations to manage the names property of the microsoft.graph.workbookWorksheet entity.
     */
    get names(): NamesRequestBuilder;
    /**
     * Provides operations to manage the pivotTables property of the microsoft.graph.workbookWorksheet entity.
     */
    get pivotTables(): PivotTablesRequestBuilder;
    /**
     * Provides operations to manage the protection property of the microsoft.graph.workbookWorksheet entity.
     */
    get protection(): ProtectionRequestBuilder;
    /**
     * Provides operations to call the range method.
     */
    get range(): RangeRequestBuilder;
    /**
     * Provides operations to manage the tables property of the microsoft.graph.workbookWorksheet entity.
     */
    get tables(): TablesRequestBuilder;
    /**
     * Provides operations to call the usedRange method.
     */
    get usedRange(): UsedRangeRequestBuilder;
    /**
     * Provides operations to call the cell method.
     * @param column Usage: column={column}
     * @param row Usage: row={row}
     * @returns a cellWithRowWithColumnRequestBuilder
     */
    cellWithRowWithColumn(column: number | undefined, row: number | undefined): CellWithRowWithColumnRequestBuilder;
    /**
     * Instantiates a new WorkbookWorksheetItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Deletes the worksheet from the workbook.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/worksheet-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of worksheet object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookWorksheet
     * @see {@link https://learn.microsoft.com/graph/api/worksheet-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<WorkbookWorksheetItemRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookWorksheet | undefined>;
    /**
     * Update the properties of worksheet object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookWorksheet
     * @see {@link https://learn.microsoft.com/graph/api/worksheet-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: WorkbookWorksheet, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookWorksheet | undefined>;
    /**
     * Provides operations to call the range method.
     * @param address Usage: address='{address}'
     * @returns a rangeWithAddressRequestBuilder
     */
    rangeWithAddress(address: string | undefined): RangeWithAddressRequestBuilder;
    /**
     * Deletes the worksheet from the workbook.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of worksheet object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<WorkbookWorksheetItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of worksheet object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookWorksheet, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Provides operations to call the usedRange method.
     * @param valuesOnly Usage: valuesOnly={valuesOnly}
     * @returns a usedRangeWithValuesOnlyRequestBuilder
     */
    usedRangeWithValuesOnly(valuesOnly: boolean | undefined): UsedRangeWithValuesOnlyRequestBuilder;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a WorkbookWorksheetItemRequestBuilder
     */
    withUrl(rawUrl: string): WorkbookWorksheetItemRequestBuilder;
}
