"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WorkbookWorksheetItemRequestBuilder = void 0;
const oDataError_1 = require("../../../../../../../models/oDataErrors/oDataError");
const workbookWorksheet_1 = require("../../../../../../../models/workbookWorksheet");
const cellWithRowWithColumn_1 = require("./cellWithRowWithColumn/");
const charts_1 = require("./charts/");
const names_1 = require("./names/");
const pivotTables_1 = require("./pivotTables/");
const protection_1 = require("./protection/");
const range_1 = require("./range/");
const rangeWithAddress_1 = require("./rangeWithAddress/");
const tables_1 = require("./tables/");
const usedRange_1 = require("./usedRange/");
const usedRangeWithValuesOnly_1 = require("./usedRangeWithValuesOnly/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the worksheets property of the microsoft.graph.workbook entity.
 */
class WorkbookWorksheetItemRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to manage the charts property of the microsoft.graph.workbookWorksheet entity.
     */
    get charts() {
        return new charts_1.ChartsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the names property of the microsoft.graph.workbookWorksheet entity.
     */
    get names() {
        return new names_1.NamesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the pivotTables property of the microsoft.graph.workbookWorksheet entity.
     */
    get pivotTables() {
        return new pivotTables_1.PivotTablesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the protection property of the microsoft.graph.workbookWorksheet entity.
     */
    get protection() {
        return new protection_1.ProtectionRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the range method.
     */
    get range() {
        return new range_1.RangeRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the tables property of the microsoft.graph.workbookWorksheet entity.
     */
    get tables() {
        return new tables_1.TablesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the usedRange method.
     */
    get usedRange() {
        return new usedRange_1.UsedRangeRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the cell method.
     * @param column Usage: column={column}
     * @param row Usage: row={row}
     * @returns a cellWithRowWithColumnRequestBuilder
     */
    cellWithRowWithColumn(column, row) {
        if (!column)
            throw new Error("column cannot be undefined");
        if (!row)
            throw new Error("row cannot be undefined");
        return new cellWithRowWithColumn_1.CellWithRowWithColumnRequestBuilder(this.pathParameters, this.requestAdapter, column, row);
    }
    ;
    /**
     * Instantiates a new WorkbookWorksheetItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/drives/{drive%2Did}/items/{driveItem%2Did}/workbook/worksheets/{workbookWorksheet%2Did}{?%24select,%24expand}");
    }
    ;
    /**
     * Deletes the worksheet from the workbook.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/worksheet-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration) {
        const requestInfo = this.toDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Retrieve the properties and relationships of worksheet object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookWorksheet
     * @see {@link https://learn.microsoft.com/graph/api/worksheet-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, workbookWorksheet_1.createWorkbookWorksheetFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Update the properties of worksheet object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookWorksheet
     * @see {@link https://learn.microsoft.com/graph/api/worksheet-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body, requestConfiguration) {
        const requestInfo = this.toPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, workbookWorksheet_1.createWorkbookWorksheetFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Provides operations to call the range method.
     * @param address Usage: address='{address}'
     * @returns a rangeWithAddressRequestBuilder
     */
    rangeWithAddress(address) {
        if (!address)
            throw new Error("address cannot be undefined");
        return new rangeWithAddress_1.RangeWithAddressRequestBuilder(this.pathParameters, this.requestAdapter, address);
    }
    ;
    /**
     * Deletes the worksheet from the workbook.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.DELETE, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Retrieve the properties and relationships of worksheet object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, workbookWorksheetItemRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Update the properties of worksheet object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.PATCH, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, workbookWorksheet_1.serializeWorkbookWorksheet);
        return requestInfo;
    }
    ;
    /**
     * Provides operations to call the usedRange method.
     * @param valuesOnly Usage: valuesOnly={valuesOnly}
     * @returns a usedRangeWithValuesOnlyRequestBuilder
     */
    usedRangeWithValuesOnly(valuesOnly) {
        if (!valuesOnly)
            throw new Error("valuesOnly cannot be undefined");
        return new usedRangeWithValuesOnly_1.UsedRangeWithValuesOnlyRequestBuilder(this.pathParameters, this.requestAdapter, valuesOnly);
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a WorkbookWorksheetItemRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new WorkbookWorksheetItemRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.WorkbookWorksheetItemRequestBuilder = WorkbookWorksheetItemRequestBuilder;
const workbookWorksheetItemRequestBuilderGetQueryParametersMapper = {
    "expand": "%24expand",
    "select": "%24select",
};
// tslint:enable
// eslint-enable
