import { type WorkbookNamedItemCollectionResponse } from '../../../../../../../../models/';
import { type WorkbookNamedItem } from '../../../../../../../../models/workbookNamedItem';
import { AddRequestBuilder } from './add/';
import { AddFormulaLocalRequestBuilder } from './addFormulaLocal/';
import { CountRequestBuilder } from './count/';
import { WorkbookNamedItemItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface NamesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the names property of the microsoft.graph.workbookWorksheet entity.
 */
export declare class NamesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the add method.
     */
    get add(): AddRequestBuilder;
    /**
     * Provides operations to call the addFormulaLocal method.
     */
    get addFormulaLocal(): AddFormulaLocalRequestBuilder;
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the names property of the microsoft.graph.workbookWorksheet entity.
     * @param workbookNamedItemId The unique identifier of workbookNamedItem
     * @returns a WorkbookNamedItemItemRequestBuilder
     */
    byWorkbookNamedItemId(workbookNamedItemId: string): WorkbookNamedItemItemRequestBuilder;
    /**
     * Instantiates a new NamesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of named item associated with the worksheet.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookNamedItemCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/worksheet-list-names?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<NamesRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookNamedItemCollectionResponse | undefined>;
    /**
     * Create new navigation property to names for drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookNamedItem
     */
    post(body: WorkbookNamedItem, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookNamedItem | undefined>;
    /**
     * Retrieve a list of named item associated with the worksheet.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<NamesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to names for drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: WorkbookNamedItem, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a namesRequestBuilder
     */
    withUrl(rawUrl: string): NamesRequestBuilder;
}
