import { type WorkbookTableCollectionResponse } from '../../../../../../../../models/';
import { type WorkbookTable } from '../../../../../../../../models/workbookTable';
import { AddRequestBuilder } from './add/';
import { CountRequestBuilder } from './count/';
import { WorkbookTableItemRequestBuilder } from './item/';
import { ItemAtWithIndexRequestBuilder } from './itemAtWithIndex/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface TablesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the tables property of the microsoft.graph.workbookWorksheet entity.
 */
export declare class TablesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the add method.
     */
    get add(): AddRequestBuilder;
    /**
     * Provides operations to call the count method.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the tables property of the microsoft.graph.workbookWorksheet entity.
     * @param workbookTableId The unique identifier of workbookTable
     * @returns a WorkbookTableItemRequestBuilder
     */
    byWorkbookTableId(workbookTableId: string): WorkbookTableItemRequestBuilder;
    /**
     * Instantiates a new TablesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of table objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookTableCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/worksheet-list-tables?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<TablesRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookTableCollectionResponse | undefined>;
    /**
     * Provides operations to call the itemAt method.
     * @param index Usage: index={index}
     * @returns a itemAtWithIndexRequestBuilder
     */
    itemAtWithIndex(index: number | undefined): ItemAtWithIndexRequestBuilder;
    /**
     * Create new navigation property to tables for drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookTable
     */
    post(body: WorkbookTable, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookTable | undefined>;
    /**
     * Retrieve a list of table objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<TablesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to tables for drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: WorkbookTable, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a tablesRequestBuilder
     */
    withUrl(rawUrl: string): TablesRequestBuilder;
}
