import { type WorkbookFilter } from '../../../../../../../../../../../../models/workbookFilter';
import { ApplyRequestBuilder } from './apply/';
import { ApplyBottomItemsFilterRequestBuilder } from './applyBottomItemsFilter/';
import { ApplyBottomPercentFilterRequestBuilder } from './applyBottomPercentFilter/';
import { ApplyCellColorFilterRequestBuilder } from './applyCellColorFilter/';
import { ApplyCustomFilterRequestBuilder } from './applyCustomFilter/';
import { ApplyDynamicFilterRequestBuilder } from './applyDynamicFilter/';
import { ApplyFontColorFilterRequestBuilder } from './applyFontColorFilter/';
import { ApplyIconFilterRequestBuilder } from './applyIconFilter/';
import { ApplyTopItemsFilterRequestBuilder } from './applyTopItemsFilter/';
import { ApplyTopPercentFilterRequestBuilder } from './applyTopPercentFilter/';
import { ApplyValuesFilterRequestBuilder } from './applyValuesFilter/';
import { ClearRequestBuilder } from './clear/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface FilterRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the filter property of the microsoft.graph.workbookTableColumn entity.
 */
export declare class FilterRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the apply method.
     */
    get apply(): ApplyRequestBuilder;
    /**
     * Provides operations to call the applyBottomItemsFilter method.
     */
    get applyBottomItemsFilter(): ApplyBottomItemsFilterRequestBuilder;
    /**
     * Provides operations to call the applyBottomPercentFilter method.
     */
    get applyBottomPercentFilter(): ApplyBottomPercentFilterRequestBuilder;
    /**
     * Provides operations to call the applyCellColorFilter method.
     */
    get applyCellColorFilter(): ApplyCellColorFilterRequestBuilder;
    /**
     * Provides operations to call the applyCustomFilter method.
     */
    get applyCustomFilter(): ApplyCustomFilterRequestBuilder;
    /**
     * Provides operations to call the applyDynamicFilter method.
     */
    get applyDynamicFilter(): ApplyDynamicFilterRequestBuilder;
    /**
     * Provides operations to call the applyFontColorFilter method.
     */
    get applyFontColorFilter(): ApplyFontColorFilterRequestBuilder;
    /**
     * Provides operations to call the applyIconFilter method.
     */
    get applyIconFilter(): ApplyIconFilterRequestBuilder;
    /**
     * Provides operations to call the applyTopItemsFilter method.
     */
    get applyTopItemsFilter(): ApplyTopItemsFilterRequestBuilder;
    /**
     * Provides operations to call the applyTopPercentFilter method.
     */
    get applyTopPercentFilter(): ApplyTopPercentFilterRequestBuilder;
    /**
     * Provides operations to call the applyValuesFilter method.
     */
    get applyValuesFilter(): ApplyValuesFilterRequestBuilder;
    /**
     * Provides operations to call the clear method.
     */
    get clear(): ClearRequestBuilder;
    /**
     * Instantiates a new FilterRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property filter for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the filter applied to the column. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookFilter
     */
    get(requestConfiguration?: RequestConfiguration<FilterRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookFilter | undefined>;
    /**
     * Update the navigation property filter in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookFilter
     */
    patch(body: WorkbookFilter, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookFilter | undefined>;
    /**
     * Delete navigation property filter for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the filter applied to the column. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<FilterRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property filter in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookFilter, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a filterRequestBuilder
     */
    withUrl(rawUrl: string): FilterRequestBuilder;
}
