import { type WorkbookTableSort } from '../../../../../../../../../../models/workbookTableSort';
import { ApplyRequestBuilder } from './apply/';
import { ClearRequestBuilder } from './clear/';
import { ReapplyRequestBuilder } from './reapply/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SortRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the sort property of the microsoft.graph.workbookTable entity.
 */
export declare class SortRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the apply method.
     */
    get apply(): ApplyRequestBuilder;
    /**
     * Provides operations to call the clear method.
     */
    get clear(): ClearRequestBuilder;
    /**
     * Provides operations to call the reapply method.
     */
    get reapply(): ReapplyRequestBuilder;
    /**
     * Instantiates a new SortRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property sort for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of tablesort object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookTableSort
     * @see {@link https://learn.microsoft.com/graph/api/tablesort-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SortRequestBuilderGetQueryParameters> | undefined): Promise<WorkbookTableSort | undefined>;
    /**
     * Update the navigation property sort in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookTableSort
     */
    patch(body: WorkbookTableSort, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WorkbookTableSort | undefined>;
    /**
     * Delete navigation property sort for drives
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of tablesort object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SortRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property sort in drives
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: WorkbookTableSort, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a sortRequestBuilder
     */
    withUrl(rawUrl: string): SortRequestBuilder;
}
