import { type EducationCategoryCollectionResponse } from '../../../../models/';
import { type EducationCategory } from '../../../../models/educationCategory';
import { CountRequestBuilder } from './count/';
import { DeltaRequestBuilder } from './delta/';
import { EducationCategoryItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AssignmentCategoriesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the assignmentCategories property of the microsoft.graph.educationClass entity.
 */
export declare class AssignmentCategoriesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to call the delta method.
     */
    get delta(): DeltaRequestBuilder;
    /**
     * Provides operations to manage the assignmentCategories property of the microsoft.graph.educationClass entity.
     * @param educationCategoryId The unique identifier of educationCategory
     * @returns a EducationCategoryItemRequestBuilder
     */
    byEducationCategoryId(educationCategoryId: string): EducationCategoryItemRequestBuilder;
    /**
     * Instantiates a new AssignmentCategoriesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of educationCategory objects. Only teachers can perform this operation.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationCategoryCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/educationclass-list-categories?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<AssignmentCategoriesRequestBuilderGetQueryParameters> | undefined): Promise<EducationCategoryCollectionResponse | undefined>;
    /**
     * Create a new educationCategory on an educationClass. Only teachers can perform this operation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationCategory
     * @see {@link https://learn.microsoft.com/graph/api/educationclass-post-category?view=graph-rest-1.0|Find more info here}
     */
    post(body: EducationCategory, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<EducationCategory | undefined>;
    /**
     * Retrieve a list of educationCategory objects. Only teachers can perform this operation.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AssignmentCategoriesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new educationCategory on an educationClass. Only teachers can perform this operation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: EducationCategory, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a assignmentCategoriesRequestBuilder
     */
    withUrl(rawUrl: string): AssignmentCategoriesRequestBuilder;
}
