import { type EducationRoot } from '../models/educationRoot';
import { ClassesRequestBuilder } from './classes/';
import { MeRequestBuilder } from './me/';
import { SchoolsRequestBuilder } from './schools/';
import { UsersRequestBuilder } from './users/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface EducationRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the educationRoot singleton.
 */
export declare class EducationRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the classes property of the microsoft.graph.educationRoot entity.
     */
    get classes(): ClassesRequestBuilder;
    /**
     * Provides operations to manage the me property of the microsoft.graph.educationRoot entity.
     */
    get me(): MeRequestBuilder;
    /**
     * Provides operations to manage the schools property of the microsoft.graph.educationRoot entity.
     */
    get schools(): SchoolsRequestBuilder;
    /**
     * Provides operations to manage the users property of the microsoft.graph.educationRoot entity.
     */
    get users(): UsersRequestBuilder;
    /**
     * Instantiates a new EducationRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationRoot
     */
    get(requestConfiguration?: RequestConfiguration<EducationRequestBuilderGetQueryParameters> | undefined): Promise<EducationRoot | undefined>;
    /**
     * Update education
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationRoot
     */
    patch(body: EducationRoot, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<EducationRoot | undefined>;
    /**
     * Get education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<EducationRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update education
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EducationRoot, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a educationRequestBuilder
     */
    withUrl(rawUrl: string): EducationRequestBuilder;
}
