import { type EducationUser } from '../../models/educationUser';
import { AssignmentsRequestBuilder } from './assignments/';
import { ClassesRequestBuilder } from './classes/';
import { RubricsRequestBuilder } from './rubrics/';
import { SchoolsRequestBuilder } from './schools/';
import { TaughtClassesRequestBuilder } from './taughtClasses/';
import { UserRequestBuilder } from './user/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface MeRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the me property of the microsoft.graph.educationRoot entity.
 */
export declare class MeRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the assignments property of the microsoft.graph.educationUser entity.
     */
    get assignments(): AssignmentsRequestBuilder;
    /**
     * Provides operations to manage the classes property of the microsoft.graph.educationUser entity.
     */
    get classes(): ClassesRequestBuilder;
    /**
     * Provides operations to manage the rubrics property of the microsoft.graph.educationUser entity.
     */
    get rubrics(): RubricsRequestBuilder;
    /**
     * Provides operations to manage the schools property of the microsoft.graph.educationUser entity.
     */
    get schools(): SchoolsRequestBuilder;
    /**
     * Provides operations to manage the taughtClasses property of the microsoft.graph.educationUser entity.
     */
    get taughtClasses(): TaughtClassesRequestBuilder;
    /**
     * Provides operations to manage the user property of the microsoft.graph.educationUser entity.
     */
    get user(): UserRequestBuilder;
    /**
     * Instantiates a new MeRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property me for education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Get me from education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationUser
     */
    get(requestConfiguration?: RequestConfiguration<MeRequestBuilderGetQueryParameters> | undefined): Promise<EducationUser | undefined>;
    /**
     * Update the navigation property me in education
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationUser
     */
    patch(body: EducationUser, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<EducationUser | undefined>;
    /**
     * Delete navigation property me for education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Get me from education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<MeRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property me in education
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EducationUser, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a meRequestBuilder
     */
    withUrl(rawUrl: string): MeRequestBuilder;
}
