import { type EducationRubricCollectionResponse } from '../../../models/';
import { type EducationRubric } from '../../../models/educationRubric';
import { CountRequestBuilder } from './count/';
import { EducationRubricItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface RubricsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the rubrics property of the microsoft.graph.educationUser entity.
 */
export declare class RubricsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the rubrics property of the microsoft.graph.educationUser entity.
     * @param educationRubricId The unique identifier of educationRubric
     * @returns a EducationRubricItemRequestBuilder
     */
    byEducationRubricId(educationRubricId: string): EducationRubricItemRequestBuilder;
    /**
     * Instantiates a new RubricsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of educationRubric objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationRubricCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/educationuser-list-rubrics?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<RubricsRequestBuilderGetQueryParameters> | undefined): Promise<EducationRubricCollectionResponse | undefined>;
    /**
     * Create a new educationRubric object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationRubric
     * @see {@link https://learn.microsoft.com/graph/api/educationuser-post-rubrics?view=graph-rest-1.0|Find more info here}
     */
    post(body: EducationRubric, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<EducationRubric | undefined>;
    /**
     * Retrieve a list of educationRubric objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<RubricsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new educationRubric object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: EducationRubric, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a rubricsRequestBuilder
     */
    withUrl(rawUrl: string): RubricsRequestBuilder;
}
