import { type EducationSchool } from '../../../models/educationSchool';
import { AdministrativeUnitRequestBuilder } from './administrativeUnit/';
import { ClassesRequestBuilder } from './classes/';
import { UsersRequestBuilder } from './users/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface EducationSchoolItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the schools property of the microsoft.graph.educationRoot entity.
 */
export declare class EducationSchoolItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the administrativeUnit property of the microsoft.graph.educationSchool entity.
     */
    get administrativeUnit(): AdministrativeUnitRequestBuilder;
    /**
     * Provides operations to manage the classes property of the microsoft.graph.educationSchool entity.
     */
    get classes(): ClassesRequestBuilder;
    /**
     * Provides operations to manage the users property of the microsoft.graph.educationSchool entity.
     */
    get users(): UsersRequestBuilder;
    /**
     * Instantiates a new EducationSchoolItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete a school.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/educationschool-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of an educationSchool object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationSchool
     * @see {@link https://learn.microsoft.com/graph/api/educationschool-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<EducationSchoolItemRequestBuilderGetQueryParameters> | undefined): Promise<EducationSchool | undefined>;
    /**
     * Update the properties of an educationSchool object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationSchool
     * @see {@link https://learn.microsoft.com/graph/api/educationschool-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: EducationSchool, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<EducationSchool | undefined>;
    /**
     * Delete a school.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of an educationSchool object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<EducationSchoolItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of an educationSchool object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EducationSchool, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a EducationSchoolItemRequestBuilder
     */
    withUrl(rawUrl: string): EducationSchoolItemRequestBuilder;
}
