import { type EducationAssignment } from '../../../../../models/educationAssignment';
import { CategoriesRequestBuilder } from './categories/';
import { PublishRequestBuilder } from './publish/';
import { ResourcesRequestBuilder } from './resources/';
import { RubricRequestBuilder } from './rubric/';
import { SetUpFeedbackResourcesFolderRequestBuilder } from './setUpFeedbackResourcesFolder/';
import { SetUpResourcesFolderRequestBuilder } from './setUpResourcesFolder/';
import { SubmissionsRequestBuilder } from './submissions/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface EducationAssignmentItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the assignments property of the microsoft.graph.educationUser entity.
 */
export declare class EducationAssignmentItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the categories property of the microsoft.graph.educationAssignment entity.
     */
    get categories(): CategoriesRequestBuilder;
    /**
     * Provides operations to call the publish method.
     */
    get publish(): PublishRequestBuilder;
    /**
     * Provides operations to manage the resources property of the microsoft.graph.educationAssignment entity.
     */
    get resources(): ResourcesRequestBuilder;
    /**
     * Provides operations to manage the rubric property of the microsoft.graph.educationAssignment entity.
     */
    get rubric(): RubricRequestBuilder;
    /**
     * Provides operations to call the setUpFeedbackResourcesFolder method.
     */
    get setUpFeedbackResourcesFolder(): SetUpFeedbackResourcesFolderRequestBuilder;
    /**
     * Provides operations to call the setUpResourcesFolder method.
     */
    get setUpResourcesFolder(): SetUpResourcesFolderRequestBuilder;
    /**
     * Provides operations to manage the submissions property of the microsoft.graph.educationAssignment entity.
     */
    get submissions(): SubmissionsRequestBuilder;
    /**
     * Instantiates a new EducationAssignmentItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property assignments for education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Assignments belonging to the user.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationAssignment
     */
    get(requestConfiguration?: RequestConfiguration<EducationAssignmentItemRequestBuilderGetQueryParameters> | undefined): Promise<EducationAssignment | undefined>;
    /**
     * Update the navigation property assignments in education
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationAssignment
     */
    patch(body: EducationAssignment, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<EducationAssignment | undefined>;
    /**
     * Delete navigation property assignments for education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Assignments belonging to the user.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<EducationAssignmentItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property assignments in education
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EducationAssignment, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a EducationAssignmentItemRequestBuilder
     */
    withUrl(rawUrl: string): EducationAssignmentItemRequestBuilder;
}
