import { type EducationSubmissionCollectionResponse } from '../../../../../../models/';
import { type EducationSubmission } from '../../../../../../models/educationSubmission';
import { CountRequestBuilder } from './count/';
import { EducationSubmissionItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SubmissionsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the submissions property of the microsoft.graph.educationAssignment entity.
 */
export declare class SubmissionsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the submissions property of the microsoft.graph.educationAssignment entity.
     * @param educationSubmissionId The unique identifier of educationSubmission
     * @returns a EducationSubmissionItemRequestBuilder
     */
    byEducationSubmissionId(educationSubmissionId: string): EducationSubmissionItemRequestBuilder;
    /**
     * Instantiates a new SubmissionsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List all the submissions associated with an assignment. Only teachers, students, and applications with application permissions can perform this operation. A teacher or an application with application permissions can get all the submissions while a student can only get submissions that they are associated with.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationSubmissionCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/educationassignment-list-submissions?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SubmissionsRequestBuilderGetQueryParameters> | undefined): Promise<EducationSubmissionCollectionResponse | undefined>;
    /**
     * Create new navigation property to submissions for education
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationSubmission
     */
    post(body: EducationSubmission, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<EducationSubmission | undefined>;
    /**
     * List all the submissions associated with an assignment. Only teachers, students, and applications with application permissions can perform this operation. A teacher or an application with application permissions can get all the submissions while a student can only get submissions that they are associated with.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SubmissionsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to submissions for education
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: EducationSubmission, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a submissionsRequestBuilder
     */
    withUrl(rawUrl: string): SubmissionsRequestBuilder;
}
