import { type EducationUser } from '../../../models/educationUser';
import { AssignmentsRequestBuilder } from './assignments/';
import { ClassesRequestBuilder } from './classes/';
import { RubricsRequestBuilder } from './rubrics/';
import { SchoolsRequestBuilder } from './schools/';
import { TaughtClassesRequestBuilder } from './taughtClasses/';
import { UserRequestBuilder } from './user/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface EducationUserItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the users property of the microsoft.graph.educationRoot entity.
 */
export declare class EducationUserItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the assignments property of the microsoft.graph.educationUser entity.
     */
    get assignments(): AssignmentsRequestBuilder;
    /**
     * Provides operations to manage the classes property of the microsoft.graph.educationUser entity.
     */
    get classes(): ClassesRequestBuilder;
    /**
     * Provides operations to manage the rubrics property of the microsoft.graph.educationUser entity.
     */
    get rubrics(): RubricsRequestBuilder;
    /**
     * Provides operations to manage the schools property of the microsoft.graph.educationUser entity.
     */
    get schools(): SchoolsRequestBuilder;
    /**
     * Provides operations to manage the taughtClasses property of the microsoft.graph.educationUser entity.
     */
    get taughtClasses(): TaughtClassesRequestBuilder;
    /**
     * Provides operations to manage the user property of the microsoft.graph.educationUser entity.
     */
    get user(): UserRequestBuilder;
    /**
     * Instantiates a new EducationUserItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete a user.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/educationuser-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of an educationUser object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationUser
     * @see {@link https://learn.microsoft.com/graph/api/educationuser-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<EducationUserItemRequestBuilderGetQueryParameters> | undefined): Promise<EducationUser | undefined>;
    /**
     * Update the properties of an educationUser object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EducationUser
     * @see {@link https://learn.microsoft.com/graph/api/educationuser-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: EducationUser, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<EducationUser | undefined>;
    /**
     * Delete a user.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of an educationUser object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<EducationUserItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of an educationUser object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EducationUser, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a EducationUserItemRequestBuilder
     */
    withUrl(rawUrl: string): EducationUserItemRequestBuilder;
}
