"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserRequestBuilder = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const user_1 = require("../../../../models/user");
const mailboxSettings_1 = require("./mailboxSettings/");
const serviceProvisioningErrors_1 = require("./serviceProvisioningErrors/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the user property of the microsoft.graph.educationUser entity.
 */
class UserRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * The mailboxSettings property
     */
    get mailboxSettings() {
        return new mailboxSettings_1.MailboxSettingsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * The serviceProvisioningErrors property
     */
    get serviceProvisioningErrors() {
        return new serviceProvisioningErrors_1.ServiceProvisioningErrorsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new UserRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/education/users/{educationUser%2Did}/user{?%24select,%24expand}");
    }
    ;
    /**
     * Retrieve the simple directory user that corresponds to this educationUser.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of User
     * @see {@link https://learn.microsoft.com/graph/api/educationuser-get-user?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, user_1.createUserFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Retrieve the simple directory user that corresponds to this educationUser.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, userRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a userRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new UserRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.UserRequestBuilder = UserRequestBuilder;
const userRequestBuilderGetQueryParametersMapper = {
    "expand": "%24expand",
    "select": "%24select",
};
// tslint:enable
// eslint-enable
