import { type LearningProviderCollectionResponse } from '../../models/';
import { type LearningProvider } from '../../models/learningProvider';
import { CountRequestBuilder } from './count/';
import { LearningProviderItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface LearningProvidersRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the learningProviders property of the microsoft.graph.employeeExperience entity.
 */
export declare class LearningProvidersRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the learningProviders property of the microsoft.graph.employeeExperience entity.
     * @param learningProviderId The unique identifier of learningProvider
     * @returns a LearningProviderItemRequestBuilder
     */
    byLearningProviderId(learningProviderId: string): LearningProviderItemRequestBuilder;
    /**
     * Instantiates a new LearningProvidersRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the learningProvider resources registered in Viva Learning for a tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of LearningProviderCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/employeeexperience-list-learningproviders?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<LearningProvidersRequestBuilderGetQueryParameters> | undefined): Promise<LearningProviderCollectionResponse | undefined>;
    /**
     * Create a new learningProvider object and register it with Viva Learning using the specified display name and logos for different themes.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of LearningProvider
     * @see {@link https://learn.microsoft.com/graph/api/employeeexperience-post-learningproviders?view=graph-rest-1.0|Find more info here}
     */
    post(body: LearningProvider, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<LearningProvider | undefined>;
    /**
     * Get a list of the learningProvider resources registered in Viva Learning for a tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<LearningProvidersRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new learningProvider object and register it with Viva Learning using the specified display name and logos for different themes.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: LearningProvider, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a learningProvidersRequestBuilder
     */
    withUrl(rawUrl: string): LearningProvidersRequestBuilder;
}
