import { type External } from '../models/externalConnectors/external';
import { ConnectionsRequestBuilder } from './connections/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ExternalRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the external singleton.
 */
export declare class ExternalRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the connections property of the microsoft.graph.externalConnectors.external entity.
     */
    get connections(): ConnectionsRequestBuilder;
    /**
     * Instantiates a new ExternalRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get external
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of External
     */
    get(requestConfiguration?: RequestConfiguration<ExternalRequestBuilderGetQueryParameters> | undefined): Promise<External | undefined>;
    /**
     * Update external
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of External
     */
    patch(body: External, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<External | undefined>;
    /**
     * Get external
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ExternalRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update external
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: External, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a externalRequestBuilder
     */
    withUrl(rawUrl: string): ExternalRequestBuilder;
}
