import { type FilterOperatorSchemaCollectionResponse } from '../models/';
import { type FilterOperatorSchema } from '../models/filterOperatorSchema';
import { CountRequestBuilder } from './count/';
import { FilterOperatorSchemaItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface FilterOperatorsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the collection of filterOperatorSchema entities.
 */
export declare class FilterOperatorsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the collection of filterOperatorSchema entities.
     * @param filterOperatorSchemaId The unique identifier of filterOperatorSchema
     * @returns a FilterOperatorSchemaItemRequestBuilder
     */
    byFilterOperatorSchemaId(filterOperatorSchemaId: string): FilterOperatorSchemaItemRequestBuilder;
    /**
     * Instantiates a new FilterOperatorsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get entities from filterOperators
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of FilterOperatorSchemaCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<FilterOperatorsRequestBuilderGetQueryParameters> | undefined): Promise<FilterOperatorSchemaCollectionResponse | undefined>;
    /**
     * Add new entity to filterOperators
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of FilterOperatorSchema
     */
    post(body: FilterOperatorSchema, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<FilterOperatorSchema | undefined>;
    /**
     * Get entities from filterOperators
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<FilterOperatorsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Add new entity to filterOperators
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: FilterOperatorSchema, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a filterOperatorsRequestBuilder
     */
    withUrl(rawUrl: string): FilterOperatorsRequestBuilder;
}
