import { type AttributeMappingFunctionSchemaCollectionResponse } from '../models/';
import { type AttributeMappingFunctionSchema } from '../models/attributeMappingFunctionSchema';
import { CountRequestBuilder } from './count/';
import { AttributeMappingFunctionSchemaItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface FunctionsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the collection of attributeMappingFunctionSchema entities.
 */
export declare class FunctionsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the collection of attributeMappingFunctionSchema entities.
     * @param attributeMappingFunctionSchemaId The unique identifier of attributeMappingFunctionSchema
     * @returns a AttributeMappingFunctionSchemaItemRequestBuilder
     */
    byAttributeMappingFunctionSchemaId(attributeMappingFunctionSchemaId: string): AttributeMappingFunctionSchemaItemRequestBuilder;
    /**
     * Instantiates a new FunctionsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get entities from functions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AttributeMappingFunctionSchemaCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<FunctionsRequestBuilderGetQueryParameters> | undefined): Promise<AttributeMappingFunctionSchemaCollectionResponse | undefined>;
    /**
     * Add new entity to functions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AttributeMappingFunctionSchema
     */
    post(body: AttributeMappingFunctionSchema, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AttributeMappingFunctionSchema | undefined>;
    /**
     * Get entities from functions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<FunctionsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Add new entity to functions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AttributeMappingFunctionSchema, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a functionsRequestBuilder
     */
    withUrl(rawUrl: string): FunctionsRequestBuilder;
}
