"use strict";
/**
 * -------------------------------------------------------------------------------------------
 * Copyright (c) Microsoft Corporation.  All Rights Reserved.  Licensed under the MIT License.
 * See License in the project root for license information.
 * -------------------------------------------------------------------------------------------
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.GraphServiceClient = void 0;
const kiota_http_fetchlibrary_1 = require("@microsoft/kiota-http-fetchlibrary");
const graphBaseServiceClient_1 = require("../graphBaseServiceClient");
const microsoft_graph_client_1 = require("@microsoft/microsoft-graph-client");
const version_1 = require("./version");
/**
 * @public
 * @class GraphServiceClient
 *
 */
class GraphServiceClient extends graphBaseServiceClient_1.GraphBaseServiceClient {
    constructor(clientOptions) {
        let httpClient;
        if (clientOptions.authProvider === undefined) {
            const error = new microsoft_graph_client_1.GraphClientError();
            error.name = "Graph Service client Initialization Failed";
            error.message = "Unable to Create Client, Please provide an authentication provider";
            throw error;
        }
        const allowedHosts = (0, microsoft_graph_client_1.updateAndReturnAllAllowedHosts)(clientOptions.authProvider, clientOptions.customHosts);
        const graphSDKConfig = {
            sdkTelemetryVersion: version_1.sdkVersion,
        };
        if (!clientOptions.middleware) {
            httpClient = new kiota_http_fetchlibrary_1.HttpClient(undefined, ...[].concat((0, microsoft_graph_client_1.getDefaultMiddlewareChain)(clientOptions, allowedHosts, graphSDKConfig)));
        }
        else {
            httpClient = new kiota_http_fetchlibrary_1.HttpClient(clientOptions.customFetch, ...[].concat(clientOptions.middleware));
        }
        const fetchRequestAdapter = new kiota_http_fetchlibrary_1.FetchRequestAdapter(clientOptions.authProvider, undefined, undefined, httpClient);
        super(fetchRequestAdapter);
        this.config = {
            baseUrl: microsoft_graph_client_1.GRAPH_BASE_URL,
            debugLogging: false,
            defaultVersion: microsoft_graph_client_1.GRAPH_API_VERSION,
        };
        for (const key in clientOptions) {
            if (Object.prototype.hasOwnProperty.call(clientOptions, key)) {
                this.config[key] = clientOptions[key];
            }
        }
        this.httpClient = httpClient;
    }
    /**
     * @public
     * @static
     * Factory to configures a client instance with authProvider, initializes the middleware chain
     * @param {clientOptions} ClientOptions - The options for client instance
     * @returns The GraphServiceClient instance
     */
    static init(clientOptions) {
        return new GraphServiceClient(clientOptions);
    }
    /**
     * @public
     * Api to make a request using a Graph URL
     * @param {url} path - The Graph API URL
     * @returns The graph request instance
     */
    api(path) {
        return new microsoft_graph_client_1.GraphRequest(this.httpClient, this.config, path);
    }
}
exports.GraphServiceClient = GraphServiceClient;
