import { type GroupLifecyclePolicyCollectionResponse } from '../models/';
import { type GroupLifecyclePolicy } from '../models/groupLifecyclePolicy';
import { CountRequestBuilder } from './count/';
import { GroupLifecyclePolicyItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface GroupLifecyclePoliciesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the collection of groupLifecyclePolicy entities.
 */
export declare class GroupLifecyclePoliciesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the collection of groupLifecyclePolicy entities.
     * @param groupLifecyclePolicyId The unique identifier of groupLifecyclePolicy
     * @returns a GroupLifecyclePolicyItemRequestBuilder
     */
    byGroupLifecyclePolicyId(groupLifecyclePolicyId: string): GroupLifecyclePolicyItemRequestBuilder;
    /**
     * Instantiates a new GroupLifecyclePoliciesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List all the groupLifecyclePolicies.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of GroupLifecyclePolicyCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/grouplifecyclepolicy-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<GroupLifecyclePoliciesRequestBuilderGetQueryParameters> | undefined): Promise<GroupLifecyclePolicyCollectionResponse | undefined>;
    /**
     * Creates a new groupLifecyclePolicy.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of GroupLifecyclePolicy
     * @see {@link https://learn.microsoft.com/graph/api/grouplifecyclepolicy-post-grouplifecyclepolicies?view=graph-rest-1.0|Find more info here}
     */
    post(body: GroupLifecyclePolicy, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<GroupLifecyclePolicy | undefined>;
    /**
     * List all the groupLifecyclePolicies.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<GroupLifecyclePoliciesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Creates a new groupLifecyclePolicy.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: GroupLifecyclePolicy, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a groupLifecyclePoliciesRequestBuilder
     */
    withUrl(rawUrl: string): GroupLifecyclePoliciesRequestBuilder;
}
