"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AddGroupRequestBuilder = exports.serializeAddGroupPostResponse = exports.serializeAddGroupPostRequestBody = exports.deserializeIntoAddGroupPostResponse = exports.deserializeIntoAddGroupPostRequestBody = exports.createAddGroupPostResponseFromDiscriminatorValue = exports.createAddGroupPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createAddGroupPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoAddGroupPostRequestBody;
}
exports.createAddGroupPostRequestBodyFromDiscriminatorValue = createAddGroupPostRequestBodyFromDiscriminatorValue;
function createAddGroupPostResponseFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoAddGroupPostResponse;
}
exports.createAddGroupPostResponseFromDiscriminatorValue = createAddGroupPostResponseFromDiscriminatorValue;
function deserializeIntoAddGroupPostRequestBody(addGroupPostRequestBody = {}) {
    return {
        "groupId": n => { addGroupPostRequestBody.groupId = n.getStringValue(); },
    };
}
exports.deserializeIntoAddGroupPostRequestBody = deserializeIntoAddGroupPostRequestBody;
function deserializeIntoAddGroupPostResponse(addGroupPostResponse = {}) {
    return {
        "value": n => { addGroupPostResponse.value = n.getBooleanValue(); },
    };
}
exports.deserializeIntoAddGroupPostResponse = deserializeIntoAddGroupPostResponse;
function serializeAddGroupPostRequestBody(writer, addGroupPostRequestBody = {}) {
    writer.writeStringValue("groupId", addGroupPostRequestBody.groupId);
    writer.writeAdditionalData(addGroupPostRequestBody.additionalData);
}
exports.serializeAddGroupPostRequestBody = serializeAddGroupPostRequestBody;
function serializeAddGroupPostResponse(writer, addGroupPostResponse = {}) {
    writer.writeBooleanValue("value", addGroupPostResponse.value);
    writer.writeAdditionalData(addGroupPostResponse.additionalData);
}
exports.serializeAddGroupPostResponse = serializeAddGroupPostResponse;
/**
 * Provides operations to call the addGroup method.
 */
class AddGroupRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new AddGroupRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/groupLifecyclePolicies/{groupLifecyclePolicy%2Did}/addGroup");
    }
    ;
    /**
     * Adds specific groups to a lifecycle policy. This action limits the group lifecycle policy to a set of groups only if the managedGroupTypes property of groupLifecyclePolicy is set to Selected.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AddGroupPostResponse
     * @see {@link https://learn.microsoft.com/graph/api/grouplifecyclepolicy-addgroup?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, createAddGroupPostResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Adds specific groups to a lifecycle policy. This action limits the group lifecycle policy to a set of groups only if the managedGroupTypes property of groupLifecyclePolicy is set to Selected.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeAddGroupPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a addGroupRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new AddGroupRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.AddGroupRequestBuilder = AddGroupRequestBuilder;
// tslint:enable
// eslint-enable
