"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TentativelyAcceptRequestBuilder = exports.serializeTentativelyAcceptPostRequestBody = exports.deserializeIntoTentativelyAcceptPostRequestBody = exports.createTentativelyAcceptPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../../../../../models/oDataErrors/oDataError");
const timeSlot_1 = require("../../../../../../../../models/timeSlot");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createTentativelyAcceptPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoTentativelyAcceptPostRequestBody;
}
exports.createTentativelyAcceptPostRequestBodyFromDiscriminatorValue = createTentativelyAcceptPostRequestBodyFromDiscriminatorValue;
function deserializeIntoTentativelyAcceptPostRequestBody(tentativelyAcceptPostRequestBody = {}) {
    return {
        "comment": n => { tentativelyAcceptPostRequestBody.comment = n.getStringValue(); },
        "proposedNewTime": n => { tentativelyAcceptPostRequestBody.proposedNewTime = n.getObjectValue(timeSlot_1.createTimeSlotFromDiscriminatorValue); },
        "sendResponse": n => { tentativelyAcceptPostRequestBody.sendResponse = n.getBooleanValue(); },
    };
}
exports.deserializeIntoTentativelyAcceptPostRequestBody = deserializeIntoTentativelyAcceptPostRequestBody;
function serializeTentativelyAcceptPostRequestBody(writer, tentativelyAcceptPostRequestBody = {}) {
    writer.writeStringValue("Comment", tentativelyAcceptPostRequestBody.comment);
    writer.writeObjectValue("ProposedNewTime", tentativelyAcceptPostRequestBody.proposedNewTime, timeSlot_1.serializeTimeSlot);
    writer.writeBooleanValue("SendResponse", tentativelyAcceptPostRequestBody.sendResponse);
    writer.writeAdditionalData(tentativelyAcceptPostRequestBody.additionalData);
}
exports.serializeTentativelyAcceptPostRequestBody = serializeTentativelyAcceptPostRequestBody;
/**
 * Provides operations to call the tentativelyAccept method.
 */
class TentativelyAcceptRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new TentativelyAcceptRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/groups/{group%2Did}/calendar/calendarView/{event%2Did}/instances/{event%2Did1}/tentativelyAccept");
    }
    ;
    /**
     * Tentatively accept the specified event in a user calendar. If the event allows proposals for new times, on responding tentative to the event, an invitee can choose to suggest an alternative time by including the proposedNewTime parameter. For more information on how to propose a time, and how to receive and accept a new time proposal, see Propose new meeting times.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/event-tentativelyaccept?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Tentatively accept the specified event in a user calendar. If the event allows proposals for new times, on responding tentative to the event, an invitee can choose to suggest an alternative time by including the proposedNewTime parameter. For more information on how to propose a time, and how to receive and accept a new time proposal, see Propose new meeting times.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeTentativelyAcceptPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a tentativelyAcceptRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new TentativelyAcceptRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.TentativelyAcceptRequestBuilder = TentativelyAcceptRequestBuilder;
// tslint:enable
// eslint-enable
