import { type Calendar } from '../../../models/';
import { AllowedCalendarSharingRolesWithUserRequestBuilder } from './allowedCalendarSharingRolesWithUser/';
import { CalendarPermissionsRequestBuilder } from './calendarPermissions/';
import { CalendarViewRequestBuilder } from './calendarView/';
import { EventsRequestBuilder } from './events/';
import { GetScheduleRequestBuilder } from './getSchedule/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface CalendarRequestBuilderGetQueryParameters {
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the calendar property of the microsoft.graph.group entity.
 */
export declare class CalendarRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the calendarPermissions property of the microsoft.graph.calendar entity.
     */
    get calendarPermissions(): CalendarPermissionsRequestBuilder;
    /**
     * Provides operations to manage the calendarView property of the microsoft.graph.calendar entity.
     */
    get calendarView(): CalendarViewRequestBuilder;
    /**
     * Provides operations to manage the events property of the microsoft.graph.calendar entity.
     */
    get events(): EventsRequestBuilder;
    /**
     * Provides operations to call the getSchedule method.
     */
    get getSchedule(): GetScheduleRequestBuilder;
    /**
     * Provides operations to call the allowedCalendarSharingRoles method.
     * @param User Usage: User='{User}'
     * @returns a allowedCalendarSharingRolesWithUserRequestBuilder
     */
    allowedCalendarSharingRolesWithUser(user: string | undefined): AllowedCalendarSharingRolesWithUserRequestBuilder;
    /**
     * Instantiates a new CalendarRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The group's calendar. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Calendar
     */
    get(requestConfiguration?: RequestConfiguration<CalendarRequestBuilderGetQueryParameters> | undefined): Promise<Calendar | undefined>;
    /**
     * The group's calendar. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<CalendarRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a calendarRequestBuilder
     */
    withUrl(rawUrl: string): CalendarRequestBuilder;
}
