"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ForwardRequestBuilder = exports.serializeForwardPostRequestBody = exports.deserializeIntoForwardPostRequestBody = exports.createForwardPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../../../../../../models/oDataErrors/oDataError");
const recipient_1 = require("../../../../../../../../../models/recipient");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createForwardPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoForwardPostRequestBody;
}
exports.createForwardPostRequestBodyFromDiscriminatorValue = createForwardPostRequestBodyFromDiscriminatorValue;
function deserializeIntoForwardPostRequestBody(forwardPostRequestBody = {}) {
    return {
        "comment": n => { forwardPostRequestBody.comment = n.getStringValue(); },
        "toRecipients": n => { forwardPostRequestBody.toRecipients = n.getCollectionOfObjectValues(recipient_1.createRecipientFromDiscriminatorValue); },
    };
}
exports.deserializeIntoForwardPostRequestBody = deserializeIntoForwardPostRequestBody;
function serializeForwardPostRequestBody(writer, forwardPostRequestBody = {}) {
    writer.writeStringValue("Comment", forwardPostRequestBody.comment);
    writer.writeCollectionOfObjectValues("ToRecipients", forwardPostRequestBody.toRecipients, recipient_1.serializeRecipient);
    writer.writeAdditionalData(forwardPostRequestBody.additionalData);
}
exports.serializeForwardPostRequestBody = serializeForwardPostRequestBody;
/**
 * Provides operations to call the forward method.
 */
class ForwardRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new ForwardRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/groups/{group%2Did}/conversations/{conversation%2Did}/threads/{conversationThread%2Did}/posts/{post%2Did}/forward");
    }
    ;
    /**
     * Forward a post to a recipient. You can specify both the parent conversation and thread in the request, or, you can specify just the parent thread without the parent conversation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/post-forward?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Forward a post to a recipient. You can specify both the parent conversation and thread in the request, or, you can specify just the parent thread without the parent conversation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeForwardPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a forwardRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new ForwardRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.ForwardRequestBuilder = ForwardRequestBuilder;
// tslint:enable
// eslint-enable
