import { type Onenote } from '../../../models/onenote';
import { NotebooksRequestBuilder } from './notebooks/';
import { OperationsRequestBuilder } from './operations/';
import { PagesRequestBuilder } from './pages/';
import { ResourcesRequestBuilder } from './resources/';
import { SectionGroupsRequestBuilder } from './sectionGroups/';
import { SectionsRequestBuilder } from './sections/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface OnenoteRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the onenote property of the microsoft.graph.group entity.
 */
export declare class OnenoteRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the notebooks property of the microsoft.graph.onenote entity.
     */
    get notebooks(): NotebooksRequestBuilder;
    /**
     * Provides operations to manage the operations property of the microsoft.graph.onenote entity.
     */
    get operations(): OperationsRequestBuilder;
    /**
     * Provides operations to manage the pages property of the microsoft.graph.onenote entity.
     */
    get pages(): PagesRequestBuilder;
    /**
     * Provides operations to manage the resources property of the microsoft.graph.onenote entity.
     */
    get resources(): ResourcesRequestBuilder;
    /**
     * Provides operations to manage the sectionGroups property of the microsoft.graph.onenote entity.
     */
    get sectionGroups(): SectionGroupsRequestBuilder;
    /**
     * Provides operations to manage the sections property of the microsoft.graph.onenote entity.
     */
    get sections(): SectionsRequestBuilder;
    /**
     * Instantiates a new OnenoteRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property onenote for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Get onenote from groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Onenote
     */
    get(requestConfiguration?: RequestConfiguration<OnenoteRequestBuilderGetQueryParameters> | undefined): Promise<Onenote | undefined>;
    /**
     * Update the navigation property onenote in groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Onenote
     */
    patch(body: Onenote, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Onenote | undefined>;
    /**
     * Delete navigation property onenote for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Get onenote from groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<OnenoteRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property onenote in groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Onenote, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a onenoteRequestBuilder
     */
    withUrl(rawUrl: string): OnenoteRequestBuilder;
}
