import { type PlannerGroup } from '../../../models/plannerGroup';
import { PlansRequestBuilder } from './plans/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface PlannerRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the planner property of the microsoft.graph.group entity.
 */
export declare class PlannerRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the plans property of the microsoft.graph.plannerGroup entity.
     */
    get plans(): PlansRequestBuilder;
    /**
     * Instantiates a new PlannerRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property planner for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Entry-point to Planner resource that might exist for a Unified Group.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PlannerGroup
     */
    get(requestConfiguration?: RequestConfiguration<PlannerRequestBuilderGetQueryParameters> | undefined): Promise<PlannerGroup | undefined>;
    /**
     * Update the navigation property planner in groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PlannerGroup
     */
    patch(body: PlannerGroup, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<PlannerGroup | undefined>;
    /**
     * Delete navigation property planner for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Entry-point to Planner resource that might exist for a Unified Group.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<PlannerRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property planner in groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: PlannerGroup, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a plannerRequestBuilder
     */
    withUrl(rawUrl: string): PlannerRequestBuilder;
}
