import { type ColumnDefinitionCollectionResponse } from '../../../../../../../models/';
import { type ColumnDefinition } from '../../../../../../../models/columnDefinition';
import { CountRequestBuilder } from './count/';
import { ColumnDefinitionItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ColumnsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the columns property of the microsoft.graph.list entity.
 */
export declare class ColumnsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the columns property of the microsoft.graph.list entity.
     * @param columnDefinitionId The unique identifier of columnDefinition
     * @returns a ColumnDefinitionItemRequestBuilder
     */
    byColumnDefinitionId(columnDefinitionId: string): ColumnDefinitionItemRequestBuilder;
    /**
     * Instantiates a new ColumnsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the collection of columns represented as [columnDefinition][columnDefinition] resources in a [list][list].
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ColumnDefinitionCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/list-list-columns?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ColumnsRequestBuilderGetQueryParameters> | undefined): Promise<ColumnDefinitionCollectionResponse | undefined>;
    /**
     * Create a column for a [list][list] with a request that specifies a [columnDefinition][columnDefinition].
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ColumnDefinition
     * @see {@link https://learn.microsoft.com/graph/api/list-post-columns?view=graph-rest-1.0|Find more info here}
     */
    post(body: ColumnDefinition, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ColumnDefinition | undefined>;
    /**
     * Get the collection of columns represented as [columnDefinition][columnDefinition] resources in a [list][list].
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ColumnsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a column for a [list][list] with a request that specifies a [columnDefinition][columnDefinition].
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ColumnDefinition, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a columnsRequestBuilder
     */
    withUrl(rawUrl: string): ColumnsRequestBuilder;
}
