import { type OnenotePage } from '../../../../../../../models/onenotePage';
import { ContentRequestBuilder } from './content/';
import { CopyToSectionRequestBuilder } from './copyToSection/';
import { OnenotePatchContentRequestBuilder } from './onenotePatchContent/';
import { ParentNotebookRequestBuilder } from './parentNotebook/';
import { ParentSectionRequestBuilder } from './parentSection/';
import { PreviewRequestBuilder } from './preview/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface OnenotePageItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the pages property of the microsoft.graph.onenote entity.
 */
export declare class OnenotePageItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the media for the group entity.
     */
    get content(): ContentRequestBuilder;
    /**
     * Provides operations to call the copyToSection method.
     */
    get copyToSection(): CopyToSectionRequestBuilder;
    /**
     * Provides operations to call the onenotePatchContent method.
     */
    get onenotePatchContent(): OnenotePatchContentRequestBuilder;
    /**
     * Provides operations to manage the parentNotebook property of the microsoft.graph.onenotePage entity.
     */
    get parentNotebook(): ParentNotebookRequestBuilder;
    /**
     * Provides operations to manage the parentSection property of the microsoft.graph.onenotePage entity.
     */
    get parentSection(): ParentSectionRequestBuilder;
    /**
     * Provides operations to call the preview method.
     */
    get preview(): PreviewRequestBuilder;
    /**
     * Instantiates a new OnenotePageItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete a OneNote page.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/page-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of a page object. Getting page information Access a page's metadata by page identifier: Getting page content You can use the page's content endpoint to get the HTML content of a page: The includeIDs=true query option is used to update pages.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OnenotePage
     * @see {@link https://learn.microsoft.com/graph/api/page-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<OnenotePageItemRequestBuilderGetQueryParameters> | undefined): Promise<OnenotePage | undefined>;
    /**
     * Update the navigation property pages in groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OnenotePage
     */
    patch(body: OnenotePage, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<OnenotePage | undefined>;
    /**
     * Delete a OneNote page.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of a page object. Getting page information Access a page's metadata by page identifier: Getting page content You can use the page's content endpoint to get the HTML content of a page: The includeIDs=true query option is used to update pages.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<OnenotePageItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property pages in groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: OnenotePage, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a OnenotePageItemRequestBuilder
     */
    withUrl(rawUrl: string): OnenotePageItemRequestBuilder;
}
