import { type Set } from '../../../../../../../models/termStore/set';
import { ChildrenRequestBuilder } from './children/';
import { ParentGroupRequestBuilder } from './parentGroup/';
import { RelationsRequestBuilder } from './relations/';
import { TermsRequestBuilder } from './terms/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SetItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the sets property of the microsoft.graph.termStore.store entity.
 */
export declare class SetItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the children property of the microsoft.graph.termStore.set entity.
     */
    get children(): ChildrenRequestBuilder;
    /**
     * Provides operations to manage the parentGroup property of the microsoft.graph.termStore.set entity.
     */
    get parentGroup(): ParentGroupRequestBuilder;
    /**
     * Provides operations to manage the relations property of the microsoft.graph.termStore.set entity.
     */
    get relations(): RelationsRequestBuilder;
    /**
     * Provides operations to manage the terms property of the microsoft.graph.termStore.set entity.
     */
    get terms(): TermsRequestBuilder;
    /**
     * Instantiates a new SetItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete a set object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/termstore-set-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of a set object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Set
     * @see {@link https://learn.microsoft.com/graph/api/termstore-set-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SetItemRequestBuilderGetQueryParameters> | undefined): Promise<Set | undefined>;
    /**
     * Update the properties of a set object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Set
     * @see {@link https://learn.microsoft.com/graph/api/termstore-set-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: Set, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Set | undefined>;
    /**
     * Delete a set object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of a set object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SetItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of a set object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Set, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a SetItemRequestBuilder
     */
    withUrl(rawUrl: string): SetItemRequestBuilder;
}
