import { type StoreCollectionResponse } from '../../../../../models/termStore/';
import { type Store } from '../../../../../models/termStore/store';
import { CountRequestBuilder } from './count/';
import { StoreItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface TermStoresRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the termStores property of the microsoft.graph.site entity.
 */
export declare class TermStoresRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the termStores property of the microsoft.graph.site entity.
     * @param storeId The unique identifier of store
     * @returns a StoreItemRequestBuilder
     */
    byStoreId(storeId: string): StoreItemRequestBuilder;
    /**
     * Instantiates a new TermStoresRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The collection of termStores under this site.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of StoreCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<TermStoresRequestBuilderGetQueryParameters> | undefined): Promise<StoreCollectionResponse | undefined>;
    /**
     * Create new navigation property to termStores for groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Store
     */
    post(body: Store, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Store | undefined>;
    /**
     * The collection of termStores under this site.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<TermStoresRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to termStores for groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: Store, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a termStoresRequestBuilder
     */
    withUrl(rawUrl: string): TermStoresRequestBuilder;
}
