import { type TermCollectionResponse } from '../../../../../../../../../models/termStore/';
import { type Term } from '../../../../../../../../../models/termStore/term';
import { CountRequestBuilder } from './count/';
import { TermItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface TermsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the terms property of the microsoft.graph.termStore.set entity.
 */
export declare class TermsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the terms property of the microsoft.graph.termStore.set entity.
     * @param termId The unique identifier of term
     * @returns a TermItemRequestBuilder
     */
    byTermId(termId: string): TermItemRequestBuilder;
    /**
     * Instantiates a new TermsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Read the properties and relationships of a term object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TermCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<TermsRequestBuilderGetQueryParameters> | undefined): Promise<TermCollectionResponse | undefined>;
    /**
     * Create new navigation property to terms for groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Term
     */
    post(body: Term, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Term | undefined>;
    /**
     * Read the properties and relationships of a term object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<TermsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to terms for groups
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: Term, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a termsRequestBuilder
     */
    withUrl(rawUrl: string): TermsRequestBuilder;
}
