import { type TimeOffCollectionResponse } from '../../../../../models/';
import { type TimeOff } from '../../../../../models/timeOff';
import { CountRequestBuilder } from './count/';
import { TimeOffItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface TimesOffRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the timesOff property of the microsoft.graph.schedule entity.
 */
export declare class TimesOffRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the timesOff property of the microsoft.graph.schedule entity.
     * @param timeOffId The unique identifier of timeOff
     * @returns a TimeOffItemRequestBuilder
     */
    byTimeOffId(timeOffId: string): TimeOffItemRequestBuilder;
    /**
     * Instantiates a new TimesOffRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the list of timeOff instances in a schedule.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TimeOffCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/schedule-list-timesoff?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<TimesOffRequestBuilderGetQueryParameters> | undefined): Promise<TimeOffCollectionResponse | undefined>;
    /**
     * Create a new timeOff instance in a schedule.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TimeOff
     * @see {@link https://learn.microsoft.com/graph/api/schedule-post-timesoff?view=graph-rest-1.0|Find more info here}
     */
    post(body: TimeOff, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<TimeOff | undefined>;
    /**
     * Get the list of timeOff instances in a schedule.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<TimesOffRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new timeOff instance in a schedule.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: TimeOff, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a timesOffRequestBuilder
     */
    withUrl(rawUrl: string): TimesOffRequestBuilder;
}
