"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidatePropertiesRequestBuilder = exports.serializeValidatePropertiesPostRequestBody = exports.deserializeIntoValidatePropertiesPostRequestBody = exports.createValidatePropertiesPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createValidatePropertiesPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoValidatePropertiesPostRequestBody;
}
exports.createValidatePropertiesPostRequestBodyFromDiscriminatorValue = createValidatePropertiesPostRequestBodyFromDiscriminatorValue;
function deserializeIntoValidatePropertiesPostRequestBody(validatePropertiesPostRequestBody = {}) {
    return {
        "displayName": n => { validatePropertiesPostRequestBody.displayName = n.getStringValue(); },
        "mailNickname": n => { validatePropertiesPostRequestBody.mailNickname = n.getStringValue(); },
        "onBehalfOfUserId": n => { validatePropertiesPostRequestBody.onBehalfOfUserId = n.getGuidValue(); },
    };
}
exports.deserializeIntoValidatePropertiesPostRequestBody = deserializeIntoValidatePropertiesPostRequestBody;
function serializeValidatePropertiesPostRequestBody(writer, validatePropertiesPostRequestBody = {}) {
    writer.writeStringValue("displayName", validatePropertiesPostRequestBody.displayName);
    writer.writeStringValue("mailNickname", validatePropertiesPostRequestBody.mailNickname);
    writer.writeGuidValue("onBehalfOfUserId", validatePropertiesPostRequestBody.onBehalfOfUserId);
    writer.writeAdditionalData(validatePropertiesPostRequestBody.additionalData);
}
exports.serializeValidatePropertiesPostRequestBody = serializeValidatePropertiesPostRequestBody;
/**
 * Provides operations to call the validateProperties method.
 */
class ValidatePropertiesRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new ValidatePropertiesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/groups/{group%2Did}/validateProperties");
    }
    ;
    /**
     * Validate that a Microsoft 365 group's display name or mail nickname complies with naming policies. Clients can use this API to determine whether a display name or mail nickname is valid before trying to update a Microsoft 365 group. To validate the properties before creating a group, use the directoryobject:validateProperties function. The following policy validations are performed for the display name and mail nickname properties: This API only returns the first validation failure that is encountered. If the properties fail multiple validations, only the first validation failure is returned. However, you can validate both the mail nickname and the display name and receive a collection of validation errors if you are only validating the prefix and suffix naming policy. To learn more about configuring naming policies, see Configure naming policy.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/group-validateproperties?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Validate that a Microsoft 365 group's display name or mail nickname complies with naming policies. Clients can use this API to determine whether a display name or mail nickname is valid before trying to update a Microsoft 365 group. To validate the properties before creating a group, use the directoryobject:validateProperties function. The following policy validations are performed for the display name and mail nickname properties: This API only returns the first validation failure that is encountered. If the properties fail multiple validations, only the first validation failure is returned. However, you can validate both the mail nickname and the display name and receive a collection of validation errors if you are only validating the prefix and suffix naming policy. To learn more about configuring naming policies, see Configure naming policy.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeValidatePropertiesPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a validatePropertiesRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new ValidatePropertiesRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.ValidatePropertiesRequestBuilder = ValidatePropertiesRequestBuilder;
// tslint:enable
// eslint-enable
