import { type IdentityApiConnector } from '../../../models/identityApiConnector';
import { UploadClientCertificateRequestBuilder } from './uploadClientCertificate/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface IdentityApiConnectorItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the apiConnectors property of the microsoft.graph.identityContainer entity.
 */
export declare class IdentityApiConnectorItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the uploadClientCertificate method.
     */
    get uploadClientCertificate(): UploadClientCertificateRequestBuilder;
    /**
     * Instantiates a new IdentityApiConnectorItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete an identityApiConnector object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/identityapiconnector-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties of an identityApiConnector object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityApiConnector
     * @see {@link https://learn.microsoft.com/graph/api/identityapiconnector-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<IdentityApiConnectorItemRequestBuilderGetQueryParameters> | undefined): Promise<IdentityApiConnector | undefined>;
    /**
     * Update the properties of an identityApiConnector object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityApiConnector
     * @see {@link https://learn.microsoft.com/graph/api/identityapiconnector-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: IdentityApiConnector, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<IdentityApiConnector | undefined>;
    /**
     * Delete an identityApiConnector object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties of an identityApiConnector object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<IdentityApiConnectorItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of an identityApiConnector object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: IdentityApiConnector, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a IdentityApiConnectorItemRequestBuilder
     */
    withUrl(rawUrl: string): IdentityApiConnectorItemRequestBuilder;
}
