import { type B2xIdentityUserFlow } from '../../../models/b2xIdentityUserFlow';
import { ApiConnectorConfigurationRequestBuilder } from './apiConnectorConfiguration/';
import { IdentityProvidersRequestBuilder } from './identityProviders/';
import { LanguagesRequestBuilder } from './languages/';
import { UserAttributeAssignmentsRequestBuilder } from './userAttributeAssignments/';
import { UserFlowIdentityProvidersRequestBuilder } from './userFlowIdentityProviders/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface B2xIdentityUserFlowItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the b2xUserFlows property of the microsoft.graph.identityContainer entity.
 */
export declare class B2xIdentityUserFlowItemRequestBuilder extends BaseRequestBuilder {
    /**
     * The apiConnectorConfiguration property
     */
    get apiConnectorConfiguration(): ApiConnectorConfigurationRequestBuilder;
    /**
     * Provides operations to manage the identityProviders property of the microsoft.graph.b2xIdentityUserFlow entity.
     */
    get identityProviders(): IdentityProvidersRequestBuilder;
    /**
     * Provides operations to manage the languages property of the microsoft.graph.b2xIdentityUserFlow entity.
     */
    get languages(): LanguagesRequestBuilder;
    /**
     * Provides operations to manage the userAttributeAssignments property of the microsoft.graph.b2xIdentityUserFlow entity.
     */
    get userAttributeAssignments(): UserAttributeAssignmentsRequestBuilder;
    /**
     * Provides operations to manage the userFlowIdentityProviders property of the microsoft.graph.b2xIdentityUserFlow entity.
     */
    get userFlowIdentityProviders(): UserFlowIdentityProvidersRequestBuilder;
    /**
     * Instantiates a new B2xIdentityUserFlowItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete a b2xIdentityUserFlow object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/b2xidentityuserflow-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of a b2xIdentityUserFlow object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of B2xIdentityUserFlow
     * @see {@link https://learn.microsoft.com/graph/api/b2xidentityuserflow-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<B2xIdentityUserFlowItemRequestBuilderGetQueryParameters> | undefined): Promise<B2xIdentityUserFlow | undefined>;
    /**
     * Update the navigation property b2xUserFlows in identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of B2xIdentityUserFlow
     */
    patch(body: B2xIdentityUserFlow, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<B2xIdentityUserFlow | undefined>;
    /**
     * Delete a b2xIdentityUserFlow object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of a b2xIdentityUserFlow object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<B2xIdentityUserFlowItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property b2xUserFlows in identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: B2xIdentityUserFlow, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a B2xIdentityUserFlowItemRequestBuilder
     */
    withUrl(rawUrl: string): B2xIdentityUserFlowItemRequestBuilder;
}
