import { type UserFlowLanguagePageCollectionResponse } from '../../../../../../models/';
import { type UserFlowLanguagePage } from '../../../../../../models/userFlowLanguagePage';
import { CountRequestBuilder } from './count/';
import { UserFlowLanguagePageItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DefaultPagesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the defaultPages property of the microsoft.graph.userFlowLanguageConfiguration entity.
 */
export declare class DefaultPagesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the defaultPages property of the microsoft.graph.userFlowLanguageConfiguration entity.
     * @param userFlowLanguagePageId The unique identifier of userFlowLanguagePage
     * @returns a UserFlowLanguagePageItemRequestBuilder
     */
    byUserFlowLanguagePageId(userFlowLanguagePageId: string): UserFlowLanguagePageItemRequestBuilder;
    /**
     * Instantiates a new DefaultPagesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Collection of pages with the default content to display in a user flow for a specified language. This collection doesn't allow any kind of modification.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserFlowLanguagePageCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<DefaultPagesRequestBuilderGetQueryParameters> | undefined): Promise<UserFlowLanguagePageCollectionResponse | undefined>;
    /**
     * Create new navigation property to defaultPages for identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserFlowLanguagePage
     */
    post(body: UserFlowLanguagePage, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<UserFlowLanguagePage | undefined>;
    /**
     * Collection of pages with the default content to display in a user flow for a specified language. This collection doesn't allow any kind of modification.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DefaultPagesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to defaultPages for identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: UserFlowLanguagePage, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a defaultPagesRequestBuilder
     */
    withUrl(rawUrl: string): DefaultPagesRequestBuilder;
}
