import { type IdentityUserFlowAttributeAssignmentCollectionResponse } from '../../../../models/';
import { type IdentityUserFlowAttributeAssignment } from '../../../../models/identityUserFlowAttributeAssignment';
import { CountRequestBuilder } from './count/';
import { GetOrderRequestBuilder } from './getOrder/';
import { IdentityUserFlowAttributeAssignmentItemRequestBuilder } from './item/';
import { SetOrderRequestBuilder } from './setOrder/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface UserAttributeAssignmentsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the userAttributeAssignments property of the microsoft.graph.b2xIdentityUserFlow entity.
 */
export declare class UserAttributeAssignmentsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to call the getOrder method.
     */
    get getOrder(): GetOrderRequestBuilder;
    /**
     * Provides operations to call the setOrder method.
     */
    get setOrder(): SetOrderRequestBuilder;
    /**
     * Provides operations to manage the userAttributeAssignments property of the microsoft.graph.b2xIdentityUserFlow entity.
     * @param identityUserFlowAttributeAssignmentId The unique identifier of identityUserFlowAttributeAssignment
     * @returns a IdentityUserFlowAttributeAssignmentItemRequestBuilder
     */
    byIdentityUserFlowAttributeAssignmentId(identityUserFlowAttributeAssignmentId: string): IdentityUserFlowAttributeAssignmentItemRequestBuilder;
    /**
     * Instantiates a new UserAttributeAssignmentsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the identityUserFlowAttributeAssignment resources from the userAttributeAssignments navigation property in a b2xIdentityUserFlow.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityUserFlowAttributeAssignmentCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/b2xidentityuserflow-list-userattributeassignments?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<UserAttributeAssignmentsRequestBuilderGetQueryParameters> | undefined): Promise<IdentityUserFlowAttributeAssignmentCollectionResponse | undefined>;
    /**
     * Create a new identityUserFlowAttributeAssignment object in a b2xIdentityUserFlow.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityUserFlowAttributeAssignment
     * @see {@link https://learn.microsoft.com/graph/api/b2xidentityuserflow-post-userattributeassignments?view=graph-rest-1.0|Find more info here}
     */
    post(body: IdentityUserFlowAttributeAssignment, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<IdentityUserFlowAttributeAssignment | undefined>;
    /**
     * Get the identityUserFlowAttributeAssignment resources from the userAttributeAssignments navigation property in a b2xIdentityUserFlow.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<UserAttributeAssignmentsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new identityUserFlowAttributeAssignment object in a b2xIdentityUserFlow.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: IdentityUserFlowAttributeAssignment, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a userAttributeAssignmentsRequestBuilder
     */
    withUrl(rawUrl: string): UserAttributeAssignmentsRequestBuilder;
}
