import { type AuthenticationContextClassReferenceCollectionResponse } from '../../../models/';
import { type AuthenticationContextClassReference } from '../../../models/authenticationContextClassReference';
import { CountRequestBuilder } from './count/';
import { AuthenticationContextClassReferenceItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AuthenticationContextClassReferencesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the authenticationContextClassReferences property of the microsoft.graph.conditionalAccessRoot entity.
 */
export declare class AuthenticationContextClassReferencesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the authenticationContextClassReferences property of the microsoft.graph.conditionalAccessRoot entity.
     * @param authenticationContextClassReferenceId The unique identifier of authenticationContextClassReference
     * @returns a AuthenticationContextClassReferenceItemRequestBuilder
     */
    byAuthenticationContextClassReferenceId(authenticationContextClassReferenceId: string): AuthenticationContextClassReferenceItemRequestBuilder;
    /**
     * Instantiates a new AuthenticationContextClassReferencesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of authenticationContextClassReference objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AuthenticationContextClassReferenceCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/conditionalaccessroot-list-authenticationcontextclassreferences?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<AuthenticationContextClassReferencesRequestBuilderGetQueryParameters> | undefined): Promise<AuthenticationContextClassReferenceCollectionResponse | undefined>;
    /**
     * Create new navigation property to authenticationContextClassReferences for identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AuthenticationContextClassReference
     */
    post(body: AuthenticationContextClassReference, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AuthenticationContextClassReference | undefined>;
    /**
     * Retrieve a list of authenticationContextClassReference objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AuthenticationContextClassReferencesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to authenticationContextClassReferences for identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AuthenticationContextClassReference, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a authenticationContextClassReferencesRequestBuilder
     */
    withUrl(rawUrl: string): AuthenticationContextClassReferencesRequestBuilder;
}
