import { type IdentityContainer } from '../models/identityContainer';
import { ApiConnectorsRequestBuilder } from './apiConnectors/';
import { B2xUserFlowsRequestBuilder } from './b2xUserFlows/';
import { ConditionalAccessRequestBuilder } from './conditionalAccess/';
import { IdentityProvidersRequestBuilder } from './identityProviders/';
import { UserFlowAttributesRequestBuilder } from './userFlowAttributes/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface IdentityRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the identityContainer singleton.
 */
export declare class IdentityRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the apiConnectors property of the microsoft.graph.identityContainer entity.
     */
    get apiConnectors(): ApiConnectorsRequestBuilder;
    /**
     * Provides operations to manage the b2xUserFlows property of the microsoft.graph.identityContainer entity.
     */
    get b2xUserFlows(): B2xUserFlowsRequestBuilder;
    /**
     * Provides operations to manage the conditionalAccess property of the microsoft.graph.identityContainer entity.
     */
    get conditionalAccess(): ConditionalAccessRequestBuilder;
    /**
     * Provides operations to manage the identityProviders property of the microsoft.graph.identityContainer entity.
     */
    get identityProviders(): IdentityProvidersRequestBuilder;
    /**
     * Provides operations to manage the userFlowAttributes property of the microsoft.graph.identityContainer entity.
     */
    get userFlowAttributes(): UserFlowAttributesRequestBuilder;
    /**
     * Instantiates a new IdentityRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityContainer
     */
    get(requestConfiguration?: RequestConfiguration<IdentityRequestBuilderGetQueryParameters> | undefined): Promise<IdentityContainer | undefined>;
    /**
     * Update identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityContainer
     */
    patch(body: IdentityContainer, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<IdentityContainer | undefined>;
    /**
     * Get identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<IdentityRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update identity
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: IdentityContainer, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a identityRequestBuilder
     */
    withUrl(rawUrl: string): IdentityRequestBuilder;
}
