import { type AccessReviewInstance } from '../../../../../../models/accessReviewInstance';
import { AcceptRecommendationsRequestBuilder } from './acceptRecommendations/';
import { ApplyDecisionsRequestBuilder } from './applyDecisions/';
import { BatchRecordDecisionsRequestBuilder } from './batchRecordDecisions/';
import { ContactedReviewersRequestBuilder } from './contactedReviewers/';
import { DecisionsRequestBuilder } from './decisions/';
import { ResetDecisionsRequestBuilder } from './resetDecisions/';
import { SendReminderRequestBuilder } from './sendReminder/';
import { StagesRequestBuilder } from './stages/';
import { StopRequestBuilder } from './stop/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AccessReviewInstanceItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the instances property of the microsoft.graph.accessReviewScheduleDefinition entity.
 */
export declare class AccessReviewInstanceItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the acceptRecommendations method.
     */
    get acceptRecommendations(): AcceptRecommendationsRequestBuilder;
    /**
     * Provides operations to call the applyDecisions method.
     */
    get applyDecisions(): ApplyDecisionsRequestBuilder;
    /**
     * Provides operations to call the batchRecordDecisions method.
     */
    get batchRecordDecisions(): BatchRecordDecisionsRequestBuilder;
    /**
     * Provides operations to manage the contactedReviewers property of the microsoft.graph.accessReviewInstance entity.
     */
    get contactedReviewers(): ContactedReviewersRequestBuilder;
    /**
     * Provides operations to manage the decisions property of the microsoft.graph.accessReviewInstance entity.
     */
    get decisions(): DecisionsRequestBuilder;
    /**
     * Provides operations to call the resetDecisions method.
     */
    get resetDecisions(): ResetDecisionsRequestBuilder;
    /**
     * Provides operations to call the sendReminder method.
     */
    get sendReminder(): SendReminderRequestBuilder;
    /**
     * Provides operations to manage the stages property of the microsoft.graph.accessReviewInstance entity.
     */
    get stages(): StagesRequestBuilder;
    /**
     * Provides operations to call the stop method.
     */
    get stop(): StopRequestBuilder;
    /**
     * Instantiates a new AccessReviewInstanceItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property instances for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of an accessReviewInstance object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessReviewInstance
     * @see {@link https://learn.microsoft.com/graph/api/accessreviewinstance-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<AccessReviewInstanceItemRequestBuilderGetQueryParameters> | undefined): Promise<AccessReviewInstance | undefined>;
    /**
     * Update the properties of an accessReviewInstance object. Only the reviewers and fallbackReviewers properties can be updated but the scope property is also required in the request body. You can only add reviewers to the fallbackReviewers property but can't remove existing fallbackReviewers. To update an accessReviewInstance, it's status must be InProgress.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessReviewInstance
     * @see {@link https://learn.microsoft.com/graph/api/accessreviewinstance-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: AccessReviewInstance, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AccessReviewInstance | undefined>;
    /**
     * Delete navigation property instances for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of an accessReviewInstance object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AccessReviewInstanceItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of an accessReviewInstance object. Only the reviewers and fallbackReviewers properties can be updated but the scope property is also required in the request body. You can only add reviewers to the fallbackReviewers property but can't remove existing fallbackReviewers. To update an accessReviewInstance, it's status must be InProgress.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: AccessReviewInstance, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a AccessReviewInstanceItemRequestBuilder
     */
    withUrl(rawUrl: string): AccessReviewInstanceItemRequestBuilder;
}
