import { type AccessReviewHistoryInstanceCollectionResponse } from '../../../../../models/';
import { type AccessReviewHistoryInstance } from '../../../../../models/accessReviewHistoryInstance';
import { CountRequestBuilder } from './count/';
import { AccessReviewHistoryInstanceItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface InstancesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the instances property of the microsoft.graph.accessReviewHistoryDefinition entity.
 */
export declare class InstancesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the instances property of the microsoft.graph.accessReviewHistoryDefinition entity.
     * @param accessReviewHistoryInstanceId The unique identifier of accessReviewHistoryInstance
     * @returns a AccessReviewHistoryInstanceItemRequestBuilder
     */
    byAccessReviewHistoryInstanceId(accessReviewHistoryInstanceId: string): AccessReviewHistoryInstanceItemRequestBuilder;
    /**
     * Instantiates a new InstancesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the instances of an access review history definition created in the last 30 days.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessReviewHistoryInstanceCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/accessreviewhistorydefinition-list-instances?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<InstancesRequestBuilderGetQueryParameters> | undefined): Promise<AccessReviewHistoryInstanceCollectionResponse | undefined>;
    /**
     * Create new navigation property to instances for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessReviewHistoryInstance
     */
    post(body: AccessReviewHistoryInstance, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AccessReviewHistoryInstance | undefined>;
    /**
     * Retrieve the instances of an access review history definition created in the last 30 days.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<InstancesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to instances for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AccessReviewHistoryInstance, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a instancesRequestBuilder
     */
    withUrl(rawUrl: string): InstancesRequestBuilder;
}
