import { type UserConsentRequestCollectionResponse } from '../../../../../models/';
import { type UserConsentRequest } from '../../../../../models/userConsentRequest';
import { CountRequestBuilder } from './count/';
import { FilterByCurrentUserWithOnRequestBuilder } from './filterByCurrentUserWithOn/';
import { UserConsentRequestItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface UserConsentRequestsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the userConsentRequests property of the microsoft.graph.appConsentRequest entity.
 */
export declare class UserConsentRequestsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the userConsentRequests property of the microsoft.graph.appConsentRequest entity.
     * @param userConsentRequestId The unique identifier of userConsentRequest
     * @returns a UserConsentRequestItemRequestBuilder
     */
    byUserConsentRequestId(userConsentRequestId: string): UserConsentRequestItemRequestBuilder;
    /**
     * Instantiates a new UserConsentRequestsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Provides operations to call the filterByCurrentUser method.
     * @param on Usage: on='{on}'
     * @returns a filterByCurrentUserWithOnRequestBuilder
     */
    filterByCurrentUserWithOn(on: string | undefined): FilterByCurrentUserWithOnRequestBuilder;
    /**
     * Retrieve a collection of userConsentRequest objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserConsentRequestCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/appconsentrequest-list-userconsentrequests?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<UserConsentRequestsRequestBuilderGetQueryParameters> | undefined): Promise<UserConsentRequestCollectionResponse | undefined>;
    /**
     * Create new navigation property to userConsentRequests for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserConsentRequest
     */
    post(body: UserConsentRequest, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<UserConsentRequest | undefined>;
    /**
     * Retrieve a collection of userConsentRequest objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<UserConsentRequestsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to userConsentRequests for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: UserConsentRequest, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a userConsentRequestsRequestBuilder
     */
    withUrl(rawUrl: string): UserConsentRequestsRequestBuilder;
}
