import { type AccessPackageQuestionCollectionResponse } from '../../../../../../../models/';
import { type AccessPackageQuestion } from '../../../../../../../models/accessPackageQuestion';
import { CountRequestBuilder } from './count/';
import { AccessPackageQuestionItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface QuestionsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the questions property of the microsoft.graph.accessPackageAssignmentPolicy entity.
 */
export declare class QuestionsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the questions property of the microsoft.graph.accessPackageAssignmentPolicy entity.
     * @param accessPackageQuestionId The unique identifier of accessPackageQuestion
     * @returns a AccessPackageQuestionItemRequestBuilder
     */
    byAccessPackageQuestionId(accessPackageQuestionId: string): AccessPackageQuestionItemRequestBuilder;
    /**
     * Instantiates a new QuestionsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Questions that are posed to the  requestor.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessPackageQuestionCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<QuestionsRequestBuilderGetQueryParameters> | undefined): Promise<AccessPackageQuestionCollectionResponse | undefined>;
    /**
     * Create new navigation property to questions for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessPackageQuestion
     */
    post(body: AccessPackageQuestion, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AccessPackageQuestion | undefined>;
    /**
     * Questions that are posed to the  requestor.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<QuestionsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to questions for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AccessPackageQuestion, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a questionsRequestBuilder
     */
    withUrl(rawUrl: string): QuestionsRequestBuilder;
}
