import { type ConnectedOrganizationCollectionResponse } from '../../../models/';
import { type ConnectedOrganization } from '../../../models/connectedOrganization';
import { CountRequestBuilder } from './count/';
import { ConnectedOrganizationItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ConnectedOrganizationsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the connectedOrganizations property of the microsoft.graph.entitlementManagement entity.
 */
export declare class ConnectedOrganizationsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the connectedOrganizations property of the microsoft.graph.entitlementManagement entity.
     * @param connectedOrganizationId The unique identifier of connectedOrganization
     * @returns a ConnectedOrganizationItemRequestBuilder
     */
    byConnectedOrganizationId(connectedOrganizationId: string): ConnectedOrganizationItemRequestBuilder;
    /**
     * Instantiates a new ConnectedOrganizationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of connectedOrganization objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ConnectedOrganizationCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/entitlementmanagement-list-connectedorganizations?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ConnectedOrganizationsRequestBuilderGetQueryParameters> | undefined): Promise<ConnectedOrganizationCollectionResponse | undefined>;
    /**
     * Create a new connectedOrganization object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ConnectedOrganization
     * @see {@link https://learn.microsoft.com/graph/api/entitlementmanagement-post-connectedorganizations?view=graph-rest-1.0|Find more info here}
     */
    post(body: ConnectedOrganization, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ConnectedOrganization | undefined>;
    /**
     * Retrieve a list of connectedOrganization objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ConnectedOrganizationsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new connectedOrganization object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ConnectedOrganization, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a connectedOrganizationsRequestBuilder
     */
    withUrl(rawUrl: string): ConnectedOrganizationsRequestBuilder;
}
