import { type AccessPackageResourceRoleScopeCollectionResponse } from '../../../models/';
import { type AccessPackageResourceRoleScope } from '../../../models/accessPackageResourceRoleScope';
import { CountRequestBuilder } from './count/';
import { AccessPackageResourceRoleScopeItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ResourceRoleScopesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the resourceRoleScopes property of the microsoft.graph.entitlementManagement entity.
 */
export declare class ResourceRoleScopesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the resourceRoleScopes property of the microsoft.graph.entitlementManagement entity.
     * @param accessPackageResourceRoleScopeId The unique identifier of accessPackageResourceRoleScope
     * @returns a AccessPackageResourceRoleScopeItemRequestBuilder
     */
    byAccessPackageResourceRoleScopeId(accessPackageResourceRoleScopeId: string): AccessPackageResourceRoleScopeItemRequestBuilder;
    /**
     * Instantiates a new ResourceRoleScopesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get resourceRoleScopes from identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessPackageResourceRoleScopeCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<ResourceRoleScopesRequestBuilderGetQueryParameters> | undefined): Promise<AccessPackageResourceRoleScopeCollectionResponse | undefined>;
    /**
     * Create new navigation property to resourceRoleScopes for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AccessPackageResourceRoleScope
     */
    post(body: AccessPackageResourceRoleScope, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AccessPackageResourceRoleScope | undefined>;
    /**
     * Get resourceRoleScopes from identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ResourceRoleScopesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to resourceRoleScopes for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AccessPackageResourceRoleScope, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a resourceRoleScopesRequestBuilder
     */
    withUrl(rawUrl: string): ResourceRoleScopesRequestBuilder;
}
