import { type UserProcessingResultCollectionResponse } from '../../../../../../models/identityGovernance/';
import { CountRequestBuilder } from './count/';
import { UserProcessingResultItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ExecutionScopeRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the executionScope property of the microsoft.graph.identityGovernance.workflow entity.
 */
export declare class ExecutionScopeRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the executionScope property of the microsoft.graph.identityGovernance.workflow entity.
     * @param userProcessingResultId The unique identifier of userProcessingResult
     * @returns a UserProcessingResultItemRequestBuilder
     */
    byUserProcessingResultId(userProcessingResultId: string): UserProcessingResultItemRequestBuilder;
    /**
     * Instantiates a new ExecutionScopeRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The unique identifier of the Microsoft Entra identity that last modified the workflow object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserProcessingResultCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<ExecutionScopeRequestBuilderGetQueryParameters> | undefined): Promise<UserProcessingResultCollectionResponse | undefined>;
    /**
     * The unique identifier of the Microsoft Entra identity that last modified the workflow object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ExecutionScopeRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a executionScopeRequestBuilder
     */
    withUrl(rawUrl: string): ExecutionScopeRequestBuilder;
}
