import { type PrivilegedAccessGroupAssignmentScheduleCollectionResponse } from '../../../../models/';
import { type PrivilegedAccessGroupAssignmentSchedule } from '../../../../models/privilegedAccessGroupAssignmentSchedule';
import { CountRequestBuilder } from './count/';
import { FilterByCurrentUserWithOnRequestBuilder } from './filterByCurrentUserWithOn/';
import { PrivilegedAccessGroupAssignmentScheduleItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AssignmentSchedulesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the assignmentSchedules property of the microsoft.graph.privilegedAccessGroup entity.
 */
export declare class AssignmentSchedulesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the assignmentSchedules property of the microsoft.graph.privilegedAccessGroup entity.
     * @param privilegedAccessGroupAssignmentScheduleId The unique identifier of privilegedAccessGroupAssignmentSchedule
     * @returns a PrivilegedAccessGroupAssignmentScheduleItemRequestBuilder
     */
    byPrivilegedAccessGroupAssignmentScheduleId(privilegedAccessGroupAssignmentScheduleId: string): PrivilegedAccessGroupAssignmentScheduleItemRequestBuilder;
    /**
     * Instantiates a new AssignmentSchedulesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Provides operations to call the filterByCurrentUser method.
     * @param on Usage: on='{on}'
     * @returns a filterByCurrentUserWithOnRequestBuilder
     */
    filterByCurrentUserWithOn(on: string | undefined): FilterByCurrentUserWithOnRequestBuilder;
    /**
     * Get a list of the privilegedAccessGroupAssignmentSchedule objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrivilegedAccessGroupAssignmentScheduleCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/privilegedaccessgroup-list-assignmentschedules?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<AssignmentSchedulesRequestBuilderGetQueryParameters> | undefined): Promise<PrivilegedAccessGroupAssignmentScheduleCollectionResponse | undefined>;
    /**
     * Create new navigation property to assignmentSchedules for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrivilegedAccessGroupAssignmentSchedule
     */
    post(body: PrivilegedAccessGroupAssignmentSchedule, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<PrivilegedAccessGroupAssignmentSchedule | undefined>;
    /**
     * Get a list of the privilegedAccessGroupAssignmentSchedule objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AssignmentSchedulesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to assignmentSchedules for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: PrivilegedAccessGroupAssignmentSchedule, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a assignmentSchedulesRequestBuilder
     */
    withUrl(rawUrl: string): AssignmentSchedulesRequestBuilder;
}
