"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EligibilityScheduleInstancesRequestBuilder = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const privilegedAccessGroupEligibilityScheduleInstance_1 = require("../../../../models/privilegedAccessGroupEligibilityScheduleInstance");
const privilegedAccessGroupEligibilityScheduleInstanceCollectionResponse_1 = require("../../../../models/privilegedAccessGroupEligibilityScheduleInstanceCollectionResponse");
const count_1 = require("./count/");
const filterByCurrentUserWithOn_1 = require("./filterByCurrentUserWithOn/");
const item_1 = require("./item/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the eligibilityScheduleInstances property of the microsoft.graph.privilegedAccessGroup entity.
 */
class EligibilityScheduleInstancesRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new count_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the eligibilityScheduleInstances property of the microsoft.graph.privilegedAccessGroup entity.
     * @param privilegedAccessGroupEligibilityScheduleInstanceId The unique identifier of privilegedAccessGroupEligibilityScheduleInstance
     * @returns a PrivilegedAccessGroupEligibilityScheduleInstanceItemRequestBuilder
     */
    byPrivilegedAccessGroupEligibilityScheduleInstanceId(privilegedAccessGroupEligibilityScheduleInstanceId) {
        if (!privilegedAccessGroupEligibilityScheduleInstanceId)
            throw new Error("privilegedAccessGroupEligibilityScheduleInstanceId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["privilegedAccessGroupEligibilityScheduleInstance%2Did"] = privilegedAccessGroupEligibilityScheduleInstanceId;
        return new item_1.PrivilegedAccessGroupEligibilityScheduleInstanceItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new EligibilityScheduleInstancesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/identityGovernance/privilegedAccess/group/eligibilityScheduleInstances{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * Provides operations to call the filterByCurrentUser method.
     * @param on Usage: on='{on}'
     * @returns a filterByCurrentUserWithOnRequestBuilder
     */
    filterByCurrentUserWithOn(on) {
        if (!on)
            throw new Error("on cannot be undefined");
        return new filterByCurrentUserWithOn_1.FilterByCurrentUserWithOnRequestBuilder(this.pathParameters, this.requestAdapter, on);
    }
    ;
    /**
     * Get a list of the privilegedAccessGroupEligibilityScheduleInstance objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrivilegedAccessGroupEligibilityScheduleInstanceCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/privilegedaccessgroup-list-eligibilityscheduleinstances?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, privilegedAccessGroupEligibilityScheduleInstanceCollectionResponse_1.createPrivilegedAccessGroupEligibilityScheduleInstanceCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Create new navigation property to eligibilityScheduleInstances for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrivilegedAccessGroupEligibilityScheduleInstance
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, privilegedAccessGroupEligibilityScheduleInstance_1.createPrivilegedAccessGroupEligibilityScheduleInstanceFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Get a list of the privilegedAccessGroupEligibilityScheduleInstance objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, eligibilityScheduleInstancesRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Create new navigation property to eligibilityScheduleInstances for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, privilegedAccessGroupEligibilityScheduleInstance_1.serializePrivilegedAccessGroupEligibilityScheduleInstance);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a eligibilityScheduleInstancesRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new EligibilityScheduleInstancesRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.EligibilityScheduleInstancesRequestBuilder = EligibilityScheduleInstancesRequestBuilder;
const eligibilityScheduleInstancesRequestBuilderGetQueryParametersMapper = {
    "count": "%24count",
    "expand": "%24expand",
    "filter": "%24filter",
    "orderby": "%24orderby",
    "search": "%24search",
    "select": "%24select",
    "skip": "%24skip",
    "top": "%24top",
};
// tslint:enable
// eslint-enable
