import { type PrivilegedAccessGroupEligibilityScheduleCollectionResponse } from '../../../../models/';
import { type PrivilegedAccessGroupEligibilitySchedule } from '../../../../models/privilegedAccessGroupEligibilitySchedule';
import { CountRequestBuilder } from './count/';
import { FilterByCurrentUserWithOnRequestBuilder } from './filterByCurrentUserWithOn/';
import { PrivilegedAccessGroupEligibilityScheduleItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface EligibilitySchedulesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the eligibilitySchedules property of the microsoft.graph.privilegedAccessGroup entity.
 */
export declare class EligibilitySchedulesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the eligibilitySchedules property of the microsoft.graph.privilegedAccessGroup entity.
     * @param privilegedAccessGroupEligibilityScheduleId The unique identifier of privilegedAccessGroupEligibilitySchedule
     * @returns a PrivilegedAccessGroupEligibilityScheduleItemRequestBuilder
     */
    byPrivilegedAccessGroupEligibilityScheduleId(privilegedAccessGroupEligibilityScheduleId: string): PrivilegedAccessGroupEligibilityScheduleItemRequestBuilder;
    /**
     * Instantiates a new EligibilitySchedulesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Provides operations to call the filterByCurrentUser method.
     * @param on Usage: on='{on}'
     * @returns a filterByCurrentUserWithOnRequestBuilder
     */
    filterByCurrentUserWithOn(on: string | undefined): FilterByCurrentUserWithOnRequestBuilder;
    /**
     * Get a list of the privilegedAccessGroupEligibilitySchedule objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrivilegedAccessGroupEligibilityScheduleCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/privilegedaccessgroup-list-eligibilityschedules?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<EligibilitySchedulesRequestBuilderGetQueryParameters> | undefined): Promise<PrivilegedAccessGroupEligibilityScheduleCollectionResponse | undefined>;
    /**
     * Create new navigation property to eligibilitySchedules for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrivilegedAccessGroupEligibilitySchedule
     */
    post(body: PrivilegedAccessGroupEligibilitySchedule, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<PrivilegedAccessGroupEligibilitySchedule | undefined>;
    /**
     * Get a list of the privilegedAccessGroupEligibilitySchedule objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<EligibilitySchedulesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to eligibilitySchedules for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: PrivilegedAccessGroupEligibilitySchedule, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a eligibilitySchedulesRequestBuilder
     */
    withUrl(rawUrl: string): EligibilitySchedulesRequestBuilder;
}
