import { type PrivilegedAccessGroup } from '../../../models/privilegedAccessGroup';
import { AssignmentApprovalsRequestBuilder } from './assignmentApprovals/';
import { AssignmentScheduleInstancesRequestBuilder } from './assignmentScheduleInstances/';
import { AssignmentScheduleRequestsRequestBuilder } from './assignmentScheduleRequests/';
import { AssignmentSchedulesRequestBuilder } from './assignmentSchedules/';
import { EligibilityScheduleInstancesRequestBuilder } from './eligibilityScheduleInstances/';
import { EligibilityScheduleRequestsRequestBuilder } from './eligibilityScheduleRequests/';
import { EligibilitySchedulesRequestBuilder } from './eligibilitySchedules/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface GroupRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the group property of the microsoft.graph.privilegedAccessRoot entity.
 */
export declare class GroupRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the assignmentApprovals property of the microsoft.graph.privilegedAccessGroup entity.
     */
    get assignmentApprovals(): AssignmentApprovalsRequestBuilder;
    /**
     * Provides operations to manage the assignmentScheduleInstances property of the microsoft.graph.privilegedAccessGroup entity.
     */
    get assignmentScheduleInstances(): AssignmentScheduleInstancesRequestBuilder;
    /**
     * Provides operations to manage the assignmentScheduleRequests property of the microsoft.graph.privilegedAccessGroup entity.
     */
    get assignmentScheduleRequests(): AssignmentScheduleRequestsRequestBuilder;
    /**
     * Provides operations to manage the assignmentSchedules property of the microsoft.graph.privilegedAccessGroup entity.
     */
    get assignmentSchedules(): AssignmentSchedulesRequestBuilder;
    /**
     * Provides operations to manage the eligibilityScheduleInstances property of the microsoft.graph.privilegedAccessGroup entity.
     */
    get eligibilityScheduleInstances(): EligibilityScheduleInstancesRequestBuilder;
    /**
     * Provides operations to manage the eligibilityScheduleRequests property of the microsoft.graph.privilegedAccessGroup entity.
     */
    get eligibilityScheduleRequests(): EligibilityScheduleRequestsRequestBuilder;
    /**
     * Provides operations to manage the eligibilitySchedules property of the microsoft.graph.privilegedAccessGroup entity.
     */
    get eligibilitySchedules(): EligibilitySchedulesRequestBuilder;
    /**
     * Instantiates a new GroupRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property group for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * A group that's governed through Privileged Identity Management (PIM).
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrivilegedAccessGroup
     */
    get(requestConfiguration?: RequestConfiguration<GroupRequestBuilderGetQueryParameters> | undefined): Promise<PrivilegedAccessGroup | undefined>;
    /**
     * Update the navigation property group in identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrivilegedAccessGroup
     */
    patch(body: PrivilegedAccessGroup, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<PrivilegedAccessGroup | undefined>;
    /**
     * Delete navigation property group for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * A group that's governed through Privileged Identity Management (PIM).
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<GroupRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property group in identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: PrivilegedAccessGroup, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a groupRequestBuilder
     */
    withUrl(rawUrl: string): GroupRequestBuilder;
}
