import { type AgreementAcceptanceCollectionResponse } from '../../../models/';
import { type AgreementAcceptance } from '../../../models/agreementAcceptance';
import { CountRequestBuilder } from './count/';
import { AgreementAcceptanceItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AgreementAcceptancesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the agreementAcceptances property of the microsoft.graph.termsOfUseContainer entity.
 */
export declare class AgreementAcceptancesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the agreementAcceptances property of the microsoft.graph.termsOfUseContainer entity.
     * @param agreementAcceptanceId The unique identifier of agreementAcceptance
     * @returns a AgreementAcceptanceItemRequestBuilder
     */
    byAgreementAcceptanceId(agreementAcceptanceId: string): AgreementAcceptanceItemRequestBuilder;
    /**
     * Instantiates a new AgreementAcceptancesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Represents the current status of a user's response to a company's customizable terms of use agreement.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AgreementAcceptanceCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<AgreementAcceptancesRequestBuilderGetQueryParameters> | undefined): Promise<AgreementAcceptanceCollectionResponse | undefined>;
    /**
     * Create new navigation property to agreementAcceptances for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AgreementAcceptance
     */
    post(body: AgreementAcceptance, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AgreementAcceptance | undefined>;
    /**
     * Represents the current status of a user's response to a company's customizable terms of use agreement.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AgreementAcceptancesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to agreementAcceptances for identityGovernance
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AgreementAcceptance, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a agreementAcceptancesRequestBuilder
     */
    withUrl(rawUrl: string): AgreementAcceptancesRequestBuilder;
}
