import { type IdentityProtectionRoot } from '../models/identityProtectionRoot';
import { RiskDetectionsRequestBuilder } from './riskDetections/';
import { RiskyServicePrincipalsRequestBuilder } from './riskyServicePrincipals/';
import { RiskyUsersRequestBuilder } from './riskyUsers/';
import { ServicePrincipalRiskDetectionsRequestBuilder } from './servicePrincipalRiskDetections/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface IdentityProtectionRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the identityProtectionRoot singleton.
 */
export declare class IdentityProtectionRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the riskDetections property of the microsoft.graph.identityProtectionRoot entity.
     */
    get riskDetections(): RiskDetectionsRequestBuilder;
    /**
     * Provides operations to manage the riskyServicePrincipals property of the microsoft.graph.identityProtectionRoot entity.
     */
    get riskyServicePrincipals(): RiskyServicePrincipalsRequestBuilder;
    /**
     * Provides operations to manage the riskyUsers property of the microsoft.graph.identityProtectionRoot entity.
     */
    get riskyUsers(): RiskyUsersRequestBuilder;
    /**
     * Provides operations to manage the servicePrincipalRiskDetections property of the microsoft.graph.identityProtectionRoot entity.
     */
    get servicePrincipalRiskDetections(): ServicePrincipalRiskDetectionsRequestBuilder;
    /**
     * Instantiates a new IdentityProtectionRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get identityProtection
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityProtectionRoot
     */
    get(requestConfiguration?: RequestConfiguration<IdentityProtectionRequestBuilderGetQueryParameters> | undefined): Promise<IdentityProtectionRoot | undefined>;
    /**
     * Update identityProtection
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IdentityProtectionRoot
     */
    patch(body: IdentityProtectionRoot, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<IdentityProtectionRoot | undefined>;
    /**
     * Get identityProtection
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<IdentityProtectionRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update identityProtection
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: IdentityProtectionRoot, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a identityProtectionRequestBuilder
     */
    withUrl(rawUrl: string): IdentityProtectionRequestBuilder;
}
