"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfirmCompromisedRequestBuilder = exports.serializeConfirmCompromisedPostRequestBody = exports.deserializeIntoConfirmCompromisedPostRequestBody = exports.createConfirmCompromisedPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createConfirmCompromisedPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoConfirmCompromisedPostRequestBody;
}
exports.createConfirmCompromisedPostRequestBodyFromDiscriminatorValue = createConfirmCompromisedPostRequestBodyFromDiscriminatorValue;
function deserializeIntoConfirmCompromisedPostRequestBody(confirmCompromisedPostRequestBody = {}) {
    return {
        "servicePrincipalIds": n => { confirmCompromisedPostRequestBody.servicePrincipalIds = n.getCollectionOfPrimitiveValues(); },
    };
}
exports.deserializeIntoConfirmCompromisedPostRequestBody = deserializeIntoConfirmCompromisedPostRequestBody;
function serializeConfirmCompromisedPostRequestBody(writer, confirmCompromisedPostRequestBody = {}) {
    writer.writeCollectionOfPrimitiveValues("servicePrincipalIds", confirmCompromisedPostRequestBody.servicePrincipalIds);
    writer.writeAdditionalData(confirmCompromisedPostRequestBody.additionalData);
}
exports.serializeConfirmCompromisedPostRequestBody = serializeConfirmCompromisedPostRequestBody;
/**
 * Provides operations to call the confirmCompromised method.
 */
class ConfirmCompromisedRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new ConfirmCompromisedRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/identityProtection/riskyServicePrincipals/confirmCompromised");
    }
    ;
    /**
     * Confirm one or more riskyServicePrincipal objects as compromised. This action sets the targeted service principal account's risk level to high.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/riskyserviceprincipal-confirmcompromised?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Confirm one or more riskyServicePrincipal objects as compromised. This action sets the targeted service principal account's risk level to high.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeConfirmCompromisedPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a confirmCompromisedRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new ConfirmCompromisedRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.ConfirmCompromisedRequestBuilder = ConfirmCompromisedRequestBuilder;
// tslint:enable
// eslint-enable
