"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DismissRequestBuilder = exports.serializeDismissPostRequestBody = exports.deserializeIntoDismissPostRequestBody = exports.createDismissPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createDismissPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoDismissPostRequestBody;
}
exports.createDismissPostRequestBodyFromDiscriminatorValue = createDismissPostRequestBodyFromDiscriminatorValue;
function deserializeIntoDismissPostRequestBody(dismissPostRequestBody = {}) {
    return {
        "servicePrincipalIds": n => { dismissPostRequestBody.servicePrincipalIds = n.getCollectionOfPrimitiveValues(); },
    };
}
exports.deserializeIntoDismissPostRequestBody = deserializeIntoDismissPostRequestBody;
function serializeDismissPostRequestBody(writer, dismissPostRequestBody = {}) {
    writer.writeCollectionOfPrimitiveValues("servicePrincipalIds", dismissPostRequestBody.servicePrincipalIds);
    writer.writeAdditionalData(dismissPostRequestBody.additionalData);
}
exports.serializeDismissPostRequestBody = serializeDismissPostRequestBody;
/**
 * Provides operations to call the dismiss method.
 */
class DismissRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new DismissRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/identityProtection/riskyServicePrincipals/dismiss");
    }
    ;
    /**
     * Dismiss the risk of one or more riskyServicePrincipal objects. This action sets the targeted service principal account's risk level to none. You can dismiss up to 60 service principal accounts in one request.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/riskyserviceprincipal-dismiss?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Dismiss the risk of one or more riskyServicePrincipal objects. This action sets the targeted service principal account's risk level to none. You can dismiss up to 60 service principal accounts in one request.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeDismissPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a dismissRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new DismissRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.DismissRequestBuilder = DismissRequestBuilder;
// tslint:enable
// eslint-enable
