import { type RiskyServicePrincipalCollectionResponse } from '../../models/';
import { type RiskyServicePrincipal } from '../../models/riskyServicePrincipal';
import { ConfirmCompromisedRequestBuilder } from './confirmCompromised/';
import { CountRequestBuilder } from './count/';
import { DismissRequestBuilder } from './dismiss/';
import { RiskyServicePrincipalItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface RiskyServicePrincipalsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the riskyServicePrincipals property of the microsoft.graph.identityProtectionRoot entity.
 */
export declare class RiskyServicePrincipalsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the confirmCompromised method.
     */
    get confirmCompromised(): ConfirmCompromisedRequestBuilder;
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to call the dismiss method.
     */
    get dismiss(): DismissRequestBuilder;
    /**
     * Provides operations to manage the riskyServicePrincipals property of the microsoft.graph.identityProtectionRoot entity.
     * @param riskyServicePrincipalId The unique identifier of riskyServicePrincipal
     * @returns a RiskyServicePrincipalItemRequestBuilder
     */
    byRiskyServicePrincipalId(riskyServicePrincipalId: string): RiskyServicePrincipalItemRequestBuilder;
    /**
     * Instantiates a new RiskyServicePrincipalsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the properties and relationships of riskyServicePrincipal objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RiskyServicePrincipalCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/identityprotectionroot-list-riskyserviceprincipals?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<RiskyServicePrincipalsRequestBuilderGetQueryParameters> | undefined): Promise<RiskyServicePrincipalCollectionResponse | undefined>;
    /**
     * Create new navigation property to riskyServicePrincipals for identityProtection
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RiskyServicePrincipal
     */
    post(body: RiskyServicePrincipal, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<RiskyServicePrincipal | undefined>;
    /**
     * Retrieve the properties and relationships of riskyServicePrincipal objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<RiskyServicePrincipalsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to riskyServicePrincipals for identityProtection
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: RiskyServicePrincipal, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a riskyServicePrincipalsRequestBuilder
     */
    withUrl(rawUrl: string): RiskyServicePrincipalsRequestBuilder;
}
