import { type RiskyUserCollectionResponse } from '../../models/';
import { type RiskyUser } from '../../models/riskyUser';
import { ConfirmCompromisedRequestBuilder } from './confirmCompromised/';
import { CountRequestBuilder } from './count/';
import { DismissRequestBuilder } from './dismiss/';
import { RiskyUserItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface RiskyUsersRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the riskyUsers property of the microsoft.graph.identityProtectionRoot entity.
 */
export declare class RiskyUsersRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the confirmCompromised method.
     */
    get confirmCompromised(): ConfirmCompromisedRequestBuilder;
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to call the dismiss method.
     */
    get dismiss(): DismissRequestBuilder;
    /**
     * Provides operations to manage the riskyUsers property of the microsoft.graph.identityProtectionRoot entity.
     * @param riskyUserId The unique identifier of riskyUser
     * @returns a RiskyUserItemRequestBuilder
     */
    byRiskyUserId(riskyUserId: string): RiskyUserItemRequestBuilder;
    /**
     * Instantiates a new RiskyUsersRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the riskyUser objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RiskyUserCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/riskyuser-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<RiskyUsersRequestBuilderGetQueryParameters> | undefined): Promise<RiskyUserCollectionResponse | undefined>;
    /**
     * Create new navigation property to riskyUsers for identityProtection
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RiskyUser
     */
    post(body: RiskyUser, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<RiskyUser | undefined>;
    /**
     * Get a list of the riskyUser objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<RiskyUsersRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to riskyUsers for identityProtection
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: RiskyUser, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a riskyUsersRequestBuilder
     */
    withUrl(rawUrl: string): RiskyUsersRequestBuilder;
}
