import { type RiskyUserHistoryItemCollectionResponse } from '../../../../models/';
import { type RiskyUserHistoryItem } from '../../../../models/riskyUserHistoryItem';
import { CountRequestBuilder } from './count/';
import { RiskyUserHistoryItemItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface HistoryRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the history property of the microsoft.graph.riskyUser entity.
 */
export declare class HistoryRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the history property of the microsoft.graph.riskyUser entity.
     * @param riskyUserHistoryItemId The unique identifier of riskyUserHistoryItem
     * @returns a RiskyUserHistoryItemItemRequestBuilder
     */
    byRiskyUserHistoryItemId(riskyUserHistoryItemId: string): RiskyUserHistoryItemItemRequestBuilder;
    /**
     * Instantiates a new HistoryRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the riskyUserHistoryItems from the history navigation property.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RiskyUserHistoryItemCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/riskyuser-list-history?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<HistoryRequestBuilderGetQueryParameters> | undefined): Promise<RiskyUserHistoryItemCollectionResponse | undefined>;
    /**
     * Create new navigation property to history for identityProtection
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RiskyUserHistoryItem
     */
    post(body: RiskyUserHistoryItem, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<RiskyUserHistoryItem | undefined>;
    /**
     * Get the riskyUserHistoryItems from the history navigation property.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<HistoryRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to history for identityProtection
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: RiskyUserHistoryItem, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a historyRequestBuilder
     */
    withUrl(rawUrl: string): HistoryRequestBuilder;
}
