"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HistoryRequestBuilder = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const riskyUserHistoryItem_1 = require("../../../../models/riskyUserHistoryItem");
const riskyUserHistoryItemCollectionResponse_1 = require("../../../../models/riskyUserHistoryItemCollectionResponse");
const count_1 = require("./count/");
const item_1 = require("./item/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the history property of the microsoft.graph.riskyUser entity.
 */
class HistoryRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new count_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the history property of the microsoft.graph.riskyUser entity.
     * @param riskyUserHistoryItemId The unique identifier of riskyUserHistoryItem
     * @returns a RiskyUserHistoryItemItemRequestBuilder
     */
    byRiskyUserHistoryItemId(riskyUserHistoryItemId) {
        if (!riskyUserHistoryItemId)
            throw new Error("riskyUserHistoryItemId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["riskyUserHistoryItem%2Did"] = riskyUserHistoryItemId;
        return new item_1.RiskyUserHistoryItemItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new HistoryRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/identityProtection/riskyUsers/{riskyUser%2Did}/history{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * Get the riskyUserHistoryItems from the history navigation property.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RiskyUserHistoryItemCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/riskyuser-list-history?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, riskyUserHistoryItemCollectionResponse_1.createRiskyUserHistoryItemCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Create new navigation property to history for identityProtection
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RiskyUserHistoryItem
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, riskyUserHistoryItem_1.createRiskyUserHistoryItemFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Get the riskyUserHistoryItems from the history navigation property.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, historyRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Create new navigation property to history for identityProtection
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, riskyUserHistoryItem_1.serializeRiskyUserHistoryItem);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a historyRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new HistoryRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.HistoryRequestBuilder = HistoryRequestBuilder;
const historyRequestBuilderGetQueryParametersMapper = {
    "count": "%24count",
    "expand": "%24expand",
    "filter": "%24filter",
    "orderby": "%24orderby",
    "search": "%24search",
    "select": "%24select",
    "skip": "%24skip",
    "top": "%24top",
};
// tslint:enable
// eslint-enable
