import { type ServicePrincipalRiskDetectionCollectionResponse } from '../../models/';
import { type ServicePrincipalRiskDetection } from '../../models/servicePrincipalRiskDetection';
import { CountRequestBuilder } from './count/';
import { ServicePrincipalRiskDetectionItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ServicePrincipalRiskDetectionsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the servicePrincipalRiskDetections property of the microsoft.graph.identityProtectionRoot entity.
 */
export declare class ServicePrincipalRiskDetectionsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the servicePrincipalRiskDetections property of the microsoft.graph.identityProtectionRoot entity.
     * @param servicePrincipalRiskDetectionId The unique identifier of servicePrincipalRiskDetection
     * @returns a ServicePrincipalRiskDetectionItemRequestBuilder
     */
    byServicePrincipalRiskDetectionId(servicePrincipalRiskDetectionId: string): ServicePrincipalRiskDetectionItemRequestBuilder;
    /**
     * Instantiates a new ServicePrincipalRiskDetectionsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the properties of a collection of servicePrincipalRiskDetection objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ServicePrincipalRiskDetectionCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/identityprotectionroot-list-serviceprincipalriskdetections?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ServicePrincipalRiskDetectionsRequestBuilderGetQueryParameters> | undefined): Promise<ServicePrincipalRiskDetectionCollectionResponse | undefined>;
    /**
     * Create new navigation property to servicePrincipalRiskDetections for identityProtection
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ServicePrincipalRiskDetection
     */
    post(body: ServicePrincipalRiskDetection, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ServicePrincipalRiskDetection | undefined>;
    /**
     * Retrieve the properties of a collection of servicePrincipalRiskDetection objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ServicePrincipalRiskDetectionsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to servicePrincipalRiskDetections for identityProtection
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ServicePrincipalRiskDetection, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a servicePrincipalRiskDetectionsRequestBuilder
     */
    withUrl(rawUrl: string): ServicePrincipalRiskDetectionsRequestBuilder;
}
