import { type ThreatAssessmentRequestCollectionResponse } from '../../models/';
import { type ThreatAssessmentRequest } from '../../models/threatAssessmentRequest';
import { CountRequestBuilder } from './count/';
import { ThreatAssessmentRequestItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ThreatAssessmentRequestsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the threatAssessmentRequests property of the microsoft.graph.informationProtection entity.
 */
export declare class ThreatAssessmentRequestsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the threatAssessmentRequests property of the microsoft.graph.informationProtection entity.
     * @param threatAssessmentRequestId The unique identifier of threatAssessmentRequest
     * @returns a ThreatAssessmentRequestItemRequestBuilder
     */
    byThreatAssessmentRequestId(threatAssessmentRequestId: string): ThreatAssessmentRequestItemRequestBuilder;
    /**
     * Instantiates a new ThreatAssessmentRequestsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of threatAssessmentRequest objects. A threat assessment request can be one of the following types:
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ThreatAssessmentRequestCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/informationprotection-list-threatassessmentrequests?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ThreatAssessmentRequestsRequestBuilderGetQueryParameters> | undefined): Promise<ThreatAssessmentRequestCollectionResponse | undefined>;
    /**
     * Create a new threat assessment request. A threat assessment request can be one of the following types:
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ThreatAssessmentRequest
     * @see {@link https://learn.microsoft.com/graph/api/informationprotection-post-threatassessmentrequests?view=graph-rest-1.0|Find more info here}
     */
    post(body: ThreatAssessmentRequest, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ThreatAssessmentRequest | undefined>;
    /**
     * Retrieve a list of threatAssessmentRequest objects. A threat assessment request can be one of the following types:
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ThreatAssessmentRequestsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new threat assessment request. A threat assessment request can be one of the following types:
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ThreatAssessmentRequest, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a threatAssessmentRequestsRequestBuilder
     */
    withUrl(rawUrl: string): ThreatAssessmentRequestsRequestBuilder;
}
