import { type ThreatAssessmentResultCollectionResponse } from '../../../../models/';
import { type ThreatAssessmentResult } from '../../../../models/threatAssessmentResult';
import { CountRequestBuilder } from './count/';
import { ThreatAssessmentResultItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ResultsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the results property of the microsoft.graph.threatAssessmentRequest entity.
 */
export declare class ResultsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the results property of the microsoft.graph.threatAssessmentRequest entity.
     * @param threatAssessmentResultId The unique identifier of threatAssessmentResult
     * @returns a ThreatAssessmentResultItemRequestBuilder
     */
    byThreatAssessmentResultId(threatAssessmentResultId: string): ThreatAssessmentResultItemRequestBuilder;
    /**
     * Instantiates a new ResultsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * A collection of threat assessment results. Read-only. By default, a GET /threatAssessmentRequests/{id} does not return this property unless you apply $expand on it.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ThreatAssessmentResultCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<ResultsRequestBuilderGetQueryParameters> | undefined): Promise<ThreatAssessmentResultCollectionResponse | undefined>;
    /**
     * Create new navigation property to results for informationProtection
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ThreatAssessmentResult
     */
    post(body: ThreatAssessmentResult, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ThreatAssessmentResult | undefined>;
    /**
     * A collection of threat assessment results. Read-only. By default, a GET /threatAssessmentRequests/{id} does not return this property unless you apply $expand on it.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ResultsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to results for informationProtection
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ThreatAssessmentResult, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a resultsRequestBuilder
     */
    withUrl(rawUrl: string): ResultsRequestBuilder;
}
