import { type InvitationCollectionResponse } from '../models/';
import { type Invitation } from '../models/invitation';
import { CountRequestBuilder } from './count/';
import { InvitationItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface InvitationsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the collection of invitation entities.
 */
export declare class InvitationsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the collection of invitation entities.
     * @param invitationId The unique identifier of invitation
     * @returns a InvitationItemRequestBuilder
     */
    byInvitationId(invitationId: string): InvitationItemRequestBuilder;
    /**
     * Instantiates a new InvitationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get entities from invitations
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of InvitationCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<InvitationsRequestBuilderGetQueryParameters> | undefined): Promise<InvitationCollectionResponse | undefined>;
    /**
     * Use this API to create a new invitation. Invitation adds an external user to the organization. When creating a new invitation, you have several options available:
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Invitation
     * @see {@link https://learn.microsoft.com/graph/api/invitation-post?view=graph-rest-1.0|Find more info here}
     */
    post(body: Invitation, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Invitation | undefined>;
    /**
     * Get entities from invitations
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<InvitationsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Use this API to create a new invitation. Invitation adds an external user to the organization. When creating a new invitation, you have several options available:
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: Invitation, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a invitationsRequestBuilder
     */
    withUrl(rawUrl: string): InvitationsRequestBuilder;
}
