import { type AccessReviewRecommendationInsightSetting } from './accessReviewRecommendationInsightSetting';
import { type AccessReviewReviewerScope } from './accessReviewReviewerScope';
import { type AdditionalDataHolder, type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export interface AccessReviewStageSettings extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * Indicate which decisions will go to the next stage. Can be a subset of Approve, Deny, Recommendation, or NotReviewed. If not provided, all decisions will go to the next stage. Optional.
     */
    decisionsThatWillMoveToNextStage?: string[];
    /**
     * Defines the sequential or parallel order of the stages and depends on the stageId. Only sequential stages are currently supported. For example, if stageId is 2, then dependsOn must be 1. If stageId is 1, don't specify dependsOn. Required if stageId isn't 1.
     */
    dependsOn?: string[];
    /**
     * The duration of the stage. Required.  NOTE: The cumulative value of this property across all stages  1. Will override the instanceDurationInDays setting on the accessReviewScheduleDefinition object. 2. Can't exceed the length of one recurrence. That is, if the review recurs weekly, the cumulative durationInDays can't exceed 7.
     */
    durationInDays?: number;
    /**
     * If provided, the fallback reviewers are asked to complete a review if the primary reviewers don't exist. For example, if managers are selected as reviewers and a principal under review doesn't have a manager in Microsoft Entra ID, the fallback reviewers are asked to review that principal. NOTE: The value of this property overrides the corresponding setting on the accessReviewScheduleDefinition object.
     */
    fallbackReviewers?: AccessReviewReviewerScope[];
    /**
     * The OdataType property
     */
    odataType?: string;
    /**
     * The recommendationInsightSettings property
     */
    recommendationInsightSettings?: AccessReviewRecommendationInsightSetting[];
    /**
     * Indicates whether showing recommendations to reviewers is enabled. Required. NOTE: The value of this property overrides override the corresponding setting on the accessReviewScheduleDefinition object.
     */
    recommendationsEnabled?: boolean;
    /**
     * Defines who the reviewers are. If none is specified, the review is a self-review (users review their own access).  For examples of options for assigning reviewers, see Assign reviewers to your access review definition using the Microsoft Graph API. NOTE: The value of this property overrides the corresponding setting on the accessReviewScheduleDefinition.
     */
    reviewers?: AccessReviewReviewerScope[];
    /**
     * Unique identifier of the accessReviewStageSettings object. The stageId is used by the dependsOn property to indicate the order of the stages. Required.
     */
    stageId?: string;
}
export declare function createAccessReviewStageSettingsFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoAccessReviewStageSettings;
export declare function deserializeIntoAccessReviewStageSettings(accessReviewStageSettings?: AccessReviewStageSettings | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeAccessReviewStageSettings(writer: SerializationWriter, accessReviewStageSettings?: AccessReviewStageSettings | undefined): void;
