import { type AgreementAcceptance } from './agreementAcceptance';
import { type AgreementFile } from './agreementFile';
import { type AgreementFileLocalization } from './agreementFileLocalization';
import { type Entity } from './entity';
import { type TermsExpiration } from './termsExpiration';
import { type Duration, type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export interface Agreement extends Entity, Parsable {
    /**
     * Read-only. Information about acceptances of this agreement.
     */
    acceptances?: AgreementAcceptance[];
    /**
     * Display name of the agreement. The display name is used for internal tracking of the agreement but is not shown to end users who view the agreement. Supports $filter (eq).
     */
    displayName?: string;
    /**
     * Default PDF linked to this agreement.
     */
    file?: AgreementFile;
    /**
     * PDFs linked to this agreement. This property is in the process of being deprecated. Use the  file property instead. Supports $expand.
     */
    files?: AgreementFileLocalization[];
    /**
     * Indicates whether end users are required to accept this agreement on every device that they access it from. The end user is required to register their device in Microsoft Entra ID, if they haven't already done so. Supports $filter (eq).
     */
    isPerDeviceAcceptanceRequired?: boolean;
    /**
     * Indicates whether the user has to expand the agreement before accepting. Supports $filter (eq).
     */
    isViewingBeforeAcceptanceRequired?: boolean;
    /**
     * Expiration schedule and frequency of agreement for all users. Supports $filter (eq).
     */
    termsExpiration?: TermsExpiration;
    /**
     * The duration after which the user must re-accept the terms of use. The value is represented in ISO 8601 format for durations. Supports $filter (eq).
     */
    userReacceptRequiredFrequency?: Duration;
}
export declare function createAgreementFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoAgreement;
export declare function deserializeIntoAgreement(agreement?: Agreement | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeAgreement(writer: SerializationWriter, agreement?: Agreement | undefined): void;
