import { type AlertDetection } from './alertDetection';
import { AlertFeedback } from './alertFeedback';
import { type AlertHistoryState } from './alertHistoryState';
import { AlertSeverity } from './alertSeverity';
import { AlertStatus } from './alertStatus';
import { type AlertTrigger } from './alertTrigger';
import { type CloudAppSecurityState } from './cloudAppSecurityState';
import { type Entity } from './entity';
import { type FileSecurityState } from './fileSecurityState';
import { type HostSecurityState } from './hostSecurityState';
import { type InvestigationSecurityState } from './investigationSecurityState';
import { type MalwareState } from './malwareState';
import { type MessageSecurityState } from './messageSecurityState';
import { type NetworkConnection } from './networkConnection';
import { type Process } from './process';
import { type RegistryKeyState } from './registryKeyState';
import { type SecurityResource } from './securityResource';
import { type SecurityVendorInformation } from './securityVendorInformation';
import { type UriClickSecurityState } from './uriClickSecurityState';
import { type UserSecurityState } from './userSecurityState';
import { type VulnerabilityState } from './vulnerabilityState';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export interface Alert extends Entity, Parsable {
    /**
     * Name or alias of the activity group (attacker) this alert is attributed to.
     */
    activityGroupName?: string;
    /**
     * The alertDetections property
     */
    alertDetections?: AlertDetection[];
    /**
     * Name of the analyst the alert is assigned to for triage, investigation, or remediation (supports update).
     */
    assignedTo?: string;
    /**
     * Azure subscription ID, present if this alert is related to an Azure resource.
     */
    azureSubscriptionId?: string;
    /**
     * Microsoft Entra tenant ID. Required.
     */
    azureTenantId?: string;
    /**
     * Category of the alert (for example, credentialTheft, ransomware, etc.).
     */
    category?: string;
    /**
     * Time at which the alert was closed. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z (supports update).
     */
    closedDateTime?: Date;
    /**
     * Security-related stateful information generated by the provider about the cloud application/s related to this alert.
     */
    cloudAppStates?: CloudAppSecurityState[];
    /**
     * Customer-provided comments on alert (for customer alert management) (supports update).
     */
    comments?: string[];
    /**
     * Confidence of the detection logic (percentage between 1-100).
     */
    confidence?: number;
    /**
     * Time at which the alert was created by the alert provider. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Required.
     */
    createdDateTime?: Date;
    /**
     * Alert description.
     */
    description?: string;
    /**
     * Set of alerts related to this alert entity (each alert is pushed to the SIEM as a separate record).
     */
    detectionIds?: string[];
    /**
     * Time at which the event(s) that served as the trigger(s) to generate the alert occurred. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Required.
     */
    eventDateTime?: Date;
    /**
     * Analyst feedback on the alert. Possible values are: unknown, truePositive, falsePositive, benignPositive. (supports update)
     */
    feedback?: AlertFeedback;
    /**
     * Security-related stateful information generated by the provider about the file(s) related to this alert.
     */
    fileStates?: FileSecurityState[];
    /**
     * The historyStates property
     */
    historyStates?: AlertHistoryState[];
    /**
     * Security-related stateful information generated by the provider about the host(s) related to this alert.
     */
    hostStates?: HostSecurityState[];
    /**
     * IDs of incidents related to current alert.
     */
    incidentIds?: string[];
    /**
     * The investigationSecurityStates property
     */
    investigationSecurityStates?: InvestigationSecurityState[];
    /**
     * The lastEventDateTime property
     */
    lastEventDateTime?: Date;
    /**
     * Time at which the alert entity was last modified. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    lastModifiedDateTime?: Date;
    /**
     * Threat Intelligence pertaining to malware related to this alert.
     */
    malwareStates?: MalwareState[];
    /**
     * The messageSecurityStates property
     */
    messageSecurityStates?: MessageSecurityState[];
    /**
     * Security-related stateful information generated by the provider about the network connection(s) related to this alert.
     */
    networkConnections?: NetworkConnection[];
    /**
     * Security-related stateful information generated by the provider about the process or processes related to this alert.
     */
    processes?: Process[];
    /**
     * Vendor/provider recommended action(s) to take as a result of the alert (for example, isolate machine, enforce2FA, reimage host).
     */
    recommendedActions?: string[];
    /**
     * Security-related stateful information generated by the provider about the registry keys related to this alert.
     */
    registryKeyStates?: RegistryKeyState[];
    /**
     * Resources related to current alert. For example, for some alerts this can have the Azure Resource value.
     */
    securityResources?: SecurityResource[];
    /**
     * The severity property
     */
    severity?: AlertSeverity;
    /**
     * Hyperlinks (URIs) to the source material related to the alert, for example, provider's user interface for alerts or log search, etc.
     */
    sourceMaterials?: string[];
    /**
     * The status property
     */
    status?: AlertStatus;
    /**
     * User-definable labels that can be applied to an alert and can serve as filter conditions (for example 'HVA', 'SAW', etc.) (supports update).
     */
    tags?: string[];
    /**
     * Alert title. Required.
     */
    title?: string;
    /**
     * Security-related information about the specific properties that triggered the alert (properties appearing in the alert). Alerts might contain information about multiple users, hosts, files, ip addresses. This field indicates which properties triggered the alert generation.
     */
    triggers?: AlertTrigger[];
    /**
     * The uriClickSecurityStates property
     */
    uriClickSecurityStates?: UriClickSecurityState[];
    /**
     * Security-related stateful information generated by the provider about the user accounts related to this alert.
     */
    userStates?: UserSecurityState[];
    /**
     * Complex type containing details about the security product/service vendor, provider, and subprovider (for example, vendor=Microsoft; provider=Windows Defender ATP; subProvider=AppLocker). Required.
     */
    vendorInformation?: SecurityVendorInformation;
    /**
     * Threat intelligence pertaining to one or more vulnerabilities related to this alert.
     */
    vulnerabilityStates?: VulnerabilityState[];
}
export declare function createAlertFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoAlert;
export declare function deserializeIntoAlert(alert?: Alert | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeAlert(writer: SerializationWriter, alert?: Alert | undefined): void;
