import { type AuthenticationMethod } from './authenticationMethod';
import { type EmailAuthenticationMethod } from './emailAuthenticationMethod';
import { type Entity } from './entity';
import { type Fido2AuthenticationMethod } from './fido2AuthenticationMethod';
import { type LongRunningOperation } from './longRunningOperation';
import { type MicrosoftAuthenticatorAuthenticationMethod } from './microsoftAuthenticatorAuthenticationMethod';
import { type PasswordAuthenticationMethod } from './passwordAuthenticationMethod';
import { type PhoneAuthenticationMethod } from './phoneAuthenticationMethod';
import { type SoftwareOathAuthenticationMethod } from './softwareOathAuthenticationMethod';
import { type TemporaryAccessPassAuthenticationMethod } from './temporaryAccessPassAuthenticationMethod';
import { type WindowsHelloForBusinessAuthenticationMethod } from './windowsHelloForBusinessAuthenticationMethod';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export interface Authentication extends Entity, Parsable {
    /**
     * The email address registered to a user for authentication.
     */
    emailMethods?: EmailAuthenticationMethod[];
    /**
     * Represents the FIDO2 security keys registered to a user for authentication.
     */
    fido2Methods?: Fido2AuthenticationMethod[];
    /**
     * Represents all authentication methods registered to a user.
     */
    methods?: AuthenticationMethod[];
    /**
     * The details of the Microsoft Authenticator app registered to a user for authentication.
     */
    microsoftAuthenticatorMethods?: MicrosoftAuthenticatorAuthenticationMethod[];
    /**
     * Represents the status of a long-running operation.
     */
    operations?: LongRunningOperation[];
    /**
     * Represents the password that's registered to a user for authentication. For security, the password itself will never be returned in the object, but action can be taken to reset a password.
     */
    passwordMethods?: PasswordAuthenticationMethod[];
    /**
     * The phone numbers registered to a user for authentication.
     */
    phoneMethods?: PhoneAuthenticationMethod[];
    /**
     * The software OATH TOTP applications registered to a user for authentication.
     */
    softwareOathMethods?: SoftwareOathAuthenticationMethod[];
    /**
     * Represents a Temporary Access Pass registered to a user for authentication through time-limited passcodes.
     */
    temporaryAccessPassMethods?: TemporaryAccessPassAuthenticationMethod[];
    /**
     * Represents the Windows Hello for Business authentication method registered to a user for authentication.
     */
    windowsHelloForBusinessMethods?: WindowsHelloForBusinessAuthenticationMethod[];
}
export declare function createAuthenticationFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoAuthentication;
export declare function deserializeIntoAuthentication(authentication?: Authentication | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeAuthentication(writer: SerializationWriter, authentication?: Authentication | undefined): void;
