import { deserializeIntoDriveItem } from './driveItem';
import { type Entity } from './entity';
import { type IdentitySet } from './identitySet';
import { type ItemReference } from './itemReference';
import { deserializeIntoListItem } from './listItem';
import { type User } from './user';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export interface BaseItem extends Entity, Parsable {
    /**
     * Identity of the user, device, or application that created the item. Read-only.
     */
    createdBy?: IdentitySet;
    /**
     * Identity of the user who created the item. Read-only.
     */
    createdByUser?: User;
    /**
     * Date and time of item creation. Read-only.
     */
    createdDateTime?: Date;
    /**
     * Provides a user-visible description of the item. Optional.
     */
    description?: string;
    /**
     * ETag for the item. Read-only.
     */
    eTag?: string;
    /**
     * Identity of the user, device, and application that last modified the item. Read-only.
     */
    lastModifiedBy?: IdentitySet;
    /**
     * Identity of the user who last modified the item. Read-only.
     */
    lastModifiedByUser?: User;
    /**
     * Date and time the item was last modified. Read-only.
     */
    lastModifiedDateTime?: Date;
    /**
     * The name of the item. Read-write.
     */
    name?: string;
    /**
     * Parent information, if the item has a parent. Read-write.
     */
    parentReference?: ItemReference;
    /**
     * URL that either displays the resource in the browser (for Office file formats), or is a direct link to the file (for other formats). Read-only.
     */
    webUrl?: string;
}
export declare function createBaseItemFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoDriveItem | typeof deserializeIntoListItem;
export declare function deserializeIntoBaseItem(baseItem?: BaseItem | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeBaseItem(writer: SerializationWriter, baseItem?: BaseItem | undefined): void;
