import { CalendarRoleType } from './calendarRoleType';
import { type EmailAddress } from './emailAddress';
import { type Entity } from './entity';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export interface CalendarPermission extends Entity, Parsable {
    /**
     * List of allowed sharing or delegating permission levels for the calendar. Possible values are: none, freeBusyRead, limitedRead, read, write, delegateWithoutPrivateEventAccess, delegateWithPrivateEventAccess, custom.
     */
    allowedRoles?: CalendarRoleType[];
    /**
     * Represents a share recipient or delegate who has access to the calendar. For the 'My Organization' share recipient, the address property is null. Read-only.
     */
    emailAddress?: EmailAddress;
    /**
     * True if the user in context (recipient or delegate) is inside the same organization as the calendar owner.
     */
    isInsideOrganization?: boolean;
    /**
     * True if the user can be removed from the list of recipients or delegates for the specified calendar, false otherwise. The 'My organization' user determines the permissions other people within your organization have to the given calendar. You can't remove 'My organization' as a share recipient to a calendar.
     */
    isRemovable?: boolean;
    /**
     * Current permission level of the calendar share recipient or delegate.
     */
    role?: CalendarRoleType;
}
export declare function createCalendarPermissionFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoCalendarPermission;
export declare function deserializeIntoCalendarPermission(calendarPermission?: CalendarPermission | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeCalendarPermission(writer: SerializationWriter, calendarPermission?: CalendarPermission | undefined): void;
