import { type AudioRoutingGroup } from './audioRoutingGroup';
import { CallDirection } from './callDirection';
import { type CallMediaState } from './callMediaState';
import { type CallOptions } from './callOptions';
import { type CallRoute } from './callRoute';
import { CallState } from './callState';
import { type CallTranscriptionInfo } from './callTranscriptionInfo';
import { type ChatInfo } from './chatInfo';
import { type CommsOperation } from './commsOperation';
import { type ContentSharingSession } from './contentSharingSession';
import { type Entity } from './entity';
import { type IncomingContext } from './incomingContext';
import { type InvitationParticipantInfo } from './invitationParticipantInfo';
import { type MediaConfig } from './mediaConfig';
import { type MeetingInfo } from './meetingInfo';
import { Modality } from './modality';
import { type Participant } from './participant';
import { type ParticipantInfo } from './participantInfo';
import { type ResultInfo } from './resultInfo';
import { type ToneInfo } from './toneInfo';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export interface Call extends Entity, Parsable {
    /**
     * The audioRoutingGroups property
     */
    audioRoutingGroups?: AudioRoutingGroup[];
    /**
     * The callback URL on which callbacks will be delivered. Must be https.
     */
    callbackUri?: string;
    /**
     * A unique identifier for all the participant calls in a conference or a unique identifier for two participant calls in a P2P call.  This needs to be copied over from Microsoft.Graph.Call.CallChainId.
     */
    callChainId?: string;
    /**
     * Contains the optional features for the call.
     */
    callOptions?: CallOptions;
    /**
     * The routing information on how the call was retargeted. Read-only.
     */
    callRoutes?: CallRoute[];
    /**
     * The chat information. Required information for joining a meeting.
     */
    chatInfo?: ChatInfo;
    /**
     * The contentSharingSessions property
     */
    contentSharingSessions?: ContentSharingSession[];
    /**
     * The direction of the call. The possible values are incoming or outgoing. Read-only.
     */
    direction?: CallDirection;
    /**
     * Call context associated with an incoming call.
     */
    incomingContext?: IncomingContext;
    /**
     * The media configuration. Required.
     */
    mediaConfig?: MediaConfig;
    /**
     * Read-only. The call media state.
     */
    mediaState?: CallMediaState;
    /**
     * The meeting information. Required information for meeting scenarios.
     */
    meetingInfo?: MeetingInfo;
    /**
     * The myParticipantId property
     */
    myParticipantId?: string;
    /**
     * The operations property
     */
    operations?: CommsOperation[];
    /**
     * The participants property
     */
    participants?: Participant[];
    /**
     * The list of requested modalities. Possible values are: unknown, audio, video, videoBasedScreenSharing, data.
     */
    requestedModalities?: Modality[];
    /**
     * The result information. For example, the result can hold termination reason. Read-only.
     */
    resultInfo?: ResultInfo;
    /**
     * The originator of the call.
     */
    source?: ParticipantInfo;
    /**
     * The call state. Possible values are: incoming, establishing, ringing, established, hold, transferring, transferAccepted, redirecting, terminating, terminated. Read-only.
     */
    state?: CallState;
    /**
     * The subject of the conversation.
     */
    subject?: string;
    /**
     * The targets of the call. Required information for creating peer to peer call.
     */
    targets?: InvitationParticipantInfo[];
    /**
     * The tenantId property
     */
    tenantId?: string;
    /**
     * The toneInfo property
     */
    toneInfo?: ToneInfo;
    /**
     * The transcription information for the call. Read-only.
     */
    transcription?: CallTranscriptionInfo;
}
export declare function createCallFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoCall;
export declare function deserializeIntoCall(call?: Call | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeCall(writer: SerializationWriter, call?: Call | undefined): void;
