"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.serializeEndpoint = exports.deserializeIntoEndpoint = exports.createEndpointFromDiscriminatorValue = void 0;
const participantEndpoint_1 = require("./participantEndpoint");
const serviceEndpoint_1 = require("./serviceEndpoint");
const userAgent_1 = require("./userAgent");
function createEndpointFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    const mappingValueNode = parseNode.getChildNode("@odata.type");
    if (mappingValueNode) {
        const mappingValue = mappingValueNode.getStringValue();
        if (mappingValue) {
            switch (mappingValue) {
                case "#microsoft.graph.callRecords.participantEndpoint":
                    return participantEndpoint_1.deserializeIntoParticipantEndpoint;
                case "#microsoft.graph.callRecords.serviceEndpoint":
                    return serviceEndpoint_1.deserializeIntoServiceEndpoint;
            }
        }
    }
    return deserializeIntoEndpoint;
}
exports.createEndpointFromDiscriminatorValue = createEndpointFromDiscriminatorValue;
function deserializeIntoEndpoint(endpoint = {}) {
    return {
        "@odata.type": n => { endpoint.odataType = n.getStringValue(); },
        "userAgent": n => { endpoint.userAgent = n.getObjectValue(userAgent_1.createUserAgentFromDiscriminatorValue); },
    };
}
exports.deserializeIntoEndpoint = deserializeIntoEndpoint;
function serializeEndpoint(writer, endpoint = {}) {
    writer.writeStringValue("@odata.type", endpoint.odataType);
    writer.writeObjectValue("userAgent", endpoint.userAgent, userAgent_1.serializeUserAgent);
    writer.writeAdditionalData(endpoint.additionalData);
}
exports.serializeEndpoint = serializeEndpoint;
// tslint:enable
// eslint-enable
