import { AudioCodec } from './audioCodec';
import { MediaStreamDirection } from './mediaStreamDirection';
import { VideoCodec } from './videoCodec';
import { type AdditionalDataHolder, type Duration, type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createMediaStreamFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoMediaStream;
export declare function deserializeIntoMediaStream(mediaStream?: MediaStream | undefined): Record<string, (node: ParseNode) => void>;
export interface MediaStream extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * Codec name used to encode audio for transmission on the network. Possible values are: unknown, invalid, cn, pcma, pcmu, amrWide, g722, g7221, g7221c, g729, multiChannelAudio, muchv2, opus, satin, satinFullband, rtAudio8, rtAudio16, silk, silkNarrow, silkWide, siren, xmsRta, unknownFutureValue.
     */
    audioCodec?: AudioCodec;
    /**
     * Average Network Mean Opinion Score degradation for stream. Represents how much the network loss and jitter has impacted the quality of received audio.
     */
    averageAudioDegradation?: number;
    /**
     * Average jitter for the stream computed as specified in [RFC 3550][], denoted in [ISO 8601][] format. For example, 1 second is denoted as 'PT1S', where 'P' is the duration designator, 'T' is the time designator, and 'S' is the second designator.
     */
    averageAudioNetworkJitter?: Duration;
    /**
     * Average estimated bandwidth available between two endpoints in bits per second.
     */
    averageBandwidthEstimate?: number;
    /**
     * Average duration of the received freezing time in the video stream.
     */
    averageFreezeDuration?: Duration;
    /**
     * Average jitter for the stream computed as specified in [RFC 3550][], denoted in [ISO 8601][] format. For example, 1 second is denoted as 'PT1S', where 'P' is the duration designator, 'T' is the time designator, and 'S' is the second designator.
     */
    averageJitter?: Duration;
    /**
     * Average packet loss rate for stream.
     */
    averagePacketLossRate?: number;
    /**
     * Ratio of the number of audio frames with samples generated by packet loss concealment to the total number of audio frames.
     */
    averageRatioOfConcealedSamples?: number;
    /**
     * Average frames per second received for all video streams computed over the duration of the session.
     */
    averageReceivedFrameRate?: number;
    /**
     * Average network propagation round-trip time computed as specified in [RFC 3550][], denoted in [ISO 8601][] format. For example, 1 second is denoted as 'PT1S', where 'P' is the duration designator, 'T' is the time designator, and 'S' is the second designator.
     */
    averageRoundTripTime?: Duration;
    /**
     * Average percentage of video frames lost as displayed to the user.
     */
    averageVideoFrameLossPercentage?: number;
    /**
     * Average frames per second received for a video stream, computed over the duration of the session.
     */
    averageVideoFrameRate?: number;
    /**
     * Average fraction of packets lost, as specified in [RFC 3550][], computed over the duration of the session.
     */
    averageVideoPacketLossRate?: number;
    /**
     * UTC time when the stream ended. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. This field is only available for streams that use the SIP protocol.
     */
    endDateTime?: Date;
    /**
     * Indicates whether the forward error correction (FEC) was used at some point during the session. The default value is null.
     */
    isAudioForwardErrorCorrectionUsed?: boolean;
    /**
     * Fraction of the call where frame rate is less than 7.5 frames per second.
     */
    lowFrameRateRatio?: number;
    /**
     * Fraction of the call that the client is running less than 70% expected video processing capability.
     */
    lowVideoProcessingCapabilityRatio?: number;
    /**
     * Maximum of audio network jitter computed over each of the 20 second windows during the session, denoted in [ISO 8601][] format. For example, 1 second is denoted as 'PT1S', where 'P' is the duration designator, 'T' is the time designator, and 'S' is the second designator.
     */
    maxAudioNetworkJitter?: Duration;
    /**
     * Maximum jitter for the stream computed as specified in RFC 3550, denoted in [ISO 8601][] format. For example, 1 second is denoted as 'PT1S', where 'P' is the duration designator, 'T' is the time designator, and 'S' is the second designator.
     */
    maxJitter?: Duration;
    /**
     * Maximum packet loss rate for the stream.
     */
    maxPacketLossRate?: number;
    /**
     * Maximum ratio of packets concealed by the healer.
     */
    maxRatioOfConcealedSamples?: number;
    /**
     * Maximum network propagation round-trip time computed as specified in [RFC 3550][], denoted in [ISO 8601][] format. For example, 1 second is denoted as 'PT1S', where 'P' is the duration designator, 'T' is the time designator, and 'S' is the second designator.
     */
    maxRoundTripTime?: Duration;
    /**
     * The OdataType property
     */
    odataType?: string;
    /**
     * Packet count for the stream.
     */
    packetUtilization?: number;
    /**
     * Packet loss rate after FEC has been applied aggregated across all video streams and codecs.
     */
    postForwardErrorCorrectionPacketLossRate?: number;
    /**
     * Average duration of the received freezing time in the video stream represented in root mean square.
     */
    rmsFreezeDuration?: Duration;
    /**
     * UTC time when the stream started. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. This field is only available for streams that use the SIP protocol.
     */
    startDateTime?: Date;
    /**
     * The streamDirection property
     */
    streamDirection?: MediaStreamDirection;
    /**
     * Unique identifier for the stream.
     */
    streamId?: string;
    /**
     * Codec name used to encode video for transmission on the network. Possible values are: unknown, invalid, av1, h263, h264, h264s, h264uc, h265, rtvc1, rtVideo, xrtvc1, unknownFutureValue.
     */
    videoCodec?: VideoCodec;
    /**
     * True if the media stream bypassed the Mediation Server and went straight between client and PSTN Gateway/PBX, false otherwise.
     */
    wasMediaBypassed?: boolean;
}
export declare function serializeMediaStream(writer: SerializationWriter, mediaStream?: MediaStream | undefined): void;
