import { ChannelMembershipType } from './channelMembershipType';
import { type ChannelSummary } from './channelSummary';
import { type ChatMessage } from './chatMessage';
import { type ConversationMember } from './conversationMember';
import { type DriveItem } from './driveItem';
import { type Entity } from './entity';
import { type SharedWithChannelTeamInfo } from './sharedWithChannelTeamInfo';
import { type TeamsTab } from './teamsTab';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export interface Channel extends Entity, Parsable {
    /**
     * Read only. Timestamp at which the channel was created.
     */
    createdDateTime?: Date;
    /**
     * Optional textual description for the channel.
     */
    description?: string;
    /**
     * Channel name as it will appear to the user in Microsoft Teams. The maximum length is 50 characters.
     */
    displayName?: string;
    /**
     * The email address for sending messages to the channel. Read-only.
     */
    email?: string;
    /**
     * Metadata for the location where the channel's files are stored.
     */
    filesFolder?: DriveItem;
    /**
     * Indicates whether the channel should automatically be marked 'favorite' for all members of the team. Can only be set programmatically with Create team. Default: false.
     */
    isFavoriteByDefault?: boolean;
    /**
     * A collection of membership records associated with the channel.
     */
    members?: ConversationMember[];
    /**
     * The type of the channel. Can be set during creation and can't be changed. The possible values are: standard, private, unknownFutureValue, shared. The default value is standard. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value in this evolvable enum: shared.
     */
    membershipType?: ChannelMembershipType;
    /**
     * A collection of all the messages in the channel. A navigation property. Nullable.
     */
    messages?: ChatMessage[];
    /**
     * A collection of teams with which a channel is shared.
     */
    sharedWithTeams?: SharedWithChannelTeamInfo[];
    /**
     * Contains summary information about the channel, including number of owners, members, guests, and an indicator for members from other tenants. The summary property will only be returned if it is specified in the $select clause of the Get channel method.
     */
    summary?: ChannelSummary;
    /**
     * A collection of all the tabs in the channel. A navigation property.
     */
    tabs?: TeamsTab[];
    /**
     * The ID of the Microsoft Entra tenant.
     */
    tenantId?: string;
    /**
     * A hyperlink that will go to the channel in Microsoft Teams. This is the URL that you get when you right-click a channel in Microsoft Teams and select Get link to channel. This URL should be treated as an opaque blob, and not parsed. Read-only.
     */
    webUrl?: string;
}
export declare function createChannelFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoChannel;
export declare function deserializeIntoChannel(channel?: Channel | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeChannel(writer: SerializationWriter, channel?: Channel | undefined): void;
