import { type ChatMessageFromIdentitySet } from './chatMessageFromIdentitySet';
import { ChatMessageType } from './chatMessageType';
import { type Entity } from './entity';
import { type EventMessageDetail } from './eventMessageDetail';
import { type ItemBody } from './itemBody';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export interface ChatMessageInfo extends Entity, Parsable {
    /**
     * Body of the chatMessage. This will still contain markers for @mentions and attachments even though the object doesn't return @mentions and attachments.
     */
    body?: ItemBody;
    /**
     * Date time object representing the time at which message was created.
     */
    createdDateTime?: Date;
    /**
     * Read-only.  If present, represents details of an event that happened in a chat, a channel, or a team, for example, members were added, and so on. For event messages, the messageType property is set to systemEventMessage.
     */
    eventDetail?: EventMessageDetail;
    /**
     * Information about the sender of the message.
     */
    from?: ChatMessageFromIdentitySet;
    /**
     * If set to true, the original message has been deleted.
     */
    isDeleted?: boolean;
    /**
     * The messageType property
     */
    messageType?: ChatMessageType;
}
export declare function createChatMessageInfoFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoChatMessageInfo;
export declare function deserializeIntoChatMessageInfo(chatMessageInfo?: ChatMessageInfo | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeChatMessageInfo(writer: SerializationWriter, chatMessageInfo?: ChatMessageInfo | undefined): void;
