import { type CrossTenantAccessPolicyB2BSetting } from './crossTenantAccessPolicyB2BSetting';
import { type CrossTenantAccessPolicyInboundTrust } from './crossTenantAccessPolicyInboundTrust';
import { type CrossTenantIdentitySyncPolicyPartner } from './crossTenantIdentitySyncPolicyPartner';
import { type InboundOutboundPolicyConfiguration } from './inboundOutboundPolicyConfiguration';
import { type AdditionalDataHolder, type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createCrossTenantAccessPolicyConfigurationPartnerFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoCrossTenantAccessPolicyConfigurationPartner;
export interface CrossTenantAccessPolicyConfigurationPartner extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * Determines the partner-specific configuration for automatic user consent settings. Unless specifically configured, the inboundAllowed and outboundAllowed properties are null and inherit from the default settings, which is always false.
     */
    automaticUserConsentSettings?: InboundOutboundPolicyConfiguration;
    /**
     * Defines your partner-specific configuration for users from other organizations accessing your resources via Microsoft Entra B2B collaboration.
     */
    b2bCollaborationInbound?: CrossTenantAccessPolicyB2BSetting;
    /**
     * Defines your partner-specific configuration for users in your organization going outbound to access resources in another organization via Microsoft Entra B2B collaboration.
     */
    b2bCollaborationOutbound?: CrossTenantAccessPolicyB2BSetting;
    /**
     * Defines your partner-specific configuration for users from other organizations accessing your resources via Azure B2B direct connect.
     */
    b2bDirectConnectInbound?: CrossTenantAccessPolicyB2BSetting;
    /**
     * Defines your partner-specific configuration for users in your organization going outbound to access resources in another organization via Microsoft Entra B2B direct connect.
     */
    b2bDirectConnectOutbound?: CrossTenantAccessPolicyB2BSetting;
    /**
     * Defines the cross-tenant policy for the synchronization of users from a partner tenant. Use this user synchronization policy to streamline collaboration between users in a multitenant organization by automating the creation, update, and deletion of users from one tenant to another.
     */
    identitySynchronization?: CrossTenantIdentitySyncPolicyPartner;
    /**
     * Determines the partner-specific configuration for trusting other Conditional Access claims from external Microsoft Entra organizations.
     */
    inboundTrust?: CrossTenantAccessPolicyInboundTrust;
    /**
     * Identifies whether the partner-specific configuration is a Cloud Service Provider for your organization.
     */
    isServiceProvider?: boolean;
    /**
     * The OdataType property
     */
    odataType?: string;
    /**
     * The tenant identifier for the partner Microsoft Entra organization. Read-only. Key.
     */
    tenantId?: string;
}
export declare function deserializeIntoCrossTenantAccessPolicyConfigurationPartner(crossTenantAccessPolicyConfigurationPartner?: CrossTenantAccessPolicyConfigurationPartner | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeCrossTenantAccessPolicyConfigurationPartner(writer: SerializationWriter, crossTenantAccessPolicyConfigurationPartner?: CrossTenantAccessPolicyConfigurationPartner | undefined): void;
