import { type DelegatedAdminAccessAssignment } from './delegatedAdminAccessAssignment';
import { type DelegatedAdminAccessDetails } from './delegatedAdminAccessDetails';
import { type DelegatedAdminRelationshipCustomerParticipant } from './delegatedAdminRelationshipCustomerParticipant';
import { type DelegatedAdminRelationshipOperation } from './delegatedAdminRelationshipOperation';
import { type DelegatedAdminRelationshipRequest } from './delegatedAdminRelationshipRequest';
import { DelegatedAdminRelationshipStatus } from './delegatedAdminRelationshipStatus';
import { type Entity } from './entity';
import { type Duration, type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createDelegatedAdminRelationshipFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoDelegatedAdminRelationship;
export interface DelegatedAdminRelationship extends Entity, Parsable {
    /**
     * The access assignments associated with the delegated admin relationship.
     */
    accessAssignments?: DelegatedAdminAccessAssignment[];
    /**
     * The accessDetails property
     */
    accessDetails?: DelegatedAdminAccessDetails;
    /**
     * The date and time in ISO 8601 format and in UTC time when the relationship became active. Read-only.
     */
    activatedDateTime?: Date;
    /**
     * The duration by which the validity of the relationship is automatically extended, denoted in ISO 8601 format. Supported values are: P0D, PT0S, P180D. The default value is PT0S. PT0S indicates that the relationship expires when the endDateTime is reached and it isn't automatically extended.
     */
    autoExtendDuration?: Duration;
    /**
     * The date and time in ISO 8601 format and in UTC time when the relationship was created. Read-only.
     */
    createdDateTime?: Date;
    /**
     * The display name and unique identifier of the customer of the relationship. This is configured either by the partner at the time the relationship is created or by the system after the customer approves the relationship. Can't be changed by the customer.
     */
    customer?: DelegatedAdminRelationshipCustomerParticipant;
    /**
     * The display name of the relationship used for ease of identification. Must be unique across all delegated admin relationships of the partner and is set by the partner only when the relationship is in the created status and can't be changed by the customer.
     */
    displayName?: string;
    /**
     * The duration of the relationship in ISO 8601 format. Must be a value between P1D and P2Y inclusive. This is set by the partner only when the relationship is in the created status and can't be changed by the customer.
     */
    duration?: Duration;
    /**
     * The date and time in ISO 8601 format and in UTC time when the status of relationship changes to either terminated or expired. Calculated as endDateTime = activatedDateTime + duration. Read-only.
     */
    endDateTime?: Date;
    /**
     * The date and time in ISO 8601 format and in UTC time when the relationship was last modified. Read-only.
     */
    lastModifiedDateTime?: Date;
    /**
     * The long running operations associated with the delegated admin relationship.
     */
    operations?: DelegatedAdminRelationshipOperation[];
    /**
     * The requests associated with the delegated admin relationship.
     */
    requests?: DelegatedAdminRelationshipRequest[];
    /**
     * The status of the relationship. Read Only. The possible values are: activating, active, approvalPending, approved, created, expired, expiring, terminated, terminating, terminationRequested, unknownFutureValue. Supports $orderby.
     */
    status?: DelegatedAdminRelationshipStatus;
}
export declare function deserializeIntoDelegatedAdminRelationship(delegatedAdminRelationship?: DelegatedAdminRelationship | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeDelegatedAdminRelationship(writer: SerializationWriter, delegatedAdminRelationship?: DelegatedAdminRelationship | undefined): void;
