import { type AndroidManagedAppProtection } from './androidManagedAppProtection';
import { type DefaultManagedAppProtection } from './defaultManagedAppProtection';
import { type Entity } from './entity';
import { type IosManagedAppProtection } from './iosManagedAppProtection';
import { type ManagedAppPolicy } from './managedAppPolicy';
import { type ManagedAppRegistration } from './managedAppRegistration';
import { type ManagedAppStatus } from './managedAppStatus';
import { type ManagedDeviceMobileAppConfiguration } from './managedDeviceMobileAppConfiguration';
import { type ManagedEBook } from './managedEBook';
import { type MdmWindowsInformationProtectionPolicy } from './mdmWindowsInformationProtectionPolicy';
import { type MobileApp } from './mobileApp';
import { type MobileAppCategory } from './mobileAppCategory';
import { type TargetedManagedAppConfiguration } from './targetedManagedAppConfiguration';
import { type VppToken } from './vppToken';
import { type WindowsInformationProtectionPolicy } from './windowsInformationProtectionPolicy';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createDeviceAppManagementFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoDeviceAppManagement;
export declare function deserializeIntoDeviceAppManagement(deviceAppManagement?: DeviceAppManagement | undefined): Record<string, (node: ParseNode) => void>;
export interface DeviceAppManagement extends Entity, Parsable {
    /**
     * Android managed app policies.
     */
    androidManagedAppProtections?: AndroidManagedAppProtection[];
    /**
     * Default managed app policies.
     */
    defaultManagedAppProtections?: DefaultManagedAppProtection[];
    /**
     * iOS managed app policies.
     */
    iosManagedAppProtections?: IosManagedAppProtection[];
    /**
     * Whether the account is enabled for syncing applications from the Microsoft Store for Business.
     */
    isEnabledForMicrosoftStoreForBusiness?: boolean;
    /**
     * Managed app policies.
     */
    managedAppPolicies?: ManagedAppPolicy[];
    /**
     * The managed app registrations.
     */
    managedAppRegistrations?: ManagedAppRegistration[];
    /**
     * The managed app statuses.
     */
    managedAppStatuses?: ManagedAppStatus[];
    /**
     * The Managed eBook.
     */
    managedEBooks?: ManagedEBook[];
    /**
     * Windows information protection for apps running on devices which are MDM enrolled.
     */
    mdmWindowsInformationProtectionPolicies?: MdmWindowsInformationProtectionPolicy[];
    /**
     * The locale information used to sync applications from the Microsoft Store for Business. Cultures that are specific to a country/region. The names of these cultures follow RFC 4646 (Windows Vista and later). The format is -<country/regioncode2>, where  is a lowercase two-letter code derived from ISO 639-1 and <country/regioncode2> is an uppercase two-letter code derived from ISO 3166. For example, en-US for English (United States) is a specific culture.
     */
    microsoftStoreForBusinessLanguage?: string;
    /**
     * The last time an application sync from the Microsoft Store for Business was completed.
     */
    microsoftStoreForBusinessLastCompletedApplicationSyncTime?: Date;
    /**
     * The last time the apps from the Microsoft Store for Business were synced successfully for the account.
     */
    microsoftStoreForBusinessLastSuccessfulSyncDateTime?: Date;
    /**
     * The mobile app categories.
     */
    mobileAppCategories?: MobileAppCategory[];
    /**
     * The Managed Device Mobile Application Configurations.
     */
    mobileAppConfigurations?: ManagedDeviceMobileAppConfiguration[];
    /**
     * The mobile apps.
     */
    mobileApps?: MobileApp[];
    /**
     * Targeted managed app configurations.
     */
    targetedManagedAppConfigurations?: TargetedManagedAppConfiguration[];
    /**
     * List of Vpp tokens for this organization.
     */
    vppTokens?: VppToken[];
    /**
     * Windows information protection for apps running on devices which are not MDM enrolled.
     */
    windowsInformationProtectionPolicies?: WindowsInformationProtectionPolicy[];
}
export declare function serializeDeviceAppManagement(writer: SerializationWriter, deviceAppManagement?: DeviceAppManagement | undefined): void;
