import { type AdministrativeUnit } from './administrativeUnit';
import { type AttributeSet } from './attributeSet';
import { type CustomSecurityAttributeDefinition } from './customSecurityAttributeDefinition';
import { type DeviceLocalCredentialInfo } from './deviceLocalCredentialInfo';
import { type DirectoryObject } from './directoryObject';
import { type Entity } from './entity';
import { type IdentityProviderBase } from './identityProviderBase';
import { type OnPremisesDirectorySynchronization } from './onPremisesDirectorySynchronization';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createDirectoryFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoDirectory;
export declare function deserializeIntoDirectory(directory?: Directory | undefined): Record<string, (node: ParseNode) => void>;
export interface Directory extends Entity, Parsable {
    /**
     * Conceptual container for user and group directory objects.
     */
    administrativeUnits?: AdministrativeUnit[];
    /**
     * Group of related custom security attribute definitions.
     */
    attributeSets?: AttributeSet[];
    /**
     * Schema of a custom security attributes (key-value pairs).
     */
    customSecurityAttributeDefinitions?: CustomSecurityAttributeDefinition[];
    /**
     * Recently deleted items. Read-only. Nullable.
     */
    deletedItems?: DirectoryObject[];
    /**
     * The credentials of the device's local administrator account backed up to Microsoft Entra ID.
     */
    deviceLocalCredentials?: DeviceLocalCredentialInfo[];
    /**
     * Configure domain federation with organizations whose identity provider (IdP) supports either the SAML or WS-Fed protocol.
     */
    federationConfigurations?: IdentityProviderBase[];
    /**
     * A container for on-premises directory synchronization functionalities that are available for the organization.
     */
    onPremisesSynchronization?: OnPremisesDirectorySynchronization[];
}
export declare function serializeDirectory(writer: SerializationWriter, directory?: Directory | undefined): void;
