import { type BaseItem } from './baseItem';
import { type DriveItem } from './driveItem';
import { type IdentitySet } from './identitySet';
import { type List } from './list';
import { type Quota } from './quota';
import { type SharepointIds } from './sharepointIds';
import { type SystemFacet } from './systemFacet';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createDriveFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoDrive;
export declare function deserializeIntoDrive(drive?: Drive | undefined): Record<string, (node: ParseNode) => void>;
export interface Drive extends BaseItem, Parsable {
    /**
     * Collection of [bundles][bundle] (albums and multi-select-shared sets of items). Only in personal OneDrive.
     */
    bundles?: DriveItem[];
    /**
     * Describes the type of drive represented by this resource. OneDrive personal drives will return personal. OneDrive for Business will return business. SharePoint document libraries will return documentLibrary. Read-only.
     */
    driveType?: string;
    /**
     * The list of items the user is following. Only in OneDrive for Business.
     */
    following?: DriveItem[];
    /**
     * All items contained in the drive. Read-only. Nullable.
     */
    items?: DriveItem[];
    /**
     * For drives in SharePoint, the underlying document library list. Read-only. Nullable.
     */
    list?: List;
    /**
     * Optional. The user account that owns the drive. Read-only.
     */
    owner?: IdentitySet;
    /**
     * Optional. Information about the drive's storage space quota. Read-only.
     */
    quota?: Quota;
    /**
     * The root folder of the drive. Read-only.
     */
    root?: DriveItem;
    /**
     * The sharePointIds property
     */
    sharePointIds?: SharepointIds;
    /**
     * Collection of common folders available in OneDrive. Read-only. Nullable.
     */
    special?: DriveItem[];
    /**
     * If present, indicates that this is a system-managed drive. Read-only.
     */
    system?: SystemFacet;
}
export declare function serializeDrive(writer: SerializationWriter, drive?: Drive | undefined): void;
