import { type EmailIdentity } from './emailIdentity';
import { type EndUserNotificationDetail } from './endUserNotificationDetail';
import { EndUserNotificationType } from './endUserNotificationType';
import { type Entity } from './entity';
import { SimulationContentSource } from './simulationContentSource';
import { SimulationContentStatus } from './simulationContentStatus';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createEndUserNotificationFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoEndUserNotification;
export declare function deserializeIntoEndUserNotification(endUserNotification?: EndUserNotification | undefined): Record<string, (node: ParseNode) => void>;
export interface EndUserNotification extends Entity, Parsable {
    /**
     * Identity of the user who created the notification.
     */
    createdBy?: EmailIdentity;
    /**
     * Date and time when the notification was created. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    createdDateTime?: Date;
    /**
     * Description of the notification as defined by the user.
     */
    description?: string;
    /**
     * The details property
     */
    details?: EndUserNotificationDetail[];
    /**
     * Name of the notification as defined by the user.
     */
    displayName?: string;
    /**
     * Identity of the user who last modified the notification.
     */
    lastModifiedBy?: EmailIdentity;
    /**
     * Date and time when the notification was last modified. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    lastModifiedDateTime?: Date;
    /**
     * Type of notification. Possible values are: unknown, positiveReinforcement, noTraining, trainingAssignment, trainingReminder, unknownFutureValue.
     */
    notificationType?: EndUserNotificationType;
    /**
     * The source of the content. Possible values are: unknown, global, tenant, unknownFutureValue.
     */
    source?: SimulationContentSource;
    /**
     * The status of the notification. Possible values are: unknown, draft, ready, archive, delete, unknownFutureValue.
     */
    status?: SimulationContentStatus;
    /**
     * Supported locales for endUserNotification content.
     */
    supportedLocales?: string[];
}
export declare function serializeEndUserNotification(writer: SerializationWriter, endUserNotification?: EndUserNotification | undefined): void;
