import { type AccessPackage } from './accessPackage';
import { type AccessPackageAssignment } from './accessPackageAssignment';
import { type AccessPackageAssignmentPolicy } from './accessPackageAssignmentPolicy';
import { type AccessPackageAssignmentRequest } from './accessPackageAssignmentRequest';
import { type AccessPackageCatalog } from './accessPackageCatalog';
import { type AccessPackageResource } from './accessPackageResource';
import { type AccessPackageResourceEnvironment } from './accessPackageResourceEnvironment';
import { type AccessPackageResourceRequest } from './accessPackageResourceRequest';
import { type AccessPackageResourceRoleScope } from './accessPackageResourceRoleScope';
import { type Approval } from './approval';
import { type ConnectedOrganization } from './connectedOrganization';
import { type EntitlementManagementSettings } from './entitlementManagementSettings';
import { type Entity } from './entity';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createEntitlementManagementFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoEntitlementManagement;
export declare function deserializeIntoEntitlementManagement(entitlementManagement?: EntitlementManagement | undefined): Record<string, (node: ParseNode) => void>;
export interface EntitlementManagement extends Entity, Parsable {
    /**
     * Approval stages for decisions associated with access package assignment requests.
     */
    accessPackageAssignmentApprovals?: Approval[];
    /**
     * Access packages define the collection of resource roles and the policies for which subjects can request or be assigned access to those resources.
     */
    accessPackages?: AccessPackage[];
    /**
     * Access package assignment policies govern which subjects can request or be assigned an access package via an access package assignment.
     */
    assignmentPolicies?: AccessPackageAssignmentPolicy[];
    /**
     * Access package assignment requests created by or on behalf of a subject.
     */
    assignmentRequests?: AccessPackageAssignmentRequest[];
    /**
     * The assignment of an access package to a subject for a period of time.
     */
    assignments?: AccessPackageAssignment[];
    /**
     * A container for access packages.
     */
    catalogs?: AccessPackageCatalog[];
    /**
     * References to a directory or domain of another organization whose users can request access.
     */
    connectedOrganizations?: ConnectedOrganization[];
    /**
     * A reference to the geolocation environments in which a resource is located.
     */
    resourceEnvironments?: AccessPackageResourceEnvironment[];
    /**
     * Represents a request to add or remove a resource to or from a catalog respectively.
     */
    resourceRequests?: AccessPackageResourceRequest[];
    /**
     * The resourceRoleScopes property
     */
    resourceRoleScopes?: AccessPackageResourceRoleScope[];
    /**
     * The resources associated with the catalogs.
     */
    resources?: AccessPackageResource[];
    /**
     * The settings that control the behavior of Microsoft Entra entitlement management.
     */
    settings?: EntitlementManagementSettings;
}
export declare function serializeEntitlementManagement(writer: SerializationWriter, entitlementManagement?: EntitlementManagement | undefined): void;
