import { type Entity } from '../entity';
import { type ActivitySettings } from './activitySettings';
import { type Configuration } from './configuration';
import { type ConnectionOperation } from './connectionOperation';
import { ConnectionState } from './connectionState';
import { type ExternalGroup } from './externalGroup';
import { type ExternalItem } from './externalItem';
import { type Schema } from './schema';
import { type SearchSettings } from './searchSettings';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createExternalConnectionFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoExternalConnection;
export declare function deserializeIntoExternalConnection(externalConnection?: ExternalConnection | undefined): Record<string, (node: ParseNode) => void>;
export interface ExternalConnection extends Entity, Parsable {
    /**
     * Collects configurable settings related to activities involving connector content.
     */
    activitySettings?: ActivitySettings;
    /**
     * Specifies additional application IDs that are allowed to manage the connection and to index content in the connection. Optional.
     */
    configuration?: Configuration;
    /**
     * The Teams app ID. Optional.
     */
    connectorId?: string;
    /**
     * Description of the connection displayed in the Microsoft 365 admin center. Optional.
     */
    description?: string;
    /**
     * The groups property
     */
    groups?: ExternalGroup[];
    /**
     * The items property
     */
    items?: ExternalItem[];
    /**
     * The display name of the connection to be displayed in the Microsoft 365 admin center. Maximum length of 128 characters. Required.
     */
    name?: string;
    /**
     * The operations property
     */
    operations?: ConnectionOperation[];
    /**
     * The schema property
     */
    schema?: Schema;
    /**
     * The settings configuring the search experience for content in this connection, such as the display templates for search results.
     */
    searchSettings?: SearchSettings;
    /**
     * Indicates the current state of the connection. Possible values are: draft, ready, obsolete, limitExceeded, unknownFutureValue.
     */
    state?: ConnectionState;
}
export declare function serializeExternalConnection(writer: SerializationWriter, externalConnection?: ExternalConnection | undefined): void;
