import { AttestationLevel } from './attestationLevel';
import { type AuthenticationMethod } from './authenticationMethod';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createFido2AuthenticationMethodFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoFido2AuthenticationMethod;
export declare function deserializeIntoFido2AuthenticationMethod(fido2AuthenticationMethod?: Fido2AuthenticationMethod | undefined): Record<string, (node: ParseNode) => void>;
export interface Fido2AuthenticationMethod extends AuthenticationMethod, Parsable {
    /**
     * Authenticator Attestation GUID, an identifier that indicates the type (e.g. make and model) of the authenticator.
     */
    aaGuid?: string;
    /**
     * The attestation certificate(s) attached to this security key.
     */
    attestationCertificates?: string[];
    /**
     * The attestation level of this FIDO2 security key. Possible values are: attested, or notAttested.
     */
    attestationLevel?: AttestationLevel;
    /**
     * The timestamp when this key was registered to the user.
     */
    createdDateTime?: Date;
    /**
     * The display name of the key as given by the user.
     */
    displayName?: string;
    /**
     * The manufacturer-assigned model of the FIDO2 security key.
     */
    model?: string;
}
export declare function serializeFido2AuthenticationMethod(writer: SerializationWriter, fido2AuthenticationMethod?: Fido2AuthenticationMethod | undefined): void;
