import { type AuthenticationMethodConfiguration } from './authenticationMethodConfiguration';
import { type AuthenticationMethodTarget } from './authenticationMethodTarget';
import { type Fido2KeyRestrictions } from './fido2KeyRestrictions';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createFido2AuthenticationMethodConfigurationFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoFido2AuthenticationMethodConfiguration;
export declare function deserializeIntoFido2AuthenticationMethodConfiguration(fido2AuthenticationMethodConfiguration?: Fido2AuthenticationMethodConfiguration | undefined): Record<string, (node: ParseNode) => void>;
export interface Fido2AuthenticationMethodConfiguration extends AuthenticationMethodConfiguration, Parsable {
    /**
     * A collection of groups that are enabled to use the authentication method.
     */
    includeTargets?: AuthenticationMethodTarget[];
    /**
     * Determines whether attestation must be enforced for FIDO2 security key registration.
     */
    isAttestationEnforced?: boolean;
    /**
     * Determines if users can register new FIDO2 security keys.
     */
    isSelfServiceRegistrationAllowed?: boolean;
    /**
     * Controls whether key restrictions are enforced on FIDO2 security keys, either allowing or disallowing certain key types as defined by Authenticator Attestation GUID (AAGUID), an identifier that indicates the type (e.g. make and model) of the authenticator.
     */
    keyRestrictions?: Fido2KeyRestrictions;
}
export declare function serializeFido2AuthenticationMethodConfiguration(writer: SerializationWriter, fido2AuthenticationMethodConfiguration?: Fido2AuthenticationMethodConfiguration | undefined): void;
