import { type Entity } from '../entity';
import { type KeyValuePair } from '../keyValuePair';
import { LifecycleTaskCategory } from './lifecycleTaskCategory';
import { type TaskProcessingResult } from './taskProcessingResult';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createTaskFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoTask;
export declare function deserializeIntoTask(task?: Task | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeTask(writer: SerializationWriter, task?: Task | undefined): void;
export interface Task extends Entity, Parsable {
    /**
     * Arguments included within the task.  For guidance to configure this property, see Configure the arguments for built-in Lifecycle Workflow tasks. Required.
     */
    arguments?: KeyValuePair[];
    /**
     * The category property
     */
    category?: LifecycleTaskCategory[];
    /**
     * A boolean value that specifies whether, if this task fails, the workflow will stop, and subsequent tasks will not run. Optional.
     */
    continueOnError?: boolean;
    /**
     * A string that describes the purpose of the task for administrative use. Optional.
     */
    description?: string;
    /**
     * A unique string that identifies the task. Required.Supports $filter(eq, ne) and orderBy.
     */
    displayName?: string;
    /**
     * An integer that states in what order the task will run in a workflow.Supports $orderby.
     */
    executionSequence?: number;
    /**
     * A boolean value that denotes whether the task is set to run or not. Optional.Supports $filter(eq, ne) and orderBy.
     */
    isEnabled?: boolean;
    /**
     * A unique template identifier for the task. For more information about the tasks that Lifecycle Workflows currently supports and their unique identifiers, see supported tasks. Required.Supports $filter(eq, ne).
     */
    taskDefinitionId?: string;
    /**
     * The result of processing the task.
     */
    taskProcessingResults?: TaskProcessingResult[];
}
