import { type Run } from './run';
import { type TaskReport } from './taskReport';
import { type UserProcessingResult } from './userProcessingResult';
import { type WorkflowBase } from './workflowBase';
import { type WorkflowVersion } from './workflowVersion';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createWorkflowFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoWorkflow;
export declare function deserializeIntoWorkflow(workflow?: Workflow | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeWorkflow(writer: SerializationWriter, workflow?: Workflow | undefined): void;
export interface Workflow extends Parsable, WorkflowBase {
    /**
     * When the workflow was deleted.Supports $filter(lt, le, gt, ge, eq, ne) and $orderby.
     */
    deletedDateTime?: Date;
    /**
     * The unique identifier of the Microsoft Entra identity that last modified the workflow object.
     */
    executionScope?: UserProcessingResult[];
    /**
     * Identifier used for individually addressing a specific workflow.Supports $filter(eq, ne) and $orderby.
     */
    id?: string;
    /**
     * The date time when the workflow is expected to run next based on the schedule interval, if there are any users matching the execution conditions. Supports $filter(lt,gt) and $orderby.
     */
    nextScheduleRunDateTime?: Date;
    /**
     * Workflow runs.
     */
    runs?: Run[];
    /**
     * Represents the aggregation of task execution data for tasks within a workflow object.
     */
    taskReports?: TaskReport[];
    /**
     * Per-user workflow execution results.
     */
    userProcessingResults?: UserProcessingResult[];
    /**
     * The current version number of the workflow. Value is 1 when the workflow is first created.Supports $filter(lt, le, gt, ge, eq, ne) and $orderby.
     */
    version?: number;
    /**
     * The workflow versions that are available.
     */
    versions?: WorkflowVersion[];
}
