import { type EmailIdentity } from './emailIdentity';
import { type Entity } from './entity';
import { type LandingPageDetail } from './landingPageDetail';
import { SimulationContentSource } from './simulationContentSource';
import { SimulationContentStatus } from './simulationContentStatus';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createLandingPageFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoLandingPage;
export declare function deserializeIntoLandingPage(landingPage?: LandingPage | undefined): Record<string, (node: ParseNode) => void>;
export interface LandingPage extends Entity, Parsable {
    /**
     * Identity of the user who created the landing page.
     */
    createdBy?: EmailIdentity;
    /**
     * Date and time when the landing page was created. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    createdDateTime?: Date;
    /**
     * Description of the landing page as defined by the user.
     */
    description?: string;
    /**
     * The detail information for a landing page associated with a simulation during its creation.
     */
    details?: LandingPageDetail[];
    /**
     * The display name of the landing page.
     */
    displayName?: string;
    /**
     * Email identity of the user who last modified the landing page.
     */
    lastModifiedBy?: EmailIdentity;
    /**
     * Date and time when the landing page was last modified. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    lastModifiedDateTime?: Date;
    /**
     * Content locale.
     */
    locale?: string;
    /**
     * The source of the content. Possible values are: unknown, global, tenant, unknownFutureValue.
     */
    source?: SimulationContentSource;
    /**
     * The status of the simulation. Possible values are: unknown, draft, ready, archive, delete, unknownFutureValue.
     */
    status?: SimulationContentStatus;
    /**
     * Supported locales.
     */
    supportedLocales?: string[];
}
export declare function serializeLandingPage(writer: SerializationWriter, landingPage?: LandingPage | undefined): void;
