import { type Entity } from './entity';
import { type LearningContent } from './learningContent';
import { type LearningCourseActivity } from './learningCourseActivity';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createLearningProviderFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoLearningProvider;
export declare function deserializeIntoLearningProvider(learningProvider?: LearningProvider | undefined): Record<string, (node: ParseNode) => void>;
export interface LearningProvider extends Entity, Parsable {
    /**
     * The display name that appears in Viva Learning. Required.
     */
    displayName?: string;
    /**
     * Indicates whether a provider can ingest learning course activity records. The default value is false. Set to true to make learningCourseActivities available for this provider.
     */
    isCourseActivitySyncEnabled?: boolean;
    /**
     * Learning catalog items for the provider.
     */
    learningContents?: LearningContent[];
    /**
     * The learningCourseActivities property
     */
    learningCourseActivities?: LearningCourseActivity[];
    /**
     * Authentication URL to access the courses for the provider. Optional.
     */
    loginWebUrl?: string;
    /**
     * The long logo URL for the dark mode that needs to be a publicly accessible image. This image would be saved to the blob storage of Viva Learning for rendering within the Viva Learning app. Required.
     */
    longLogoWebUrlForDarkTheme?: string;
    /**
     * The long logo URL for the light mode that needs to be a publicly accessible image. This image would be saved to the blob storage of Viva Learning for rendering within the Viva Learning app. Required.
     */
    longLogoWebUrlForLightTheme?: string;
    /**
     * The square logo URL for the dark mode that needs to be a publicly accessible image. This image would be saved to the blob storage of Viva Learning for rendering within the Viva Learning app. Required.
     */
    squareLogoWebUrlForDarkTheme?: string;
    /**
     * The square logo URL for the light mode that needs to be a publicly accessible image. This image would be saved to the blob storage of Viva Learning for rendering within the Viva Learning app. Required.
     */
    squareLogoWebUrlForLightTheme?: string;
}
export declare function serializeLearningProvider(writer: SerializationWriter, learningProvider?: LearningProvider | undefined): void;
