import { type BaseItem } from './baseItem';
import { type ContentTypeInfo } from './contentTypeInfo';
import { type DocumentSetVersion } from './documentSetVersion';
import { type DriveItem } from './driveItem';
import { type FieldValueSet } from './fieldValueSet';
import { type ItemAnalytics } from './itemAnalytics';
import { type ListItemVersion } from './listItemVersion';
import { type SharepointIds } from './sharepointIds';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createListItemFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoListItem;
export declare function deserializeIntoListItem(listItem?: ListItem | undefined): Record<string, (node: ParseNode) => void>;
export interface ListItem extends BaseItem, Parsable {
    /**
     * Analytics about the view activities that took place on this item.
     */
    analytics?: ItemAnalytics;
    /**
     * The content type of this list item
     */
    contentType?: ContentTypeInfo;
    /**
     * Version information for a document set version created by a user.
     */
    documentSetVersions?: DocumentSetVersion[];
    /**
     * For document libraries, the driveItem relationship exposes the listItem as a [driveItem][]
     */
    driveItem?: DriveItem;
    /**
     * The values of the columns set on this list item.
     */
    fields?: FieldValueSet;
    /**
     * Returns identifiers useful for SharePoint REST compatibility. Read-only.
     */
    sharepointIds?: SharepointIds;
    /**
     * The list of previous versions of the list item.
     */
    versions?: ListItemVersion[];
}
export declare function serializeListItem(writer: SerializationWriter, listItem?: ListItem | undefined): void;
