"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.serializeLocation = exports.deserializeIntoLocation = exports.createLocationFromDiscriminatorValue = void 0;
const locationConstraintItem_1 = require("./locationConstraintItem");
const locationType_1 = require("./locationType");
const locationUniqueIdType_1 = require("./locationUniqueIdType");
const outlookGeoCoordinates_1 = require("./outlookGeoCoordinates");
const physicalAddress_1 = require("./physicalAddress");
function createLocationFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    const mappingValueNode = parseNode.getChildNode("@odata.type");
    if (mappingValueNode) {
        const mappingValue = mappingValueNode.getStringValue();
        if (mappingValue) {
            switch (mappingValue) {
                case "#microsoft.graph.locationConstraintItem":
                    return locationConstraintItem_1.deserializeIntoLocationConstraintItem;
            }
        }
    }
    return deserializeIntoLocation;
}
exports.createLocationFromDiscriminatorValue = createLocationFromDiscriminatorValue;
function deserializeIntoLocation(location = {}) {
    return {
        "address": n => { location.address = n.getObjectValue(physicalAddress_1.createPhysicalAddressFromDiscriminatorValue); },
        "coordinates": n => { location.coordinates = n.getObjectValue(outlookGeoCoordinates_1.createOutlookGeoCoordinatesFromDiscriminatorValue); },
        "displayName": n => { location.displayName = n.getStringValue(); },
        "locationEmailAddress": n => { location.locationEmailAddress = n.getStringValue(); },
        "locationType": n => { location.locationType = n.getEnumValue(locationType_1.LocationType); },
        "locationUri": n => { location.locationUri = n.getStringValue(); },
        "@odata.type": n => { location.odataType = n.getStringValue(); },
        "uniqueId": n => { location.uniqueId = n.getStringValue(); },
        "uniqueIdType": n => { location.uniqueIdType = n.getEnumValue(locationUniqueIdType_1.LocationUniqueIdType); },
    };
}
exports.deserializeIntoLocation = deserializeIntoLocation;
function serializeLocation(writer, location = {}) {
    writer.writeObjectValue("address", location.address, physicalAddress_1.serializePhysicalAddress);
    writer.writeObjectValue("coordinates", location.coordinates, outlookGeoCoordinates_1.serializeOutlookGeoCoordinates);
    writer.writeStringValue("displayName", location.displayName);
    writer.writeStringValue("locationEmailAddress", location.locationEmailAddress);
    writer.writeEnumValue("locationType", location.locationType);
    writer.writeStringValue("locationUri", location.locationUri);
    writer.writeStringValue("@odata.type", location.odataType);
    writer.writeStringValue("uniqueId", location.uniqueId);
    writer.writeEnumValue("uniqueIdType", location.uniqueIdType);
    writer.writeAdditionalData(location.additionalData);
}
exports.serializeLocation = serializeLocation;
// tslint:enable
// eslint-enable
