import { type AttributeMapping } from './attributeMapping';
import { type Filter } from './filter';
import { ObjectFlowTypes } from './objectFlowTypes';
import { type ObjectMappingMetadataEntry } from './objectMappingMetadataEntry';
import { type AdditionalDataHolder, type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createObjectMappingFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoObjectMapping;
export declare function deserializeIntoObjectMapping(objectMapping?: ObjectMapping | undefined): Record<string, (node: ParseNode) => void>;
export interface ObjectMapping extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * Attribute mappings define which attributes to map from the source object into the target object and how they should flow. A number of functions are available to support the transformation of the original source values.
     */
    attributeMappings?: AttributeMapping[];
    /**
     * When true, this object mapping will be processed during synchronization. When false, this object mapping will be skipped.
     */
    enabled?: boolean;
    /**
     * The flowTypes property
     */
    flowTypes?: ObjectFlowTypes[];
    /**
     * Additional extension properties. Unless mentioned explicitly, metadata values should not be changed.
     */
    metadata?: ObjectMappingMetadataEntry[];
    /**
     * Human-friendly name of the object mapping.
     */
    name?: string;
    /**
     * The OdataType property
     */
    odataType?: string;
    /**
     * Defines a filter to be used when deciding whether a given object should be provisioned. For example, you might want to only provision users that are located in the US.
     */
    scope?: Filter;
    /**
     * Name of the object in the source directory. Must match the object name from the source directory definition.
     */
    sourceObjectName?: string;
    /**
     * Name of the object in target directory. Must match the object name from the target directory definition.
     */
    targetObjectName?: string;
}
export declare function serializeObjectMapping(writer: SerializationWriter, objectMapping?: ObjectMapping | undefined): void;
