import { type DirectoryObject } from './directoryObject';
import { type OnPremisesProvisioningError } from './onPremisesProvisioningError';
import { type Phone } from './phone';
import { type PhysicalOfficeAddress } from './physicalOfficeAddress';
import { type ServiceProvisioningError } from './serviceProvisioningError';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createOrgContactFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoOrgContact;
export declare function deserializeIntoOrgContact(orgContact?: OrgContact | undefined): Record<string, (node: ParseNode) => void>;
export interface OrgContact extends DirectoryObject, Parsable {
    /**
     * Postal addresses for this organizational contact. For now a contact can only have one physical address.
     */
    addresses?: PhysicalOfficeAddress[];
    /**
     * Name of the company that this organizational contact belongs to.  Supports $filter (eq, ne, not, ge, le, in, startsWith, and eq for null values).
     */
    companyName?: string;
    /**
     * The name for the department in which the contact works.  Supports $filter (eq, ne, not, ge, le, in, startsWith, and eq for null values).
     */
    department?: string;
    /**
     * The contact's direct reports. (The users and contacts that have their manager property set to this contact.)  Read-only. Nullable. Supports $expand.
     */
    directReports?: DirectoryObject[];
    /**
     * Display name for this organizational contact. Supports $filter (eq, ne, not, ge, le, in, startsWith, and eq for null values), $search, and $orderby.
     */
    displayName?: string;
    /**
     * First name for this organizational contact. Supports $filter (eq, ne, not, ge, le, in, startsWith, and eq for null values).
     */
    givenName?: string;
    /**
     * Job title for this organizational contact. Supports $filter (eq, ne, not, ge, le, in, startsWith, and eq for null values).
     */
    jobTitle?: string;
    /**
     * The SMTP address for the contact, for example, 'jeff@contoso.onmicrosoft.com'. Supports $filter (eq, ne, not, ge, le, in, startsWith, and eq for null values).
     */
    mail?: string;
    /**
     * Email alias (portion of email address pre-pending the @ symbol) for this organizational contact. Supports $filter (eq, ne, not, ge, le, in, startsWith, and eq for null values).
     */
    mailNickname?: string;
    /**
     * The user or contact that is this contact's manager. Read-only. Supports $expand and $filter (eq) by id.
     */
    manager?: DirectoryObject;
    /**
     * Groups that this contact is a member of. Read-only. Nullable. Supports $expand.
     */
    memberOf?: DirectoryObject[];
    /**
     * Date and time when this organizational contact was last synchronized from on-premises AD. This date and time information uses ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, not, ge, le, in).
     */
    onPremisesLastSyncDateTime?: Date;
    /**
     * List of any synchronization provisioning errors for this organizational contact. Supports $filter (eq, not for category and propertyCausingError), /$count eq 0, /$count ne 0.
     */
    onPremisesProvisioningErrors?: OnPremisesProvisioningError[];
    /**
     * true if this object is synced from an on-premises directory; false if this object was originally synced from an on-premises directory but is no longer synced and now mastered in Exchange; null if this object has never been synced from an on-premises directory (default).   Supports $filter (eq, ne, not, in, and eq for null values).
     */
    onPremisesSyncEnabled?: boolean;
    /**
     * List of phones for this organizational contact. Phone types can be mobile, business, and businessFax. Only one of each type can ever be present in the collection.
     */
    phones?: Phone[];
    /**
     * For example: 'SMTP: bob@contoso.com', 'smtp: bob@sales.contoso.com'. The any operator is required for filter expressions on multi-valued properties. Supports $filter (eq, not, ge, le, startsWith, /$count eq 0, /$count ne 0).
     */
    proxyAddresses?: string[];
    /**
     * The serviceProvisioningErrors property
     */
    serviceProvisioningErrors?: ServiceProvisioningError[];
    /**
     * Last name for this organizational contact. Supports $filter (eq, ne, not, ge, le, in, startsWith, and eq for null values).
     */
    surname?: string;
    /**
     * Groups that this contact is a member of, including groups that the contact is nested under. Read-only. Nullable.
     */
    transitiveMemberOf?: DirectoryObject[];
}
export declare function serializeOrgContact(writer: SerializationWriter, orgContact?: OrgContact | undefined): void;
