import { type AssignedPlan } from './assignedPlan';
import { type CertificateBasedAuthConfiguration } from './certificateBasedAuthConfiguration';
import { type DirectoryObject } from './directoryObject';
import { type Extension } from './extension';
import { MdmAuthority } from './mdmAuthority';
import { type OrganizationalBranding } from './organizationalBranding';
import { PartnerTenantType } from './partnerTenantType';
import { type PrivacyProfile } from './privacyProfile';
import { type ProvisionedPlan } from './provisionedPlan';
import { type VerifiedDomain } from './verifiedDomain';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createOrganizationFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoOrganization;
export declare function deserializeIntoOrganization(organization?: Organization | undefined): Record<string, (node: ParseNode) => void>;
export interface Organization extends DirectoryObject, Parsable {
    /**
     * The collection of service plans associated with the tenant. Not nullable.
     */
    assignedPlans?: AssignedPlan[];
    /**
     * Branding for the organization. Nullable.
     */
    branding?: OrganizationalBranding;
    /**
     * Telephone number for the organization. Although this is a string collection, only one number can be set for this property.
     */
    businessPhones?: string[];
    /**
     * Navigation property to manage certificate-based authentication configuration. Only a single instance of certificateBasedAuthConfiguration can be created in the collection.
     */
    certificateBasedAuthConfiguration?: CertificateBasedAuthConfiguration[];
    /**
     * City name of the address for the organization.
     */
    city?: string;
    /**
     * Country/region name of the address for the organization.
     */
    country?: string;
    /**
     * Country or region abbreviation for the organization in ISO 3166-2 format.
     */
    countryLetterCode?: string;
    /**
     * Timestamp of when the organization was created. The value cannot be modified and is automatically populated when the organization is created. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.
     */
    createdDateTime?: Date;
    /**
     * Two-letter ISO 3166 country code indicating the default service usage location of an organization.
     */
    defaultUsageLocation?: string;
    /**
     * The display name for the tenant.
     */
    displayName?: string;
    /**
     * The collection of open extensions defined for the organization. Read-only. Nullable.
     */
    extensions?: Extension[];
    /**
     * Not nullable.
     */
    marketingNotificationEmails?: string[];
    /**
     * Mobile device management authority.
     */
    mobileDeviceManagementAuthority?: MdmAuthority;
    /**
     * The time and date at which the tenant was last synced with the on-premises directory. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.
     */
    onPremisesLastSyncDateTime?: Date;
    /**
     * true if this object is synced from an on-premises directory; false if this object was originally synced from an on-premises directory but is no longer synced. Nullable. null if this object has never been synced from an on-premises directory (default).
     */
    onPremisesSyncEnabled?: boolean;
    /**
     * The type of partnership this tenant has with Microsoft. The possible values are: microsoftSupport, syndicatePartner, breadthPartner, breadthPartnerDelegatedAdmin, resellerPartnerDelegatedAdmin, valueAddedResellerPartnerDelegatedAdmin, unknownFutureValue. Nullable. For more information about the possible types, see partnerTenantType values.
     */
    partnerTenantType?: PartnerTenantType;
    /**
     * Postal code of the address for the organization.
     */
    postalCode?: string;
    /**
     * The preferred language for the organization. Should follow ISO 639-1 Code; for example, en.
     */
    preferredLanguage?: string;
    /**
     * The privacy profile of an organization.
     */
    privacyProfile?: PrivacyProfile;
    /**
     * Not nullable.
     */
    provisionedPlans?: ProvisionedPlan[];
    /**
     * Not nullable.
     */
    securityComplianceNotificationMails?: string[];
    /**
     * Not nullable.
     */
    securityComplianceNotificationPhones?: string[];
    /**
     * State name of the address for the organization.
     */
    state?: string;
    /**
     * Street name of the address for organization.
     */
    street?: string;
    /**
     * Not nullable.
     */
    technicalNotificationMails?: string[];
    /**
     * Not nullable. The tenant type option that was selected when the tenant was created. The possible values are:  AAD - An enterprise identity access management (IAM) service that serves business-to-employee and business-to-business (B2B) scenarios.  AAD B2C A customer identity access management (CIAM) service that serves business-to-consumer (B2C) scenarios.
     */
    tenantType?: string;
    /**
     * The collection of domains associated with this tenant. Not nullable.
     */
    verifiedDomains?: VerifiedDomain[];
}
export declare function serializeOrganization(writer: SerializationWriter, organization?: Organization | undefined): void;
