import { type Entity } from './entity';
import { type IdentitySet } from './identitySet';
import { type ItemReference } from './itemReference';
import { type SharePointIdentitySet } from './sharePointIdentitySet';
import { type SharingInvitation } from './sharingInvitation';
import { type SharingLink } from './sharingLink';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createPermissionFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoPermission;
export declare function deserializeIntoPermission(permission?: Permission | undefined): Record<string, (node: ParseNode) => void>;
export interface Permission extends Entity, Parsable {
    /**
     * A format of yyyy-MM-ddTHH:mm:ssZ of DateTimeOffset indicates the expiration time of the permission. DateTime.MinValue indicates there's no expiration set for this permission. Optional.
     */
    expirationDateTime?: Date;
    /**
     * The grantedTo property
     */
    grantedTo?: IdentitySet;
    /**
     * The grantedToIdentities property
     */
    grantedToIdentities?: IdentitySet[];
    /**
     * For link type permissions, the details of the users to whom permission was granted. Read-only.
     */
    grantedToIdentitiesV2?: SharePointIdentitySet[];
    /**
     * For user type permissions, the details of the users and applications for this permission. Read-only.
     */
    grantedToV2?: SharePointIdentitySet;
    /**
     * Indicates whether the password is set for this permission. This property only appears in the response. Optional. Read-only. For OneDrive Personal only..
     */
    hasPassword?: boolean;
    /**
     * Provides a reference to the ancestor of the current permission, if it's inherited from an ancestor. Read-only.
     */
    inheritedFrom?: ItemReference;
    /**
     * Details of any associated sharing invitation for this permission. Read-only.
     */
    invitation?: SharingInvitation;
    /**
     * Provides the link details of the current permission, if it's a link type permission. Read-only.
     */
    link?: SharingLink;
    /**
     * The type of permission, for example, read. See below for the full list of roles. Read-only.
     */
    roles?: string[];
    /**
     * A unique token that can be used to access this shared item via the shares API. Read-only.
     */
    shareId?: string;
}
export declare function serializePermission(writer: SerializationWriter, permission?: Permission | undefined): void;
