import { type Entity } from './entity';
import { PermissionType } from './permissionType';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createPermissionGrantConditionSetFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoPermissionGrantConditionSet;
export declare function deserializeIntoPermissionGrantConditionSet(permissionGrantConditionSet?: PermissionGrantConditionSet | undefined): Record<string, (node: ParseNode) => void>;
export interface PermissionGrantConditionSet extends Entity, Parsable {
    /**
     * A list of appId values for the client applications to match with, or a list with the single value all to match any client application. Default is the single value all.
     */
    clientApplicationIds?: string[];
    /**
     * A list of Microsoft Partner Network (MPN) IDs for verified publishers of the client application, or a list with the single value all to match with client apps from any publisher. Default is the single value all.
     */
    clientApplicationPublisherIds?: string[];
    /**
     * Set to true to only match on client applications with a verified publisher. Set to false to match on any client app, even if it doesn't have a verified publisher. Default is false.
     */
    clientApplicationsFromVerifiedPublisherOnly?: boolean;
    /**
     * A list of Microsoft Entra tenant IDs in which the client application is registered, or a list with the single value all to match with client apps registered in any tenant. Default is the single value all.
     */
    clientApplicationTenantIds?: string[];
    /**
     * The permission classification for the permission being granted, or all to match with any permission classification (including permissions that aren't classified). Default is all.
     */
    permissionClassification?: string;
    /**
     * The list of id values for the specific permissions to match with, or a list with the single value all to match with any permission. The id of delegated permissions can be found in the oauth2PermissionScopes property of the API's servicePrincipal object. The id of application permissions can be found in the appRoles property of the API's servicePrincipal object. The id of resource-specific application permissions can be found in the resourceSpecificApplicationPermissions property of the API's servicePrincipal object. Default is the single value all.
     */
    permissions?: string[];
    /**
     * The permission type of the permission being granted. Possible values: application for application permissions (for example app roles), or delegated for delegated permissions. The value delegatedUserConsentable indicates delegated permissions that haven't been configured by the API publisher to require admin consent—this value may be used in built-in permission grant policies, but can't be used in custom permission grant policies. Required.
     */
    permissionType?: PermissionType;
    /**
     * The appId of the resource application (for example the API) for which a permission is being granted, or any to match with any resource application or API. Default is any.
     */
    resourceApplication?: string;
}
export declare function serializePermissionGrantConditionSet(writer: SerializationWriter, permissionGrantConditionSet?: PermissionGrantConditionSet | undefined): void;
