import { type Entity } from './entity';
import { type Location } from './location';
import { type PersonType } from './personType';
import { type Phone } from './phone';
import { type ScoredEmailAddress } from './scoredEmailAddress';
import { type Website } from './website';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createPersonFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoPerson;
export declare function deserializeIntoPerson(person?: Person | undefined): Record<string, (node: ParseNode) => void>;
export interface Person extends Entity, Parsable {
    /**
     * The person's birthday.
     */
    birthday?: string;
    /**
     * The name of the person's company.
     */
    companyName?: string;
    /**
     * The person's department.
     */
    department?: string;
    /**
     * The person's display name.
     */
    displayName?: string;
    /**
     * The person's given name.
     */
    givenName?: string;
    /**
     * The instant message voice over IP (VOIP) session initiation protocol (SIP) address for the user. Read-only.
     */
    imAddress?: string;
    /**
     * True if the user has flagged this person as a favorite.
     */
    isFavorite?: boolean;
    /**
     * The person's job title.
     */
    jobTitle?: string;
    /**
     * The location of the person's office.
     */
    officeLocation?: string;
    /**
     * Free-form notes that the user has taken about this person.
     */
    personNotes?: string;
    /**
     * The type of person.
     */
    personType?: PersonType;
    /**
     * The person's phone numbers.
     */
    phones?: Phone[];
    /**
     * The person's addresses.
     */
    postalAddresses?: Location[];
    /**
     * The person's profession.
     */
    profession?: string;
    /**
     * The person's email addresses.
     */
    scoredEmailAddresses?: ScoredEmailAddress[];
    /**
     * The person's surname.
     */
    surname?: string;
    /**
     * The user principal name (UPN) of the person. The UPN is an Internet-style login name for the person based on the Internet standard RFC 822. By convention, this should map to the person's email name. The general format is alias@domain.
     */
    userPrincipalName?: string;
    /**
     * The person's websites.
     */
    websites?: Website[];
    /**
     * The phonetic Japanese name of the person's company.
     */
    yomiCompany?: string;
}
export declare function serializePerson(writer: SerializationWriter, person?: Person | undefined): void;
