import { type ActivityBasedTimeoutPolicy } from './activityBasedTimeoutPolicy';
import { type AdminConsentRequestPolicy } from './adminConsentRequestPolicy';
import { type AppManagementPolicy } from './appManagementPolicy';
import { type AuthenticationFlowsPolicy } from './authenticationFlowsPolicy';
import { type AuthenticationMethodsPolicy } from './authenticationMethodsPolicy';
import { type AuthenticationStrengthPolicy } from './authenticationStrengthPolicy';
import { type AuthorizationPolicy } from './authorizationPolicy';
import { type ClaimsMappingPolicy } from './claimsMappingPolicy';
import { type ConditionalAccessPolicy } from './conditionalAccessPolicy';
import { type CrossTenantAccessPolicy } from './crossTenantAccessPolicy';
import { type Entity } from './entity';
import { type FeatureRolloutPolicy } from './featureRolloutPolicy';
import { type HomeRealmDiscoveryPolicy } from './homeRealmDiscoveryPolicy';
import { type IdentitySecurityDefaultsEnforcementPolicy } from './identitySecurityDefaultsEnforcementPolicy';
import { type PermissionGrantPolicy } from './permissionGrantPolicy';
import { type TenantAppManagementPolicy } from './tenantAppManagementPolicy';
import { type TokenIssuancePolicy } from './tokenIssuancePolicy';
import { type TokenLifetimePolicy } from './tokenLifetimePolicy';
import { type UnifiedRoleManagementPolicy } from './unifiedRoleManagementPolicy';
import { type UnifiedRoleManagementPolicyAssignment } from './unifiedRoleManagementPolicyAssignment';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createPolicyRootFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoPolicyRoot;
export declare function deserializeIntoPolicyRoot(policyRoot?: PolicyRoot | undefined): Record<string, (node: ParseNode) => void>;
export interface PolicyRoot extends Entity, Parsable {
    /**
     * The policy that controls the idle time out for web sessions for applications.
     */
    activityBasedTimeoutPolicies?: ActivityBasedTimeoutPolicy[];
    /**
     * The policy by which consent requests are created and managed for the entire tenant.
     */
    adminConsentRequestPolicy?: AdminConsentRequestPolicy;
    /**
     * The policies that enforce app management restrictions for specific applications and service principals, overriding the defaultAppManagementPolicy.
     */
    appManagementPolicies?: AppManagementPolicy[];
    /**
     * The policy configuration of the self-service sign-up experience of external users.
     */
    authenticationFlowsPolicy?: AuthenticationFlowsPolicy;
    /**
     * The authentication methods and the users that are allowed to use them to sign in and perform multifactor authentication (MFA) in Microsoft Entra ID.
     */
    authenticationMethodsPolicy?: AuthenticationMethodsPolicy;
    /**
     * The authentication method combinations that are to be used in scenarios defined by Microsoft Entra Conditional Access.
     */
    authenticationStrengthPolicies?: AuthenticationStrengthPolicy[];
    /**
     * The policy that controls Microsoft Entra authorization settings.
     */
    authorizationPolicy?: AuthorizationPolicy;
    /**
     * The claim-mapping policies for WS-Fed, SAML, OAuth 2.0, and OpenID Connect protocols, for tokens issued to a specific application.
     */
    claimsMappingPolicies?: ClaimsMappingPolicy[];
    /**
     * The custom rules that define an access scenario.
     */
    conditionalAccessPolicies?: ConditionalAccessPolicy[];
    /**
     * The custom rules that define an access scenario when interacting with external Microsoft Entra tenants.
     */
    crossTenantAccessPolicy?: CrossTenantAccessPolicy;
    /**
     * The tenant-wide policy that enforces app management restrictions for all applications and service principals.
     */
    defaultAppManagementPolicy?: TenantAppManagementPolicy;
    /**
     * The feature rollout policy associated with a directory object.
     */
    featureRolloutPolicies?: FeatureRolloutPolicy[];
    /**
     * The policy to control Microsoft Entra authentication behavior for federated users.
     */
    homeRealmDiscoveryPolicies?: HomeRealmDiscoveryPolicy[];
    /**
     * The policy that represents the security defaults that protect against common attacks.
     */
    identitySecurityDefaultsEnforcementPolicy?: IdentitySecurityDefaultsEnforcementPolicy;
    /**
     * The policy that specifies the conditions under which consent can be granted.
     */
    permissionGrantPolicies?: PermissionGrantPolicy[];
    /**
     * Specifies the various policies associated with scopes and roles.
     */
    roleManagementPolicies?: UnifiedRoleManagementPolicy[];
    /**
     * The assignment of a role management policy to a role definition object.
     */
    roleManagementPolicyAssignments?: UnifiedRoleManagementPolicyAssignment[];
    /**
     * The policy that specifies the characteristics of SAML tokens issued by Microsoft Entra ID.
     */
    tokenIssuancePolicies?: TokenIssuancePolicy[];
    /**
     * The policy that controls the lifetime of a JWT access token, an ID token, or a SAML 1.1/2.0 token issued by Microsoft Entra ID.
     */
    tokenLifetimePolicies?: TokenLifetimePolicy[];
}
export declare function serializePolicyRoot(writer: SerializationWriter, policyRoot?: PolicyRoot | undefined): void;
