import { type IntegerRange } from './integerRange';
import { PrintColorMode } from './printColorMode';
import { PrintDuplexMode } from './printDuplexMode';
import { PrinterFeedOrientation } from './printerFeedOrientation';
import { PrintFinishing } from './printFinishing';
import { type PrintMargin } from './printMargin';
import { PrintMultipageLayout } from './printMultipageLayout';
import { PrintOrientation } from './printOrientation';
import { PrintQuality } from './printQuality';
import { PrintScaling } from './printScaling';
import { type AdditionalDataHolder, type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createPrintJobConfigurationFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoPrintJobConfiguration;
export declare function deserializeIntoPrintJobConfiguration(printJobConfiguration?: PrintJobConfiguration | undefined): Record<string, (node: ParseNode) => void>;
export interface PrintJobConfiguration extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * Whether the printer should collate pages wehen printing multiple copies of a multi-page document.
     */
    collate?: boolean;
    /**
     * The color mode the printer should use to print the job. Valid values are described in the table below. Read-only.
     */
    colorMode?: PrintColorMode;
    /**
     * The number of copies that should be printed. Read-only.
     */
    copies?: number;
    /**
     * The resolution to use when printing the job, expressed in dots per inch (DPI). Read-only.
     */
    dpi?: number;
    /**
     * The duplex mode the printer should use when printing the job. Valid values are described in the table below. Read-only.
     */
    duplexMode?: PrintDuplexMode;
    /**
     * The orientation to use when feeding media into the printer. Valid values are described in the following table. Read-only.
     */
    feedOrientation?: PrinterFeedOrientation;
    /**
     * Finishing processes to use when printing.
     */
    finishings?: PrintFinishing[];
    /**
     * The fitPdfToPage property
     */
    fitPdfToPage?: boolean;
    /**
     * The input bin (tray) to use when printing. See the printer's capabilities for a list of supported input bins.
     */
    inputBin?: string;
    /**
     * The margin settings to use when printing.
     */
    margin?: PrintMargin;
    /**
     * The media size to use when printing. Supports standard size names for ISO and ANSI media sizes.
     */
    mediaSize?: string;
    /**
     * The mediaType property
     */
    mediaType?: string;
    /**
     * The multipageLayout property
     */
    multipageLayout?: PrintMultipageLayout;
    /**
     * The OdataType property
     */
    odataType?: string;
    /**
     * The orientation property
     */
    orientation?: PrintOrientation;
    /**
     * The outputBin property
     */
    outputBin?: string;
    /**
     * The pageRanges property
     */
    pageRanges?: IntegerRange[];
    /**
     * The pagesPerSheet property
     */
    pagesPerSheet?: number;
    /**
     * The quality property
     */
    quality?: PrintQuality;
    /**
     * The scaling property
     */
    scaling?: PrintScaling;
}
export declare function serializePrintJobConfiguration(writer: SerializationWriter, printJobConfiguration?: PrintJobConfiguration | undefined): void;
