import { type File } from './file';
import { type FileSystemInfo } from './fileSystemInfo';
import { type Folder } from './folder';
import { type IdentitySet } from './identitySet';
import { type Image } from './image';
import { type ItemReference } from './itemReference';
import { type PackageEscaped } from './packageEscaped';
import { type Shared } from './shared';
import { type SharepointIds } from './sharepointIds';
import { type SpecialFolder } from './specialFolder';
import { type Video } from './video';
import { type AdditionalDataHolder, type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createRemoteItemFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoRemoteItem;
export declare function deserializeIntoRemoteItem(remoteItem?: RemoteItem | undefined): Record<string, (node: ParseNode) => void>;
export interface RemoteItem extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * Identity of the user, device, and application which created the item. Read-only.
     */
    createdBy?: IdentitySet;
    /**
     * Date and time of item creation. Read-only.
     */
    createdDateTime?: Date;
    /**
     * Indicates that the remote item is a file. Read-only.
     */
    file?: File;
    /**
     * Information about the remote item from the local file system. Read-only.
     */
    fileSystemInfo?: FileSystemInfo;
    /**
     * Indicates that the remote item is a folder. Read-only.
     */
    folder?: Folder;
    /**
     * Unique identifier for the remote item in its drive. Read-only.
     */
    id?: string;
    /**
     * Image metadata, if the item is an image. Read-only.
     */
    image?: Image;
    /**
     * Identity of the user, device, and application which last modified the item. Read-only.
     */
    lastModifiedBy?: IdentitySet;
    /**
     * Date and time the item was last modified. Read-only.
     */
    lastModifiedDateTime?: Date;
    /**
     * Optional. Filename of the remote item. Read-only.
     */
    name?: string;
    /**
     * The OdataType property
     */
    odataType?: string;
    /**
     * If present, indicates that this item is a package instead of a folder or file. Packages are treated like files in some contexts and folders in others. Read-only.
     */
    packageEscaped?: PackageEscaped;
    /**
     * Properties of the parent of the remote item. Read-only.
     */
    parentReference?: ItemReference;
    /**
     * Indicates that the item has been shared with others and provides information about the shared state of the item. Read-only.
     */
    shared?: Shared;
    /**
     * Provides interop between items in OneDrive for Business and SharePoint with the full set of item identifiers. Read-only.
     */
    sharepointIds?: SharepointIds;
    /**
     * Size of the remote item. Read-only.
     */
    size?: number;
    /**
     * If the current item is also available as a special folder, this facet is returned. Read-only.
     */
    specialFolder?: SpecialFolder;
    /**
     * Video metadata, if the item is a video. Read-only.
     */
    video?: Video;
    /**
     * DAV compatible URL for the item.
     */
    webDavUrl?: string;
    /**
     * URL that displays the resource in the browser. Read-only.
     */
    webUrl?: string;
}
export declare function serializeRemoteItem(writer: SerializationWriter, remoteItem?: RemoteItem | undefined): void;
