import { type Entity } from './entity';
import { type RiskyServicePrincipalHistoryItem } from './index';
import { RiskDetail } from './riskDetail';
import { RiskLevel } from './riskLevel';
import { RiskState } from './riskState';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createRiskyServicePrincipalFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoRiskyServicePrincipal;
export declare function deserializeIntoRiskyServicePrincipal(riskyServicePrincipal?: RiskyServicePrincipal | undefined): Record<string, (node: ParseNode) => void>;
export interface RiskyServicePrincipal extends Entity, Parsable {
    /**
     * The globally unique identifier for the associated application (its appId property), if any.
     */
    appId?: string;
    /**
     * The display name for the service principal.
     */
    displayName?: string;
    /**
     * Represents the risk history of Microsoft Entra service principals.
     */
    history?: RiskyServicePrincipalHistoryItem[];
    /**
     * true if the service principal account is enabled; otherwise, false.
     */
    isEnabled?: boolean;
    /**
     * Indicates whether Microsoft Entra ID is currently processing the service principal's risky state.
     */
    isProcessing?: boolean;
    /**
     * Details of the detected risk. Note: Details for this property are only available for Workload Identities Premium customers. Events in tenants without this license will be returned hidden. The possible values are: none, hidden,  unknownFutureValue, adminConfirmedServicePrincipalCompromised, adminDismissedAllRiskForServicePrincipal. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value(s) in this evolvable enum: adminConfirmedServicePrincipalCompromised , adminDismissedAllRiskForServicePrincipal.
     */
    riskDetail?: RiskDetail;
    /**
     * The date and time that the risk state was last updated. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2021 is 2021-01-01T00:00:00Z. Supports $filter (eq).
     */
    riskLastUpdatedDateTime?: Date;
    /**
     * Level of the detected risky workload identity. The possible values are: low, medium, high, hidden, none, unknownFutureValue. Supports $filter (eq).
     */
    riskLevel?: RiskLevel;
    /**
     * State of the service principal's risk. The possible values are: none, confirmedSafe, remediated, dismissed, atRisk, confirmedCompromised, unknownFutureValue.
     */
    riskState?: RiskState;
    /**
     * Identifies whether the service principal represents an Application, a ManagedIdentity, or a legacy application (socialIdp). This is set by Microsoft Entra ID internally and is inherited from servicePrincipal.
     */
    servicePrincipalType?: string;
}
export declare function serializeRiskyServicePrincipal(writer: SerializationWriter, riskyServicePrincipal?: RiskyServicePrincipal | undefined): void;
