import { type Entity } from './entity';
import { type OfferShiftRequest } from './offerShiftRequest';
import { type OpenShift } from './openShift';
import { type OpenShiftChangeRequest } from './openShiftChangeRequest';
import { OperationStatus } from './operationStatus';
import { type SchedulingGroup } from './schedulingGroup';
import { type Shift } from './shift';
import { type SwapShiftsChangeRequest } from './swapShiftsChangeRequest';
import { type TimeOff } from './timeOff';
import { type TimeOffReason } from './timeOffReason';
import { type TimeOffRequest } from './timeOffRequest';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createScheduleFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoSchedule;
export declare function deserializeIntoSchedule(schedule?: Schedule | undefined): Record<string, (node: ParseNode) => void>;
export interface Schedule extends Entity, Parsable {
    /**
     * Indicates whether the schedule is enabled for the team. Required.
     */
    enabled?: boolean;
    /**
     * The offer requests for shifts in the schedule.
     */
    offerShiftRequests?: OfferShiftRequest[];
    /**
     * Indicates whether offer shift requests are enabled for the schedule.
     */
    offerShiftRequestsEnabled?: boolean;
    /**
     * The open shift requests in the schedule.
     */
    openShiftChangeRequests?: OpenShiftChangeRequest[];
    /**
     * The set of open shifts in a scheduling group in the schedule.
     */
    openShifts?: OpenShift[];
    /**
     * Indicates whether open shifts are enabled for the schedule.
     */
    openShiftsEnabled?: boolean;
    /**
     * The status of the schedule provisioning. The possible values are notStarted, running, completed, failed.
     */
    provisionStatus?: OperationStatus;
    /**
     * Additional information about why schedule provisioning failed.
     */
    provisionStatusCode?: string;
    /**
     * The logical grouping of users in the schedule (usually by role).
     */
    schedulingGroups?: SchedulingGroup[];
    /**
     * The shifts in the schedule.
     */
    shifts?: Shift[];
    /**
     * The swap requests for shifts in the schedule.
     */
    swapShiftsChangeRequests?: SwapShiftsChangeRequest[];
    /**
     * Indicates whether swap shifts requests are enabled for the schedule.
     */
    swapShiftsRequestsEnabled?: boolean;
    /**
     * Indicates whether time clock is enabled for the schedule.
     */
    timeClockEnabled?: boolean;
    /**
     * The set of reasons for a time off in the schedule.
     */
    timeOffReasons?: TimeOffReason[];
    /**
     * The time off requests in the schedule.
     */
    timeOffRequests?: TimeOffRequest[];
    /**
     * Indicates whether time off requests are enabled for the schedule.
     */
    timeOffRequestsEnabled?: boolean;
    /**
     * The instances of times off in the schedule.
     */
    timesOff?: TimeOff[];
    /**
     * Indicates the time zone of the schedule team using tz database format. Required.
     */
    timeZone?: string;
    /**
     * The workforceIntegrationIds property
     */
    workforceIntegrationIds?: string[];
}
export declare function serializeSchedule(writer: SerializationWriter, schedule?: Schedule | undefined): void;
