import { type ComplianceInformation } from './complianceInformation';
import { type Entity } from './entity';
import { type SecureScoreControlStateUpdate } from './secureScoreControlStateUpdate';
import { type SecurityVendorInformation } from './securityVendorInformation';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createSecureScoreControlProfileFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoSecureScoreControlProfile;
export declare function deserializeIntoSecureScoreControlProfile(secureScoreControlProfile?: SecureScoreControlProfile | undefined): Record<string, (node: ParseNode) => void>;
export interface SecureScoreControlProfile extends Entity, Parsable {
    /**
     * Control action type (Config, Review, Behavior).
     */
    actionType?: string;
    /**
     * URL to where the control can be actioned.
     */
    actionUrl?: string;
    /**
     * GUID string for tenant ID.
     */
    azureTenantId?: string;
    /**
     * The collection of compliance information associated with secure score control
     */
    complianceInformation?: ComplianceInformation[];
    /**
     * Control action category (Identity, Data, Device, Apps, Infrastructure).
     */
    controlCategory?: string;
    /**
     * Flag to indicate where the tenant has marked a control (ignored, thirdParty, reviewed) (supports update).
     */
    controlStateUpdates?: SecureScoreControlStateUpdate[];
    /**
     * Flag to indicate if a control is depreciated.
     */
    deprecated?: boolean;
    /**
     * Resource cost of implemmentating control (low, moderate, high).
     */
    implementationCost?: string;
    /**
     * Time at which the control profile entity was last modified. The Timestamp type represents date and time
     */
    lastModifiedDateTime?: Date;
    /**
     * max attainable score for the control.
     */
    maxScore?: number;
    /**
     * Microsoft's stack ranking of control.
     */
    rank?: number;
    /**
     * Description of what the control will help remediate.
     */
    remediation?: string;
    /**
     * Description of the impact on users of the remediation.
     */
    remediationImpact?: string;
    /**
     * Service that owns the control (Exchange, Sharepoint, Microsoft Entra ID).
     */
    service?: string;
    /**
     * List of threats the control mitigates (accountBreach, dataDeletion, dataExfiltration, dataSpillage,
     */
    threats?: string[];
    /**
     * The tier property
     */
    tier?: string;
    /**
     * The title property
     */
    title?: string;
    /**
     * The userImpact property
     */
    userImpact?: string;
    /**
     * The vendorInformation property
     */
    vendorInformation?: SecurityVendorInformation;
}
export declare function serializeSecureScoreControlProfile(writer: SerializationWriter, secureScoreControlProfile?: SecureScoreControlProfile | undefined): void;
