import { type Entity } from '../entity';
import { AlertClassification } from './alertClassification';
import { type AlertComment } from './alertComment';
import { AlertDetermination } from './alertDetermination';
import { type AlertEvidence } from './alertEvidence';
import { AlertSeverity } from './alertSeverity';
import { AlertStatus } from './alertStatus';
import { DetectionSource } from './detectionSource';
import { ServiceSource } from './serviceSource';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export interface Alert extends Entity, Parsable {
    /**
     * The adversary or activity group that is associated with this alert.
     */
    actorDisplayName?: string;
    /**
     * The alertPolicyId property
     */
    alertPolicyId?: string;
    /**
     * URL for the alert page in the Microsoft 365 Defender portal.
     */
    alertWebUrl?: string;
    /**
     * Owner of the alert, or null if no owner is assigned.
     */
    assignedTo?: string;
    /**
     * The attack kill-chain category that the alert belongs to. Aligned with the MITRE ATT&CK framework.
     */
    category?: string;
    /**
     * Specifies whether the alert represents a true threat. Possible values are: unknown, falsePositive, truePositive, informationalExpectedActivity, unknownFutureValue.
     */
    classification?: AlertClassification;
    /**
     * Array of comments created by the Security Operations (SecOps) team during the alert management process.
     */
    comments?: AlertComment[];
    /**
     * Time when Microsoft 365 Defender created the alert.
     */
    createdDateTime?: Date;
    /**
     * String value describing each alert.
     */
    description?: string;
    /**
     * Detection technology or sensor that identified the notable component or activity. Possible values are: unknown, microsoftDefenderForEndpoint, antivirus, smartScreen, customTi, microsoftDefenderForOffice365, automatedInvestigation, microsoftThreatExperts, customDetection, microsoftDefenderForIdentity, cloudAppSecurity, microsoft365Defender, azureAdIdentityProtection, manual, microsoftDataLossPrevention, appGovernancePolicy, appGovernanceDetection, unknownFutureValue, microsoftDefenderForCloud, microsoftDefenderForIoT, microsoftDefenderForServers, microsoftDefenderForStorage, microsoftDefenderForDNS, microsoftDefenderForDatabases, microsoftDefenderForContainers, microsoftDefenderForNetwork, microsoftDefenderForAppService, microsoftDefenderForKeyVault, microsoftDefenderForResourceManager, microsoftDefenderForApiManagement. You must use the Prefer: include-unknown-enum-members request header to get the following value(s) in this evolvable enum: microsoftDefenderForCloud, microsoftDefenderForIoT, microsoftDefenderForServers, microsoftDefenderForStorage, microsoftDefenderForDNS, microsoftDefenderForDatabases, microsoftDefenderForContainers, microsoftDefenderForNetwork, microsoftDefenderForAppService, microsoftDefenderForKeyVault, microsoftDefenderForResourceManager, microsoftDefenderForApiManagement.
     */
    detectionSource?: DetectionSource;
    /**
     * The ID of the detector that triggered the alert.
     */
    detectorId?: string;
    /**
     * Specifies the result of the investigation, whether the alert represents a true attack and if so, the nature of the attack. Possible values are: unknown, apt, malware, securityPersonnel, securityTesting, unwantedSoftware, other, multiStagedAttack, compromisedUser, phishing, maliciousUserActivity, clean, insufficientData, confirmedUserActivity, lineOfBusinessApplication, unknownFutureValue.
     */
    determination?: AlertDetermination;
    /**
     * Collection of evidence related to the alert.
     */
    evidence?: AlertEvidence[];
    /**
     * The earliest activity associated with the alert.
     */
    firstActivityDateTime?: Date;
    /**
     * Unique identifier to represent the incident this alert resource is associated with.
     */
    incidentId?: string;
    /**
     * URL for the incident page in the Microsoft 365 Defender portal.
     */
    incidentWebUrl?: string;
    /**
     * The oldest activity associated with the alert.
     */
    lastActivityDateTime?: Date;
    /**
     * Time when the alert was last updated at Microsoft 365 Defender.
     */
    lastUpdateDateTime?: Date;
    /**
     * The attack techniques, as aligned with the MITRE ATT&CK framework.
     */
    mitreTechniques?: string[];
    /**
     * The productName property
     */
    productName?: string;
    /**
     * The ID of the alert as it appears in the security provider product that generated the alert.
     */
    providerAlertId?: string;
    /**
     * Recommended response and remediation actions to take in the event this alert was generated.
     */
    recommendedActions?: string;
    /**
     * Time when the alert was resolved.
     */
    resolvedDateTime?: Date;
    /**
     * The serviceSource property
     */
    serviceSource?: ServiceSource;
    /**
     * The severity property
     */
    severity?: AlertSeverity;
    /**
     * The status property
     */
    status?: AlertStatus;
    /**
     * The Microsoft Entra tenant the alert was created in.
     */
    tenantId?: string;
    /**
     * The threat associated with this alert.
     */
    threatDisplayName?: string;
    /**
     * Threat family associated with this alert.
     */
    threatFamilyName?: string;
    /**
     * Brief identifying string value describing the alert.
     */
    title?: string;
}
export declare function createAlertFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoAlert;
export declare function deserializeIntoAlert(alert?: Alert | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeAlert(writer: SerializationWriter, alert?: Alert | undefined): void;
