import { type Entity } from '../entity';
import { type ArticleIndicator } from './articleIndicator';
import { type FormattedContent } from './formattedContent';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export interface Article extends Entity, Parsable {
    /**
     * The body property
     */
    body?: FormattedContent;
    /**
     * The date and time when this article was created. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    createdDateTime?: Date;
    /**
     * URL of the header image for this article, used for display purposes.
     */
    imageUrl?: string;
    /**
     * Indicators related to this article.
     */
    indicators?: ArticleIndicator[];
    /**
     * Indicates whether this article is currently featured by Microsoft.
     */
    isFeatured?: boolean;
    /**
     * The most recent date and time when this article was updated. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    lastUpdatedDateTime?: Date;
    /**
     * The summary property
     */
    summary?: FormattedContent;
    /**
     * Tags for this article, communicating keywords, or key concepts.
     */
    tags?: string[];
    /**
     * The title of this article.
     */
    title?: string;
}
export declare function createArticleFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoArticle;
export declare function deserializeIntoArticle(article?: Article | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeArticle(writer: SerializationWriter, article?: Article | undefined): void;
