import { type AlertEvidence } from './alertEvidence';
import { DefenderAvStatus } from './defenderAvStatus';
import { DeviceHealthStatus } from './deviceHealthStatus';
import { DeviceRiskScore } from './deviceRiskScore';
import { type LoggedOnUser } from './loggedOnUser';
import { OnboardingStatus } from './onboardingStatus';
import { type VmMetadata } from './vmMetadata';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createDeviceEvidenceFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoDeviceEvidence;
export declare function deserializeIntoDeviceEvidence(deviceEvidence?: DeviceEvidence | undefined): Record<string, (node: ParseNode) => void>;
export interface DeviceEvidence extends AlertEvidence, Parsable {
    /**
     * A unique identifier assigned to a device by Microsoft Entra ID when device is Microsoft Entra joined.
     */
    azureAdDeviceId?: string;
    /**
     * State of the Defender AntiMalware engine. The possible values are: notReporting, disabled, notUpdated, updated, unknown, notSupported, unknownFutureValue.
     */
    defenderAvStatus?: DefenderAvStatus;
    /**
     * The fully qualified domain name (FQDN) for the device.
     */
    deviceDnsName?: string;
    /**
     * The date and time when the device was first seen.
     */
    firstSeenDateTime?: Date;
    /**
     * The health state of the device. The possible values are: active, inactive, impairedCommunication, noSensorData, noSensorDataImpairedCommunication, unknown, unknownFutureValue.
     */
    healthStatus?: DeviceHealthStatus;
    /**
     * Ip interfaces of the device during the time of the alert.
     */
    ipInterfaces?: string[];
    /**
     * Users that were logged on the machine during the time of the alert.
     */
    loggedOnUsers?: LoggedOnUser[];
    /**
     * A unique identifier assigned to a device by Microsoft Defender for Endpoint.
     */
    mdeDeviceId?: string;
    /**
     * The status of the machine onboarding to Microsoft Defender for Endpoint. The possible values are: insufficientInfo, onboarded, canBeOnboarded, unsupported, unknownFutureValue.
     */
    onboardingStatus?: OnboardingStatus;
    /**
     * The build version for the operating system the device is running.
     */
    osBuild?: number;
    /**
     * The operating system platform the device is running.
     */
    osPlatform?: string;
    /**
     * The ID of the role-based access control (RBAC) device group.
     */
    rbacGroupId?: number;
    /**
     * The name of the RBAC device group.
     */
    rbacGroupName?: string;
    /**
     * Risk score as evaluated by Microsoft Defender for Endpoint. The possible values are: none, informational, low, medium, high, unknownFutureValue.
     */
    riskScore?: DeviceRiskScore;
    /**
     * The version of the operating system platform.
     */
    version?: string;
    /**
     * Metadata of the virtual machine (VM) on which Microsoft Defender for Endpoint is running.
     */
    vmMetadata?: VmMetadata;
}
export declare function serializeDeviceEvidence(writer: SerializationWriter, deviceEvidence?: DeviceEvidence | undefined): void;
