import { type Artifact } from './artifact';
import { type HostComponent } from './hostComponent';
import { type HostCookie } from './hostCookie';
import { type HostPair } from './hostPair';
import { type HostPort } from './hostPort';
import { type HostReputation } from './hostReputation';
import { type HostSslCertificate } from './hostSslCertificate';
import { type HostTracker } from './hostTracker';
import { type PassiveDnsRecord } from './passiveDnsRecord';
import { type Subdomain } from './subdomain';
import { type WhoisRecord } from './whoisRecord';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createHostFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoHost;
export declare function deserializeIntoHost(host?: Host | undefined): Record<string, (node: ParseNode) => void>;
export interface Host extends Artifact, Parsable {
    /**
     * The hostPairs that are resources associated with a host, where that host is the parentHost and has an outgoing pairing to a childHost.
     */
    childHostPairs?: HostPair[];
    /**
     * The hostComponents that are associated with this host.
     */
    components?: HostComponent[];
    /**
     * The hostCookies that are associated with this host.
     */
    cookies?: HostCookie[];
    /**
     * The first date and time when this host was observed. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    firstSeenDateTime?: Date;
    /**
     * The hostPairs that are associated with this host, where this host is either the parentHost or childHost.
     */
    hostPairs?: HostPair[];
    /**
     * The most recent date and time when this host was observed. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    lastSeenDateTime?: Date;
    /**
     * The hostPairs that are associated with a host, where that host is the childHost and has an incoming pairing with a parentHost.
     */
    parentHostPairs?: HostPair[];
    /**
     * Passive DNS retrieval about this host.
     */
    passiveDns?: PassiveDnsRecord[];
    /**
     * Reverse passive DNS retrieval about this host.
     */
    passiveDnsReverse?: PassiveDnsRecord[];
    /**
     * The hostPorts associated with a host.
     */
    ports?: HostPort[];
    /**
     * Represents a calculated reputation of this host.
     */
    reputation?: HostReputation;
    /**
     * The hostSslCertificates that are associated with this host.
     */
    sslCertificates?: HostSslCertificate[];
    /**
     * The subdomains that are associated with this host.
     */
    subdomains?: Subdomain[];
    /**
     * The hostTrackers that are associated with this host.
     */
    trackers?: HostTracker[];
    /**
     * The most recent whoisRecord for this host.
     */
    whois?: WhoisRecord;
}
export declare function serializeHost(writer: SerializationWriter, host?: Host | undefined): void;
