import { type Artifact } from './artifact';
import { type Host } from './host';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createHostComponentFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoHostComponent;
export declare function deserializeIntoHostComponent(hostComponent?: HostComponent | undefined): Record<string, (node: ParseNode) => void>;
export interface HostComponent extends Artifact, Parsable {
    /**
     * The type of component that was detected (for example, Operating System, Framework, Remote Access, or Server).
     */
    category?: string;
    /**
     * The first date and time when Microsoft Defender Threat Intelligence observed this web component. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014, is 2014-01-01T00:00:00Z.
     */
    firstSeenDateTime?: Date;
    /**
     * The host property
     */
    host?: Host;
    /**
     * The most recent date and time when Microsoft Defender Threat Intelligence observed this web component. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014, is 2014-01-01T00:00:00Z.
     */
    lastSeenDateTime?: Date;
    /**
     * A name running on the artifact, for example, Microsoft IIS.
     */
    name?: string;
    /**
     * The component version running on the artifact, for example, v8.5. This shouldn't be assumed to be strictly numerical.
     */
    version?: string;
}
export declare function serializeHostComponent(writer: SerializationWriter, hostComponent?: HostComponent | undefined): void;
