import { type Entity } from '../entity';
import { type Host } from './host';
import { type HostPortBanner } from './hostPortBanner';
import { type HostPortComponent } from './hostPortComponent';
import { HostPortProtocol } from './hostPortProtocol';
import { HostPortStatus } from './hostPortStatus';
import { type SslCertificate } from './sslCertificate';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createHostPortFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoHostPort;
export declare function deserializeIntoHostPort(hostPort?: HostPort | undefined): Record<string, (node: ParseNode) => void>;
export interface HostPort extends Entity, Parsable {
    /**
     * The hostPortBanners retrieved from scanning the port.
     */
    banners?: HostPortBanner[];
    /**
     * The first date and time when Microsoft Defender Threat Intelligence observed the hostPort. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014, is 2014-01-01T00:00:00Z.
     */
    firstSeenDateTime?: Date;
    /**
     * The host property
     */
    host?: Host;
    /**
     * The last date and time when Microsoft Defender Threat Intelligence scanned the hostPort. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014, is 2014-01-01T00:00:00Z.
     */
    lastScanDateTime?: Date;
    /**
     * The last date and time when Microsoft Defender Threat Intelligence observed the hostPort. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014, is 2014-01-01T00:00:00Z.
     */
    lastSeenDateTime?: Date;
    /**
     * The most recent sslCertificate used to communicate on the port.
     */
    mostRecentSslCertificate?: SslCertificate;
    /**
     * The numerical identifier of the port which is standardized across the internet.
     */
    port?: number;
    /**
     * The general protocol used to scan the port. The possible values are: tcp, udp, unknownFutureValue.
     */
    protocol?: HostPortProtocol;
    /**
     * The hostPortComponents retrieved from scanning the port.
     */
    services?: HostPortComponent[];
    /**
     * The status of the port. The possible values are: open, filtered, closed, unknownFutureValue.
     */
    status?: HostPortStatus;
    /**
     * The total amount of times that Microsoft Defender Threat Intelligence has observed the hostPort in all its scans.
     */
    timesObserved?: number;
}
export declare function serializeHostPort(writer: SerializationWriter, hostPort?: HostPort | undefined): void;
