import { type Entity } from '../entity';
import { type Alert } from './alert';
import { AlertClassification } from './alertClassification';
import { type AlertComment } from './alertComment';
import { AlertDetermination } from './alertDetermination';
import { AlertSeverity } from './alertSeverity';
import { IncidentStatus } from './incidentStatus';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createIncidentFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoIncident;
export declare function deserializeIntoIncident(incident?: Incident | undefined): Record<string, (node: ParseNode) => void>;
export interface Incident extends Entity, Parsable {
    /**
     * The list of related alerts. Supports $expand.
     */
    alerts?: Alert[];
    /**
     * Owner of the incident, or null if no owner is assigned. Free editable text.
     */
    assignedTo?: string;
    /**
     * The specification for the incident. Possible values are: unknown, falsePositive, truePositive, informationalExpectedActivity, unknownFutureValue.
     */
    classification?: AlertClassification;
    /**
     * Array of comments created by the Security Operations (SecOps) team when the incident is managed.
     */
    comments?: AlertComment[];
    /**
     * Time when the incident was first created.
     */
    createdDateTime?: Date;
    /**
     * Array of custom tags associated with an incident.
     */
    customTags?: string[];
    /**
     * The description property
     */
    description?: string;
    /**
     * Specifies the determination of the incident. Possible values are: unknown, apt, malware, securityPersonnel, securityTesting, unwantedSoftware, other, multiStagedAttack, compromisedUser, phishing, maliciousUserActivity, clean, insufficientData, confirmedUserActivity, lineOfBusinessApplication, unknownFutureValue.
     */
    determination?: AlertDetermination;
    /**
     * The incident name.
     */
    displayName?: string;
    /**
     * The URL for the incident page in the Microsoft 365 Defender portal.
     */
    incidentWebUrl?: string;
    /**
     * The lastModifiedBy property
     */
    lastModifiedBy?: string;
    /**
     * Time when the incident was last updated.
     */
    lastUpdateDateTime?: Date;
    /**
     * Only populated in case an incident is grouped together with another incident, as part of the logic that processes incidents. In such a case, the status property is redirected.
     */
    redirectIncidentId?: string;
    /**
     * The severity property
     */
    severity?: AlertSeverity;
    /**
     * The status property
     */
    status?: IncidentStatus;
    /**
     * The systemTags property
     */
    systemTags?: string[];
    /**
     * The Microsoft Entra tenant in which the alert was created.
     */
    tenantId?: string;
}
export declare function serializeIncident(writer: SerializationWriter, incident?: Incident | undefined): void;
