import { type Entity } from '../entity';
import { type FormattedContent } from './formattedContent';
import { type IntelligenceProfileCountryOrRegionOfOrigin } from './intelligenceProfileCountryOrRegionOfOrigin';
import { type IntelligenceProfileIndicator } from './intelligenceProfileIndicator';
import { IntelligenceProfileKind } from './intelligenceProfileKind';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createIntelligenceProfileFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoIntelligenceProfile;
export declare function deserializeIntoIntelligenceProfile(intelligenceProfile?: IntelligenceProfile | undefined): Record<string, (node: ParseNode) => void>;
export interface IntelligenceProfile extends Entity, Parsable {
    /**
     * A list of commonly-known aliases for the threat intelligence included in the intelligenceProfile.
     */
    aliases?: string[];
    /**
     * The country/region of origin for the given actor or threat associated with this intelligenceProfile.
     */
    countriesOrRegionsOfOrigin?: IntelligenceProfileCountryOrRegionOfOrigin[];
    /**
     * The description property
     */
    description?: FormattedContent;
    /**
     * The date and time when this intelligenceProfile was first active. The timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    firstActiveDateTime?: Date;
    /**
     * Includes an assemblage of high-fidelity network indicators of compromise.
     */
    indicators?: IntelligenceProfileIndicator[];
    /**
     * The kind property
     */
    kind?: IntelligenceProfileKind;
    /**
     * The summary property
     */
    summary?: FormattedContent;
    /**
     * Known targets related to this intelligenceProfile.
     */
    targets?: string[];
    /**
     * The title of this intelligenceProfile.
     */
    title?: string;
    /**
     * Formatted information featuring a description of the distinctive tactics, techniques, and procedures (TTP) of the group, followed by a list of all known custom, commodity, and publicly available implants used by the group.
     */
    tradecraft?: FormattedContent;
}
export declare function serializeIntelligenceProfile(writer: SerializationWriter, intelligenceProfile?: IntelligenceProfile | undefined): void;
