import { type Artifact } from './artifact';
import { type Host } from './host';
import { type SslCertificateEntity } from './sslCertificateEntity';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createSslCertificateFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoSslCertificate;
export declare function deserializeIntoSslCertificate(sslCertificate?: SslCertificate | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeSslCertificate(writer: SerializationWriter, sslCertificate?: SslCertificate | undefined): void;
export interface SslCertificate extends Artifact, Parsable {
    /**
     * The date and time when a certificate expires. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    expirationDateTime?: Date;
    /**
     * A hash of the certificate calculated on the data and signature.
     */
    fingerprint?: string;
    /**
     * The first date and time when this sslCertificate was observed. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    firstSeenDateTime?: Date;
    /**
     * The date and time when a certificate was issued. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    issueDateTime?: Date;
    /**
     * The entity that grants this certificate.
     */
    issuer?: SslCertificateEntity;
    /**
     * The most recent date and time when this sslCertificate was observed. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    lastSeenDateTime?: Date;
    /**
     * The hosts related with this sslCertificate.
     */
    relatedHosts?: Host[];
    /**
     * The serial number associated with an SSL certificate.
     */
    serialNumber?: string;
    /**
     * A SHA-1 hash of the certificate. Note: This is not the signature.
     */
    sha1?: string;
    /**
     * The person, site, machine, and so on, this certificate is for.
     */
    subject?: SslCertificateEntity;
}
