import { type Entity } from '../entity';
import { type Host } from './host';
import { type WhoisContact } from './whoisContact';
import { type WhoisNameserver } from './whoisNameserver';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createWhoisBaseRecordFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoWhoisBaseRecord;
export declare function deserializeIntoWhoisBaseRecord(whoisBaseRecord?: WhoisBaseRecord | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeWhoisBaseRecord(writer: SerializationWriter, whoisBaseRecord?: WhoisBaseRecord | undefined): void;
export interface WhoisBaseRecord extends Entity, Parsable {
    /**
     * The contact information for the abuse contact.
     */
    abuse?: WhoisContact;
    /**
     * The contact information for the admin contact.
     */
    admin?: WhoisContact;
    /**
     * The contact information for the billing contact.
     */
    billing?: WhoisContact;
    /**
     * The domain status for this WHOIS object.
     */
    domainStatus?: string;
    /**
     * The date and time when this WHOIS record expires with the registrar. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    expirationDateTime?: Date;
    /**
     * The first seen date and time of this WHOIS record. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    firstSeenDateTime?: Date;
    /**
     * The host property
     */
    host?: Host;
    /**
     * The last seen date and time of this WHOIS record. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    lastSeenDateTime?: Date;
    /**
     * The date and time when this WHOIS record was last modified. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    lastUpdateDateTime?: Date;
    /**
     * The nameservers for this WHOIS object.
     */
    nameservers?: WhoisNameserver[];
    /**
     * The contact information for the noc contact.
     */
    noc?: WhoisContact;
    /**
     * The raw WHOIS details for this WHOIS object.
     */
    rawWhoisText?: string;
    /**
     * The contact information for the registrant contact.
     */
    registrant?: WhoisContact;
    /**
     * The contact information for the registrar contact.
     */
    registrar?: WhoisContact;
    /**
     * The date and time when this WHOIS record was registered with a registrar. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    registrationDateTime?: Date;
    /**
     * The contact information for the technical contact.
     */
    technical?: WhoisContact;
    /**
     * The WHOIS server that provides the details.
     */
    whoisServer?: string;
    /**
     * The contact information for the zone contact.
     */
    zone?: WhoisContact;
}
