import { ActivityType } from './activityType';
import { type Entity } from './entity';
import { RiskDetail } from './riskDetail';
import { RiskDetectionTimingType } from './riskDetectionTimingType';
import { RiskLevel } from './riskLevel';
import { RiskState } from './riskState';
import { type SignInLocation } from './signInLocation';
import { TokenIssuerType } from './tokenIssuerType';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createServicePrincipalRiskDetectionFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoServicePrincipalRiskDetection;
export declare function deserializeIntoServicePrincipalRiskDetection(servicePrincipalRiskDetection?: ServicePrincipalRiskDetection | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeServicePrincipalRiskDetection(writer: SerializationWriter, servicePrincipalRiskDetection?: ServicePrincipalRiskDetection | undefined): void;
export interface ServicePrincipalRiskDetection extends Entity, Parsable {
    /**
     * Indicates the activity type the detected risk is linked to.  The possible values are: signin, servicePrincipal. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value(s) in this evolvable enum: servicePrincipal.
     */
    activity?: ActivityType;
    /**
     * Date and time when the risky activity occurred. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     */
    activityDateTime?: Date;
    /**
     * Additional information associated with the risk detection. This string value is represented as a JSON object with the quotations escaped.
     */
    additionalInfo?: string;
    /**
     * The unique identifier for the associated application.
     */
    appId?: string;
    /**
     * Correlation ID of the sign-in activity associated with the risk detection. This property is null if the risk detection is not associated with a sign-in activity.
     */
    correlationId?: string;
    /**
     * Date and time when the risk was detected. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    detectedDateTime?: Date;
    /**
     * Timing of the detected risk , whether real-time or offline. The possible values are: notDefined, realtime, nearRealtime, offline, unknownFutureValue.
     */
    detectionTimingType?: RiskDetectionTimingType;
    /**
     * Provides the IP address of the client from where the risk occurred.
     */
    ipAddress?: string;
    /**
     * The unique identifier for the key credential associated with the risk detection.
     */
    keyIds?: string[];
    /**
     * Date and time when the risk detection was last updated.
     */
    lastUpdatedDateTime?: Date;
    /**
     * Location from where the sign-in was initiated.
     */
    location?: SignInLocation;
    /**
     * Request identifier of the sign-in activity associated with the risk detection. This property is null if the risk detection is not associated with a sign-in activity. Supports $filter (eq).
     */
    requestId?: string;
    /**
     * Details of the detected risk. Note: Details for this property are only available for Workload Identities Premium customers. Events in tenants without this license will be returned hidden. The possible values are: none, hidden, adminConfirmedServicePrincipalCompromised, adminDismissedAllRiskForServicePrincipal. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value(s) in this evolvable enum: adminConfirmedServicePrincipalCompromised , adminDismissedAllRiskForServicePrincipal.
     */
    riskDetail?: RiskDetail;
    /**
     * The type of risk event detected. The possible values are: investigationsThreatIntelligence, generic, adminConfirmedServicePrincipalCompromised, suspiciousSignins, leakedCredentials, anomalousServicePrincipalActivity, maliciousApplication, suspiciousApplication.
     */
    riskEventType?: string;
    /**
     * Level of the detected risk. Note: Details for this property are only available for Workload Identities Premium customers. Events in tenants without this license will be returned hidden. The possible values are: low, medium, high, hidden, none.
     */
    riskLevel?: RiskLevel;
    /**
     * The state of a detected risky service principal or sign-in activity. The possible values are: none, dismissed, atRisk, confirmedCompromised.
     */
    riskState?: RiskState;
    /**
     * The display name for the service principal.
     */
    servicePrincipalDisplayName?: string;
    /**
     * The unique identifier for the service principal. Supports $filter (eq).
     */
    servicePrincipalId?: string;
    /**
     * Source of the risk detection. For example, identityProtection.
     */
    source?: string;
    /**
     * Indicates the type of token issuer for the detected sign-in risk. The possible values are: AzureAD.
     */
    tokenIssuerType?: TokenIssuerType;
}
