import { type Entity } from './entity';
import { type IdleSessionSignOut } from './idleSessionSignOut';
import { ImageTaggingChoice } from './imageTaggingChoice';
import { SharingCapabilities } from './sharingCapabilities';
import { SharingDomainRestrictionMode } from './sharingDomainRestrictionMode';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
import { type Guid } from 'guid-typescript';
export declare function createSharepointSettingsFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoSharepointSettings;
export declare function deserializeIntoSharepointSettings(sharepointSettings?: SharepointSettings | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeSharepointSettings(writer: SerializationWriter, sharepointSettings?: SharepointSettings | undefined): void;
export interface SharepointSettings extends Entity, Parsable {
    /**
     * Collection of trusted domain GUIDs for the OneDrive sync app.
     */
    allowedDomainGuidsForSyncApp?: Guid[];
    /**
     * Collection of managed paths available for site creation. Read-only.
     */
    availableManagedPathsForSiteCreation?: string[];
    /**
     * The number of days for preserving a deleted user's OneDrive.
     */
    deletedUserPersonalSiteRetentionPeriodInDays?: number;
    /**
     * Collection of file extensions not uploaded by the OneDrive sync app.
     */
    excludedFileExtensionsForSyncApp?: string[];
    /**
     * Specifies the idle session sign-out policies for the tenant.
     */
    idleSessionSignOut?: IdleSessionSignOut;
    /**
     * Specifies the image tagging option for the tenant. Possible values are: disabled, basic, enhanced.
     */
    imageTaggingOption?: ImageTaggingChoice;
    /**
     * Indicates whether comments are allowed on modern site pages in SharePoint.
     */
    isCommentingOnSitePagesEnabled?: boolean;
    /**
     * Indicates whether push notifications are enabled for OneDrive events.
     */
    isFileActivityNotificationEnabled?: boolean;
    /**
     * Indicates whether legacy authentication protocols are enabled for the tenant.
     */
    isLegacyAuthProtocolsEnabled?: boolean;
    /**
     * Indicates whether if Fluid Framework is allowed on SharePoint sites.
     */
    isLoopEnabled?: boolean;
    /**
     * Indicates whether files can be synced using the OneDrive sync app for Mac.
     */
    isMacSyncAppEnabled?: boolean;
    /**
     * Indicates whether guests must sign in using the same account to which sharing invitations are sent.
     */
    isRequireAcceptingUserToMatchInvitedUserEnabled?: boolean;
    /**
     * Indicates whether guests are allowed to reshare files, folders, and sites they don't own.
     */
    isResharingByExternalUsersEnabled?: boolean;
    /**
     * Indicates whether mobile push notifications are enabled for SharePoint.
     */
    isSharePointMobileNotificationEnabled?: boolean;
    /**
     * Indicates whether the newsfeed is allowed on the modern site pages in SharePoint.
     */
    isSharePointNewsfeedEnabled?: boolean;
    /**
     * Indicates whether users are allowed to create sites.
     */
    isSiteCreationEnabled?: boolean;
    /**
     * Indicates whether the UI commands for creating sites are shown.
     */
    isSiteCreationUIEnabled?: boolean;
    /**
     * Indicates whether creating new modern pages is allowed on SharePoint sites.
     */
    isSitePagesCreationEnabled?: boolean;
    /**
     * Indicates whether site storage space is automatically managed or if specific storage limits are set per site.
     */
    isSitesStorageLimitAutomatic?: boolean;
    /**
     * Indicates whether the sync button in OneDrive is hidden.
     */
    isSyncButtonHiddenOnPersonalSite?: boolean;
    /**
     * Indicates whether users are allowed to sync files only on PCs joined to specific domains.
     */
    isUnmanagedSyncAppForTenantRestricted?: boolean;
    /**
     * The default OneDrive storage limit for all new and existing users who are assigned a qualifying license. Measured in megabytes (MB).
     */
    personalSiteDefaultStorageLimitInMB?: number;
    /**
     * Collection of email domains that are allowed for sharing outside the organization.
     */
    sharingAllowedDomainList?: string[];
    /**
     * Collection of email domains that are blocked for sharing outside the organization.
     */
    sharingBlockedDomainList?: string[];
    /**
     * Sharing capability for the tenant. Possible values are: disabled, externalUserSharingOnly, externalUserAndGuestSharing, existingExternalUserSharingOnly.
     */
    sharingCapability?: SharingCapabilities;
    /**
     * Specifies the external sharing mode for domains. Possible values are: none, allowList, blockList.
     */
    sharingDomainRestrictionMode?: SharingDomainRestrictionMode;
    /**
     * The value of the team site managed path. This is the path under which new team sites will be created.
     */
    siteCreationDefaultManagedPath?: string;
    /**
     * The default storage quota for a new site upon creation. Measured in megabytes (MB).
     */
    siteCreationDefaultStorageLimitInMB?: number;
    /**
     * The default timezone of a tenant for newly created sites. For a list of possible values, see SPRegionalSettings.TimeZones property.
     */
    tenantDefaultTimezone?: string;
}
