import { type AuthoredNote } from './authoredNote';
import { type DataSubject } from './dataSubject';
import { DataSubjectType } from './dataSubjectType';
import { type Entity } from './entity';
import { type Identity } from './identity';
import { type IdentitySet } from './identitySet';
import { type SubjectRightsRequestDetail } from './subjectRightsRequestDetail';
import { type SubjectRightsRequestHistory } from './subjectRightsRequestHistory';
import { type SubjectRightsRequestMailboxLocation } from './subjectRightsRequestMailboxLocation';
import { type SubjectRightsRequestSiteLocation } from './subjectRightsRequestSiteLocation';
import { type SubjectRightsRequestStageDetail } from './subjectRightsRequestStageDetail';
import { SubjectRightsRequestStatus } from './subjectRightsRequestStatus';
import { SubjectRightsRequestType } from './subjectRightsRequestType';
import { type Team } from './team';
import { type User } from './user';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createSubjectRightsRequestFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoSubjectRightsRequest;
export declare function deserializeIntoSubjectRightsRequest(subjectRightsRequest?: SubjectRightsRequest | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeSubjectRightsRequest(writer: SerializationWriter, subjectRightsRequest?: SubjectRightsRequest | undefined): void;
export interface SubjectRightsRequest extends Entity, Parsable {
    /**
     * Collection of users who can approve the request. Currently only supported for requests of type delete.
     */
    approvers?: User[];
    /**
     * Identity that the request is assigned to.
     */
    assignedTo?: Identity;
    /**
     * The date and time when the request was closed. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    closedDateTime?: Date;
    /**
     * Collection of users who can collaborate on the request.
     */
    collaborators?: User[];
    /**
     * KQL based content query that should be used for search. This property is defined only for APIs accessed using the /security query path and not the /privacy query path.
     */
    contentQuery?: string;
    /**
     * Identity information for the entity that created the request.
     */
    createdBy?: IdentitySet;
    /**
     * The date and time when the request was created. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    createdDateTime?: Date;
    /**
     * Information about the data subject.
     */
    dataSubject?: DataSubject;
    /**
     * The type of the data subject. Possible values are: customer, currentEmployee, formerEmployee, prospectiveEmployee, student, teacher, faculty, other, unknownFutureValue.
     */
    dataSubjectType?: DataSubjectType;
    /**
     * Description for the request.
     */
    description?: string;
    /**
     * The name of the request.
     */
    displayName?: string;
    /**
     * The external ID for the request that is immutable after creation and is used for tracking the request for the external system. This property is defined only for APIs accessed using the /security query path and not the /privacy query path.
     */
    externalId?: string;
    /**
     * Collection of history change events.
     */
    history?: SubjectRightsRequestHistory[];
    /**
     * Include all versions of the documents. By default, the current copies of the documents are returned. If SharePoint sites have versioning enabled, including all versions includes the historical copies of the documents. This property is defined only for APIs accessed using the /security query path and not the /privacy query path.
     */
    includeAllVersions?: boolean;
    /**
     * Include content authored by the data subject. This property is defined only for APIs accessed using the /security query path and not the /privacy query path.
     */
    includeAuthoredContent?: boolean;
    /**
     * Insight about the request.
     */
    insight?: SubjectRightsRequestDetail;
    /**
     * The date and time when the request is internally due. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    internalDueDateTime?: Date;
    /**
     * Identity information for the entity that last modified the request.
     */
    lastModifiedBy?: IdentitySet;
    /**
     * The date and time when the request was last modified. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    lastModifiedDateTime?: Date;
    /**
     * The mailbox locations that should be searched. This property is defined only for APIs accessed using the /security query path and not the /privacy query path.
     */
    mailboxLocations?: SubjectRightsRequestMailboxLocation;
    /**
     * List of notes associated with the request.
     */
    notes?: AuthoredNote[];
    /**
     * Pause the request after estimate has finished. By default, the data estimate runs and then pauses, allowing you to preview results and then select the option to retrieve data in the UI. You can set this property to false if you want it to perform the estimate and then automatically begin with the retrieval of the content. This property is defined only for APIs accessed using the /security query path and not the /privacy query path.
     */
    pauseAfterEstimate?: boolean;
    /**
     * List of regulations that this request fulfill.
     */
    regulations?: string[];
    /**
     * The SharePoint and OneDrive site locations that should be searched. This property is defined only for APIs accessed using the /security query path and not the /privacy query path.
     */
    siteLocations?: SubjectRightsRequestSiteLocation;
    /**
     * Information about the different stages for the request.
     */
    stages?: SubjectRightsRequestStageDetail[];
    /**
     * The status of the request. Possible values are: active, closed, unknownFutureValue.
     */
    status?: SubjectRightsRequestStatus;
    /**
     * Information about the Microsoft Teams team that was created for the request.
     */
    team?: Team;
    /**
     * The type of the request. Possible values are: export, delete, access, tagForAction, unknownFutureValue.
     */
    type?: SubjectRightsRequestType;
}
