import { type ContainerFilter } from './containerFilter';
import { type GroupFilter } from './groupFilter';
import { type ObjectMapping } from './objectMapping';
import { type StringKeyStringValuePair } from './stringKeyStringValuePair';
import { type AdditionalDataHolder, type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createSynchronizationRuleFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoSynchronizationRule;
export declare function deserializeIntoSynchronizationRule(synchronizationRule?: SynchronizationRule | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeSynchronizationRule(writer: SerializationWriter, synchronizationRule?: SynchronizationRule | undefined): void;
export interface SynchronizationRule extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The containerFilter property
     */
    containerFilter?: ContainerFilter;
    /**
     * true if the synchronization rule can be customized; false if this rule is read-only and shouldn't be changed.
     */
    editable?: boolean;
    /**
     * The groupFilter property
     */
    groupFilter?: GroupFilter;
    /**
     * Synchronization rule identifier. Must be one of the identifiers recognized by the synchronization engine. Supported rule identifiers can be found in the synchronization template returned by the API.
     */
    id?: string;
    /**
     * Additional extension properties. Unless instructed explicitly by the support team, metadata values shouldn't be changed.
     */
    metadata?: StringKeyStringValuePair[];
    /**
     * Human-readable name of the synchronization rule. Not nullable.
     */
    name?: string;
    /**
     * Collection of object mappings supported by the rule. Tells the synchronization engine which objects should be synchronized.
     */
    objectMappings?: ObjectMapping[];
    /**
     * The OdataType property
     */
    odataType?: string;
    /**
     * Priority relative to other rules in the synchronizationSchema. Rules with the lowest priority number will be processed first.
     */
    priority?: number;
    /**
     * Name of the source directory. Must match one of the directory definitions in synchronizationSchema.
     */
    sourceDirectoryName?: string;
    /**
     * Name of the target directory. Must match one of the directory definitions in synchronizationSchema.
     */
    targetDirectoryName?: string;
}
