import { type EmailIdentity } from './emailIdentity';
import { type Entity } from './entity';
import { SimulationContentSource } from './simulationContentSource';
import { TrainingAvailabilityStatus } from './trainingAvailabilityStatus';
import { type TrainingLanguageDetail } from './trainingLanguageDetail';
import { TrainingType } from './trainingType';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createTrainingFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoTraining;
export declare function deserializeIntoTraining(training?: Training | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeTraining(writer: SerializationWriter, training?: Training | undefined): void;
export interface Training extends Entity, Parsable {
    /**
     * Training availability status. Possible values are: unknown, notAvailable, available, archive, delete, unknownFutureValue.
     */
    availabilityStatus?: TrainingAvailabilityStatus;
    /**
     * Identity of the user who created the training.
     */
    createdBy?: EmailIdentity;
    /**
     * Date and time when the training was created. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    createdDateTime?: Date;
    /**
     * The description for the training.
     */
    description?: string;
    /**
     * The display name for the training.
     */
    displayName?: string;
    /**
     * Training duration.
     */
    durationInMinutes?: number;
    /**
     * Indicates whether the training has any evaluation.
     */
    hasEvaluation?: boolean;
    /**
     * Language specific details on a training.
     */
    languageDetails?: TrainingLanguageDetail[];
    /**
     * Identity of the user who last modified the training.
     */
    lastModifiedBy?: EmailIdentity;
    /**
     * Date and time when the training was last modified. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    lastModifiedDateTime?: Date;
    /**
     * Training content source. Possible values are: unknown, global, tenant, unknownFutureValue.
     */
    source?: SimulationContentSource;
    /**
     * Supported locales for content for the associated training.
     */
    supportedLocales?: string[];
    /**
     * Training tags.
     */
    tags?: string[];
    /**
     * The type of training. Possible values are: unknown, phishing, unknownFutureValue.
     */
    type?: TrainingType;
}
