import { type Entity } from './entity';
import { type UnifiedRolePermission } from './unifiedRolePermission';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createUnifiedRoleDefinitionFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoUnifiedRoleDefinition;
export declare function deserializeIntoUnifiedRoleDefinition(unifiedRoleDefinition?: UnifiedRoleDefinition | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeUnifiedRoleDefinition(writer: SerializationWriter, unifiedRoleDefinition?: UnifiedRoleDefinition | undefined): void;
export interface UnifiedRoleDefinition extends Entity, Parsable {
    /**
     * The description for the unifiedRoleDefinition. Read-only when isBuiltIn is true.
     */
    description?: string;
    /**
     * The display name for the unifiedRoleDefinition. Read-only when isBuiltIn is true. Required.  Supports $filter (eq, in).
     */
    displayName?: string;
    /**
     * Read-only collection of role definitions that the given role definition inherits from. Only Microsoft Entra built-in roles (isBuiltIn is true) support this attribute. Supports $expand.
     */
    inheritsPermissionsFrom?: UnifiedRoleDefinition[];
    /**
     * Flag indicating whether the role definition is part of the default set included in Microsoft Entra or a custom definition. Read-only. Supports $filter (eq, in).
     */
    isBuiltIn?: boolean;
    /**
     * Flag indicating whether the role is enabled for assignment. If false the role is not available for assignment. Read-only when isBuiltIn is true.
     */
    isEnabled?: boolean;
    /**
     * List of the scopes or permissions the role definition applies to. Currently only / is supported. Read-only when isBuiltIn is true. DO NOT USE. This will be deprecated soon. Attach scope to role assignment.
     */
    resourceScopes?: string[];
    /**
     * List of permissions included in the role. Read-only when isBuiltIn is true. Required.
     */
    rolePermissions?: UnifiedRolePermission[];
    /**
     * Custom template identifier that can be set when isBuiltIn is false but is read-only when isBuiltIn is true. This identifier is typically used if one needs an identifier to be the same across different directories.
     */
    templateId?: string;
    /**
     * Indicates version of the role definition. Read-only when isBuiltIn is true.
     */
    version?: string;
}
