import { type Entity } from './entity';
import { SignInUserType } from './signInUserType';
import { UserDefaultAuthenticationMethod } from './userDefaultAuthenticationMethod';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createUserRegistrationDetailsFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoUserRegistrationDetails;
export declare function deserializeIntoUserRegistrationDetails(userRegistrationDetails?: UserRegistrationDetails | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeUserRegistrationDetails(writer: SerializationWriter, userRegistrationDetails?: UserRegistrationDetails | undefined): void;
export interface UserRegistrationDetails extends Entity, Parsable {
    /**
     * Indicates whether the user has an admin role in the tenant. This value can be used to check the authentication methods that privileged accounts are registered for and capable of.
     */
    isAdmin?: boolean;
    /**
     * Indicates whether the user has registered a strong authentication method for multifactor authentication. The method must be allowed by the authentication methods policy. Supports $filter (eq).
     */
    isMfaCapable?: boolean;
    /**
     * Indicates whether the user has registered a strong authentication method for multifactor authentication. The method may not necessarily be allowed by the authentication methods policy. Supports $filter (eq).
     */
    isMfaRegistered?: boolean;
    /**
     * Indicates whether the user has registered a passwordless strong authentication method (including FIDO2, Windows Hello for Business, and Microsoft Authenticator (Passwordless)) that is allowed by the authentication methods policy. Supports $filter (eq).
     */
    isPasswordlessCapable?: boolean;
    /**
     * Indicates whether the user has registered the required number of authentication methods for self-service password reset and the user is allowed to perform self-service password reset by policy. Supports $filter (eq).
     */
    isSsprCapable?: boolean;
    /**
     * Indicates whether the user is allowed to perform self-service password reset by policy. The user may not necessarily have registered the required number of authentication methods for self-service password reset. Supports $filter (eq).
     */
    isSsprEnabled?: boolean;
    /**
     * Indicates whether the user has registered the required number of authentication methods for self-service password reset. The user may not necessarily be allowed to perform self-service password reset by policy. Supports $filter (eq).
     */
    isSsprRegistered?: boolean;
    /**
     * Indicates whether system preferred authentication method is enabled. If enabled, the system dynamically determines the most secure authentication method among the methods registered by the user. Supports $filter (eq).
     */
    isSystemPreferredAuthenticationMethodEnabled?: boolean;
    /**
     * The date and time (UTC) when the record was last updated. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    lastUpdatedDateTime?: Date;
    /**
     * Collection of authentication methods registered, such as mobilePhone, email, passKeyDeviceBound. Supports $filter (any with eq).
     */
    methodsRegistered?: string[];
    /**
     * Collection of authentication methods that the system determined to be the most secure authentication methods among the registered methods for second factor authentication. Possible values are: push, oath, voiceMobile, voiceAlternateMobile, voiceOffice, sms, none, unknownFutureValue. Supports $filter (any with eq).
     */
    systemPreferredAuthenticationMethods?: string[];
    /**
     * The user display name, such as Adele Vance. Supports $filter (eq, startsWith) and $orderby.
     */
    userDisplayName?: string;
    /**
     * The method the user selected as the default second-factor for performing multifactor authentication. Possible values are: push, oath, voiceMobile, voiceAlternateMobile, voiceOffice, sms, none, unknownFutureValue. This property is used as preferred MFA method when isSystemPreferredAuthenticationMethodEnabled is false. Supports $filter (any with eq).
     */
    userPreferredMethodForSecondaryAuthentication?: UserDefaultAuthenticationMethod;
    /**
     * The user principal name, such as AdeleV@contoso.com. Supports $filter (eq, startsWith) and $orderby.
     */
    userPrincipalName?: string;
    /**
     * Identifies whether the user is a member or guest in the tenant. The possible values are: member, guest, unknownFutureValue.
     */
    userType?: SignInUserType;
}
