import { type DeviceCompliancePolicy } from './deviceCompliancePolicy';
import { RequiredPasswordType } from './requiredPasswordType';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createWindows10CompliancePolicyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoWindows10CompliancePolicy;
export declare function deserializeIntoWindows10CompliancePolicy(windows10CompliancePolicy?: Windows10CompliancePolicy | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeWindows10CompliancePolicy(writer: SerializationWriter, windows10CompliancePolicy?: Windows10CompliancePolicy | undefined): void;
export interface Windows10CompliancePolicy extends DeviceCompliancePolicy, Parsable {
    /**
     * Require devices to be reported healthy by Windows Device Health Attestation - bit locker is enabled
     */
    bitLockerEnabled?: boolean;
    /**
     * Require devices to be reported as healthy by Windows Device Health Attestation.
     */
    codeIntegrityEnabled?: boolean;
    /**
     * Require devices to be reported as healthy by Windows Device Health Attestation - early launch antimalware driver is enabled.
     */
    earlyLaunchAntiMalwareDriverEnabled?: boolean;
    /**
     * Maximum Windows Phone version.
     */
    mobileOsMaximumVersion?: string;
    /**
     * Minimum Windows Phone version.
     */
    mobileOsMinimumVersion?: string;
    /**
     * Maximum Windows 10 version.
     */
    osMaximumVersion?: string;
    /**
     * Minimum Windows 10 version.
     */
    osMinimumVersion?: string;
    /**
     * Indicates whether or not to block simple password.
     */
    passwordBlockSimple?: boolean;
    /**
     * The password expiration in days.
     */
    passwordExpirationDays?: number;
    /**
     * The number of character sets required in the password.
     */
    passwordMinimumCharacterSetCount?: number;
    /**
     * The minimum password length.
     */
    passwordMinimumLength?: number;
    /**
     * Minutes of inactivity before a password is required.
     */
    passwordMinutesOfInactivityBeforeLock?: number;
    /**
     * The number of previous passwords to prevent re-use of.
     */
    passwordPreviousPasswordBlockCount?: number;
    /**
     * Require a password to unlock Windows device.
     */
    passwordRequired?: boolean;
    /**
     * Require a password to unlock an idle device.
     */
    passwordRequiredToUnlockFromIdle?: boolean;
    /**
     * Possible values of required passwords.
     */
    passwordRequiredType?: RequiredPasswordType;
    /**
     * Require devices to be reported as healthy by Windows Device Health Attestation.
     */
    requireHealthyDeviceReport?: boolean;
    /**
     * Require devices to be reported as healthy by Windows Device Health Attestation - secure boot is enabled.
     */
    secureBootEnabled?: boolean;
    /**
     * Require encryption on windows devices.
     */
    storageRequireEncryption?: boolean;
}
