import { type Entity } from './entity';
import { WindowsDefenderProductStatus } from './windowsDefenderProductStatus';
import { WindowsDeviceHealthState } from './windowsDeviceHealthState';
import { type WindowsDeviceMalwareState } from './windowsDeviceMalwareState';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createWindowsProtectionStateFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoWindowsProtectionState;
export declare function deserializeIntoWindowsProtectionState(windowsProtectionState?: WindowsProtectionState | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeWindowsProtectionState(writer: SerializationWriter, windowsProtectionState?: WindowsProtectionState | undefined): void;
export interface WindowsProtectionState extends Entity, Parsable {
    /**
     * Current anti malware version
     */
    antiMalwareVersion?: string;
    /**
     * Device malware list
     */
    detectedMalwareState?: WindowsDeviceMalwareState[];
    /**
     * Indicates device's health state. Possible values are: clean, fullScanPending, rebootPending, manualStepsPending, offlineScanPending, critical. Possible values are: clean, fullScanPending, rebootPending, manualStepsPending, offlineScanPending, critical.
     */
    deviceState?: WindowsDeviceHealthState[];
    /**
     * Current endpoint protection engine's version
     */
    engineVersion?: string;
    /**
     * When TRUE indicates full scan is overdue, when FALSE indicates full scan is not overdue. Defaults to setting on client device.
     */
    fullScanOverdue?: boolean;
    /**
     * When TRUE indicates full scan is required, when FALSE indicates full scan is not required. Defaults to setting on client device.
     */
    fullScanRequired?: boolean;
    /**
     * When TRUE indicates the device is a virtual machine, when FALSE indicates the device is not a virtual machine. Defaults to setting on client device.
     */
    isVirtualMachine?: boolean;
    /**
     * Last quick scan datetime
     */
    lastFullScanDateTime?: Date;
    /**
     * Last full scan signature version
     */
    lastFullScanSignatureVersion?: string;
    /**
     * Last quick scan datetime
     */
    lastQuickScanDateTime?: Date;
    /**
     * Last quick scan signature version
     */
    lastQuickScanSignatureVersion?: string;
    /**
     * Last device health status reported time
     */
    lastReportedDateTime?: Date;
    /**
     * When TRUE indicates anti malware is enabled when FALSE indicates anti malware is not enabled.
     */
    malwareProtectionEnabled?: boolean;
    /**
     * When TRUE indicates network inspection system enabled, when FALSE indicates network inspection system is not enabled. Defaults to setting on client device.
     */
    networkInspectionSystemEnabled?: boolean;
    /**
     * Product Status of Windows Defender Antivirus. Possible values are: noStatus, serviceNotRunning, serviceStartedWithoutMalwareProtection, pendingFullScanDueToThreatAction, pendingRebootDueToThreatAction, pendingManualStepsDueToThreatAction, avSignaturesOutOfDate, asSignaturesOutOfDate, noQuickScanHappenedForSpecifiedPeriod, noFullScanHappenedForSpecifiedPeriod, systemInitiatedScanInProgress, systemInitiatedCleanInProgress, samplesPendingSubmission, productRunningInEvaluationMode, productRunningInNonGenuineMode, productExpired, offlineScanRequired, serviceShutdownAsPartOfSystemShutdown, threatRemediationFailedCritically, threatRemediationFailedNonCritically, noStatusFlagsSet, platformOutOfDate, platformUpdateInProgress, platformAboutToBeOutdated, signatureOrPlatformEndOfLifeIsPastOrIsImpending, windowsSModeSignaturesInUseOnNonWin10SInstall. Possible values are: noStatus, serviceNotRunning, serviceStartedWithoutMalwareProtection, pendingFullScanDueToThreatAction, pendingRebootDueToThreatAction, pendingManualStepsDueToThreatAction, avSignaturesOutOfDate, asSignaturesOutOfDate, noQuickScanHappenedForSpecifiedPeriod, noFullScanHappenedForSpecifiedPeriod, systemInitiatedScanInProgress, systemInitiatedCleanInProgress, samplesPendingSubmission, productRunningInEvaluationMode, productRunningInNonGenuineMode, productExpired, offlineScanRequired, serviceShutdownAsPartOfSystemShutdown, threatRemediationFailedCritically, threatRemediationFailedNonCritically, noStatusFlagsSet, platformOutOfDate, platformUpdateInProgress, platformAboutToBeOutdated, signatureOrPlatformEndOfLifeIsPastOrIsImpending, windowsSModeSignaturesInUseOnNonWin10SInstall.
     */
    productStatus?: WindowsDefenderProductStatus[];
    /**
     * When TRUE indicates quick scan is overdue, when FALSE indicates quick scan is not overdue. Defaults to setting on client device.
     */
    quickScanOverdue?: boolean;
    /**
     * When TRUE indicates real time protection is enabled, when FALSE indicates real time protection is not enabled. Defaults to setting on client device.
     */
    realTimeProtectionEnabled?: boolean;
    /**
     * When TRUE indicates reboot is required, when FALSE indicates when TRUE indicates reboot is not required. Defaults to setting on client device.
     */
    rebootRequired?: boolean;
    /**
     * When TRUE indicates signature is out of date, when FALSE indicates signature is not out of date. Defaults to setting on client device.
     */
    signatureUpdateOverdue?: boolean;
    /**
     * Current malware definitions version
     */
    signatureVersion?: string;
    /**
     * When TRUE indicates the Windows Defender tamper protection feature is enabled, when FALSE indicates the Windows Defender tamper protection feature is not enabled. Defaults to setting on client device.
     */
    tamperProtectionEnabled?: boolean;
}
