import { type Entity } from './entity';
import { type Json } from './json';
import { type WorkbookRangeFormat } from './workbookRangeFormat';
import { type WorkbookRangeSort } from './workbookRangeSort';
import { type WorkbookWorksheet } from './workbookWorksheet';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createWorkbookRangeFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoWorkbookRange;
export declare function deserializeIntoWorkbookRange(workbookRange?: WorkbookRange | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeWorkbookRange(writer: SerializationWriter, workbookRange?: WorkbookRange | undefined): void;
export interface WorkbookRange extends Entity, Parsable {
    /**
     * Represents the range reference in A1-style. Address value contains the Sheet reference (for example, Sheet1!A1:B4). Read-only.
     */
    address?: string;
    /**
     * Represents range reference for the specified range in the language of the user. Read-only.
     */
    addressLocal?: string;
    /**
     * Number of cells in the range. Read-only.
     */
    cellCount?: number;
    /**
     * Represents the total number of columns in the range. Read-only.
     */
    columnCount?: number;
    /**
     * Represents if all columns of the current range are hidden.
     */
    columnHidden?: boolean;
    /**
     * Represents the column number of the first cell in the range. Zero-indexed. Read-only.
     */
    columnIndex?: number;
    /**
     * Returns a format object, encapsulating the range's font, fill, borders, alignment, and other properties. Read-only.
     */
    format?: WorkbookRangeFormat;
    /**
     * Represents the formula in A1-style notation.
     */
    formulas?: Json;
    /**
     * Represents the formula in A1-style notation, in the user's language and number-formatting locale.  For example, the English '=SUM(A1, 1.5)' formula would become '=SUMME(A1; 1,5)' in German.
     */
    formulasLocal?: Json;
    /**
     * Represents the formula in R1C1-style notation.
     */
    formulasR1C1?: Json;
    /**
     * Represents if all cells of the current range are hidden. Read-only.
     */
    hidden?: boolean;
    /**
     * Represents Excel's number format code for the given cell.
     */
    numberFormat?: Json;
    /**
     * Returns the total number of rows in the range. Read-only.
     */
    rowCount?: number;
    /**
     * Represents if all rows of the current range are hidden.
     */
    rowHidden?: boolean;
    /**
     * Returns the row number of the first cell in the range. Zero-indexed. Read-only.
     */
    rowIndex?: number;
    /**
     * The worksheet containing the current range. Read-only.
     */
    sort?: WorkbookRangeSort;
    /**
     * Text values of the specified range. The Text value doesn't depend on the cell width. The # sign substitution that happens in Excel UI doesn't affect the text value returned by the API. Read-only.
     */
    text?: Json;
    /**
     * Represents the raw values of the specified range. The data returned could be of type string, number, or a boolean. Cell that contains an error returns the error string.
     */
    values?: Json;
    /**
     * Represents the type of data of each cell. The possible values are: Unknown, Empty, String, Integer, Double, Boolean, Error. Read-only.
     */
    valueTypes?: Json;
    /**
     * The worksheet containing the current range. Read-only.
     */
    worksheet?: WorkbookWorksheet;
}
