import { type Entity } from './entity';
import { type WorkbookTableColumn } from './workbookTableColumn';
import { type WorkbookTableRow } from './workbookTableRow';
import { type WorkbookTableSort } from './workbookTableSort';
import { type WorkbookWorksheet } from './workbookWorksheet';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createWorkbookTableFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoWorkbookTable;
export declare function deserializeIntoWorkbookTable(workbookTable?: WorkbookTable | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeWorkbookTable(writer: SerializationWriter, workbookTable?: WorkbookTable | undefined): void;
export interface WorkbookTable extends Entity, Parsable {
    /**
     * Represents a collection of all the columns in the table. Read-only.
     */
    columns?: WorkbookTableColumn[];
    /**
     * Indicates whether the first column contains special formatting.
     */
    highlightFirstColumn?: boolean;
    /**
     * Indicates whether the last column contains special formatting.
     */
    highlightLastColumn?: boolean;
    /**
     * Legacy ID used in older Excel clients. The value of the identifier remains the same even when the table is renamed. This property should be interpreted as an opaque string value and shouldn't be parsed to any other type. Read-only.
     */
    legacyId?: string;
    /**
     * Name of the table.
     */
    name?: string;
    /**
     * Represents a collection of all the rows in the table. Read-only.
     */
    rows?: WorkbookTableRow[];
    /**
     * Indicates whether the columns show banded formatting in which odd columns are highlighted differently from even ones to make reading the table easier.
     */
    showBandedColumns?: boolean;
    /**
     * Indicates whether the rows show banded formatting in which odd rows are highlighted differently from even ones to make reading the table easier.
     */
    showBandedRows?: boolean;
    /**
     * Indicates whether the filter buttons are visible at the top of each column header. Setting this is only allowed if the table contains a header row.
     */
    showFilterButton?: boolean;
    /**
     * Indicates whether the header row is visible or not. This value can be set to show or remove the header row.
     */
    showHeaders?: boolean;
    /**
     * Indicates whether the total row is visible or not. This value can be set to show or remove the total row.
     */
    showTotals?: boolean;
    /**
     * Represents the sorting for the table. Read-only.
     */
    sort?: WorkbookTableSort;
    /**
     * Constant value that represents the Table style. The possible values are: TableStyleLight1 through TableStyleLight21, TableStyleMedium1 through TableStyleMedium28, TableStyleStyleDark1 through TableStyleStyleDark11. A custom user-defined style present in the workbook can also be specified.
     */
    style?: string;
    /**
     * The worksheet containing the current table. Read-only.
     */
    worksheet?: WorkbookWorksheet;
}
