import { type OrganizationalBrandingLocalization } from '../../../../../models/organizationalBrandingLocalization';
import { BackgroundImageRequestBuilder } from './backgroundImage/';
import { BannerLogoRequestBuilder } from './bannerLogo/';
import { CustomCSSRequestBuilder } from './customCSS/';
import { FaviconRequestBuilder } from './favicon/';
import { HeaderLogoRequestBuilder } from './headerLogo/';
import { SquareLogoRequestBuilder } from './squareLogo/';
import { SquareLogoDarkRequestBuilder } from './squareLogoDark/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface OrganizationalBrandingLocalizationItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the localizations property of the microsoft.graph.organizationalBranding entity.
 */
export declare class OrganizationalBrandingLocalizationItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the media for the organization entity.
     */
    get backgroundImage(): BackgroundImageRequestBuilder;
    /**
     * Provides operations to manage the media for the organization entity.
     */
    get bannerLogo(): BannerLogoRequestBuilder;
    /**
     * Provides operations to manage the media for the organization entity.
     */
    get customCSS(): CustomCSSRequestBuilder;
    /**
     * Provides operations to manage the media for the organization entity.
     */
    get favicon(): FaviconRequestBuilder;
    /**
     * Provides operations to manage the media for the organization entity.
     */
    get headerLogo(): HeaderLogoRequestBuilder;
    /**
     * Provides operations to manage the media for the organization entity.
     */
    get squareLogo(): SquareLogoRequestBuilder;
    /**
     * Provides operations to manage the media for the organization entity.
     */
    get squareLogoDark(): SquareLogoDarkRequestBuilder;
    /**
     * Instantiates a new OrganizationalBrandingLocalizationItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete a localized branding object. To delete the organizationalBrandingLocalization object, all images (Stream types) must first be removed from the object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/organizationalbrandinglocalization-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of an organizationalBrandingLocalization object. To retrieve a localization branding object, specify the value of id in the URL.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OrganizationalBrandingLocalization
     * @see {@link https://learn.microsoft.com/graph/api/organizationalbrandinglocalization-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<OrganizationalBrandingLocalizationItemRequestBuilderGetQueryParameters> | undefined): Promise<OrganizationalBrandingLocalization | undefined>;
    /**
     * Update the properties of an organizationalBrandingLocalization object for a specific localization.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OrganizationalBrandingLocalization
     * @see {@link https://learn.microsoft.com/graph/api/organizationalbrandinglocalization-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: OrganizationalBrandingLocalization, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<OrganizationalBrandingLocalization | undefined>;
    /**
     * Delete a localized branding object. To delete the organizationalBrandingLocalization object, all images (Stream types) must first be removed from the object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of an organizationalBrandingLocalization object. To retrieve a localization branding object, specify the value of id in the URL.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<OrganizationalBrandingLocalizationItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of an organizationalBrandingLocalization object for a specific localization.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: OrganizationalBrandingLocalization, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a OrganizationalBrandingLocalizationItemRequestBuilder
     */
    withUrl(rawUrl: string): OrganizationalBrandingLocalizationItemRequestBuilder;
}
