import { type RoomCollectionResponse } from '../../../../models/';
import { type Room } from '../../../../models/room';
import { CountRequestBuilder } from './count/';
import { RoomItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface RoomsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the rooms property of the microsoft.graph.roomList entity.
 */
export declare class RoomsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the rooms property of the microsoft.graph.roomList entity.
     * @param roomId The unique identifier of room
     * @returns a RoomItemRequestBuilder
     */
    byRoomId(roomId: string): RoomItemRequestBuilder;
    /**
     * Instantiates a new RoomsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get rooms from places
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RoomCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<RoomsRequestBuilderGetQueryParameters> | undefined): Promise<RoomCollectionResponse | undefined>;
    /**
     * Create new navigation property to rooms for places
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Room
     */
    post(body: Room, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Room | undefined>;
    /**
     * Get rooms from places
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<RoomsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to rooms for places
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: Room, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a roomsRequestBuilder
     */
    withUrl(rawUrl: string): RoomsRequestBuilder;
}
