import { type PlannerTaskCollectionResponse } from '../../../../models/';
import { type PlannerTask } from '../../../../models/plannerTask';
import { CountRequestBuilder } from './count/';
import { PlannerTaskItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface TasksRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the tasks property of the microsoft.graph.plannerBucket entity.
 */
export declare class TasksRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the tasks property of the microsoft.graph.plannerBucket entity.
     * @param plannerTaskId The unique identifier of plannerTask
     * @returns a PlannerTaskItemRequestBuilder
     */
    byPlannerTaskId(plannerTaskId: string): PlannerTaskItemRequestBuilder;
    /**
     * Instantiates a new TasksRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of plannerTask objects associated to a plannerBucket object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PlannerTaskCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/plannerbucket-list-tasks?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<TasksRequestBuilderGetQueryParameters> | undefined): Promise<PlannerTaskCollectionResponse | undefined>;
    /**
     * Create new navigation property to tasks for planner
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PlannerTask
     */
    post(body: PlannerTask, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<PlannerTask | undefined>;
    /**
     * Retrieve a list of plannerTask objects associated to a plannerBucket object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<TasksRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to tasks for planner
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: PlannerTask, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a tasksRequestBuilder
     */
    withUrl(rawUrl: string): TasksRequestBuilder;
}
