import { type PlannerTask } from '../../../models/plannerTask';
import { AssignedToTaskBoardFormatRequestBuilder } from './assignedToTaskBoardFormat/';
import { BucketTaskBoardFormatRequestBuilder } from './bucketTaskBoardFormat/';
import { DetailsRequestBuilder } from './details/';
import { ProgressTaskBoardFormatRequestBuilder } from './progressTaskBoardFormat/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface PlannerTaskItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the tasks property of the microsoft.graph.planner entity.
 */
export declare class PlannerTaskItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the assignedToTaskBoardFormat property of the microsoft.graph.plannerTask entity.
     */
    get assignedToTaskBoardFormat(): AssignedToTaskBoardFormatRequestBuilder;
    /**
     * Provides operations to manage the bucketTaskBoardFormat property of the microsoft.graph.plannerTask entity.
     */
    get bucketTaskBoardFormat(): BucketTaskBoardFormatRequestBuilder;
    /**
     * Provides operations to manage the details property of the microsoft.graph.plannerTask entity.
     */
    get details(): DetailsRequestBuilder;
    /**
     * Provides operations to manage the progressTaskBoardFormat property of the microsoft.graph.plannerTask entity.
     */
    get progressTaskBoardFormat(): ProgressTaskBoardFormatRequestBuilder;
    /**
     * Instantiates a new PlannerTaskItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete a plannerTask object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/plannertask-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of plannerTask object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PlannerTask
     * @see {@link https://learn.microsoft.com/graph/api/plannertask-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<PlannerTaskItemRequestBuilderGetQueryParameters> | undefined): Promise<PlannerTask | undefined>;
    /**
     * Update the navigation property tasks in planner
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PlannerTask
     * @see {@link https://learn.microsoft.com/graph/api/plannertask-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: PlannerTask, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<PlannerTask | undefined>;
    /**
     * Delete a plannerTask object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of plannerTask object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<PlannerTaskItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property tasks in planner
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: PlannerTask, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a PlannerTaskItemRequestBuilder
     */
    withUrl(rawUrl: string): PlannerTaskItemRequestBuilder;
}
