import { type ActivityBasedTimeoutPolicyCollectionResponse } from '../../models/';
import { type ActivityBasedTimeoutPolicy } from '../../models/activityBasedTimeoutPolicy';
import { CountRequestBuilder } from './count/';
import { ActivityBasedTimeoutPolicyItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ActivityBasedTimeoutPoliciesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the activityBasedTimeoutPolicies property of the microsoft.graph.policyRoot entity.
 */
export declare class ActivityBasedTimeoutPoliciesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the activityBasedTimeoutPolicies property of the microsoft.graph.policyRoot entity.
     * @param activityBasedTimeoutPolicyId The unique identifier of activityBasedTimeoutPolicy
     * @returns a ActivityBasedTimeoutPolicyItemRequestBuilder
     */
    byActivityBasedTimeoutPolicyId(activityBasedTimeoutPolicyId: string): ActivityBasedTimeoutPolicyItemRequestBuilder;
    /**
     * Instantiates a new ActivityBasedTimeoutPoliciesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of activityBasedTimeoutPolicy objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ActivityBasedTimeoutPolicyCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/activitybasedtimeoutpolicy-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ActivityBasedTimeoutPoliciesRequestBuilderGetQueryParameters> | undefined): Promise<ActivityBasedTimeoutPolicyCollectionResponse | undefined>;
    /**
     * Create a new activityBasedTimeoutPolicy object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ActivityBasedTimeoutPolicy
     * @see {@link https://learn.microsoft.com/graph/api/activitybasedtimeoutpolicy-post-activitybasedtimeoutpolicies?view=graph-rest-1.0|Find more info here}
     */
    post(body: ActivityBasedTimeoutPolicy, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ActivityBasedTimeoutPolicy | undefined>;
    /**
     * Get a list of activityBasedTimeoutPolicy objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ActivityBasedTimeoutPoliciesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new activityBasedTimeoutPolicy object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ActivityBasedTimeoutPolicy, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a activityBasedTimeoutPoliciesRequestBuilder
     */
    withUrl(rawUrl: string): ActivityBasedTimeoutPoliciesRequestBuilder;
}
