import { type AppManagementPolicyCollectionResponse } from '../../models/';
import { type AppManagementPolicy } from '../../models/appManagementPolicy';
import { CountRequestBuilder } from './count/';
import { AppManagementPolicyItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AppManagementPoliciesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the appManagementPolicies property of the microsoft.graph.policyRoot entity.
 */
export declare class AppManagementPoliciesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the appManagementPolicies property of the microsoft.graph.policyRoot entity.
     * @param appManagementPolicyId The unique identifier of appManagementPolicy
     * @returns a AppManagementPolicyItemRequestBuilder
     */
    byAppManagementPolicyId(appManagementPolicyId: string): AppManagementPolicyItemRequestBuilder;
    /**
     * Instantiates a new AppManagementPoliciesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of appManagementPolicy objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AppManagementPolicyCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/appmanagementpolicy-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<AppManagementPoliciesRequestBuilderGetQueryParameters> | undefined): Promise<AppManagementPolicyCollectionResponse | undefined>;
    /**
     * Create an appManagementPolicy object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AppManagementPolicy
     * @see {@link https://learn.microsoft.com/graph/api/appmanagementpolicy-post?view=graph-rest-1.0|Find more info here}
     */
    post(body: AppManagementPolicy, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AppManagementPolicy | undefined>;
    /**
     * Retrieve a list of appManagementPolicy objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AppManagementPoliciesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create an appManagementPolicy object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AppManagementPolicy, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a appManagementPoliciesRequestBuilder
     */
    withUrl(rawUrl: string): AppManagementPoliciesRequestBuilder;
}
