import { type AuthenticationMethodConfigurationCollectionResponse } from '../../../models/';
import { type AuthenticationMethodConfiguration } from '../../../models/authenticationMethodConfiguration';
import { CountRequestBuilder } from './count/';
import { AuthenticationMethodConfigurationItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AuthenticationMethodConfigurationsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the authenticationMethodConfigurations property of the microsoft.graph.authenticationMethodsPolicy entity.
 */
export declare class AuthenticationMethodConfigurationsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the authenticationMethodConfigurations property of the microsoft.graph.authenticationMethodsPolicy entity.
     * @param authenticationMethodConfigurationId The unique identifier of authenticationMethodConfiguration
     * @returns a AuthenticationMethodConfigurationItemRequestBuilder
     */
    byAuthenticationMethodConfigurationId(authenticationMethodConfigurationId: string): AuthenticationMethodConfigurationItemRequestBuilder;
    /**
     * Instantiates a new AuthenticationMethodConfigurationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Represents the settings for each authentication method. Automatically expanded on GET /policies/authenticationMethodsPolicy.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AuthenticationMethodConfigurationCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<AuthenticationMethodConfigurationsRequestBuilderGetQueryParameters> | undefined): Promise<AuthenticationMethodConfigurationCollectionResponse | undefined>;
    /**
     * Create new navigation property to authenticationMethodConfigurations for policies
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AuthenticationMethodConfiguration
     */
    post(body: AuthenticationMethodConfiguration, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AuthenticationMethodConfiguration | undefined>;
    /**
     * Represents the settings for each authentication method. Automatically expanded on GET /policies/authenticationMethodsPolicy.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AuthenticationMethodConfigurationsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to authenticationMethodConfigurations for policies
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AuthenticationMethodConfiguration, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a authenticationMethodConfigurationsRequestBuilder
     */
    withUrl(rawUrl: string): AuthenticationMethodConfigurationsRequestBuilder;
}
