import { type ConditionalAccessPolicyCollectionResponse } from '../../models/';
import { type ConditionalAccessPolicy } from '../../models/conditionalAccessPolicy';
import { CountRequestBuilder } from './count/';
import { ConditionalAccessPolicyItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ConditionalAccessPoliciesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the conditionalAccessPolicies property of the microsoft.graph.policyRoot entity.
 */
export declare class ConditionalAccessPoliciesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the conditionalAccessPolicies property of the microsoft.graph.policyRoot entity.
     * @param conditionalAccessPolicyId The unique identifier of conditionalAccessPolicy
     * @returns a ConditionalAccessPolicyItemRequestBuilder
     */
    byConditionalAccessPolicyId(conditionalAccessPolicyId: string): ConditionalAccessPolicyItemRequestBuilder;
    /**
     * Instantiates a new ConditionalAccessPoliciesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The custom rules that define an access scenario.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ConditionalAccessPolicyCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<ConditionalAccessPoliciesRequestBuilderGetQueryParameters> | undefined): Promise<ConditionalAccessPolicyCollectionResponse | undefined>;
    /**
     * Create new navigation property to conditionalAccessPolicies for policies
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ConditionalAccessPolicy
     */
    post(body: ConditionalAccessPolicy, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ConditionalAccessPolicy | undefined>;
    /**
     * The custom rules that define an access scenario.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ConditionalAccessPoliciesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to conditionalAccessPolicies for policies
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ConditionalAccessPolicy, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a conditionalAccessPoliciesRequestBuilder
     */
    withUrl(rawUrl: string): ConditionalAccessPoliciesRequestBuilder;
}
