import { type PolicyRoot } from '../models/policyRoot';
import { ActivityBasedTimeoutPoliciesRequestBuilder } from './activityBasedTimeoutPolicies/';
import { AdminConsentRequestPolicyRequestBuilder } from './adminConsentRequestPolicy/';
import { AppManagementPoliciesRequestBuilder } from './appManagementPolicies/';
import { AuthenticationFlowsPolicyRequestBuilder } from './authenticationFlowsPolicy/';
import { AuthenticationMethodsPolicyRequestBuilder } from './authenticationMethodsPolicy/';
import { AuthenticationStrengthPoliciesRequestBuilder } from './authenticationStrengthPolicies/';
import { AuthorizationPolicyRequestBuilder } from './authorizationPolicy/';
import { ClaimsMappingPoliciesRequestBuilder } from './claimsMappingPolicies/';
import { ConditionalAccessPoliciesRequestBuilder } from './conditionalAccessPolicies/';
import { CrossTenantAccessPolicyRequestBuilder } from './crossTenantAccessPolicy/';
import { DefaultAppManagementPolicyRequestBuilder } from './defaultAppManagementPolicy/';
import { FeatureRolloutPoliciesRequestBuilder } from './featureRolloutPolicies/';
import { HomeRealmDiscoveryPoliciesRequestBuilder } from './homeRealmDiscoveryPolicies/';
import { IdentitySecurityDefaultsEnforcementPolicyRequestBuilder } from './identitySecurityDefaultsEnforcementPolicy/';
import { PermissionGrantPoliciesRequestBuilder } from './permissionGrantPolicies/';
import { RoleManagementPoliciesRequestBuilder } from './roleManagementPolicies/';
import { RoleManagementPolicyAssignmentsRequestBuilder } from './roleManagementPolicyAssignments/';
import { TokenIssuancePoliciesRequestBuilder } from './tokenIssuancePolicies/';
import { TokenLifetimePoliciesRequestBuilder } from './tokenLifetimePolicies/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface PoliciesRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the policyRoot singleton.
 */
export declare class PoliciesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the activityBasedTimeoutPolicies property of the microsoft.graph.policyRoot entity.
     */
    get activityBasedTimeoutPolicies(): ActivityBasedTimeoutPoliciesRequestBuilder;
    /**
     * Provides operations to manage the adminConsentRequestPolicy property of the microsoft.graph.policyRoot entity.
     */
    get adminConsentRequestPolicy(): AdminConsentRequestPolicyRequestBuilder;
    /**
     * Provides operations to manage the appManagementPolicies property of the microsoft.graph.policyRoot entity.
     */
    get appManagementPolicies(): AppManagementPoliciesRequestBuilder;
    /**
     * Provides operations to manage the authenticationFlowsPolicy property of the microsoft.graph.policyRoot entity.
     */
    get authenticationFlowsPolicy(): AuthenticationFlowsPolicyRequestBuilder;
    /**
     * Provides operations to manage the authenticationMethodsPolicy property of the microsoft.graph.policyRoot entity.
     */
    get authenticationMethodsPolicy(): AuthenticationMethodsPolicyRequestBuilder;
    /**
     * Provides operations to manage the authenticationStrengthPolicies property of the microsoft.graph.policyRoot entity.
     */
    get authenticationStrengthPolicies(): AuthenticationStrengthPoliciesRequestBuilder;
    /**
     * Provides operations to manage the authorizationPolicy property of the microsoft.graph.policyRoot entity.
     */
    get authorizationPolicy(): AuthorizationPolicyRequestBuilder;
    /**
     * Provides operations to manage the claimsMappingPolicies property of the microsoft.graph.policyRoot entity.
     */
    get claimsMappingPolicies(): ClaimsMappingPoliciesRequestBuilder;
    /**
     * Provides operations to manage the conditionalAccessPolicies property of the microsoft.graph.policyRoot entity.
     */
    get conditionalAccessPolicies(): ConditionalAccessPoliciesRequestBuilder;
    /**
     * Provides operations to manage the crossTenantAccessPolicy property of the microsoft.graph.policyRoot entity.
     */
    get crossTenantAccessPolicy(): CrossTenantAccessPolicyRequestBuilder;
    /**
     * Provides operations to manage the defaultAppManagementPolicy property of the microsoft.graph.policyRoot entity.
     */
    get defaultAppManagementPolicy(): DefaultAppManagementPolicyRequestBuilder;
    /**
     * Provides operations to manage the featureRolloutPolicies property of the microsoft.graph.policyRoot entity.
     */
    get featureRolloutPolicies(): FeatureRolloutPoliciesRequestBuilder;
    /**
     * Provides operations to manage the homeRealmDiscoveryPolicies property of the microsoft.graph.policyRoot entity.
     */
    get homeRealmDiscoveryPolicies(): HomeRealmDiscoveryPoliciesRequestBuilder;
    /**
     * Provides operations to manage the identitySecurityDefaultsEnforcementPolicy property of the microsoft.graph.policyRoot entity.
     */
    get identitySecurityDefaultsEnforcementPolicy(): IdentitySecurityDefaultsEnforcementPolicyRequestBuilder;
    /**
     * Provides operations to manage the permissionGrantPolicies property of the microsoft.graph.policyRoot entity.
     */
    get permissionGrantPolicies(): PermissionGrantPoliciesRequestBuilder;
    /**
     * Provides operations to manage the roleManagementPolicies property of the microsoft.graph.policyRoot entity.
     */
    get roleManagementPolicies(): RoleManagementPoliciesRequestBuilder;
    /**
     * Provides operations to manage the roleManagementPolicyAssignments property of the microsoft.graph.policyRoot entity.
     */
    get roleManagementPolicyAssignments(): RoleManagementPolicyAssignmentsRequestBuilder;
    /**
     * Provides operations to manage the tokenIssuancePolicies property of the microsoft.graph.policyRoot entity.
     */
    get tokenIssuancePolicies(): TokenIssuancePoliciesRequestBuilder;
    /**
     * Provides operations to manage the tokenLifetimePolicies property of the microsoft.graph.policyRoot entity.
     */
    get tokenLifetimePolicies(): TokenLifetimePoliciesRequestBuilder;
    /**
     * Instantiates a new PoliciesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get policies
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PolicyRoot
     */
    get(requestConfiguration?: RequestConfiguration<PoliciesRequestBuilderGetQueryParameters> | undefined): Promise<PolicyRoot | undefined>;
    /**
     * Update policies
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PolicyRoot
     */
    patch(body: PolicyRoot, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<PolicyRoot | undefined>;
    /**
     * Get policies
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<PoliciesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update policies
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: PolicyRoot, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a policiesRequestBuilder
     */
    withUrl(rawUrl: string): PoliciesRequestBuilder;
}
