import { type UnifiedRoleManagementPolicyAssignmentCollectionResponse } from '../../models/';
import { type UnifiedRoleManagementPolicyAssignment } from '../../models/unifiedRoleManagementPolicyAssignment';
import { CountRequestBuilder } from './count/';
import { UnifiedRoleManagementPolicyAssignmentItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface RoleManagementPolicyAssignmentsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the roleManagementPolicyAssignments property of the microsoft.graph.policyRoot entity.
 */
export declare class RoleManagementPolicyAssignmentsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the roleManagementPolicyAssignments property of the microsoft.graph.policyRoot entity.
     * @param unifiedRoleManagementPolicyAssignmentId The unique identifier of unifiedRoleManagementPolicyAssignment
     * @returns a UnifiedRoleManagementPolicyAssignmentItemRequestBuilder
     */
    byUnifiedRoleManagementPolicyAssignmentId(unifiedRoleManagementPolicyAssignmentId: string): UnifiedRoleManagementPolicyAssignmentItemRequestBuilder;
    /**
     * Instantiates a new RoleManagementPolicyAssignmentsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the details of all role management policy assignments made in PIM for Microsoft Entra roles and PIM for groups.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UnifiedRoleManagementPolicyAssignmentCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/policyroot-list-rolemanagementpolicyassignments?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<RoleManagementPolicyAssignmentsRequestBuilderGetQueryParameters> | undefined): Promise<UnifiedRoleManagementPolicyAssignmentCollectionResponse | undefined>;
    /**
     * Create new navigation property to roleManagementPolicyAssignments for policies
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UnifiedRoleManagementPolicyAssignment
     */
    post(body: UnifiedRoleManagementPolicyAssignment, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<UnifiedRoleManagementPolicyAssignment | undefined>;
    /**
     * Get the details of all role management policy assignments made in PIM for Microsoft Entra roles and PIM for groups.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<RoleManagementPolicyAssignmentsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to roleManagementPolicyAssignments for policies
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: UnifiedRoleManagementPolicyAssignment, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a roleManagementPolicyAssignmentsRequestBuilder
     */
    withUrl(rawUrl: string): RoleManagementPolicyAssignmentsRequestBuilder;
}
