import { type Print } from '../models/print';
import { ConnectorsRequestBuilder } from './connectors/';
import { OperationsRequestBuilder } from './operations/';
import { PrintersRequestBuilder } from './printers/';
import { ServicesRequestBuilder } from './services/';
import { SharesRequestBuilder } from './shares/';
import { TaskDefinitionsRequestBuilder } from './taskDefinitions/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface PrintRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the print singleton.
 */
export declare class PrintRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the connectors property of the microsoft.graph.print entity.
     */
    get connectors(): ConnectorsRequestBuilder;
    /**
     * Provides operations to manage the operations property of the microsoft.graph.print entity.
     */
    get operations(): OperationsRequestBuilder;
    /**
     * Provides operations to manage the printers property of the microsoft.graph.print entity.
     */
    get printers(): PrintersRequestBuilder;
    /**
     * Provides operations to manage the services property of the microsoft.graph.print entity.
     */
    get services(): ServicesRequestBuilder;
    /**
     * Provides operations to manage the shares property of the microsoft.graph.print entity.
     */
    get shares(): SharesRequestBuilder;
    /**
     * Provides operations to manage the taskDefinitions property of the microsoft.graph.print entity.
     */
    get taskDefinitions(): TaskDefinitionsRequestBuilder;
    /**
     * Instantiates a new PrintRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get print
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Print
     */
    get(requestConfiguration?: RequestConfiguration<PrintRequestBuilderGetQueryParameters> | undefined): Promise<Print | undefined>;
    /**
     * Update print
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Print
     */
    patch(body: Print, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Print | undefined>;
    /**
     * Get print
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<PrintRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update print
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Print, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a printRequestBuilder
     */
    withUrl(rawUrl: string): PrintRequestBuilder;
}
