import { type PrintCertificateSigningRequest } from '../../../models/printCertificateSigningRequest';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createCreatePostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoCreatePostRequestBody;
export interface CreatePostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The certificateSigningRequest property
     */
    certificateSigningRequest?: PrintCertificateSigningRequest;
    /**
     * The connectorId property
     */
    connectorId?: string;
    /**
     * The displayName property
     */
    displayName?: string;
    /**
     * The hasPhysicalDevice property
     */
    hasPhysicalDevice?: boolean;
    /**
     * The manufacturer property
     */
    manufacturer?: string;
    /**
     * The model property
     */
    model?: string;
    /**
     * The physicalDeviceId property
     */
    physicalDeviceId?: string;
}
export declare function deserializeIntoCreatePostRequestBody(createPostRequestBody?: CreatePostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeCreatePostRequestBody(writer: SerializationWriter, createPostRequestBody?: CreatePostRequestBody | undefined): void;
/**
 * Provides operations to call the create method.
 */
export declare class CreateRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new CreateRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Create (register) a printer with the Universal Print service. This is a long-running operation and as such, it returns a printerCreateOperation that can be used to track and verify the registration of the printer. For help creating the required Certificate Signing Request (CSR) for creating printer, see the CSR generation code sample.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/printer-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: CreatePostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Create (register) a printer with the Universal Print service. This is a long-running operation and as such, it returns a printerCreateOperation that can be used to track and verify the registration of the printer. For help creating the required Certificate Signing Request (CSR) for creating printer, see the CSR generation code sample.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: CreatePostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a createRequestBuilder
     */
    withUrl(rawUrl: string): CreateRequestBuilder;
}
