import { type PrinterCollectionResponse } from '../../models/';
import { type Printer } from '../../models/printer';
import { CountRequestBuilder } from './count/';
import { CreateRequestBuilder } from './create/';
import { PrinterItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface PrintersRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the printers property of the microsoft.graph.print entity.
 */
export declare class PrintersRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to call the create method.
     */
    get create(): CreateRequestBuilder;
    /**
     * Provides operations to manage the printers property of the microsoft.graph.print entity.
     * @param printerId The unique identifier of printer
     * @returns a PrinterItemRequestBuilder
     */
    byPrinterId(printerId: string): PrinterItemRequestBuilder;
    /**
     * Instantiates a new PrintersRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the list of printers that are registered in the tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrinterCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/print-list-printers?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<PrintersRequestBuilderGetQueryParameters> | undefined): Promise<PrinterCollectionResponse | undefined>;
    /**
     * Create new navigation property to printers for print
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Printer
     */
    post(body: Printer, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Printer | undefined>;
    /**
     * Retrieve the list of printers that are registered in the tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<PrintersRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to printers for print
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: Printer, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a printersRequestBuilder
     */
    withUrl(rawUrl: string): PrintersRequestBuilder;
}
