import { type Printer } from '../../../models/printer';
import { ConnectorsRequestBuilder } from './connectors/';
import { JobsRequestBuilder } from './jobs/';
import { RestoreFactoryDefaultsRequestBuilder } from './restoreFactoryDefaults/';
import { SharesRequestBuilder } from './shares/';
import { TaskTriggersRequestBuilder } from './taskTriggers/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface PrinterItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the printers property of the microsoft.graph.print entity.
 */
export declare class PrinterItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the connectors property of the microsoft.graph.printer entity.
     */
    get connectors(): ConnectorsRequestBuilder;
    /**
     * Provides operations to manage the jobs property of the microsoft.graph.printerBase entity.
     */
    get jobs(): JobsRequestBuilder;
    /**
     * Provides operations to call the restoreFactoryDefaults method.
     */
    get restoreFactoryDefaults(): RestoreFactoryDefaultsRequestBuilder;
    /**
     * Provides operations to manage the shares property of the microsoft.graph.printer entity.
     */
    get shares(): SharesRequestBuilder;
    /**
     * Provides operations to manage the taskTriggers property of the microsoft.graph.printer entity.
     */
    get taskTriggers(): TaskTriggersRequestBuilder;
    /**
     * Instantiates a new PrinterItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete (unregister) a printer.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/printer-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of a printer object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Printer
     * @see {@link https://learn.microsoft.com/graph/api/printer-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<PrinterItemRequestBuilderGetQueryParameters> | undefined): Promise<Printer | undefined>;
    /**
     * Update the properties of a printer object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Printer
     * @see {@link https://learn.microsoft.com/graph/api/printer-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: Printer, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Printer | undefined>;
    /**
     * Delete (unregister) a printer.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of a printer object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<PrinterItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of a printer object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Printer, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a PrinterItemRequestBuilder
     */
    withUrl(rawUrl: string): PrinterItemRequestBuilder;
}
