"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RedirectRequestBuilder = exports.serializeRedirectPostRequestBody = exports.deserializeIntoRedirectPostRequestBody = exports.createRedirectPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../../../models/oDataErrors/oDataError");
const printJob_1 = require("../../../../../../models/printJob");
const printJobConfiguration_1 = require("../../../../../../models/printJobConfiguration");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createRedirectPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoRedirectPostRequestBody;
}
exports.createRedirectPostRequestBodyFromDiscriminatorValue = createRedirectPostRequestBodyFromDiscriminatorValue;
function deserializeIntoRedirectPostRequestBody(redirectPostRequestBody = {}) {
    return {
        "configuration": n => { redirectPostRequestBody.configuration = n.getObjectValue(printJobConfiguration_1.createPrintJobConfigurationFromDiscriminatorValue); },
        "destinationPrinterId": n => { redirectPostRequestBody.destinationPrinterId = n.getStringValue(); },
    };
}
exports.deserializeIntoRedirectPostRequestBody = deserializeIntoRedirectPostRequestBody;
function serializeRedirectPostRequestBody(writer, redirectPostRequestBody = {}) {
    writer.writeObjectValue("configuration", redirectPostRequestBody.configuration, printJobConfiguration_1.serializePrintJobConfiguration);
    writer.writeStringValue("destinationPrinterId", redirectPostRequestBody.destinationPrinterId);
    writer.writeAdditionalData(redirectPostRequestBody.additionalData);
}
exports.serializeRedirectPostRequestBody = serializeRedirectPostRequestBody;
/**
 * Provides operations to call the redirect method.
 */
class RedirectRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new RedirectRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/print/printers/{printer%2Did}/jobs/{printJob%2Did}/redirect");
    }
    ;
    /**
     * Redirect a print job to a different printer. Redirecting a print job will only succeed if there is a printTask in a processing state on the associated print job, started by a trigger that the requesting app created.  For details about how to use this API to add pull printing support to Universal Print, see Extending Universal Print to support pull printing.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrintJob
     * @see {@link https://learn.microsoft.com/graph/api/printjob-redirect?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, printJob_1.createPrintJobFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Redirect a print job to a different printer. Redirecting a print job will only succeed if there is a printTask in a processing state on the associated print job, started by a trigger that the requesting app created.  For details about how to use this API to add pull printing support to Universal Print, see Extending Universal Print to support pull printing.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeRedirectPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a redirectRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new RedirectRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.RedirectRequestBuilder = RedirectRequestBuilder;
// tslint:enable
// eslint-enable
