import { type PrinterShareCollectionResponse } from '../../models/';
import { type PrinterShare } from '../../models/printerShare';
import { CountRequestBuilder } from './count/';
import { PrinterShareItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SharesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the shares property of the microsoft.graph.print entity.
 */
export declare class SharesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the shares property of the microsoft.graph.print entity.
     * @param printerShareId The unique identifier of printerShare
     * @returns a PrinterShareItemRequestBuilder
     */
    byPrinterShareId(printerShareId: string): PrinterShareItemRequestBuilder;
    /**
     * Instantiates a new SharesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of printerShares.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrinterShareCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/print-list-shares?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SharesRequestBuilderGetQueryParameters> | undefined): Promise<PrinterShareCollectionResponse | undefined>;
    /**
     * Create a new printerShare for the specified printer.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrinterShare
     * @see {@link https://learn.microsoft.com/graph/api/print-post-shares?view=graph-rest-1.0|Find more info here}
     */
    post(body: PrinterShare, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<PrinterShare | undefined>;
    /**
     * Retrieve a list of printerShares.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SharesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new printerShare for the specified printer.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: PrinterShare, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a sharesRequestBuilder
     */
    withUrl(rawUrl: string): SharesRequestBuilder;
}
