"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbortRequestBuilder = exports.serializeAbortPostRequestBody = exports.deserializeIntoAbortPostRequestBody = exports.createAbortPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createAbortPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoAbortPostRequestBody;
}
exports.createAbortPostRequestBodyFromDiscriminatorValue = createAbortPostRequestBodyFromDiscriminatorValue;
function deserializeIntoAbortPostRequestBody(abortPostRequestBody = {}) {
    return {
        "reason": n => { abortPostRequestBody.reason = n.getStringValue(); },
    };
}
exports.deserializeIntoAbortPostRequestBody = deserializeIntoAbortPostRequestBody;
function serializeAbortPostRequestBody(writer, abortPostRequestBody = {}) {
    writer.writeStringValue("reason", abortPostRequestBody.reason);
    writer.writeAdditionalData(abortPostRequestBody.additionalData);
}
exports.serializeAbortPostRequestBody = serializeAbortPostRequestBody;
/**
 * Provides operations to call the abort method.
 */
class AbortRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new AbortRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/print/shares/{printerShare%2Did}/jobs/{printJob%2Did}/abort");
    }
    ;
    /**
     * Abort a print job. Only applications using application permissions can abort a print job. Aborting a print job will only succeed if there is a printTask in a processing state on the associated print job, started by a trigger that the requesting app created. For details about how to register a task trigger, see Extending Universal Print to support pull printing.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/printjob-abort?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Abort a print job. Only applications using application permissions can abort a print job. Aborting a print job will only succeed if there is a printTask in a processing state on the associated print job, started by a trigger that the requesting app created. For details about how to register a task trigger, see Extending Universal Print to support pull printing.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeAbortPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a abortRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new AbortRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.AbortRequestBuilder = AbortRequestBuilder;
// tslint:enable
// eslint-enable
