import { type PrintJob } from '../../../../../models/printJob';
import { AbortRequestBuilder } from './abort/';
import { CancelRequestBuilder } from './cancel/';
import { DocumentsRequestBuilder } from './documents/';
import { RedirectRequestBuilder } from './redirect/';
import { StartRequestBuilder } from './start/';
import { TasksRequestBuilder } from './tasks/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface PrintJobItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the jobs property of the microsoft.graph.printerBase entity.
 */
export declare class PrintJobItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the abort method.
     */
    get abort(): AbortRequestBuilder;
    /**
     * Provides operations to call the cancel method.
     */
    get cancel(): CancelRequestBuilder;
    /**
     * Provides operations to manage the documents property of the microsoft.graph.printJob entity.
     */
    get documents(): DocumentsRequestBuilder;
    /**
     * Provides operations to call the redirect method.
     */
    get redirect(): RedirectRequestBuilder;
    /**
     * Provides operations to call the start method.
     */
    get start(): StartRequestBuilder;
    /**
     * Provides operations to manage the tasks property of the microsoft.graph.printJob entity.
     */
    get tasks(): TasksRequestBuilder;
    /**
     * Instantiates a new PrintJobItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property jobs for print
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * The list of jobs that are queued for printing by the printer/printerShare.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrintJob
     */
    get(requestConfiguration?: RequestConfiguration<PrintJobItemRequestBuilderGetQueryParameters> | undefined): Promise<PrintJob | undefined>;
    /**
     * Update the navigation property jobs in print
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrintJob
     */
    patch(body: PrintJob, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<PrintJob | undefined>;
    /**
     * Delete navigation property jobs for print
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * The list of jobs that are queued for printing by the printer/printerShare.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<PrintJobItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property jobs in print
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: PrintJob, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a PrintJobItemRequestBuilder
     */
    withUrl(rawUrl: string): PrintJobItemRequestBuilder;
}
