import { type PrintJob } from '../../../../../../models/printJob';
import { type PrintJobConfiguration } from '../../../../../../models/printJobConfiguration';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createRedirectPostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoRedirectPostRequestBody;
export declare function deserializeIntoRedirectPostRequestBody(redirectPostRequestBody?: RedirectPostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export interface RedirectPostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The configuration property
     */
    configuration?: PrintJobConfiguration;
    /**
     * The destinationPrinterId property
     */
    destinationPrinterId?: string;
}
export declare function serializeRedirectPostRequestBody(writer: SerializationWriter, redirectPostRequestBody?: RedirectPostRequestBody | undefined): void;
/**
 * Provides operations to call the redirect method.
 */
export declare class RedirectRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new RedirectRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Redirect a print job to a different printer. Redirecting a print job will only succeed if there is a printTask in a processing state on the associated print job, started by a trigger that the requesting app created.  For details about how to use this API to add pull printing support to Universal Print, see Extending Universal Print to support pull printing.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PrintJob
     * @see {@link https://learn.microsoft.com/graph/api/printjob-redirect?view=graph-rest-1.0|Find more info here}
     */
    post(body: RedirectPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<PrintJob | undefined>;
    /**
     * Redirect a print job to a different printer. Redirecting a print job will only succeed if there is a printTask in a processing state on the associated print job, started by a trigger that the requesting app created.  For details about how to use this API to add pull printing support to Universal Print, see Extending Universal Print to support pull printing.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: RedirectPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a redirectRequestBuilder
     */
    withUrl(rawUrl: string): RedirectRequestBuilder;
}
