import { type Privacy } from '../models/privacy';
import { SubjectRightsRequestsRequestBuilder } from './subjectRightsRequests/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface PrivacyRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the privacy singleton.
 */
export declare class PrivacyRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the subjectRightsRequests property of the microsoft.graph.privacy entity.
     */
    get subjectRightsRequests(): SubjectRightsRequestsRequestBuilder;
    /**
     * Instantiates a new PrivacyRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get privacy
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Privacy
     */
    get(requestConfiguration?: RequestConfiguration<PrivacyRequestBuilderGetQueryParameters> | undefined): Promise<Privacy | undefined>;
    /**
     * Update privacy
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Privacy
     */
    patch(body: Privacy, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Privacy | undefined>;
    /**
     * Get privacy
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<PrivacyRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update privacy
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Privacy, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a privacyRequestBuilder
     */
    withUrl(rawUrl: string): PrivacyRequestBuilder;
}
