import { type AuthenticationMethodsRoot } from '../../models/authenticationMethodsRoot';
import { UserRegistrationDetailsRequestBuilder } from './userRegistrationDetails/';
import { UsersRegisteredByFeatureRequestBuilder } from './usersRegisteredByFeature/';
import { UsersRegisteredByFeatureWithIncludedUserTypesWithIncludedUserRolesRequestBuilder } from './usersRegisteredByFeatureWithIncludedUserTypesWithIncludedUserRoles/';
import { UsersRegisteredByMethodRequestBuilder } from './usersRegisteredByMethod/';
import { UsersRegisteredByMethodWithIncludedUserTypesWithIncludedUserRolesRequestBuilder } from './usersRegisteredByMethodWithIncludedUserTypesWithIncludedUserRoles/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AuthenticationMethodsRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the authenticationMethods property of the microsoft.graph.reportRoot entity.
 */
export declare class AuthenticationMethodsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the userRegistrationDetails property of the microsoft.graph.authenticationMethodsRoot entity.
     */
    get userRegistrationDetails(): UserRegistrationDetailsRequestBuilder;
    /**
     * Provides operations to call the usersRegisteredByFeature method.
     */
    get usersRegisteredByFeature(): UsersRegisteredByFeatureRequestBuilder;
    /**
     * Provides operations to call the usersRegisteredByMethod method.
     */
    get usersRegisteredByMethod(): UsersRegisteredByMethodRequestBuilder;
    /**
     * Instantiates a new AuthenticationMethodsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property authenticationMethods for reports
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Container for navigation properties for Microsoft Entra authentication methods resources.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AuthenticationMethodsRoot
     */
    get(requestConfiguration?: RequestConfiguration<AuthenticationMethodsRequestBuilderGetQueryParameters> | undefined): Promise<AuthenticationMethodsRoot | undefined>;
    /**
     * Update the navigation property authenticationMethods in reports
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AuthenticationMethodsRoot
     */
    patch(body: AuthenticationMethodsRoot, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AuthenticationMethodsRoot | undefined>;
    /**
     * Delete navigation property authenticationMethods for reports
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Container for navigation properties for Microsoft Entra authentication methods resources.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AuthenticationMethodsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property authenticationMethods in reports
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: AuthenticationMethodsRoot, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Provides operations to call the usersRegisteredByFeature method.
     * @param includedUserRoles Usage: includedUserRoles='{includedUserRoles}'
     * @param includedUserTypes Usage: includedUserTypes='{includedUserTypes}'
     * @returns a usersRegisteredByFeatureWithIncludedUserTypesWithIncludedUserRolesRequestBuilder
     */
    usersRegisteredByFeatureWithIncludedUserTypesWithIncludedUserRoles(includedUserRoles: string | undefined, includedUserTypes: string | undefined): UsersRegisteredByFeatureWithIncludedUserTypesWithIncludedUserRolesRequestBuilder;
    /**
     * Provides operations to call the usersRegisteredByMethod method.
     * @param includedUserRoles Usage: includedUserRoles='{includedUserRoles}'
     * @param includedUserTypes Usage: includedUserTypes='{includedUserTypes}'
     * @returns a usersRegisteredByMethodWithIncludedUserTypesWithIncludedUserRolesRequestBuilder
     */
    usersRegisteredByMethodWithIncludedUserTypesWithIncludedUserRoles(includedUserRoles: string | undefined, includedUserTypes: string | undefined): UsersRegisteredByMethodWithIncludedUserTypesWithIncludedUserRolesRequestBuilder;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a authenticationMethodsRequestBuilder
     */
    withUrl(rawUrl: string): AuthenticationMethodsRequestBuilder;
}
