import { type UserRegistrationDetailsCollectionResponse } from '../../../models/';
import { type UserRegistrationDetails } from '../../../models/userRegistrationDetails';
import { CountRequestBuilder } from './count/';
import { UserRegistrationDetailsItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface UserRegistrationDetailsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the userRegistrationDetails property of the microsoft.graph.authenticationMethodsRoot entity.
 */
export declare class UserRegistrationDetailsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the userRegistrationDetails property of the microsoft.graph.authenticationMethodsRoot entity.
     * @param userRegistrationDetailsId The unique identifier of userRegistrationDetails
     * @returns a UserRegistrationDetailsItemRequestBuilder
     */
    byUserRegistrationDetailsId(userRegistrationDetailsId: string): UserRegistrationDetailsItemRequestBuilder;
    /**
     * Instantiates a new UserRegistrationDetailsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the authentication methods registered for a user as defined in the userRegistrationDetails object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserRegistrationDetailsCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/authenticationmethodsroot-list-userregistrationdetails?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<UserRegistrationDetailsRequestBuilderGetQueryParameters> | undefined): Promise<UserRegistrationDetailsCollectionResponse | undefined>;
    /**
     * Create new navigation property to userRegistrationDetails for reports
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserRegistrationDetails
     */
    post(body: UserRegistrationDetails, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<UserRegistrationDetails | undefined>;
    /**
     * Get a list of the authentication methods registered for a user as defined in the userRegistrationDetails object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<UserRegistrationDetailsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to userRegistrationDetails for reports
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: UserRegistrationDetails, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a userRegistrationDetailsRequestBuilder
     */
    withUrl(rawUrl: string): UserRegistrationDetailsRequestBuilder;
}
