"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeviceConfigurationUserActivityRequestBuilder = void 0;
const oDataError_1 = require("../../models/oDataErrors/oDataError");
const report_1 = require("../../models/report");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to call the deviceConfigurationUserActivity method.
 */
class DeviceConfigurationUserActivityRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new DeviceConfigurationUserActivityRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/reports/deviceConfigurationUserActivity()");
    }
    ;
    /**
     * Metadata for the device configuration user activity report
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Report
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, report_1.createReportFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Metadata for the device configuration user activity report
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a deviceConfigurationUserActivityRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new DeviceConfigurationUserActivityRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.DeviceConfigurationUserActivityRequestBuilder = DeviceConfigurationUserActivityRequestBuilder;
// tslint:enable
// eslint-enable
