import { type SecurityReportsRoot } from '../../models/securityReportsRoot';
import { GetAttackSimulationRepeatOffendersRequestBuilder } from './getAttackSimulationRepeatOffenders/';
import { GetAttackSimulationSimulationUserCoverageRequestBuilder } from './getAttackSimulationSimulationUserCoverage/';
import { GetAttackSimulationTrainingUserCoverageRequestBuilder } from './getAttackSimulationTrainingUserCoverage/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SecurityRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the security property of the microsoft.graph.reportRoot entity.
 */
export declare class SecurityRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the getAttackSimulationRepeatOffenders method.
     */
    get getAttackSimulationRepeatOffenders(): GetAttackSimulationRepeatOffendersRequestBuilder;
    /**
     * Provides operations to call the getAttackSimulationSimulationUserCoverage method.
     */
    get getAttackSimulationSimulationUserCoverage(): GetAttackSimulationSimulationUserCoverageRequestBuilder;
    /**
     * Provides operations to call the getAttackSimulationTrainingUserCoverage method.
     */
    get getAttackSimulationTrainingUserCoverage(): GetAttackSimulationTrainingUserCoverageRequestBuilder;
    /**
     * Instantiates a new SecurityRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property security for reports
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Represents an abstract type that contains resources for attack simulation and training reports.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SecurityReportsRoot
     */
    get(requestConfiguration?: RequestConfiguration<SecurityRequestBuilderGetQueryParameters> | undefined): Promise<SecurityReportsRoot | undefined>;
    /**
     * Update the navigation property security in reports
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SecurityReportsRoot
     */
    patch(body: SecurityReportsRoot, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<SecurityReportsRoot | undefined>;
    /**
     * Delete navigation property security for reports
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Represents an abstract type that contains resources for attack simulation and training reports.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SecurityRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property security in reports
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: SecurityReportsRoot, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a securityRequestBuilder
     */
    withUrl(rawUrl: string): SecurityRequestBuilder;
}
