import { type UnifiedRoleAssignmentSchedule } from '../../../../models/unifiedRoleAssignmentSchedule';
import { ActivatedUsingRequestBuilder } from './activatedUsing/';
import { AppScopeRequestBuilder } from './appScope/';
import { DirectoryScopeRequestBuilder } from './directoryScope/';
import { PrincipalRequestBuilder } from './principal/';
import { RoleDefinitionRequestBuilder } from './roleDefinition/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface UnifiedRoleAssignmentScheduleItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the roleAssignmentSchedules property of the microsoft.graph.rbacApplication entity.
 */
export declare class UnifiedRoleAssignmentScheduleItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the activatedUsing property of the microsoft.graph.unifiedRoleAssignmentSchedule entity.
     */
    get activatedUsing(): ActivatedUsingRequestBuilder;
    /**
     * Provides operations to manage the appScope property of the microsoft.graph.unifiedRoleScheduleBase entity.
     */
    get appScope(): AppScopeRequestBuilder;
    /**
     * Provides operations to manage the directoryScope property of the microsoft.graph.unifiedRoleScheduleBase entity.
     */
    get directoryScope(): DirectoryScopeRequestBuilder;
    /**
     * Provides operations to manage the principal property of the microsoft.graph.unifiedRoleScheduleBase entity.
     */
    get principal(): PrincipalRequestBuilder;
    /**
     * Provides operations to manage the roleDefinition property of the microsoft.graph.unifiedRoleScheduleBase entity.
     */
    get roleDefinition(): RoleDefinitionRequestBuilder;
    /**
     * Instantiates a new UnifiedRoleAssignmentScheduleItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property roleAssignmentSchedules for roleManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the schedule for an active role assignment operation.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UnifiedRoleAssignmentSchedule
     * @see {@link https://learn.microsoft.com/graph/api/unifiedroleassignmentschedule-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<UnifiedRoleAssignmentScheduleItemRequestBuilderGetQueryParameters> | undefined): Promise<UnifiedRoleAssignmentSchedule | undefined>;
    /**
     * Update the navigation property roleAssignmentSchedules in roleManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UnifiedRoleAssignmentSchedule
     */
    patch(body: UnifiedRoleAssignmentSchedule, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<UnifiedRoleAssignmentSchedule | undefined>;
    /**
     * Delete navigation property roleAssignmentSchedules for roleManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the schedule for an active role assignment operation.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<UnifiedRoleAssignmentScheduleItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property roleAssignmentSchedules in roleManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: UnifiedRoleAssignmentSchedule, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a UnifiedRoleAssignmentScheduleItemRequestBuilder
     */
    withUrl(rawUrl: string): UnifiedRoleAssignmentScheduleItemRequestBuilder;
}
