import { type RbacApplication } from '../../models/rbacApplication';
import { ResourceNamespacesRequestBuilder } from './resourceNamespaces/';
import { RoleAssignmentsRequestBuilder } from './roleAssignments/';
import { RoleAssignmentScheduleInstancesRequestBuilder } from './roleAssignmentScheduleInstances/';
import { RoleAssignmentScheduleRequestsRequestBuilder } from './roleAssignmentScheduleRequests/';
import { RoleAssignmentSchedulesRequestBuilder } from './roleAssignmentSchedules/';
import { RoleDefinitionsRequestBuilder } from './roleDefinitions/';
import { RoleEligibilityScheduleInstancesRequestBuilder } from './roleEligibilityScheduleInstances/';
import { RoleEligibilityScheduleRequestsRequestBuilder } from './roleEligibilityScheduleRequests/';
import { RoleEligibilitySchedulesRequestBuilder } from './roleEligibilitySchedules/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface EntitlementManagementRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the entitlementManagement property of the microsoft.graph.roleManagement entity.
 */
export declare class EntitlementManagementRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the resourceNamespaces property of the microsoft.graph.rbacApplication entity.
     */
    get resourceNamespaces(): ResourceNamespacesRequestBuilder;
    /**
     * Provides operations to manage the roleAssignments property of the microsoft.graph.rbacApplication entity.
     */
    get roleAssignments(): RoleAssignmentsRequestBuilder;
    /**
     * Provides operations to manage the roleAssignmentScheduleInstances property of the microsoft.graph.rbacApplication entity.
     */
    get roleAssignmentScheduleInstances(): RoleAssignmentScheduleInstancesRequestBuilder;
    /**
     * Provides operations to manage the roleAssignmentScheduleRequests property of the microsoft.graph.rbacApplication entity.
     */
    get roleAssignmentScheduleRequests(): RoleAssignmentScheduleRequestsRequestBuilder;
    /**
     * Provides operations to manage the roleAssignmentSchedules property of the microsoft.graph.rbacApplication entity.
     */
    get roleAssignmentSchedules(): RoleAssignmentSchedulesRequestBuilder;
    /**
     * Provides operations to manage the roleDefinitions property of the microsoft.graph.rbacApplication entity.
     */
    get roleDefinitions(): RoleDefinitionsRequestBuilder;
    /**
     * Provides operations to manage the roleEligibilityScheduleInstances property of the microsoft.graph.rbacApplication entity.
     */
    get roleEligibilityScheduleInstances(): RoleEligibilityScheduleInstancesRequestBuilder;
    /**
     * Provides operations to manage the roleEligibilityScheduleRequests property of the microsoft.graph.rbacApplication entity.
     */
    get roleEligibilityScheduleRequests(): RoleEligibilityScheduleRequestsRequestBuilder;
    /**
     * Provides operations to manage the roleEligibilitySchedules property of the microsoft.graph.rbacApplication entity.
     */
    get roleEligibilitySchedules(): RoleEligibilitySchedulesRequestBuilder;
    /**
     * Instantiates a new EntitlementManagementRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property entitlementManagement for roleManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Container for roles and assignments for entitlement management resources.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RbacApplication
     */
    get(requestConfiguration?: RequestConfiguration<EntitlementManagementRequestBuilderGetQueryParameters> | undefined): Promise<RbacApplication | undefined>;
    /**
     * Update the navigation property entitlementManagement in roleManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RbacApplication
     */
    patch(body: RbacApplication, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<RbacApplication | undefined>;
    /**
     * Delete navigation property entitlementManagement for roleManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Container for roles and assignments for entitlement management resources.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<EntitlementManagementRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property entitlementManagement in roleManagement
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: RbacApplication, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a entitlementManagementRequestBuilder
     */
    withUrl(rawUrl: string): EntitlementManagementRequestBuilder;
}
