import { type Alert } from '../../../models/security/alert';
import { CommentsRequestBuilder } from './comments/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AlertItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the alerts_v2 property of the microsoft.graph.security entity.
 */
export declare class AlertItemRequestBuilder extends BaseRequestBuilder {
    /**
     * The comments property
     */
    get comments(): CommentsRequestBuilder;
    /**
     * Instantiates a new AlertItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property alerts_v2 for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Get the properties and relationships of an alert in an organization based on the specified alert id property.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Alert
     * @see {@link https://learn.microsoft.com/graph/api/security-alert-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<AlertItemRequestBuilderGetQueryParameters> | undefined): Promise<Alert | undefined>;
    /**
     * Update the properties of an alert object in an organization based on the specified alert id property.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Alert
     * @see {@link https://learn.microsoft.com/graph/api/security-alert-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: Alert, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Alert | undefined>;
    /**
     * Delete navigation property alerts_v2 for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Get the properties and relationships of an alert in an organization based on the specified alert id property.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AlertItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of an alert object in an organization based on the specified alert id property.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Alert, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a AlertItemRequestBuilder
     */
    withUrl(rawUrl: string): AlertItemRequestBuilder;
}
