import { type EndUserNotificationDetailCollectionResponse } from '../../../../../models/';
import { type EndUserNotificationDetail } from '../../../../../models/endUserNotificationDetail';
import { CountRequestBuilder } from './count/';
import { EndUserNotificationDetailItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DetailsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the details property of the microsoft.graph.endUserNotification entity.
 */
export declare class DetailsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the details property of the microsoft.graph.endUserNotification entity.
     * @param endUserNotificationDetailId The unique identifier of endUserNotificationDetail
     * @returns a EndUserNotificationDetailItemRequestBuilder
     */
    byEndUserNotificationDetailId(endUserNotificationDetailId: string): EndUserNotificationDetailItemRequestBuilder;
    /**
     * Instantiates a new DetailsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get details from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EndUserNotificationDetailCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<DetailsRequestBuilderGetQueryParameters> | undefined): Promise<EndUserNotificationDetailCollectionResponse | undefined>;
    /**
     * Create new navigation property to details for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EndUserNotificationDetail
     */
    post(body: EndUserNotificationDetail, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<EndUserNotificationDetail | undefined>;
    /**
     * Get details from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DetailsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to details for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: EndUserNotificationDetail, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a detailsRequestBuilder
     */
    withUrl(rawUrl: string): DetailsRequestBuilder;
}
