import { type EndUserNotification } from '../../../../models/endUserNotification';
import { DetailsRequestBuilder } from './details/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface EndUserNotificationItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the endUserNotifications property of the microsoft.graph.attackSimulationRoot entity.
 */
export declare class EndUserNotificationItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the details property of the microsoft.graph.endUserNotification entity.
     */
    get details(): DetailsRequestBuilder;
    /**
     * Instantiates a new EndUserNotificationItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property endUserNotifications for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Represents an end user's notification for an attack simulation training.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EndUserNotification
     */
    get(requestConfiguration?: RequestConfiguration<EndUserNotificationItemRequestBuilderGetQueryParameters> | undefined): Promise<EndUserNotification | undefined>;
    /**
     * Update the navigation property endUserNotifications in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EndUserNotification
     */
    patch(body: EndUserNotification, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<EndUserNotification | undefined>;
    /**
     * Delete navigation property endUserNotifications for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Represents an end user's notification for an attack simulation training.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<EndUserNotificationItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property endUserNotifications in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EndUserNotification, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a EndUserNotificationItemRequestBuilder
     */
    withUrl(rawUrl: string): EndUserNotificationItemRequestBuilder;
}
