import { type AttackSimulationRoot } from '../../models/attackSimulationRoot';
import { EndUserNotificationsRequestBuilder } from './endUserNotifications/';
import { LandingPagesRequestBuilder } from './landingPages/';
import { LoginPagesRequestBuilder } from './loginPages/';
import { OperationsRequestBuilder } from './operations/';
import { PayloadsRequestBuilder } from './payloads/';
import { SimulationAutomationsRequestBuilder } from './simulationAutomations/';
import { SimulationsRequestBuilder } from './simulations/';
import { TrainingsRequestBuilder } from './trainings/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AttackSimulationRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the attackSimulation property of the microsoft.graph.security entity.
 */
export declare class AttackSimulationRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the endUserNotifications property of the microsoft.graph.attackSimulationRoot entity.
     */
    get endUserNotifications(): EndUserNotificationsRequestBuilder;
    /**
     * Provides operations to manage the landingPages property of the microsoft.graph.attackSimulationRoot entity.
     */
    get landingPages(): LandingPagesRequestBuilder;
    /**
     * Provides operations to manage the loginPages property of the microsoft.graph.attackSimulationRoot entity.
     */
    get loginPages(): LoginPagesRequestBuilder;
    /**
     * Provides operations to manage the operations property of the microsoft.graph.attackSimulationRoot entity.
     */
    get operations(): OperationsRequestBuilder;
    /**
     * Provides operations to manage the payloads property of the microsoft.graph.attackSimulationRoot entity.
     */
    get payloads(): PayloadsRequestBuilder;
    /**
     * Provides operations to manage the simulationAutomations property of the microsoft.graph.attackSimulationRoot entity.
     */
    get simulationAutomations(): SimulationAutomationsRequestBuilder;
    /**
     * Provides operations to manage the simulations property of the microsoft.graph.attackSimulationRoot entity.
     */
    get simulations(): SimulationsRequestBuilder;
    /**
     * Provides operations to manage the trainings property of the microsoft.graph.attackSimulationRoot entity.
     */
    get trainings(): TrainingsRequestBuilder;
    /**
     * Instantiates a new AttackSimulationRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property attackSimulation for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Get attackSimulation from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AttackSimulationRoot
     */
    get(requestConfiguration?: RequestConfiguration<AttackSimulationRequestBuilderGetQueryParameters> | undefined): Promise<AttackSimulationRoot | undefined>;
    /**
     * Update the navigation property attackSimulation in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AttackSimulationRoot
     */
    patch(body: AttackSimulationRoot, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AttackSimulationRoot | undefined>;
    /**
     * Delete navigation property attackSimulation for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Get attackSimulation from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AttackSimulationRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property attackSimulation in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: AttackSimulationRoot, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a attackSimulationRequestBuilder
     */
    withUrl(rawUrl: string): AttackSimulationRequestBuilder;
}
