import { type LandingPageCollectionResponse } from '../../../models/';
import { type LandingPage } from '../../../models/landingPage';
import { CountRequestBuilder } from './count/';
import { LandingPageItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface LandingPagesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the landingPages property of the microsoft.graph.attackSimulationRoot entity.
 */
export declare class LandingPagesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the landingPages property of the microsoft.graph.attackSimulationRoot entity.
     * @param landingPageId The unique identifier of landingPage
     * @returns a LandingPageItemRequestBuilder
     */
    byLandingPageId(landingPageId: string): LandingPageItemRequestBuilder;
    /**
     * Instantiates a new LandingPagesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the landingPage objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of LandingPageCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/attacksimulationroot-list-landingpage?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<LandingPagesRequestBuilderGetQueryParameters> | undefined): Promise<LandingPageCollectionResponse | undefined>;
    /**
     * Create new navigation property to landingPages for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of LandingPage
     */
    post(body: LandingPage, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<LandingPage | undefined>;
    /**
     * Get a list of the landingPage objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<LandingPagesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to landingPages for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: LandingPage, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a landingPagesRequestBuilder
     */
    withUrl(rawUrl: string): LandingPagesRequestBuilder;
}
