import { type Simulation } from '../../../../models/simulation';
import { LandingPageRequestBuilder } from './landingPage/';
import { LoginPageRequestBuilder } from './loginPage/';
import { PayloadRequestBuilder } from './payload/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SimulationItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the simulations property of the microsoft.graph.attackSimulationRoot entity.
 */
export declare class SimulationItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the landingPage property of the microsoft.graph.simulation entity.
     */
    get landingPage(): LandingPageRequestBuilder;
    /**
     * Provides operations to manage the loginPage property of the microsoft.graph.simulation entity.
     */
    get loginPage(): LoginPageRequestBuilder;
    /**
     * Provides operations to manage the payload property of the microsoft.graph.simulation entity.
     */
    get payload(): PayloadRequestBuilder;
    /**
     * Instantiates a new SimulationItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete an attack simulation campaign for a tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/simulation-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Get an attack simulation campaign for a tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Simulation
     * @see {@link https://learn.microsoft.com/graph/api/simulation-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SimulationItemRequestBuilderGetQueryParameters> | undefined): Promise<Simulation | undefined>;
    /**
     * Update an attack simulation campaign for a tenant.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Simulation
     * @see {@link https://learn.microsoft.com/graph/api/simulation-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: Simulation, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Simulation | undefined>;
    /**
     * Delete an attack simulation campaign for a tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Get an attack simulation campaign for a tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SimulationItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update an attack simulation campaign for a tenant.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Simulation, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a SimulationItemRequestBuilder
     */
    withUrl(rawUrl: string): SimulationItemRequestBuilder;
}
