import { type TrainingLanguageDetailCollectionResponse } from '../../../../../models/';
import { type TrainingLanguageDetail } from '../../../../../models/trainingLanguageDetail';
import { CountRequestBuilder } from './count/';
import { TrainingLanguageDetailItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface LanguageDetailsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the languageDetails property of the microsoft.graph.training entity.
 */
export declare class LanguageDetailsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the languageDetails property of the microsoft.graph.training entity.
     * @param trainingLanguageDetailId The unique identifier of trainingLanguageDetail
     * @returns a TrainingLanguageDetailItemRequestBuilder
     */
    byTrainingLanguageDetailId(trainingLanguageDetailId: string): TrainingLanguageDetailItemRequestBuilder;
    /**
     * Instantiates a new LanguageDetailsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Language specific details on a training.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TrainingLanguageDetailCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<LanguageDetailsRequestBuilderGetQueryParameters> | undefined): Promise<TrainingLanguageDetailCollectionResponse | undefined>;
    /**
     * Create new navigation property to languageDetails for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TrainingLanguageDetail
     */
    post(body: TrainingLanguageDetail, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<TrainingLanguageDetail | undefined>;
    /**
     * Language specific details on a training.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<LanguageDetailsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to languageDetails for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: TrainingLanguageDetail, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a languageDetailsRequestBuilder
     */
    withUrl(rawUrl: string): LanguageDetailsRequestBuilder;
}
