import { type EdiscoveryCustodian } from '../../../../../../models/security/ediscoveryCustodian';
import { LastIndexOperationRequestBuilder } from './lastIndexOperation/';
import { MicrosoftGraphSecurityActivateRequestBuilder } from './microsoftGraphSecurityActivate/';
import { MicrosoftGraphSecurityApplyHoldRequestBuilder } from './microsoftGraphSecurityApplyHold/';
import { MicrosoftGraphSecurityReleaseRequestBuilder } from './microsoftGraphSecurityRelease/';
import { MicrosoftGraphSecurityRemoveHoldRequestBuilder } from './microsoftGraphSecurityRemoveHold/';
import { MicrosoftGraphSecurityUpdateIndexRequestBuilder } from './microsoftGraphSecurityUpdateIndex/';
import { SiteSourcesRequestBuilder } from './siteSources/';
import { UnifiedGroupSourcesRequestBuilder } from './unifiedGroupSources/';
import { UserSourcesRequestBuilder } from './userSources/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface EdiscoveryCustodianItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the custodians property of the microsoft.graph.security.ediscoveryCase entity.
 */
export declare class EdiscoveryCustodianItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the lastIndexOperation property of the microsoft.graph.security.ediscoveryCustodian entity.
     */
    get lastIndexOperation(): LastIndexOperationRequestBuilder;
    /**
     * Provides operations to call the activate method.
     */
    get microsoftGraphSecurityActivate(): MicrosoftGraphSecurityActivateRequestBuilder;
    /**
     * Provides operations to call the applyHold method.
     */
    get microsoftGraphSecurityApplyHold(): MicrosoftGraphSecurityApplyHoldRequestBuilder;
    /**
     * Provides operations to call the release method.
     */
    get microsoftGraphSecurityRelease(): MicrosoftGraphSecurityReleaseRequestBuilder;
    /**
     * Provides operations to call the removeHold method.
     */
    get microsoftGraphSecurityRemoveHold(): MicrosoftGraphSecurityRemoveHoldRequestBuilder;
    /**
     * Provides operations to call the updateIndex method.
     */
    get microsoftGraphSecurityUpdateIndex(): MicrosoftGraphSecurityUpdateIndexRequestBuilder;
    /**
     * Provides operations to manage the siteSources property of the microsoft.graph.security.ediscoveryCustodian entity.
     */
    get siteSources(): SiteSourcesRequestBuilder;
    /**
     * Provides operations to manage the unifiedGroupSources property of the microsoft.graph.security.ediscoveryCustodian entity.
     */
    get unifiedGroupSources(): UnifiedGroupSourcesRequestBuilder;
    /**
     * Provides operations to manage the userSources property of the microsoft.graph.security.ediscoveryCustodian entity.
     */
    get userSources(): UserSourcesRequestBuilder;
    /**
     * Instantiates a new EdiscoveryCustodianItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property custodians for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of an ediscoveryCustodian object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryCustodian
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoverycustodian-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<EdiscoveryCustodianItemRequestBuilderGetQueryParameters> | undefined): Promise<EdiscoveryCustodian | undefined>;
    /**
     * Update the navigation property custodians in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryCustodian
     */
    patch(body: EdiscoveryCustodian, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<EdiscoveryCustodian | undefined>;
    /**
     * Delete navigation property custodians for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of an ediscoveryCustodian object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<EdiscoveryCustodianItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property custodians in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EdiscoveryCustodian, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a EdiscoveryCustodianItemRequestBuilder
     */
    withUrl(rawUrl: string): EdiscoveryCustodianItemRequestBuilder;
}
