import { type EdiscoveryCase } from '../../../../models/security/ediscoveryCase';
import { CustodiansRequestBuilder } from './custodians/';
import { MicrosoftGraphSecurityCloseRequestBuilder } from './microsoftGraphSecurityClose/';
import { MicrosoftGraphSecurityReopenRequestBuilder } from './microsoftGraphSecurityReopen/';
import { NoncustodialDataSourcesRequestBuilder } from './noncustodialDataSources/';
import { OperationsRequestBuilder } from './operations/';
import { ReviewSetsRequestBuilder } from './reviewSets/';
import { SearchesRequestBuilder } from './searches/';
import { SettingsRequestBuilder } from './settings/';
import { TagsRequestBuilder } from './tags/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface EdiscoveryCaseItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the ediscoveryCases property of the microsoft.graph.security.casesRoot entity.
 */
export declare class EdiscoveryCaseItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the custodians property of the microsoft.graph.security.ediscoveryCase entity.
     */
    get custodians(): CustodiansRequestBuilder;
    /**
     * Provides operations to call the close method.
     */
    get microsoftGraphSecurityClose(): MicrosoftGraphSecurityCloseRequestBuilder;
    /**
     * Provides operations to call the reopen method.
     */
    get microsoftGraphSecurityReopen(): MicrosoftGraphSecurityReopenRequestBuilder;
    /**
     * Provides operations to manage the noncustodialDataSources property of the microsoft.graph.security.ediscoveryCase entity.
     */
    get noncustodialDataSources(): NoncustodialDataSourcesRequestBuilder;
    /**
     * Provides operations to manage the operations property of the microsoft.graph.security.ediscoveryCase entity.
     */
    get operations(): OperationsRequestBuilder;
    /**
     * Provides operations to manage the reviewSets property of the microsoft.graph.security.ediscoveryCase entity.
     */
    get reviewSets(): ReviewSetsRequestBuilder;
    /**
     * Provides operations to manage the searches property of the microsoft.graph.security.ediscoveryCase entity.
     */
    get searches(): SearchesRequestBuilder;
    /**
     * Provides operations to manage the settings property of the microsoft.graph.security.ediscoveryCase entity.
     */
    get settings(): SettingsRequestBuilder;
    /**
     * Provides operations to manage the tags property of the microsoft.graph.security.ediscoveryCase entity.
     */
    get tags(): TagsRequestBuilder;
    /**
     * Instantiates a new EdiscoveryCaseItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete an ediscoveryCase object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/security-casesroot-delete-ediscoverycases?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of an ediscoveryCase object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryCase
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoverycase-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<EdiscoveryCaseItemRequestBuilderGetQueryParameters> | undefined): Promise<EdiscoveryCase | undefined>;
    /**
     * Update the properties of an ediscoveryCase object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryCase
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoverycase-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: EdiscoveryCase, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<EdiscoveryCase | undefined>;
    /**
     * Delete an ediscoveryCase object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of an ediscoveryCase object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<EdiscoveryCaseItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of an ediscoveryCase object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EdiscoveryCase, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a EdiscoveryCaseItemRequestBuilder
     */
    withUrl(rawUrl: string): EdiscoveryCaseItemRequestBuilder;
}
