import { type EdiscoveryNoncustodialDataSourceCollectionResponse } from '../../../../../models/security/';
import { type EdiscoveryNoncustodialDataSource } from '../../../../../models/security/ediscoveryNoncustodialDataSource';
import { CountRequestBuilder } from './count/';
import { EdiscoveryNoncustodialDataSourceItemRequestBuilder } from './item/';
import { MicrosoftGraphSecurityApplyHoldRequestBuilder } from './microsoftGraphSecurityApplyHold/';
import { MicrosoftGraphSecurityRemoveHoldRequestBuilder } from './microsoftGraphSecurityRemoveHold/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface NoncustodialDataSourcesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the noncustodialDataSources property of the microsoft.graph.security.ediscoveryCase entity.
 */
export declare class NoncustodialDataSourcesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to call the applyHold method.
     */
    get microsoftGraphSecurityApplyHold(): MicrosoftGraphSecurityApplyHoldRequestBuilder;
    /**
     * Provides operations to call the removeHold method.
     */
    get microsoftGraphSecurityRemoveHold(): MicrosoftGraphSecurityRemoveHoldRequestBuilder;
    /**
     * Provides operations to manage the noncustodialDataSources property of the microsoft.graph.security.ediscoveryCase entity.
     * @param ediscoveryNoncustodialDataSourceId The unique identifier of ediscoveryNoncustodialDataSource
     * @returns a EdiscoveryNoncustodialDataSourceItemRequestBuilder
     */
    byEdiscoveryNoncustodialDataSourceId(ediscoveryNoncustodialDataSourceId: string): EdiscoveryNoncustodialDataSourceItemRequestBuilder;
    /**
     * Instantiates a new NoncustodialDataSourcesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Returns a list of case ediscoveryNoncustodialDataSource objects for this case.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryNoncustodialDataSourceCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<NoncustodialDataSourcesRequestBuilderGetQueryParameters> | undefined): Promise<EdiscoveryNoncustodialDataSourceCollectionResponse | undefined>;
    /**
     * Create a new ediscoveryNoncustodialDataSource object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryNoncustodialDataSource
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoverycase-post-noncustodialdatasources?view=graph-rest-1.0|Find more info here}
     */
    post(body: EdiscoveryNoncustodialDataSource, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<EdiscoveryNoncustodialDataSource | undefined>;
    /**
     * Returns a list of case ediscoveryNoncustodialDataSource objects for this case.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<NoncustodialDataSourcesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new ediscoveryNoncustodialDataSource object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: EdiscoveryNoncustodialDataSource, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a noncustodialDataSourcesRequestBuilder
     */
    withUrl(rawUrl: string): NoncustodialDataSourcesRequestBuilder;
}
