"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MicrosoftGraphSecurityAddToReviewSetRequestBuilder = exports.serializeAddToReviewSetPostRequestBody = exports.deserializeIntoAddToReviewSetPostRequestBody = exports.createAddToReviewSetPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../../../../models/oDataErrors/oDataError");
const additionalDataOptions_1 = require("../../../../../../../models/security/additionalDataOptions");
const ediscoverySearch_1 = require("../../../../../../../models/security/ediscoverySearch");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createAddToReviewSetPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoAddToReviewSetPostRequestBody;
}
exports.createAddToReviewSetPostRequestBodyFromDiscriminatorValue = createAddToReviewSetPostRequestBodyFromDiscriminatorValue;
function deserializeIntoAddToReviewSetPostRequestBody(addToReviewSetPostRequestBody = {}) {
    return {
        "additionalDataOptions": n => { addToReviewSetPostRequestBody.additionalDataOptions = n.getCollectionOfEnumValues(additionalDataOptions_1.AdditionalDataOptions); },
        "search": n => { addToReviewSetPostRequestBody.search = n.getObjectValue(ediscoverySearch_1.createEdiscoverySearchFromDiscriminatorValue); },
    };
}
exports.deserializeIntoAddToReviewSetPostRequestBody = deserializeIntoAddToReviewSetPostRequestBody;
function serializeAddToReviewSetPostRequestBody(writer, addToReviewSetPostRequestBody = {}) {
    writer.writeEnumValue("additionalDataOptions", addToReviewSetPostRequestBody.additionalDataOptions);
    writer.writeObjectValue("search", addToReviewSetPostRequestBody.search, ediscoverySearch_1.serializeEdiscoverySearch);
    writer.writeAdditionalData(addToReviewSetPostRequestBody.additionalData);
}
exports.serializeAddToReviewSetPostRequestBody = serializeAddToReviewSetPostRequestBody;
/**
 * Provides operations to call the addToReviewSet method.
 */
class MicrosoftGraphSecurityAddToReviewSetRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new MicrosoftGraphSecurityAddToReviewSetRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/security/cases/ediscoveryCases/{ediscoveryCase%2Did}/reviewSets/{ediscoveryReviewSet%2Did}/microsoft.graph.security.addToReviewSet");
    }
    ;
    /**
     * Start the process of adding a collection from Microsoft 365 services to a review set. After the operation is created, you can get the status of the operation by retrieving the Location parameter from the response headers. The location provides a URL that will return a Add to review set operation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoveryreviewset-addtoreviewset?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Start the process of adding a collection from Microsoft 365 services to a review set. After the operation is created, you can get the status of the operation by retrieving the Location parameter from the response headers. The location provides a URL that will return a Add to review set operation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeAddToReviewSetPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a microsoftGraphSecurityAddToReviewSetRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new MicrosoftGraphSecurityAddToReviewSetRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.MicrosoftGraphSecurityAddToReviewSetRequestBuilder = MicrosoftGraphSecurityAddToReviewSetRequestBuilder;
// tslint:enable
// eslint-enable
