import { ExportFileStructure } from '../../../../../../../models/security/exportFileStructure';
import { ExportOptions } from '../../../../../../../models/security/exportOptions';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createExportPostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoExportPostRequestBody;
export declare function deserializeIntoExportPostRequestBody(exportPostRequestBody?: ExportPostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export interface ExportPostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The description property
     */
    description?: string;
    /**
     * The exportOptions property
     */
    exportOptions?: ExportOptions[];
    /**
     * The exportStructure property
     */
    exportStructure?: ExportFileStructure;
    /**
     * The outputName property
     */
    outputName?: string;
}
export declare function serializeExportPostRequestBody(writer: SerializationWriter, exportPostRequestBody?: ExportPostRequestBody | undefined): void;
/**
 * Provides operations to call the export method.
 */
export declare class MicrosoftGraphSecurityExportRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new MicrosoftGraphSecurityExportRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Initiate an export from a ediscoveryReviewSet. For details, see Export documents from a review set in eDiscovery (Premium).
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoveryreviewset-export?view=graph-rest-1.0|Find more info here}
     */
    post(body: ExportPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Initiate an export from a ediscoveryReviewSet. For details, see Export documents from a review set in eDiscovery (Premium).
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ExportPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a microsoftGraphSecurityExportRequestBuilder
     */
    withUrl(rawUrl: string): MicrosoftGraphSecurityExportRequestBuilder;
}
