"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MicrosoftGraphSecurityExportRequestBuilder = exports.serializeExportPostRequestBody = exports.deserializeIntoExportPostRequestBody = exports.createExportPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../../../../models/oDataErrors/oDataError");
const exportFileStructure_1 = require("../../../../../../../models/security/exportFileStructure");
const exportOptions_1 = require("../../../../../../../models/security/exportOptions");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createExportPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoExportPostRequestBody;
}
exports.createExportPostRequestBodyFromDiscriminatorValue = createExportPostRequestBodyFromDiscriminatorValue;
function deserializeIntoExportPostRequestBody(exportPostRequestBody = {}) {
    return {
        "description": n => { exportPostRequestBody.description = n.getStringValue(); },
        "exportOptions": n => { exportPostRequestBody.exportOptions = n.getCollectionOfEnumValues(exportOptions_1.ExportOptions); },
        "exportStructure": n => { exportPostRequestBody.exportStructure = n.getEnumValue(exportFileStructure_1.ExportFileStructure); },
        "outputName": n => { exportPostRequestBody.outputName = n.getStringValue(); },
    };
}
exports.deserializeIntoExportPostRequestBody = deserializeIntoExportPostRequestBody;
function serializeExportPostRequestBody(writer, exportPostRequestBody = {}) {
    writer.writeStringValue("description", exportPostRequestBody.description);
    writer.writeEnumValue("exportOptions", exportPostRequestBody.exportOptions);
    writer.writeEnumValue("exportStructure", exportPostRequestBody.exportStructure);
    writer.writeStringValue("outputName", exportPostRequestBody.outputName);
    writer.writeAdditionalData(exportPostRequestBody.additionalData);
}
exports.serializeExportPostRequestBody = serializeExportPostRequestBody;
/**
 * Provides operations to call the export method.
 */
class MicrosoftGraphSecurityExportRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new MicrosoftGraphSecurityExportRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/security/cases/ediscoveryCases/{ediscoveryCase%2Did}/reviewSets/{ediscoveryReviewSet%2Did}/microsoft.graph.security.export");
    }
    ;
    /**
     * Initiate an export from a ediscoveryReviewSet. For details, see Export documents from a review set in eDiscovery (Premium).
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoveryreviewset-export?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Initiate an export from a ediscoveryReviewSet. For details, see Export documents from a review set in eDiscovery (Premium).
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeExportPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a microsoftGraphSecurityExportRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new MicrosoftGraphSecurityExportRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.MicrosoftGraphSecurityExportRequestBuilder = MicrosoftGraphSecurityExportRequestBuilder;
// tslint:enable
// eslint-enable
