import { type EdiscoveryReviewSetQueryCollectionResponse } from '../../../../../../../models/security/';
import { type EdiscoveryReviewSetQuery } from '../../../../../../../models/security/ediscoveryReviewSetQuery';
import { CountRequestBuilder } from './count/';
import { EdiscoveryReviewSetQueryItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface QueriesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the queries property of the microsoft.graph.security.ediscoveryReviewSet entity.
 */
export declare class QueriesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the queries property of the microsoft.graph.security.ediscoveryReviewSet entity.
     * @param ediscoveryReviewSetQueryId The unique identifier of ediscoveryReviewSetQuery
     * @returns a EdiscoveryReviewSetQueryItemRequestBuilder
     */
    byEdiscoveryReviewSetQueryId(ediscoveryReviewSetQueryId: string): EdiscoveryReviewSetQueryItemRequestBuilder;
    /**
     * Instantiates a new QueriesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the list of queries associated with an eDiscovery review set.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryReviewSetQueryCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoveryreviewset-list-queries?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<QueriesRequestBuilderGetQueryParameters> | undefined): Promise<EdiscoveryReviewSetQueryCollectionResponse | undefined>;
    /**
     * Create a new ediscoveryReviewSetQuery object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryReviewSetQuery
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoveryreviewset-post-queries?view=graph-rest-1.0|Find more info here}
     */
    post(body: EdiscoveryReviewSetQuery, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<EdiscoveryReviewSetQuery | undefined>;
    /**
     * Get the list of queries associated with an eDiscovery review set.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<QueriesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new ediscoveryReviewSetQuery object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: EdiscoveryReviewSetQuery, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a queriesRequestBuilder
     */
    withUrl(rawUrl: string): QueriesRequestBuilder;
}
