import { type EdiscoveryReviewTag } from '../../../../../../models/security/ediscoveryReviewTag';
import { ChildTagsRequestBuilder } from './childTags/';
import { ParentRequestBuilder } from './parent/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface EdiscoveryReviewTagItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the tags property of the microsoft.graph.security.ediscoveryCase entity.
 */
export declare class EdiscoveryReviewTagItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the childTags property of the microsoft.graph.security.ediscoveryReviewTag entity.
     */
    get childTags(): ChildTagsRequestBuilder;
    /**
     * Provides operations to manage the parent property of the microsoft.graph.security.ediscoveryReviewTag entity.
     */
    get parent(): ParentRequestBuilder;
    /**
     * Instantiates a new EdiscoveryReviewTagItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Remove an ediscoveryReviewTag object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoverycase-delete-tags?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of an ediscoveryReviewTag object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryReviewTag
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoveryreviewtag-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<EdiscoveryReviewTagItemRequestBuilderGetQueryParameters> | undefined): Promise<EdiscoveryReviewTag | undefined>;
    /**
     * Update the properties of an ediscoveryReviewTag object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of EdiscoveryReviewTag
     * @see {@link https://learn.microsoft.com/graph/api/security-ediscoveryreviewtag-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: EdiscoveryReviewTag, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<EdiscoveryReviewTag | undefined>;
    /**
     * Remove an ediscoveryReviewTag object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of an ediscoveryReviewTag object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<EdiscoveryReviewTagItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of an ediscoveryReviewTag object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: EdiscoveryReviewTag, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a EdiscoveryReviewTagItemRequestBuilder
     */
    withUrl(rawUrl: string): EdiscoveryReviewTagItemRequestBuilder;
}
