import { type Security } from '../models/security';
import { Alerts_v2RequestBuilder } from './alerts_v2/';
import { AlertsRequestBuilder } from './alerts/';
import { AttackSimulationRequestBuilder } from './attackSimulation/';
import { CasesRequestBuilder } from './cases/';
import { IncidentsRequestBuilder } from './incidents/';
import { MicrosoftGraphSecurityRunHuntingQueryRequestBuilder } from './microsoftGraphSecurityRunHuntingQuery/';
import { SecureScoreControlProfilesRequestBuilder } from './secureScoreControlProfiles/';
import { SecureScoresRequestBuilder } from './secureScores/';
import { SubjectRightsRequestsRequestBuilder } from './subjectRightsRequests/';
import { ThreatIntelligenceRequestBuilder } from './threatIntelligence/';
import { TriggersRequestBuilder } from './triggers/';
import { TriggerTypesRequestBuilder } from './triggerTypes/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SecurityRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the security singleton.
 */
export declare class SecurityRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the alerts property of the microsoft.graph.security entity.
     */
    get alerts(): AlertsRequestBuilder;
    /**
     * Provides operations to manage the alerts_v2 property of the microsoft.graph.security entity.
     */
    get alerts_v2(): Alerts_v2RequestBuilder;
    /**
     * Provides operations to manage the attackSimulation property of the microsoft.graph.security entity.
     */
    get attackSimulation(): AttackSimulationRequestBuilder;
    /**
     * Provides operations to manage the cases property of the microsoft.graph.security entity.
     */
    get cases(): CasesRequestBuilder;
    /**
     * Provides operations to manage the incidents property of the microsoft.graph.security entity.
     */
    get incidents(): IncidentsRequestBuilder;
    /**
     * Provides operations to call the runHuntingQuery method.
     */
    get microsoftGraphSecurityRunHuntingQuery(): MicrosoftGraphSecurityRunHuntingQueryRequestBuilder;
    /**
     * Provides operations to manage the secureScoreControlProfiles property of the microsoft.graph.security entity.
     */
    get secureScoreControlProfiles(): SecureScoreControlProfilesRequestBuilder;
    /**
     * Provides operations to manage the secureScores property of the microsoft.graph.security entity.
     */
    get secureScores(): SecureScoresRequestBuilder;
    /**
     * Provides operations to manage the subjectRightsRequests property of the microsoft.graph.security entity.
     */
    get subjectRightsRequests(): SubjectRightsRequestsRequestBuilder;
    /**
     * Provides operations to manage the threatIntelligence property of the microsoft.graph.security entity.
     */
    get threatIntelligence(): ThreatIntelligenceRequestBuilder;
    /**
     * Provides operations to manage the triggers property of the microsoft.graph.security entity.
     */
    get triggers(): TriggersRequestBuilder;
    /**
     * Provides operations to manage the triggerTypes property of the microsoft.graph.security entity.
     */
    get triggerTypes(): TriggerTypesRequestBuilder;
    /**
     * Instantiates a new SecurityRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Security
     */
    get(requestConfiguration?: RequestConfiguration<SecurityRequestBuilderGetQueryParameters> | undefined): Promise<Security | undefined>;
    /**
     * Update security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Security
     */
    patch(body: Security, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Security | undefined>;
    /**
     * Get security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SecurityRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Security, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a securityRequestBuilder
     */
    withUrl(rawUrl: string): SecurityRequestBuilder;
}
