"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SecurityRequestBuilder = void 0;
const oDataError_1 = require("../models/oDataErrors/oDataError");
const security_1 = require("../models/security");
const alerts_v2_1 = require("./alerts_v2/");
const alerts_1 = require("./alerts/");
const attackSimulation_1 = require("./attackSimulation/");
const cases_1 = require("./cases/");
const incidents_1 = require("./incidents/");
const microsoftGraphSecurityRunHuntingQuery_1 = require("./microsoftGraphSecurityRunHuntingQuery/");
const secureScoreControlProfiles_1 = require("./secureScoreControlProfiles/");
const secureScores_1 = require("./secureScores/");
const subjectRightsRequests_1 = require("./subjectRightsRequests/");
const threatIntelligence_1 = require("./threatIntelligence/");
const triggers_1 = require("./triggers/");
const triggerTypes_1 = require("./triggerTypes/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the security singleton.
 */
class SecurityRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to manage the alerts property of the microsoft.graph.security entity.
     */
    get alerts() {
        return new alerts_1.AlertsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the alerts_v2 property of the microsoft.graph.security entity.
     */
    get alerts_v2() {
        return new alerts_v2_1.Alerts_v2RequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the attackSimulation property of the microsoft.graph.security entity.
     */
    get attackSimulation() {
        return new attackSimulation_1.AttackSimulationRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the cases property of the microsoft.graph.security entity.
     */
    get cases() {
        return new cases_1.CasesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the incidents property of the microsoft.graph.security entity.
     */
    get incidents() {
        return new incidents_1.IncidentsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the runHuntingQuery method.
     */
    get microsoftGraphSecurityRunHuntingQuery() {
        return new microsoftGraphSecurityRunHuntingQuery_1.MicrosoftGraphSecurityRunHuntingQueryRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the secureScoreControlProfiles property of the microsoft.graph.security entity.
     */
    get secureScoreControlProfiles() {
        return new secureScoreControlProfiles_1.SecureScoreControlProfilesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the secureScores property of the microsoft.graph.security entity.
     */
    get secureScores() {
        return new secureScores_1.SecureScoresRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the subjectRightsRequests property of the microsoft.graph.security entity.
     */
    get subjectRightsRequests() {
        return new subjectRightsRequests_1.SubjectRightsRequestsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the threatIntelligence property of the microsoft.graph.security entity.
     */
    get threatIntelligence() {
        return new threatIntelligence_1.ThreatIntelligenceRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the triggers property of the microsoft.graph.security entity.
     */
    get triggers() {
        return new triggers_1.TriggersRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the triggerTypes property of the microsoft.graph.security entity.
     */
    get triggerTypes() {
        return new triggerTypes_1.TriggerTypesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new SecurityRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/security{?%24select,%24expand}");
    }
    ;
    /**
     * Get security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Security
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, security_1.createSecurityFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Update security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Security
     */
    patch(body, requestConfiguration) {
        const requestInfo = this.toPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, security_1.createSecurityFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Get security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, securityRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Update security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.PATCH, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, security_1.serializeSecurity);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a securityRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new SecurityRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.SecurityRequestBuilder = SecurityRequestBuilder;
const securityRequestBuilderGetQueryParametersMapper = {
    "expand": "%24expand",
    "select": "%24select",
};
// tslint:enable
// eslint-enable
