import { type SecureScoreControlProfileCollectionResponse } from '../../models/';
import { type SecureScoreControlProfile } from '../../models/secureScoreControlProfile';
import { CountRequestBuilder } from './count/';
import { SecureScoreControlProfileItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SecureScoreControlProfilesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the secureScoreControlProfiles property of the microsoft.graph.security entity.
 */
export declare class SecureScoreControlProfilesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the secureScoreControlProfiles property of the microsoft.graph.security entity.
     * @param secureScoreControlProfileId The unique identifier of secureScoreControlProfile
     * @returns a SecureScoreControlProfileItemRequestBuilder
     */
    bySecureScoreControlProfileId(secureScoreControlProfileId: string): SecureScoreControlProfileItemRequestBuilder;
    /**
     * Instantiates a new SecureScoreControlProfilesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the properties and relationships of a secureScoreControlProfiles object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SecureScoreControlProfileCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/security-list-securescorecontrolprofiles?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SecureScoreControlProfilesRequestBuilderGetQueryParameters> | undefined): Promise<SecureScoreControlProfileCollectionResponse | undefined>;
    /**
     * Create new navigation property to secureScoreControlProfiles for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SecureScoreControlProfile
     */
    post(body: SecureScoreControlProfile, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<SecureScoreControlProfile | undefined>;
    /**
     * Retrieve the properties and relationships of a secureScoreControlProfiles object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SecureScoreControlProfilesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to secureScoreControlProfiles for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: SecureScoreControlProfile, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a secureScoreControlProfilesRequestBuilder
     */
    withUrl(rawUrl: string): SecureScoreControlProfilesRequestBuilder;
}
