import { type SecureScoreCollectionResponse } from '../../models/';
import { type SecureScore } from '../../models/secureScore';
import { CountRequestBuilder } from './count/';
import { SecureScoreItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SecureScoresRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the secureScores property of the microsoft.graph.security entity.
 */
export declare class SecureScoresRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the secureScores property of the microsoft.graph.security entity.
     * @param secureScoreId The unique identifier of secureScore
     * @returns a SecureScoreItemRequestBuilder
     */
    bySecureScoreId(secureScoreId: string): SecureScoreItemRequestBuilder;
    /**
     * Instantiates a new SecureScoresRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of secureScore objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SecureScoreCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/security-list-securescores?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SecureScoresRequestBuilderGetQueryParameters> | undefined): Promise<SecureScoreCollectionResponse | undefined>;
    /**
     * Create new navigation property to secureScores for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SecureScore
     */
    post(body: SecureScore, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<SecureScore | undefined>;
    /**
     * Retrieve a list of secureScore objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SecureScoresRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to secureScores for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: SecureScore, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a secureScoresRequestBuilder
     */
    withUrl(rawUrl: string): SecureScoresRequestBuilder;
}
