import { type SubjectRightsRequestCollectionResponse } from '../../models/';
import { type SubjectRightsRequest } from '../../models/subjectRightsRequest';
import { CountRequestBuilder } from './count/';
import { SubjectRightsRequestItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SubjectRightsRequestsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the subjectRightsRequests property of the microsoft.graph.security entity.
 */
export declare class SubjectRightsRequestsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the subjectRightsRequests property of the microsoft.graph.security entity.
     * @param subjectRightsRequestId The unique identifier of subjectRightsRequest
     * @returns a SubjectRightsRequestItemRequestBuilder
     */
    bySubjectRightsRequestId(subjectRightsRequestId: string): SubjectRightsRequestItemRequestBuilder;
    /**
     * Instantiates a new SubjectRightsRequestsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get subjectRightsRequests from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SubjectRightsRequestCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<SubjectRightsRequestsRequestBuilderGetQueryParameters> | undefined): Promise<SubjectRightsRequestCollectionResponse | undefined>;
    /**
     * Create new navigation property to subjectRightsRequests for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SubjectRightsRequest
     */
    post(body: SubjectRightsRequest, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<SubjectRightsRequest | undefined>;
    /**
     * Get subjectRightsRequests from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SubjectRightsRequestsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to subjectRightsRequests for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: SubjectRightsRequest, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a subjectRightsRequestsRequestBuilder
     */
    withUrl(rawUrl: string): SubjectRightsRequestsRequestBuilder;
}
