import { type SubjectRightsRequest } from '../../../models/subjectRightsRequest';
import { ApproversRequestBuilder } from './approvers/';
import { CollaboratorsRequestBuilder } from './collaborators/';
import { GetFinalAttachmentRequestBuilder } from './getFinalAttachment/';
import { GetFinalReportRequestBuilder } from './getFinalReport/';
import { NotesRequestBuilder } from './notes/';
import { TeamRequestBuilder } from './team/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SubjectRightsRequestItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the subjectRightsRequests property of the microsoft.graph.security entity.
 */
export declare class SubjectRightsRequestItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the approvers property of the microsoft.graph.subjectRightsRequest entity.
     */
    get approvers(): ApproversRequestBuilder;
    /**
     * Provides operations to manage the collaborators property of the microsoft.graph.subjectRightsRequest entity.
     */
    get collaborators(): CollaboratorsRequestBuilder;
    /**
     * Provides operations to call the getFinalAttachment method.
     */
    get getFinalAttachment(): GetFinalAttachmentRequestBuilder;
    /**
     * Provides operations to call the getFinalReport method.
     */
    get getFinalReport(): GetFinalReportRequestBuilder;
    /**
     * Provides operations to manage the notes property of the microsoft.graph.subjectRightsRequest entity.
     */
    get notes(): NotesRequestBuilder;
    /**
     * Provides operations to manage the team property of the microsoft.graph.subjectRightsRequest entity.
     */
    get team(): TeamRequestBuilder;
    /**
     * Instantiates a new SubjectRightsRequestItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property subjectRightsRequests for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Get subjectRightsRequests from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SubjectRightsRequest
     */
    get(requestConfiguration?: RequestConfiguration<SubjectRightsRequestItemRequestBuilderGetQueryParameters> | undefined): Promise<SubjectRightsRequest | undefined>;
    /**
     * Update the navigation property subjectRightsRequests in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SubjectRightsRequest
     */
    patch(body: SubjectRightsRequest, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<SubjectRightsRequest | undefined>;
    /**
     * Delete navigation property subjectRightsRequests for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Get subjectRightsRequests from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SubjectRightsRequestItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property subjectRightsRequests in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: SubjectRightsRequest, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a SubjectRightsRequestItemRequestBuilder
     */
    withUrl(rawUrl: string): SubjectRightsRequestItemRequestBuilder;
}
