import { type ArticleIndicatorCollectionResponse } from '../../../../../models/security/';
import { CountRequestBuilder } from './count/';
import { ArticleIndicatorItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface IndicatorsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the indicators property of the microsoft.graph.security.article entity.
 */
export declare class IndicatorsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the indicators property of the microsoft.graph.security.article entity.
     * @param articleIndicatorId The unique identifier of articleIndicator
     * @returns a ArticleIndicatorItemRequestBuilder
     */
    byArticleIndicatorId(articleIndicatorId: string): ArticleIndicatorItemRequestBuilder;
    /**
     * Instantiates a new IndicatorsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of articleIndicator objects that represent indicators of threat or compromise related to the contents of an article.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ArticleIndicatorCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/security-article-list-indicators?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<IndicatorsRequestBuilderGetQueryParameters> | undefined): Promise<ArticleIndicatorCollectionResponse | undefined>;
    /**
     * Get a list of articleIndicator objects that represent indicators of threat or compromise related to the contents of an article.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<IndicatorsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a indicatorsRequestBuilder
     */
    withUrl(rawUrl: string): IndicatorsRequestBuilder;
}
