import { type HostCookieCollectionResponse } from '../../../models/security/';
import { type HostCookie } from '../../../models/security/hostCookie';
import { CountRequestBuilder } from './count/';
import { HostCookieItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface HostCookiesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the hostCookies property of the microsoft.graph.security.threatIntelligence entity.
 */
export declare class HostCookiesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the hostCookies property of the microsoft.graph.security.threatIntelligence entity.
     * @param hostCookieId The unique identifier of hostCookie
     * @returns a HostCookieItemRequestBuilder
     */
    byHostCookieId(hostCookieId: string): HostCookieItemRequestBuilder;
    /**
     * Instantiates a new HostCookiesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Read the properties and relationships of a hostCookie object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostCookieCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<HostCookiesRequestBuilderGetQueryParameters> | undefined): Promise<HostCookieCollectionResponse | undefined>;
    /**
     * Create new navigation property to hostCookies for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostCookie
     */
    post(body: HostCookie, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<HostCookie | undefined>;
    /**
     * Read the properties and relationships of a hostCookie object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<HostCookiesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to hostCookies for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: HostCookie, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a hostCookiesRequestBuilder
     */
    withUrl(rawUrl: string): HostCookiesRequestBuilder;
}
