import { type HostPairCollectionResponse } from '../../../models/security/';
import { type HostPair } from '../../../models/security/hostPair';
import { CountRequestBuilder } from './count/';
import { HostPairItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface HostPairsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the hostPairs property of the microsoft.graph.security.threatIntelligence entity.
 */
export declare class HostPairsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the hostPairs property of the microsoft.graph.security.threatIntelligence entity.
     * @param hostPairId The unique identifier of hostPair
     * @returns a HostPairItemRequestBuilder
     */
    byHostPairId(hostPairId: string): HostPairItemRequestBuilder;
    /**
     * Instantiates a new HostPairsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Read the properties and relationships of a hostPair object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostPairCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<HostPairsRequestBuilderGetQueryParameters> | undefined): Promise<HostPairCollectionResponse | undefined>;
    /**
     * Create new navigation property to hostPairs for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostPair
     */
    post(body: HostPair, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<HostPair | undefined>;
    /**
     * Read the properties and relationships of a hostPair object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<HostPairsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to hostPairs for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: HostPair, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a hostPairsRequestBuilder
     */
    withUrl(rawUrl: string): HostPairsRequestBuilder;
}
