import { type HostPair } from '../../../../models/security/hostPair';
import { ChildHostRequestBuilder } from './childHost/';
import { ParentHostRequestBuilder } from './parentHost/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface HostPairItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the hostPairs property of the microsoft.graph.security.threatIntelligence entity.
 */
export declare class HostPairItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the childHost property of the microsoft.graph.security.hostPair entity.
     */
    get childHost(): ChildHostRequestBuilder;
    /**
     * Provides operations to manage the parentHost property of the microsoft.graph.security.hostPair entity.
     */
    get parentHost(): ParentHostRequestBuilder;
    /**
     * Instantiates a new HostPairItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property hostPairs for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of a hostPair object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostPair
     * @see {@link https://learn.microsoft.com/graph/api/security-hostpair-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<HostPairItemRequestBuilderGetQueryParameters> | undefined): Promise<HostPair | undefined>;
    /**
     * Update the navigation property hostPairs in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostPair
     */
    patch(body: HostPair, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<HostPair | undefined>;
    /**
     * Delete navigation property hostPairs for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of a hostPair object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<HostPairItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property hostPairs in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: HostPair, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a HostPairItemRequestBuilder
     */
    withUrl(rawUrl: string): HostPairItemRequestBuilder;
}
