import { type HostPortCollectionResponse } from '../../../models/security/';
import { type HostPort } from '../../../models/security/hostPort';
import { CountRequestBuilder } from './count/';
import { HostPortItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface HostPortsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the hostPorts property of the microsoft.graph.security.threatIntelligence entity.
 */
export declare class HostPortsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the hostPorts property of the microsoft.graph.security.threatIntelligence entity.
     * @param hostPortId The unique identifier of hostPort
     * @returns a HostPortItemRequestBuilder
     */
    byHostPortId(hostPortId: string): HostPortItemRequestBuilder;
    /**
     * Instantiates a new HostPortsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Read the properties and relationships of a hostPort object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostPortCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<HostPortsRequestBuilderGetQueryParameters> | undefined): Promise<HostPortCollectionResponse | undefined>;
    /**
     * Create new navigation property to hostPorts for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostPort
     */
    post(body: HostPort, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<HostPort | undefined>;
    /**
     * Read the properties and relationships of a hostPort object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<HostPortsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to hostPorts for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: HostPort, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a hostPortsRequestBuilder
     */
    withUrl(rawUrl: string): HostPortsRequestBuilder;
}
