import { type HostPort } from '../../../../models/security/hostPort';
import { HostRequestBuilder } from './host/';
import { MostRecentSslCertificateRequestBuilder } from './mostRecentSslCertificate/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface HostPortItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the hostPorts property of the microsoft.graph.security.threatIntelligence entity.
 */
export declare class HostPortItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the host property of the microsoft.graph.security.hostPort entity.
     */
    get host(): HostRequestBuilder;
    /**
     * Provides operations to manage the mostRecentSslCertificate property of the microsoft.graph.security.hostPort entity.
     */
    get mostRecentSslCertificate(): MostRecentSslCertificateRequestBuilder;
    /**
     * Instantiates a new HostPortItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property hostPorts for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of a hostPort object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostPort
     * @see {@link https://learn.microsoft.com/graph/api/security-hostport-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<HostPortItemRequestBuilderGetQueryParameters> | undefined): Promise<HostPort | undefined>;
    /**
     * Update the navigation property hostPorts in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of HostPort
     */
    patch(body: HostPort, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<HostPort | undefined>;
    /**
     * Delete navigation property hostPorts for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of a hostPort object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<HostPortItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property hostPorts in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: HostPort, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a HostPortItemRequestBuilder
     */
    withUrl(rawUrl: string): HostPortItemRequestBuilder;
}
