import { type Host } from '../../../../models/security/host';
import { ChildHostPairsRequestBuilder } from './childHostPairs/';
import { ComponentsRequestBuilder } from './components/';
import { CookiesRequestBuilder } from './cookies/';
import { HostPairsRequestBuilder } from './hostPairs/';
import { ParentHostPairsRequestBuilder } from './parentHostPairs/';
import { PassiveDnsRequestBuilder } from './passiveDns/';
import { PassiveDnsReverseRequestBuilder } from './passiveDnsReverse/';
import { PortsRequestBuilder } from './ports/';
import { ReputationRequestBuilder } from './reputation/';
import { SslCertificatesRequestBuilder } from './sslCertificates/';
import { SubdomainsRequestBuilder } from './subdomains/';
import { TrackersRequestBuilder } from './trackers/';
import { WhoisRequestBuilder } from './whois/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface HostItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the hosts property of the microsoft.graph.security.threatIntelligence entity.
 */
export declare class HostItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the childHostPairs property of the microsoft.graph.security.host entity.
     */
    get childHostPairs(): ChildHostPairsRequestBuilder;
    /**
     * Provides operations to manage the components property of the microsoft.graph.security.host entity.
     */
    get components(): ComponentsRequestBuilder;
    /**
     * Provides operations to manage the cookies property of the microsoft.graph.security.host entity.
     */
    get cookies(): CookiesRequestBuilder;
    /**
     * Provides operations to manage the hostPairs property of the microsoft.graph.security.host entity.
     */
    get hostPairs(): HostPairsRequestBuilder;
    /**
     * Provides operations to manage the parentHostPairs property of the microsoft.graph.security.host entity.
     */
    get parentHostPairs(): ParentHostPairsRequestBuilder;
    /**
     * Provides operations to manage the passiveDns property of the microsoft.graph.security.host entity.
     */
    get passiveDns(): PassiveDnsRequestBuilder;
    /**
     * Provides operations to manage the passiveDnsReverse property of the microsoft.graph.security.host entity.
     */
    get passiveDnsReverse(): PassiveDnsReverseRequestBuilder;
    /**
     * Provides operations to manage the ports property of the microsoft.graph.security.host entity.
     */
    get ports(): PortsRequestBuilder;
    /**
     * Provides operations to manage the reputation property of the microsoft.graph.security.host entity.
     */
    get reputation(): ReputationRequestBuilder;
    /**
     * Provides operations to manage the sslCertificates property of the microsoft.graph.security.host entity.
     */
    get sslCertificates(): SslCertificatesRequestBuilder;
    /**
     * Provides operations to manage the subdomains property of the microsoft.graph.security.host entity.
     */
    get subdomains(): SubdomainsRequestBuilder;
    /**
     * Provides operations to manage the trackers property of the microsoft.graph.security.host entity.
     */
    get trackers(): TrackersRequestBuilder;
    /**
     * Provides operations to manage the whois property of the microsoft.graph.security.host entity.
     */
    get whois(): WhoisRequestBuilder;
    /**
     * Instantiates a new HostItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property hosts for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of a host object. The host resource is the abstract base type that returns an implementation. A host can be of one of the following types:
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Host
     * @see {@link https://learn.microsoft.com/graph/api/security-host-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<HostItemRequestBuilderGetQueryParameters> | undefined): Promise<Host | undefined>;
    /**
     * Update the navigation property hosts in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Host
     */
    patch(body: Host, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Host | undefined>;
    /**
     * Delete navigation property hosts for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of a host object. The host resource is the abstract base type that returns an implementation. A host can be of one of the following types:
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<HostItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property hosts in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Host, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a HostItemRequestBuilder
     */
    withUrl(rawUrl: string): HostItemRequestBuilder;
}
