import { type PassiveDnsRecordCollectionResponse } from '../../../../../models/security/';
import { CountRequestBuilder } from './count/';
import { PassiveDnsRecordItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface PassiveDnsReverseRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the passiveDnsReverse property of the microsoft.graph.security.host entity.
 */
export declare class PassiveDnsReverseRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the passiveDnsReverse property of the microsoft.graph.security.host entity.
     * @param passiveDnsRecordId The unique identifier of passiveDnsRecord
     * @returns a PassiveDnsRecordItemRequestBuilder
     */
    byPassiveDnsRecordId(passiveDnsRecordId: string): PassiveDnsRecordItemRequestBuilder;
    /**
     * Instantiates a new PassiveDnsReverseRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a collection of passiveDnsRecord resources from a reverse passive DNS retrieval.  A reverse DNS lookup queries the hostname of a host using an IP address.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PassiveDnsRecordCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/security-host-list-passivednsreverse?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<PassiveDnsReverseRequestBuilderGetQueryParameters> | undefined): Promise<PassiveDnsRecordCollectionResponse | undefined>;
    /**
     * Get a collection of passiveDnsRecord resources from a reverse passive DNS retrieval.  A reverse DNS lookup queries the hostname of a host using an IP address.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<PassiveDnsReverseRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a passiveDnsReverseRequestBuilder
     */
    withUrl(rawUrl: string): PassiveDnsReverseRequestBuilder;
}
