import { type SubdomainCollectionResponse } from '../../../../../models/security/';
import { CountRequestBuilder } from './count/';
import { SubdomainItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SubdomainsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the subdomains property of the microsoft.graph.security.host entity.
 */
export declare class SubdomainsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the subdomains property of the microsoft.graph.security.host entity.
     * @param subdomainId The unique identifier of subdomain
     * @returns a SubdomainItemRequestBuilder
     */
    bySubdomainId(subdomainId: string): SubdomainItemRequestBuilder;
    /**
     * Instantiates a new SubdomainsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the list of subdomain resources associated with a host.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SubdomainCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/security-host-list-subdomains?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SubdomainsRequestBuilderGetQueryParameters> | undefined): Promise<SubdomainCollectionResponse | undefined>;
    /**
     * Get the list of subdomain resources associated with a host.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SubdomainsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a subdomainsRequestBuilder
     */
    withUrl(rawUrl: string): SubdomainsRequestBuilder;
}
