import { type IntelligenceProfileCollectionResponse } from '../../../models/security/';
import { type IntelligenceProfile } from '../../../models/security/intelligenceProfile';
import { CountRequestBuilder } from './count/';
import { IntelligenceProfileItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface IntelProfilesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the intelProfiles property of the microsoft.graph.security.threatIntelligence entity.
 */
export declare class IntelProfilesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the intelProfiles property of the microsoft.graph.security.threatIntelligence entity.
     * @param intelligenceProfileId The unique identifier of intelligenceProfile
     * @returns a IntelligenceProfileItemRequestBuilder
     */
    byIntelligenceProfileId(intelligenceProfileId: string): IntelligenceProfileItemRequestBuilder;
    /**
     * Instantiates a new IntelProfilesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the intelligenceProfile objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IntelligenceProfileCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/security-threatintelligence-list-intelprofiles?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<IntelProfilesRequestBuilderGetQueryParameters> | undefined): Promise<IntelligenceProfileCollectionResponse | undefined>;
    /**
     * Create new navigation property to intelProfiles for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IntelligenceProfile
     */
    post(body: IntelligenceProfile, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<IntelligenceProfile | undefined>;
    /**
     * Get a list of the intelligenceProfile objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<IntelProfilesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to intelProfiles for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: IntelligenceProfile, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a intelProfilesRequestBuilder
     */
    withUrl(rawUrl: string): IntelProfilesRequestBuilder;
}
