import { type IntelligenceProfileIndicatorCollectionResponse } from '../../../models/security/';
import { type IntelligenceProfileIndicator } from '../../../models/security/intelligenceProfileIndicator';
import { CountRequestBuilder } from './count/';
import { IntelligenceProfileIndicatorItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface IntelligenceProfileIndicatorsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the intelligenceProfileIndicators property of the microsoft.graph.security.threatIntelligence entity.
 */
export declare class IntelligenceProfileIndicatorsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the intelligenceProfileIndicators property of the microsoft.graph.security.threatIntelligence entity.
     * @param intelligenceProfileIndicatorId The unique identifier of intelligenceProfileIndicator
     * @returns a IntelligenceProfileIndicatorItemRequestBuilder
     */
    byIntelligenceProfileIndicatorId(intelligenceProfileIndicatorId: string): IntelligenceProfileIndicatorItemRequestBuilder;
    /**
     * Instantiates a new IntelligenceProfileIndicatorsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Read the properties and relationships of a intelligenceProfileIndicator object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IntelligenceProfileIndicatorCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<IntelligenceProfileIndicatorsRequestBuilderGetQueryParameters> | undefined): Promise<IntelligenceProfileIndicatorCollectionResponse | undefined>;
    /**
     * Create new navigation property to intelligenceProfileIndicators for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of IntelligenceProfileIndicator
     */
    post(body: IntelligenceProfileIndicator, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<IntelligenceProfileIndicator | undefined>;
    /**
     * Read the properties and relationships of a intelligenceProfileIndicator object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<IntelligenceProfileIndicatorsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to intelligenceProfileIndicators for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: IntelligenceProfileIndicator, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a intelligenceProfileIndicatorsRequestBuilder
     */
    withUrl(rawUrl: string): IntelligenceProfileIndicatorsRequestBuilder;
}
