import { type PassiveDnsRecord } from '../../../../models/security/passiveDnsRecord';
import { ArtifactRequestBuilder } from './artifact/';
import { ParentHostRequestBuilder } from './parentHost/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface PassiveDnsRecordItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the passiveDnsRecords property of the microsoft.graph.security.threatIntelligence entity.
 */
export declare class PassiveDnsRecordItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the artifact property of the microsoft.graph.security.passiveDnsRecord entity.
     */
    get artifact(): ArtifactRequestBuilder;
    /**
     * Provides operations to manage the parentHost property of the microsoft.graph.security.passiveDnsRecord entity.
     */
    get parentHost(): ParentHostRequestBuilder;
    /**
     * Instantiates a new PassiveDnsRecordItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property passiveDnsRecords for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of a passiveDnsRecord object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PassiveDnsRecord
     * @see {@link https://learn.microsoft.com/graph/api/security-passivednsrecord-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<PassiveDnsRecordItemRequestBuilderGetQueryParameters> | undefined): Promise<PassiveDnsRecord | undefined>;
    /**
     * Update the navigation property passiveDnsRecords in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PassiveDnsRecord
     */
    patch(body: PassiveDnsRecord, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<PassiveDnsRecord | undefined>;
    /**
     * Delete navigation property passiveDnsRecords for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of a passiveDnsRecord object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<PassiveDnsRecordItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property passiveDnsRecords in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: PassiveDnsRecord, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a PassiveDnsRecordItemRequestBuilder
     */
    withUrl(rawUrl: string): PassiveDnsRecordItemRequestBuilder;
}
