import { type SslCertificate } from '../../../../models/security/sslCertificate';
import { RelatedHostsRequestBuilder } from './relatedHosts/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SslCertificateItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the sslCertificates property of the microsoft.graph.security.threatIntelligence entity.
 */
export declare class SslCertificateItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the relatedHosts property of the microsoft.graph.security.sslCertificate entity.
     */
    get relatedHosts(): RelatedHostsRequestBuilder;
    /**
     * Instantiates a new SslCertificateItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property sslCertificates for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Get the properties and relationships of an sslCertificate object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SslCertificate
     * @see {@link https://learn.microsoft.com/graph/api/security-sslcertificate-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SslCertificateItemRequestBuilderGetQueryParameters> | undefined): Promise<SslCertificate | undefined>;
    /**
     * Update the navigation property sslCertificates in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SslCertificate
     */
    patch(body: SslCertificate, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<SslCertificate | undefined>;
    /**
     * Delete navigation property sslCertificates for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Get the properties and relationships of an sslCertificate object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SslCertificateItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property sslCertificates in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: SslCertificate, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a SslCertificateItemRequestBuilder
     */
    withUrl(rawUrl: string): SslCertificateItemRequestBuilder;
}
