import { type RetentionEventTypeCollectionResponse } from '../../../models/security/';
import { type RetentionEventType } from '../../../models/security/retentionEventType';
import { CountRequestBuilder } from './count/';
import { RetentionEventTypeItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface RetentionEventTypesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the retentionEventTypes property of the microsoft.graph.security.triggerTypesRoot entity.
 */
export declare class RetentionEventTypesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the retentionEventTypes property of the microsoft.graph.security.triggerTypesRoot entity.
     * @param retentionEventTypeId The unique identifier of retentionEventType
     * @returns a RetentionEventTypeItemRequestBuilder
     */
    byRetentionEventTypeId(retentionEventTypeId: string): RetentionEventTypeItemRequestBuilder;
    /**
     * Instantiates a new RetentionEventTypesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the retentionEventType objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RetentionEventTypeCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/security-retentioneventtype-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<RetentionEventTypesRequestBuilderGetQueryParameters> | undefined): Promise<RetentionEventTypeCollectionResponse | undefined>;
    /**
     * Create a new retentionEventType object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RetentionEventType
     * @see {@link https://learn.microsoft.com/graph/api/security-retentioneventtype-post?view=graph-rest-1.0|Find more info here}
     */
    post(body: RetentionEventType, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<RetentionEventType | undefined>;
    /**
     * Get a list of the retentionEventType objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<RetentionEventTypesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new retentionEventType object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: RetentionEventType, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a retentionEventTypesRequestBuilder
     */
    withUrl(rawUrl: string): RetentionEventTypesRequestBuilder;
}
