import { type KeyCredential } from '../../../models/keyCredential';
import { type PasswordCredential } from '../../../models/passwordCredential';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export interface AddKeyPostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The keyCredential property
     */
    keyCredential?: KeyCredential;
    /**
     * The passwordCredential property
     */
    passwordCredential?: PasswordCredential;
    /**
     * The proof property
     */
    proof?: string;
}
export declare function createAddKeyPostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoAddKeyPostRequestBody;
export declare function deserializeIntoAddKeyPostRequestBody(addKeyPostRequestBody?: AddKeyPostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeAddKeyPostRequestBody(writer: SerializationWriter, addKeyPostRequestBody?: AddKeyPostRequestBody | undefined): void;
/**
 * Provides operations to call the addKey method.
 */
export declare class AddKeyRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new AddKeyRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Adds a key credential to a servicePrincipal. This method along with removeKey can be used by a servicePrincipal to automate rolling its expiring keys. As part of the request validation for this method, a proof of possession of an existing key is verified before the action can be performed.  ServicePrincipals that don’t have any existing valid certificates (i.e.: no certificates have been added yet, or all certificates have expired), won’t be able to use this service action. Update servicePrincipal can be used to perform an update instead.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of KeyCredential
     * @see {@link https://learn.microsoft.com/graph/api/serviceprincipal-addkey?view=graph-rest-1.0|Find more info here}
     */
    post(body: AddKeyPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<KeyCredential | undefined>;
    /**
     * Adds a key credential to a servicePrincipal. This method along with removeKey can be used by a servicePrincipal to automate rolling its expiring keys. As part of the request validation for this method, a proof of possession of an existing key is verified before the action can be performed.  ServicePrincipals that don’t have any existing valid certificates (i.e.: no certificates have been added yet, or all certificates have expired), won’t be able to use this service action. Update servicePrincipal can be used to perform an update instead.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AddKeyPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a addKeyRequestBuilder
     */
    withUrl(rawUrl: string): AddKeyRequestBuilder;
}
