"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AddPasswordRequestBuilder = exports.serializeAddPasswordPostRequestBody = exports.deserializeIntoAddPasswordPostRequestBody = exports.createAddPasswordPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const passwordCredential_1 = require("../../../models/passwordCredential");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createAddPasswordPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoAddPasswordPostRequestBody;
}
exports.createAddPasswordPostRequestBodyFromDiscriminatorValue = createAddPasswordPostRequestBodyFromDiscriminatorValue;
function deserializeIntoAddPasswordPostRequestBody(addPasswordPostRequestBody = {}) {
    return {
        "passwordCredential": n => { addPasswordPostRequestBody.passwordCredential = n.getObjectValue(passwordCredential_1.createPasswordCredentialFromDiscriminatorValue); },
    };
}
exports.deserializeIntoAddPasswordPostRequestBody = deserializeIntoAddPasswordPostRequestBody;
function serializeAddPasswordPostRequestBody(writer, addPasswordPostRequestBody = {}) {
    writer.writeObjectValue("passwordCredential", addPasswordPostRequestBody.passwordCredential, passwordCredential_1.serializePasswordCredential);
    writer.writeAdditionalData(addPasswordPostRequestBody.additionalData);
}
exports.serializeAddPasswordPostRequestBody = serializeAddPasswordPostRequestBody;
/**
 * Provides operations to call the addPassword method.
 */
class AddPasswordRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new AddPasswordRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/servicePrincipals/{servicePrincipal%2Did}/addPassword");
    }
    ;
    /**
     * Add a strong password or secret to a servicePrincipal object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PasswordCredential
     * @see {@link https://learn.microsoft.com/graph/api/serviceprincipal-addpassword?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, passwordCredential_1.createPasswordCredentialFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Add a strong password or secret to a servicePrincipal object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeAddPasswordPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a addPasswordRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new AddPasswordRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.AddPasswordRequestBuilder = AddPasswordRequestBuilder;
// tslint:enable
// eslint-enable
