"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RemoveKeyRequestBuilder = exports.serializeRemoveKeyPostRequestBody = exports.deserializeIntoRemoveKeyPostRequestBody = exports.createRemoveKeyPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createRemoveKeyPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoRemoveKeyPostRequestBody;
}
exports.createRemoveKeyPostRequestBodyFromDiscriminatorValue = createRemoveKeyPostRequestBodyFromDiscriminatorValue;
function deserializeIntoRemoveKeyPostRequestBody(removeKeyPostRequestBody = {}) {
    return {
        "keyId": n => { removeKeyPostRequestBody.keyId = n.getGuidValue(); },
        "proof": n => { removeKeyPostRequestBody.proof = n.getStringValue(); },
    };
}
exports.deserializeIntoRemoveKeyPostRequestBody = deserializeIntoRemoveKeyPostRequestBody;
function serializeRemoveKeyPostRequestBody(writer, removeKeyPostRequestBody = {}) {
    writer.writeGuidValue("keyId", removeKeyPostRequestBody.keyId);
    writer.writeStringValue("proof", removeKeyPostRequestBody.proof);
    writer.writeAdditionalData(removeKeyPostRequestBody.additionalData);
}
exports.serializeRemoveKeyPostRequestBody = serializeRemoveKeyPostRequestBody;
/**
 * Provides operations to call the removeKey method.
 */
class RemoveKeyRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new RemoveKeyRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/servicePrincipals/{servicePrincipal%2Did}/removeKey");
    }
    ;
    /**
     * Remove a key credential from a servicePrincipal. This method along with addKey can be used by a servicePrincipal to automate rolling its expiring keys. As part of the request validation for this method, a proof of possession of an existing key is verified before the action can be performed.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/serviceprincipal-removekey?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Remove a key credential from a servicePrincipal. This method along with addKey can be used by a servicePrincipal to automate rolling its expiring keys. As part of the request validation for this method, a proof of possession of an existing key is verified before the action can be performed.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeRemoveKeyPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a removeKeyRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new RemoveKeyRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.RemoveKeyRequestBuilder = RemoveKeyRequestBuilder;
// tslint:enable
// eslint-enable
