import { type SynchronizationSchema } from '../../../../../../models/synchronizationSchema';
import { DirectoriesRequestBuilder } from './directories/';
import { FilterOperatorsRequestBuilder } from './filterOperators/';
import { FunctionsRequestBuilder } from './functions/';
import { ParseExpressionRequestBuilder } from './parseExpression/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SchemaRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the schema property of the microsoft.graph.synchronizationJob entity.
 */
export declare class SchemaRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the directories property of the microsoft.graph.synchronizationSchema entity.
     */
    get directories(): DirectoriesRequestBuilder;
    /**
     * Provides operations to call the filterOperators method.
     */
    get filterOperators(): FilterOperatorsRequestBuilder;
    /**
     * Provides operations to call the functions method.
     */
    get functions(): FunctionsRequestBuilder;
    /**
     * Provides operations to call the parseExpression method.
     */
    get parseExpression(): ParseExpressionRequestBuilder;
    /**
     * Instantiates a new SchemaRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property schema for servicePrincipals
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the schema for a given synchronization job or template.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SynchronizationSchema
     * @see {@link https://learn.microsoft.com/graph/api/synchronization-synchronizationschema-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SchemaRequestBuilderGetQueryParameters> | undefined): Promise<SynchronizationSchema | undefined>;
    /**
     * Update the synchronization schema for a given job or template. This method fully replaces the current schema with the one provided in the request. To update the schema of a template, make the call on the application object. You must be the owner of the application.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SynchronizationSchema
     * @see {@link https://learn.microsoft.com/graph/api/synchronization-synchronizationschema-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: SynchronizationSchema, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<SynchronizationSchema | undefined>;
    /**
     * Delete navigation property schema for servicePrincipals
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the schema for a given synchronization job or template.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SchemaRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the synchronization schema for a given job or template. This method fully replaces the current schema with the one provided in the request. To update the schema of a template, make the call on the application object. You must be the owner of the application.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: SynchronizationSchema, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a schemaRequestBuilder
     */
    withUrl(rawUrl: string): SchemaRequestBuilder;
}
