import { type SharedDriveItem } from '../../models/sharedDriveItem';
import { CreatedByUserRequestBuilder } from './createdByUser/';
import { DriveItemRequestBuilder } from './driveItem/';
import { ItemsRequestBuilder } from './items/';
import { LastModifiedByUserRequestBuilder } from './lastModifiedByUser/';
import { ListRequestBuilder } from './list/';
import { ListItemRequestBuilder } from './listItem/';
import { PermissionRequestBuilder } from './permission/';
import { RootRequestBuilder } from './root/';
import { SiteRequestBuilder } from './site/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SharedDriveItemItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the collection of sharedDriveItem entities.
 */
export declare class SharedDriveItemItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the createdByUser property of the microsoft.graph.baseItem entity.
     */
    get createdByUser(): CreatedByUserRequestBuilder;
    /**
     * Provides operations to manage the driveItem property of the microsoft.graph.sharedDriveItem entity.
     */
    get driveItem(): DriveItemRequestBuilder;
    /**
     * Provides operations to manage the items property of the microsoft.graph.sharedDriveItem entity.
     */
    get items(): ItemsRequestBuilder;
    /**
     * Provides operations to manage the lastModifiedByUser property of the microsoft.graph.baseItem entity.
     */
    get lastModifiedByUser(): LastModifiedByUserRequestBuilder;
    /**
     * Provides operations to manage the list property of the microsoft.graph.sharedDriveItem entity.
     */
    get list(): ListRequestBuilder;
    /**
     * Provides operations to manage the listItem property of the microsoft.graph.sharedDriveItem entity.
     */
    get listItem(): ListItemRequestBuilder;
    /**
     * Provides operations to manage the permission property of the microsoft.graph.sharedDriveItem entity.
     */
    get permission(): PermissionRequestBuilder;
    /**
     * Provides operations to manage the root property of the microsoft.graph.sharedDriveItem entity.
     */
    get root(): RootRequestBuilder;
    /**
     * Provides operations to manage the site property of the microsoft.graph.sharedDriveItem entity.
     */
    get site(): SiteRequestBuilder;
    /**
     * Instantiates a new SharedDriveItemItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from shares
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Access a shared DriveItem or a collection of shared items by using a shareId or sharing URL. To use a sharing URL with this API, your app needs to transform the URL into a sharing token.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SharedDriveItem
     * @see {@link https://learn.microsoft.com/graph/api/shares-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SharedDriveItemItemRequestBuilderGetQueryParameters> | undefined): Promise<SharedDriveItem | undefined>;
    /**
     * Update entity in shares
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SharedDriveItem
     */
    patch(body: SharedDriveItem, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<SharedDriveItem | undefined>;
    /**
     * Delete entity from shares
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Access a shared DriveItem or a collection of shared items by using a shareId or sharing URL. To use a sharing URL with this API, your app needs to transform the URL into a sharing token.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SharedDriveItemItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update entity in shares
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: SharedDriveItem, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a SharedDriveItemItemRequestBuilder
     */
    withUrl(rawUrl: string): SharedDriveItemItemRequestBuilder;
}
