import { type ItemAnalytics } from '../../../models/itemAnalytics';
import { AllTimeRequestBuilder } from './allTime/';
import { ItemActivityStatsRequestBuilder } from './itemActivityStats/';
import { LastSevenDaysRequestBuilder } from './lastSevenDays/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AnalyticsRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the analytics property of the microsoft.graph.site entity.
 */
export declare class AnalyticsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the allTime property of the microsoft.graph.itemAnalytics entity.
     */
    get allTime(): AllTimeRequestBuilder;
    /**
     * Provides operations to manage the itemActivityStats property of the microsoft.graph.itemAnalytics entity.
     */
    get itemActivityStats(): ItemActivityStatsRequestBuilder;
    /**
     * Provides operations to manage the lastSevenDays property of the microsoft.graph.itemAnalytics entity.
     */
    get lastSevenDays(): LastSevenDaysRequestBuilder;
    /**
     * Instantiates a new AnalyticsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property analytics for sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Analytics about the view activities that took place in this site.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ItemAnalytics
     */
    get(requestConfiguration?: RequestConfiguration<AnalyticsRequestBuilderGetQueryParameters> | undefined): Promise<ItemAnalytics | undefined>;
    /**
     * Update the navigation property analytics in sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ItemAnalytics
     */
    patch(body: ItemAnalytics, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ItemAnalytics | undefined>;
    /**
     * Delete navigation property analytics for sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Analytics about the view activities that took place in this site.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AnalyticsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property analytics in sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ItemAnalytics, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a analyticsRequestBuilder
     */
    withUrl(rawUrl: string): AnalyticsRequestBuilder;
}
