import { type ItemActivityStatCollectionResponse } from '../../../../models/';
import { type ItemActivityStat } from '../../../../models/itemActivityStat';
import { CountRequestBuilder } from './count/';
import { ItemActivityStatItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ItemActivityStatsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the itemActivityStats property of the microsoft.graph.itemAnalytics entity.
 */
export declare class ItemActivityStatsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the itemActivityStats property of the microsoft.graph.itemAnalytics entity.
     * @param itemActivityStatId The unique identifier of itemActivityStat
     * @returns a ItemActivityStatItemRequestBuilder
     */
    byItemActivityStatId(itemActivityStatId: string): ItemActivityStatItemRequestBuilder;
    /**
     * Instantiates a new ItemActivityStatsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get itemActivityStats from sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ItemActivityStatCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<ItemActivityStatsRequestBuilderGetQueryParameters> | undefined): Promise<ItemActivityStatCollectionResponse | undefined>;
    /**
     * Create new navigation property to itemActivityStats for sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ItemActivityStat
     */
    post(body: ItemActivityStat, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ItemActivityStat | undefined>;
    /**
     * Get itemActivityStats from sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ItemActivityStatsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to itemActivityStats for sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ItemActivityStat, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a itemActivityStatsRequestBuilder
     */
    withUrl(rawUrl: string): ItemActivityStatsRequestBuilder;
}
