import { type ContentType } from '../../../../models/contentType';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export interface AddCopyPostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The contentType property
     */
    contentType?: string;
}
export declare function createAddCopyPostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoAddCopyPostRequestBody;
export declare function deserializeIntoAddCopyPostRequestBody(addCopyPostRequestBody?: AddCopyPostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeAddCopyPostRequestBody(writer: SerializationWriter, addCopyPostRequestBody?: AddCopyPostRequestBody | undefined): void;
/**
 * Provides operations to call the addCopy method.
 */
export declare class AddCopyRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new AddCopyRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Add a copy of a [content type][contentType] from a [site][site] to a [list][list].
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ContentType
     * @see {@link https://learn.microsoft.com/graph/api/contenttype-addcopy?view=graph-rest-1.0|Find more info here}
     */
    post(body: AddCopyPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ContentType | undefined>;
    /**
     * Add a copy of a [content type][contentType] from a [site][site] to a [list][list].
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: AddCopyPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a addCopyRequestBuilder
     */
    withUrl(rawUrl: string): AddCopyRequestBuilder;
}
