import { type ContentTypeCollectionResponse } from '../../../../../models/';
import { CountRequestBuilder } from './count/';
import { ContentTypeItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface BaseTypesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the baseTypes property of the microsoft.graph.contentType entity.
 */
export declare class BaseTypesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the baseTypes property of the microsoft.graph.contentType entity.
     * @param contentTypeId1 The unique identifier of contentType
     * @returns a ContentTypeItemRequestBuilder
     */
    byContentTypeId1(contentTypeId1: string): ContentTypeItemRequestBuilder;
    /**
     * Instantiates a new BaseTypesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The collection of content types that are ancestors of this content type.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ContentTypeCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<BaseTypesRequestBuilderGetQueryParameters> | undefined): Promise<ContentTypeCollectionResponse | undefined>;
    /**
     * The collection of content types that are ancestors of this content type.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<BaseTypesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a baseTypesRequestBuilder
     */
    withUrl(rawUrl: string): BaseTypesRequestBuilder;
}
