"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SiteItemRequestBuilder = void 0;
const oDataError_1 = require("../../models/oDataErrors/oDataError");
const site_1 = require("../../models/site");
const analytics_1 = require("./analytics/");
const columns_1 = require("./columns/");
const contentTypes_1 = require("./contentTypes/");
const createdByUser_1 = require("./createdByUser/");
const drive_1 = require("./drive/");
const drives_1 = require("./drives/");
const externalColumns_1 = require("./externalColumns/");
const getActivitiesByInterval_1 = require("./getActivitiesByInterval/");
const getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval_1 = require("./getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval/");
const getApplicableContentTypesForListWithListId_1 = require("./getApplicableContentTypesForListWithListId/");
const getByPathWithPath_1 = require("./getByPathWithPath/");
const items_1 = require("./items/");
const lastModifiedByUser_1 = require("./lastModifiedByUser/");
const lists_1 = require("./lists/");
const onenote_1 = require("./onenote/");
const operations_1 = require("./operations/");
const permissions_1 = require("./permissions/");
const sites_1 = require("./sites/");
const termStore_1 = require("./termStore/");
const termStores_1 = require("./termStores/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the collection of site entities.
 */
class SiteItemRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to manage the analytics property of the microsoft.graph.site entity.
     */
    get analytics() {
        return new analytics_1.AnalyticsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the columns property of the microsoft.graph.site entity.
     */
    get columns() {
        return new columns_1.ColumnsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the contentTypes property of the microsoft.graph.site entity.
     */
    get contentTypes() {
        return new contentTypes_1.ContentTypesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the createdByUser property of the microsoft.graph.baseItem entity.
     */
    get createdByUser() {
        return new createdByUser_1.CreatedByUserRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the drive property of the microsoft.graph.site entity.
     */
    get drive() {
        return new drive_1.DriveRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the drives property of the microsoft.graph.site entity.
     */
    get drives() {
        return new drives_1.DrivesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the externalColumns property of the microsoft.graph.site entity.
     */
    get externalColumns() {
        return new externalColumns_1.ExternalColumnsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the getActivitiesByInterval method.
     */
    get getActivitiesByInterval() {
        return new getActivitiesByInterval_1.GetActivitiesByIntervalRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the items property of the microsoft.graph.site entity.
     */
    get items() {
        return new items_1.ItemsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the lastModifiedByUser property of the microsoft.graph.baseItem entity.
     */
    get lastModifiedByUser() {
        return new lastModifiedByUser_1.LastModifiedByUserRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the lists property of the microsoft.graph.site entity.
     */
    get lists() {
        return new lists_1.ListsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the onenote property of the microsoft.graph.site entity.
     */
    get onenote() {
        return new onenote_1.OnenoteRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the operations property of the microsoft.graph.site entity.
     */
    get operations() {
        return new operations_1.OperationsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the permissions property of the microsoft.graph.site entity.
     */
    get permissions() {
        return new permissions_1.PermissionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the sites property of the microsoft.graph.site entity.
     */
    get sites() {
        return new sites_1.SitesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the termStore property of the microsoft.graph.site entity.
     */
    get termStore() {
        return new termStore_1.TermStoreRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the termStores property of the microsoft.graph.site entity.
     */
    get termStores() {
        return new termStores_1.TermStoresRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new SiteItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/sites/{site%2Did}{?%24select,%24expand}");
    }
    ;
    /**
     * Retrieve properties and relationships for a [site][] resource.A site resource represents a team site in SharePoint.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Site
     * @see {@link https://learn.microsoft.com/graph/api/site-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, site_1.createSiteFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Provides operations to call the getActivitiesByInterval method.
     * @param endDateTime Usage: endDateTime='{endDateTime}'
     * @param interval Usage: interval='{interval}'
     * @param startDateTime Usage: startDateTime='{startDateTime}'
     * @returns a getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder
     */
    getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval(endDateTime, interval, startDateTime) {
        if (!endDateTime)
            throw new Error("endDateTime cannot be undefined");
        if (!interval)
            throw new Error("interval cannot be undefined");
        if (!startDateTime)
            throw new Error("startDateTime cannot be undefined");
        return new getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval_1.GetActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder(this.pathParameters, this.requestAdapter, endDateTime, interval, startDateTime);
    }
    ;
    /**
     * Provides operations to call the getApplicableContentTypesForList method.
     * @param listId Usage: listId='{listId}'
     * @returns a getApplicableContentTypesForListWithListIdRequestBuilder
     */
    getApplicableContentTypesForListWithListId(listId) {
        if (!listId)
            throw new Error("listId cannot be undefined");
        return new getApplicableContentTypesForListWithListId_1.GetApplicableContentTypesForListWithListIdRequestBuilder(this.pathParameters, this.requestAdapter, listId);
    }
    ;
    /**
     * Provides operations to call the getByPath method.
     * @param path Usage: path='{path}'
     * @returns a getByPathWithPathRequestBuilder
     */
    getByPathWithPath(path) {
        if (!path)
            throw new Error("path cannot be undefined");
        return new getByPathWithPath_1.GetByPathWithPathRequestBuilder(this.pathParameters, this.requestAdapter, path);
    }
    ;
    /**
     * Update entity in sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Site
     */
    patch(body, requestConfiguration) {
        const requestInfo = this.toPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, site_1.createSiteFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Retrieve properties and relationships for a [site][] resource.A site resource represents a team site in SharePoint.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, siteItemRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Update entity in sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.PATCH, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, site_1.serializeSite);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a SiteItemRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new SiteItemRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.SiteItemRequestBuilder = SiteItemRequestBuilder;
const siteItemRequestBuilderGetQueryParametersMapper = {
    "expand": "%24expand",
    "select": "%24select",
};
// tslint:enable
// eslint-enable
