"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContentTypesRequestBuilder = void 0;
const contentType_1 = require("../../../../../models/contentType");
const contentTypeCollectionResponse_1 = require("../../../../../models/contentTypeCollectionResponse");
const oDataError_1 = require("../../../../../models/oDataErrors/oDataError");
const addCopy_1 = require("./addCopy/");
const addCopyFromContentTypeHub_1 = require("./addCopyFromContentTypeHub/");
const count_1 = require("./count/");
const getCompatibleHubContentTypes_1 = require("./getCompatibleHubContentTypes/");
const item_1 = require("./item/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the contentTypes property of the microsoft.graph.list entity.
 */
class ContentTypesRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to call the addCopy method.
     */
    get addCopy() {
        return new addCopy_1.AddCopyRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the addCopyFromContentTypeHub method.
     */
    get addCopyFromContentTypeHub() {
        return new addCopyFromContentTypeHub_1.AddCopyFromContentTypeHubRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new count_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the getCompatibleHubContentTypes method.
     */
    get getCompatibleHubContentTypes() {
        return new getCompatibleHubContentTypes_1.GetCompatibleHubContentTypesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the contentTypes property of the microsoft.graph.list entity.
     * @param contentTypeId The unique identifier of contentType
     * @returns a ContentTypeItemRequestBuilder
     */
    byContentTypeId(contentTypeId) {
        if (!contentTypeId)
            throw new Error("contentTypeId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["contentType%2Did"] = contentTypeId;
        return new item_1.ContentTypeItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new ContentTypesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/sites/{site%2Did}/lists/{list%2Did}/contentTypes{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * Get the collection of [contentType][contentType] resources in a [list][].
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ContentTypeCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/list-list-contenttypes?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, contentTypeCollectionResponse_1.createContentTypeCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Create new navigation property to contentTypes for sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ContentType
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, contentType_1.createContentTypeFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Get the collection of [contentType][contentType] resources in a [list][].
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, contentTypesRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Create new navigation property to contentTypes for sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, contentType_1.serializeContentType);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a contentTypesRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new ContentTypesRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.ContentTypesRequestBuilder = ContentTypesRequestBuilder;
const contentTypesRequestBuilderGetQueryParametersMapper = {
    "count": "%24count",
    "expand": "%24expand",
    "filter": "%24filter",
    "orderby": "%24orderby",
    "search": "%24search",
    "select": "%24select",
    "skip": "%24skip",
    "top": "%24top",
};
// tslint:enable
// eslint-enable
