import { type ColumnLinkCollectionResponse } from '../../../../../../../models/';
import { type ColumnLink } from '../../../../../../../models/columnLink';
import { CountRequestBuilder } from './count/';
import { ColumnLinkItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ColumnLinksRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the columnLinks property of the microsoft.graph.contentType entity.
 */
export declare class ColumnLinksRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the columnLinks property of the microsoft.graph.contentType entity.
     * @param columnLinkId The unique identifier of columnLink
     * @returns a ColumnLinkItemRequestBuilder
     */
    byColumnLinkId(columnLinkId: string): ColumnLinkItemRequestBuilder;
    /**
     * Instantiates a new ColumnLinksRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The collection of columns that are required by this content type.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ColumnLinkCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<ColumnLinksRequestBuilderGetQueryParameters> | undefined): Promise<ColumnLinkCollectionResponse | undefined>;
    /**
     * Create new navigation property to columnLinks for sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ColumnLink
     */
    post(body: ColumnLink, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ColumnLink | undefined>;
    /**
     * The collection of columns that are required by this content type.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ColumnLinksRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to columnLinks for sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ColumnLink, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a columnLinksRequestBuilder
     */
    withUrl(rawUrl: string): ColumnLinksRequestBuilder;
}
