import { type ContentType } from '../../../../../../models/contentType';
import { AssociateWithHubSitesRequestBuilder } from './associateWithHubSites/';
import { BaseRequestBuilderEscaped } from './base/';
import { BaseTypesRequestBuilder } from './baseTypes/';
import { ColumnLinksRequestBuilder } from './columnLinks/';
import { ColumnPositionsRequestBuilder } from './columnPositions/';
import { ColumnsRequestBuilder } from './columns/';
import { CopyToDefaultContentLocationRequestBuilder } from './copyToDefaultContentLocation/';
import { IsPublishedRequestBuilder } from './isPublished/';
import { PublishRequestBuilder } from './publish/';
import { UnpublishRequestBuilder } from './unpublish/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ContentTypeItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the contentTypes property of the microsoft.graph.list entity.
 */
export declare class ContentTypeItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the associateWithHubSites method.
     */
    get associateWithHubSites(): AssociateWithHubSitesRequestBuilder;
    /**
     * Provides operations to manage the base property of the microsoft.graph.contentType entity.
     */
    get base(): BaseRequestBuilderEscaped;
    /**
     * Provides operations to manage the baseTypes property of the microsoft.graph.contentType entity.
     */
    get baseTypes(): BaseTypesRequestBuilder;
    /**
     * Provides operations to manage the columnLinks property of the microsoft.graph.contentType entity.
     */
    get columnLinks(): ColumnLinksRequestBuilder;
    /**
     * Provides operations to manage the columnPositions property of the microsoft.graph.contentType entity.
     */
    get columnPositions(): ColumnPositionsRequestBuilder;
    /**
     * Provides operations to manage the columns property of the microsoft.graph.contentType entity.
     */
    get columns(): ColumnsRequestBuilder;
    /**
     * Provides operations to call the copyToDefaultContentLocation method.
     */
    get copyToDefaultContentLocation(): CopyToDefaultContentLocationRequestBuilder;
    /**
     * Provides operations to call the isPublished method.
     */
    get isPublished(): IsPublishedRequestBuilder;
    /**
     * Provides operations to call the publish method.
     */
    get publish(): PublishRequestBuilder;
    /**
     * Provides operations to call the unpublish method.
     */
    get unpublish(): UnpublishRequestBuilder;
    /**
     * Instantiates a new ContentTypeItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property contentTypes for sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * The collection of content types present in this list.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ContentType
     */
    get(requestConfiguration?: RequestConfiguration<ContentTypeItemRequestBuilderGetQueryParameters> | undefined): Promise<ContentType | undefined>;
    /**
     * Update the navigation property contentTypes in sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ContentType
     */
    patch(body: ContentType, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ContentType | undefined>;
    /**
     * Delete navigation property contentTypes for sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * The collection of content types present in this list.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ContentTypeItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property contentTypes in sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ContentType, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ContentTypeItemRequestBuilder
     */
    withUrl(rawUrl: string): ContentTypeItemRequestBuilder;
}
