import { type BaseCollectionPaginationCountResponse } from '../../../../../models/baseCollectionPaginationCountResponse';
import { type DriveRecipient } from '../../../../../models/driveRecipient';
import { type Permission } from '../../../../../models/permission';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createGrantPostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoGrantPostRequestBody;
export declare function createGrantPostResponseFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoGrantPostResponse;
export declare function deserializeIntoGrantPostRequestBody(grantPostRequestBody?: GrantPostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export declare function deserializeIntoGrantPostResponse(grantPostResponse?: GrantPostResponse | undefined): Record<string, (node: ParseNode) => void>;
export interface GrantPostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The recipients property
     */
    recipients?: DriveRecipient[];
    /**
     * The roles property
     */
    roles?: string[];
}
export interface GrantPostResponse extends BaseCollectionPaginationCountResponse, Parsable {
    /**
     * The value property
     */
    value?: Permission[];
}
export declare function serializeGrantPostRequestBody(writer: SerializationWriter, grantPostRequestBody?: GrantPostRequestBody | undefined): void;
export declare function serializeGrantPostResponse(writer: SerializationWriter, grantPostResponse?: GrantPostResponse | undefined): void;
/**
 * Provides operations to call the grant method.
 */
export declare class GrantRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new GrantRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Grant users access to a link represented by a [permission][].
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of GrantPostResponse
     * @see {@link https://learn.microsoft.com/graph/api/permission-grant?view=graph-rest-1.0|Find more info here}
     */
    post(body: GrantPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<GrantPostResponse | undefined>;
    /**
     * Grant users access to a link represented by a [permission][].
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: GrantPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a grantRequestBuilder
     */
    withUrl(rawUrl: string): GrantRequestBuilder;
}
