import { type Store } from '../../../../models/termStore/store';
import { GroupsRequestBuilder } from './groups/';
import { SetsRequestBuilder } from './sets/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface StoreItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the termStores property of the microsoft.graph.site entity.
 */
export declare class StoreItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the groups property of the microsoft.graph.termStore.store entity.
     */
    get groups(): GroupsRequestBuilder;
    /**
     * Provides operations to manage the sets property of the microsoft.graph.termStore.store entity.
     */
    get sets(): SetsRequestBuilder;
    /**
     * Instantiates a new StoreItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property termStores for sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * The collection of termStores under this site.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Store
     */
    get(requestConfiguration?: RequestConfiguration<StoreItemRequestBuilderGetQueryParameters> | undefined): Promise<Store | undefined>;
    /**
     * Update the navigation property termStores in sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Store
     */
    patch(body: Store, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Store | undefined>;
    /**
     * Delete navigation property termStores for sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * The collection of termStores under this site.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<StoreItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property termStores in sites
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Store, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a StoreItemRequestBuilder
     */
    withUrl(rawUrl: string): StoreItemRequestBuilder;
}
