import { type BookingAppointmentCollectionResponse } from '../../../../models/';
import { type BookingAppointment } from '../../../../models/bookingAppointment';
import { CountRequestBuilder } from './count/';
import { BookingAppointmentItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface CalendarViewRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * The end date and time of the time range, represented in ISO 8601 format. For example, 2019-11-08T20:00:00-08:00
     */
    end?: string;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * The start date and time of the time range, represented in ISO 8601 format. For example, 2019-11-08T19:00:00-08:00
     */
    start?: string;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the calendarView property of the microsoft.graph.bookingBusiness entity.
 */
export declare class CalendarViewRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the calendarView property of the microsoft.graph.bookingBusiness entity.
     * @param bookingAppointmentId The unique identifier of bookingAppointment
     * @returns a BookingAppointmentItemRequestBuilder
     */
    byBookingAppointmentId(bookingAppointmentId: string): BookingAppointmentItemRequestBuilder;
    /**
     * Instantiates a new CalendarViewRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The set of appointments of this business in a specified date range. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BookingAppointmentCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/bookingbusiness-list-calendarview?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<CalendarViewRequestBuilderGetQueryParameters> | undefined): Promise<BookingAppointmentCollectionResponse | undefined>;
    /**
     * Create new navigation property to calendarView for solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BookingAppointment
     */
    post(body: BookingAppointment, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<BookingAppointment | undefined>;
    /**
     * The set of appointments of this business in a specified date range. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<CalendarViewRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to calendarView for solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: BookingAppointment, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a calendarViewRequestBuilder
     */
    withUrl(rawUrl: string): CalendarViewRequestBuilder;
}
