import { type BookingServiceCollectionResponse } from '../../../../models/';
import { type BookingService } from '../../../../models/bookingService';
import { CountRequestBuilder } from './count/';
import { BookingServiceItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ServicesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the services property of the microsoft.graph.bookingBusiness entity.
 */
export declare class ServicesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the services property of the microsoft.graph.bookingBusiness entity.
     * @param bookingServiceId The unique identifier of bookingService
     * @returns a BookingServiceItemRequestBuilder
     */
    byBookingServiceId(bookingServiceId: string): BookingServiceItemRequestBuilder;
    /**
     * Instantiates a new ServicesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of bookingService objects in the specified bookingBusiness.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BookingServiceCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/bookingbusiness-list-services?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ServicesRequestBuilderGetQueryParameters> | undefined): Promise<BookingServiceCollectionResponse | undefined>;
    /**
     * Create a new bookingService for the specified bookingBusiness.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of BookingService
     * @see {@link https://learn.microsoft.com/graph/api/bookingbusiness-post-services?view=graph-rest-1.0|Find more info here}
     */
    post(body: BookingService, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<BookingService | undefined>;
    /**
     * Get a list of bookingService objects in the specified bookingBusiness.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ServicesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new bookingService for the specified bookingBusiness.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: BookingService, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a servicesRequestBuilder
     */
    withUrl(rawUrl: string): ServicesRequestBuilder;
}
