import { type VirtualEventCollectionResponse } from '../../../models/';
import { type VirtualEvent } from '../../../models/virtualEvent';
import { CountRequestBuilder } from './count/';
import { VirtualEventItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface EventsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the events property of the microsoft.graph.virtualEventsRoot entity.
 */
export declare class EventsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the events property of the microsoft.graph.virtualEventsRoot entity.
     * @param virtualEventId The unique identifier of virtualEvent
     * @returns a VirtualEventItemRequestBuilder
     */
    byVirtualEventId(virtualEventId: string): VirtualEventItemRequestBuilder;
    /**
     * Instantiates a new EventsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get events from solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VirtualEventCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<EventsRequestBuilderGetQueryParameters> | undefined): Promise<VirtualEventCollectionResponse | undefined>;
    /**
     * Create new navigation property to events for solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VirtualEvent
     */
    post(body: VirtualEvent, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<VirtualEvent | undefined>;
    /**
     * Get events from solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<EventsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to events for solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: VirtualEvent, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a eventsRequestBuilder
     */
    withUrl(rawUrl: string): EventsRequestBuilder;
}
