import { type VirtualEvent } from '../../../../models/virtualEvent';
import { SessionsRequestBuilder } from './sessions/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface VirtualEventItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the events property of the microsoft.graph.virtualEventsRoot entity.
 */
export declare class VirtualEventItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the sessions property of the microsoft.graph.virtualEvent entity.
     */
    get sessions(): SessionsRequestBuilder;
    /**
     * Instantiates a new VirtualEventItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property events for solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Get events from solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VirtualEvent
     */
    get(requestConfiguration?: RequestConfiguration<VirtualEventItemRequestBuilderGetQueryParameters> | undefined): Promise<VirtualEvent | undefined>;
    /**
     * Update the navigation property events in solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VirtualEvent
     */
    patch(body: VirtualEvent, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<VirtualEvent | undefined>;
    /**
     * Delete navigation property events for solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Get events from solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<VirtualEventItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property events in solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: VirtualEvent, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a VirtualEventItemRequestBuilder
     */
    withUrl(rawUrl: string): VirtualEventItemRequestBuilder;
}
