import { type VirtualEventsRoot } from '../../models/virtualEventsRoot';
import { EventsRequestBuilder } from './events/';
import { WebinarsRequestBuilder } from './webinars/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface VirtualEventsRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the virtualEvents property of the microsoft.graph.solutionsRoot entity.
 */
export declare class VirtualEventsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the events property of the microsoft.graph.virtualEventsRoot entity.
     */
    get events(): EventsRequestBuilder;
    /**
     * Provides operations to manage the webinars property of the microsoft.graph.virtualEventsRoot entity.
     */
    get webinars(): WebinarsRequestBuilder;
    /**
     * Instantiates a new VirtualEventsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property virtualEvents for solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Get virtualEvents from solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VirtualEventsRoot
     */
    get(requestConfiguration?: RequestConfiguration<VirtualEventsRequestBuilderGetQueryParameters> | undefined): Promise<VirtualEventsRoot | undefined>;
    /**
     * Update the navigation property virtualEvents in solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VirtualEventsRoot
     */
    patch(body: VirtualEventsRoot, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<VirtualEventsRoot | undefined>;
    /**
     * Delete navigation property virtualEvents for solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Get virtualEvents from solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<VirtualEventsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property virtualEvents in solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: VirtualEventsRoot, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a virtualEventsRequestBuilder
     */
    withUrl(rawUrl: string): VirtualEventsRequestBuilder;
}
