import { type VirtualEventWebinarCollectionResponse } from '../../../models/';
import { type VirtualEventWebinar } from '../../../models/virtualEventWebinar';
import { CountRequestBuilder } from './count/';
import { GetByUserIdAndRoleWithUserIdWithRoleRequestBuilder } from './getByUserIdAndRoleWithUserIdWithRole/';
import { GetByUserRoleWithRoleRequestBuilder } from './getByUserRoleWithRole/';
import { VirtualEventWebinarItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface WebinarsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the webinars property of the microsoft.graph.virtualEventsRoot entity.
 */
export declare class WebinarsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the webinars property of the microsoft.graph.virtualEventsRoot entity.
     * @param virtualEventWebinarId The unique identifier of virtualEventWebinar
     * @returns a VirtualEventWebinarItemRequestBuilder
     */
    byVirtualEventWebinarId(virtualEventWebinarId: string): VirtualEventWebinarItemRequestBuilder;
    /**
     * Instantiates a new WebinarsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get webinars from solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VirtualEventWebinarCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<WebinarsRequestBuilderGetQueryParameters> | undefined): Promise<VirtualEventWebinarCollectionResponse | undefined>;
    /**
     * Provides operations to call the getByUserIdAndRole method.
     * @param role Usage: role='{role}'
     * @param userId Usage: userId='{userId}'
     * @returns a getByUserIdAndRoleWithUserIdWithRoleRequestBuilder
     */
    getByUserIdAndRoleWithUserIdWithRole(role: string | undefined, userId: string | undefined): GetByUserIdAndRoleWithUserIdWithRoleRequestBuilder;
    /**
     * Provides operations to call the getByUserRole method.
     * @param role Usage: role='{role}'
     * @returns a getByUserRoleWithRoleRequestBuilder
     */
    getByUserRoleWithRole(role: string | undefined): GetByUserRoleWithRoleRequestBuilder;
    /**
     * Create new navigation property to webinars for solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VirtualEventWebinar
     */
    post(body: VirtualEventWebinar, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<VirtualEventWebinar | undefined>;
    /**
     * Get webinars from solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<WebinarsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to webinars for solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: VirtualEventWebinar, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a webinarsRequestBuilder
     */
    withUrl(rawUrl: string): WebinarsRequestBuilder;
}
