"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebinarsRequestBuilder = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const virtualEventWebinar_1 = require("../../../models/virtualEventWebinar");
const virtualEventWebinarCollectionResponse_1 = require("../../../models/virtualEventWebinarCollectionResponse");
const count_1 = require("./count/");
const getByUserIdAndRoleWithUserIdWithRole_1 = require("./getByUserIdAndRoleWithUserIdWithRole/");
const getByUserRoleWithRole_1 = require("./getByUserRoleWithRole/");
const item_1 = require("./item/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the webinars property of the microsoft.graph.virtualEventsRoot entity.
 */
class WebinarsRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new count_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the webinars property of the microsoft.graph.virtualEventsRoot entity.
     * @param virtualEventWebinarId The unique identifier of virtualEventWebinar
     * @returns a VirtualEventWebinarItemRequestBuilder
     */
    byVirtualEventWebinarId(virtualEventWebinarId) {
        if (!virtualEventWebinarId)
            throw new Error("virtualEventWebinarId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["virtualEventWebinar%2Did"] = virtualEventWebinarId;
        return new item_1.VirtualEventWebinarItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new WebinarsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/solutions/virtualEvents/webinars{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * Get webinars from solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VirtualEventWebinarCollectionResponse
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, virtualEventWebinarCollectionResponse_1.createVirtualEventWebinarCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Provides operations to call the getByUserIdAndRole method.
     * @param role Usage: role='{role}'
     * @param userId Usage: userId='{userId}'
     * @returns a getByUserIdAndRoleWithUserIdWithRoleRequestBuilder
     */
    getByUserIdAndRoleWithUserIdWithRole(role, userId) {
        if (!role)
            throw new Error("role cannot be undefined");
        if (!userId)
            throw new Error("userId cannot be undefined");
        return new getByUserIdAndRoleWithUserIdWithRole_1.GetByUserIdAndRoleWithUserIdWithRoleRequestBuilder(this.pathParameters, this.requestAdapter, role, userId);
    }
    ;
    /**
     * Provides operations to call the getByUserRole method.
     * @param role Usage: role='{role}'
     * @returns a getByUserRoleWithRoleRequestBuilder
     */
    getByUserRoleWithRole(role) {
        if (!role)
            throw new Error("role cannot be undefined");
        return new getByUserRoleWithRole_1.GetByUserRoleWithRoleRequestBuilder(this.pathParameters, this.requestAdapter, role);
    }
    ;
    /**
     * Create new navigation property to webinars for solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VirtualEventWebinar
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, virtualEventWebinar_1.createVirtualEventWebinarFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Get webinars from solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, webinarsRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Create new navigation property to webinars for solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, virtualEventWebinar_1.serializeVirtualEventWebinar);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a webinarsRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new WebinarsRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.WebinarsRequestBuilder = WebinarsRequestBuilder;
const webinarsRequestBuilderGetQueryParametersMapper = {
    "count": "%24count",
    "expand": "%24expand",
    "filter": "%24filter",
    "orderby": "%24orderby",
    "search": "%24search",
    "select": "%24select",
    "skip": "%24skip",
    "top": "%24top",
};
// tslint:enable
// eslint-enable
