import { type VirtualEventRegistrationCollectionResponse } from '../../../../../models/';
import { type VirtualEventRegistration } from '../../../../../models/virtualEventRegistration';
import { CountRequestBuilder } from './count/';
import { VirtualEventRegistrationItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface RegistrationsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the registrations property of the microsoft.graph.virtualEventWebinar entity.
 */
export declare class RegistrationsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the registrations property of the microsoft.graph.virtualEventWebinar entity.
     * @param virtualEventRegistrationId The unique identifier of virtualEventRegistration
     * @returns a VirtualEventRegistrationItemRequestBuilder
     */
    byVirtualEventRegistrationId(virtualEventRegistrationId: string): VirtualEventRegistrationItemRequestBuilder;
    /**
     * Instantiates a new RegistrationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get registrations from solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VirtualEventRegistrationCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<RegistrationsRequestBuilderGetQueryParameters> | undefined): Promise<VirtualEventRegistrationCollectionResponse | undefined>;
    /**
     * Create new navigation property to registrations for solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VirtualEventRegistration
     */
    post(body: VirtualEventRegistration, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<VirtualEventRegistration | undefined>;
    /**
     * Get registrations from solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<RegistrationsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to registrations for solutions
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: VirtualEventRegistration, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a registrationsRequestBuilder
     */
    withUrl(rawUrl: string): RegistrationsRequestBuilder;
}
