import { type SubscribedSku } from '../../models/subscribedSku';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SubscribedSkuItemRequestBuilderGetQueryParameters {
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the collection of subscribedSku entities.
 */
export declare class SubscribedSkuItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new SubscribedSkuItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from subscribedSkus
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Get a specific commercial subscription that an organization has acquired.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SubscribedSku
     * @see {@link https://learn.microsoft.com/graph/api/subscribedsku-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SubscribedSkuItemRequestBuilderGetQueryParameters> | undefined): Promise<SubscribedSku | undefined>;
    /**
     * Update entity in subscribedSkus
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SubscribedSku
     */
    patch(body: SubscribedSku, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<SubscribedSku | undefined>;
    /**
     * Delete entity from subscribedSkus
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Get a specific commercial subscription that an organization has acquired.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SubscribedSkuItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update entity in subscribedSkus
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: SubscribedSku, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a SubscribedSkuItemRequestBuilder
     */
    withUrl(rawUrl: string): SubscribedSkuItemRequestBuilder;
}
