import { type Channel } from '../../../../models/channel';
import { CompleteMigrationRequestBuilder } from './completeMigration/';
import { DoesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalNameRequestBuilder } from './doesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalName/';
import { FilesFolderRequestBuilder } from './filesFolder/';
import { MembersRequestBuilder } from './members/';
import { MessagesRequestBuilder } from './messages/';
import { ProvisionEmailRequestBuilder } from './provisionEmail/';
import { RemoveEmailRequestBuilder } from './removeEmail/';
import { SharedWithTeamsRequestBuilder } from './sharedWithTeams/';
import { TabsRequestBuilder } from './tabs/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ChannelItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the channels property of the microsoft.graph.team entity.
 */
export declare class ChannelItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the completeMigration method.
     */
    get completeMigration(): CompleteMigrationRequestBuilder;
    /**
     * Provides operations to call the doesUserHaveAccess method.
     */
    get doesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalName(): DoesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalNameRequestBuilder;
    /**
     * Provides operations to manage the filesFolder property of the microsoft.graph.channel entity.
     */
    get filesFolder(): FilesFolderRequestBuilder;
    /**
     * Provides operations to manage the members property of the microsoft.graph.channel entity.
     */
    get members(): MembersRequestBuilder;
    /**
     * Provides operations to manage the messages property of the microsoft.graph.channel entity.
     */
    get messages(): MessagesRequestBuilder;
    /**
     * Provides operations to call the provisionEmail method.
     */
    get provisionEmail(): ProvisionEmailRequestBuilder;
    /**
     * Provides operations to call the removeEmail method.
     */
    get removeEmail(): RemoveEmailRequestBuilder;
    /**
     * Provides operations to manage the sharedWithTeams property of the microsoft.graph.channel entity.
     */
    get sharedWithTeams(): SharedWithTeamsRequestBuilder;
    /**
     * Provides operations to manage the tabs property of the microsoft.graph.channel entity.
     */
    get tabs(): TabsRequestBuilder;
    /**
     * Instantiates a new ChannelItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete the channel.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/channel-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of a channel. This method supports federation. Only a user who is a member of the shared channel can retrieve channel information.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Channel
     * @see {@link https://learn.microsoft.com/graph/api/channel-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ChannelItemRequestBuilderGetQueryParameters> | undefined): Promise<Channel | undefined>;
    /**
     * Update the properties of the specified channel.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Channel
     * @see {@link https://learn.microsoft.com/graph/api/channel-patch?view=graph-rest-1.0|Find more info here}
     */
    patch(body: Channel, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Channel | undefined>;
    /**
     * Delete the channel.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of a channel. This method supports federation. Only a user who is a member of the shared channel can retrieve channel information.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ChannelItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of the specified channel.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Channel, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ChannelItemRequestBuilder
     */
    withUrl(rawUrl: string): ChannelItemRequestBuilder;
}
