import { type ChatMessageHostedContentCollectionResponse } from '../../../../../../../models/';
import { type ChatMessageHostedContent } from '../../../../../../../models/chatMessageHostedContent';
import { CountRequestBuilder } from './count/';
import { ChatMessageHostedContentItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface HostedContentsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the hostedContents property of the microsoft.graph.chatMessage entity.
 */
export declare class HostedContentsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the hostedContents property of the microsoft.graph.chatMessage entity.
     * @param chatMessageHostedContentId The unique identifier of chatMessageHostedContent
     * @returns a ChatMessageHostedContentItemRequestBuilder
     */
    byChatMessageHostedContentId(chatMessageHostedContentId: string): ChatMessageHostedContentItemRequestBuilder;
    /**
     * Instantiates a new HostedContentsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the list of chatMessageHostedContent objects from a message. This API only lists the hosted content objects. To get the content bytes, see get chatmessage hosted content
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ChatMessageHostedContentCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/chatmessage-list-hostedcontents?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<HostedContentsRequestBuilderGetQueryParameters> | undefined): Promise<ChatMessageHostedContentCollectionResponse | undefined>;
    /**
     * Create new navigation property to hostedContents for teams
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ChatMessageHostedContent
     */
    post(body: ChatMessageHostedContent, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ChatMessageHostedContent | undefined>;
    /**
     * Retrieve the list of chatMessageHostedContent objects from a message. This API only lists the hosted content objects. To get the content bytes, see get chatmessage hosted content
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<HostedContentsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to hostedContents for teams
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ChatMessageHostedContent, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a hostedContentsRequestBuilder
     */
    withUrl(rawUrl: string): HostedContentsRequestBuilder;
}
