import { type SharedWithChannelTeamInfoCollectionResponse } from '../../../../../models/';
import { type SharedWithChannelTeamInfo } from '../../../../../models/sharedWithChannelTeamInfo';
import { CountRequestBuilder } from './count/';
import { SharedWithChannelTeamInfoItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SharedWithTeamsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the sharedWithTeams property of the microsoft.graph.channel entity.
 */
export declare class SharedWithTeamsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the sharedWithTeams property of the microsoft.graph.channel entity.
     * @param sharedWithChannelTeamInfoId The unique identifier of sharedWithChannelTeamInfo
     * @returns a SharedWithChannelTeamInfoItemRequestBuilder
     */
    bySharedWithChannelTeamInfoId(sharedWithChannelTeamInfoId: string): SharedWithChannelTeamInfoItemRequestBuilder;
    /**
     * Instantiates a new SharedWithTeamsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the list of teams that has been shared a specified channel. This operation is allowed only for channels with a membershipType value of shared.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SharedWithChannelTeamInfoCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/sharedwithchannelteaminfo-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SharedWithTeamsRequestBuilderGetQueryParameters> | undefined): Promise<SharedWithChannelTeamInfoCollectionResponse | undefined>;
    /**
     * Create new navigation property to sharedWithTeams for teams
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SharedWithChannelTeamInfo
     */
    post(body: SharedWithChannelTeamInfo, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<SharedWithChannelTeamInfo | undefined>;
    /**
     * Get the list of teams that has been shared a specified channel. This operation is allowed only for channels with a membershipType value of shared.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SharedWithTeamsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to sharedWithTeams for teams
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: SharedWithChannelTeamInfo, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a sharedWithTeamsRequestBuilder
     */
    withUrl(rawUrl: string): SharedWithTeamsRequestBuilder;
}
