"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UpgradeRequestBuilder = exports.serializeUpgradePostRequestBody = exports.deserializeIntoUpgradePostRequestBody = exports.createUpgradePostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../../models/oDataErrors/oDataError");
const teamsAppPermissionSet_1 = require("../../../../../models/teamsAppPermissionSet");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createUpgradePostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoUpgradePostRequestBody;
}
exports.createUpgradePostRequestBodyFromDiscriminatorValue = createUpgradePostRequestBodyFromDiscriminatorValue;
function deserializeIntoUpgradePostRequestBody(upgradePostRequestBody = {}) {
    return {
        "consentedPermissionSet": n => { upgradePostRequestBody.consentedPermissionSet = n.getObjectValue(teamsAppPermissionSet_1.createTeamsAppPermissionSetFromDiscriminatorValue); },
    };
}
exports.deserializeIntoUpgradePostRequestBody = deserializeIntoUpgradePostRequestBody;
function serializeUpgradePostRequestBody(writer, upgradePostRequestBody = {}) {
    writer.writeObjectValue("consentedPermissionSet", upgradePostRequestBody.consentedPermissionSet, teamsAppPermissionSet_1.serializeTeamsAppPermissionSet);
    writer.writeAdditionalData(upgradePostRequestBody.additionalData);
}
exports.serializeUpgradePostRequestBody = serializeUpgradePostRequestBody;
/**
 * Provides operations to call the upgrade method.
 */
class UpgradeRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new UpgradeRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/teams/{team%2Did}/installedApps/{teamsAppInstallation%2Did}/upgrade");
    }
    ;
    /**
     * Upgrade an app installation within a chat.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/chat-teamsappinstallation-upgrade?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Upgrade an app installation within a chat.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeUpgradePostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a upgradeRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new UpgradeRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.UpgradeRequestBuilder = UpgradeRequestBuilder;
// tslint:enable
// eslint-enable
