import { type ChatMessage } from '../../../../../models/chatMessage';
import { HostedContentsRequestBuilder } from './hostedContents/';
import { RepliesRequestBuilder } from './replies/';
import { SetReactionRequestBuilder } from './setReaction/';
import { SoftDeleteRequestBuilder } from './softDelete/';
import { UndoSoftDeleteRequestBuilder } from './undoSoftDelete/';
import { UnsetReactionRequestBuilder } from './unsetReaction/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ChatMessageItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the messages property of the microsoft.graph.channel entity.
 */
export declare class ChatMessageItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the hostedContents property of the microsoft.graph.chatMessage entity.
     */
    get hostedContents(): HostedContentsRequestBuilder;
    /**
     * Provides operations to manage the replies property of the microsoft.graph.chatMessage entity.
     */
    get replies(): RepliesRequestBuilder;
    /**
     * Provides operations to call the setReaction method.
     */
    get setReaction(): SetReactionRequestBuilder;
    /**
     * Provides operations to call the softDelete method.
     */
    get softDelete(): SoftDeleteRequestBuilder;
    /**
     * Provides operations to call the undoSoftDelete method.
     */
    get undoSoftDelete(): UndoSoftDeleteRequestBuilder;
    /**
     * Provides operations to call the unsetReaction method.
     */
    get unsetReaction(): UnsetReactionRequestBuilder;
    /**
     * Instantiates a new ChatMessageItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property messages for teams
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve a single message or a message reply in a channel or a chat.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ChatMessage
     * @see {@link https://learn.microsoft.com/graph/api/chatmessage-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ChatMessageItemRequestBuilderGetQueryParameters> | undefined): Promise<ChatMessage | undefined>;
    /**
     * Update a chatMessage object. With the exception of the policyViolation property, all properties of a chatMessage can be updated in delegated permissions scenarios.Only the policyViolation property of a chatMessage can be updated in application permissions scenarios. The update only works for chats where members are Microsoft Teams users. If one of the participants is using Skype, the operation will fail. This method does not support federation. Only the user in the tenant who sent the message can perform data loss prevention (DLP) updates on the specified chat message.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ChatMessage
     * @see {@link https://learn.microsoft.com/graph/api/chatmessage-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: ChatMessage, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ChatMessage | undefined>;
    /**
     * Delete navigation property messages for teams
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve a single message or a message reply in a channel or a chat.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ChatMessageItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update a chatMessage object. With the exception of the policyViolation property, all properties of a chatMessage can be updated in delegated permissions scenarios.Only the policyViolation property of a chatMessage can be updated in application permissions scenarios. The update only works for chats where members are Microsoft Teams users. If one of the participants is using Skype, the operation will fail. This method does not support federation. Only the user in the tenant who sent the message can perform data loss prevention (DLP) updates on the specified chat message.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ChatMessage, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ChatMessageItemRequestBuilder
     */
    withUrl(rawUrl: string): ChatMessageItemRequestBuilder;
}
