import { type OpenShift } from '../../../../../models/openShift';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface OpenShiftItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the openShifts property of the microsoft.graph.schedule entity.
 */
export declare class OpenShiftItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new OpenShiftItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete an openShift object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/openshift-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of an openshift object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OpenShift
     * @see {@link https://learn.microsoft.com/graph/api/openshift-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<OpenShiftItemRequestBuilderGetQueryParameters> | undefined): Promise<OpenShift | undefined>;
    /**
     * Update the properties of an openShift object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OpenShift
     * @see {@link https://learn.microsoft.com/graph/api/openshift-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: OpenShift, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<OpenShift | undefined>;
    /**
     * Delete an openShift object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of an openshift object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<OpenShiftItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of an openShift object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: OpenShift, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a OpenShiftItemRequestBuilder
     */
    withUrl(rawUrl: string): OpenShiftItemRequestBuilder;
}
