import { type TeamsTemplateCollectionResponse } from '../models/';
import { type TeamsTemplate } from '../models/teamsTemplate';
import { CountRequestBuilder } from './count/';
import { TeamsTemplateItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface TeamsTemplatesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the collection of teamsTemplate entities.
 */
export declare class TeamsTemplatesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the collection of teamsTemplate entities.
     * @param teamsTemplateId The unique identifier of teamsTemplate
     * @returns a TeamsTemplateItemRequestBuilder
     */
    byTeamsTemplateId(teamsTemplateId: string): TeamsTemplateItemRequestBuilder;
    /**
     * Instantiates a new TeamsTemplatesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get entities from teamsTemplates
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TeamsTemplateCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<TeamsTemplatesRequestBuilderGetQueryParameters> | undefined): Promise<TeamsTemplateCollectionResponse | undefined>;
    /**
     * Add new entity to teamsTemplates
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TeamsTemplate
     */
    post(body: TeamsTemplate, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<TeamsTemplate | undefined>;
    /**
     * Get entities from teamsTemplates
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<TeamsTemplatesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Add new entity to teamsTemplates
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: TeamsTemplate, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a teamsTemplatesRequestBuilder
     */
    withUrl(rawUrl: string): TeamsTemplatesRequestBuilder;
}
