import { type ChannelCollectionResponse } from '../../../../models/';
import { type Channel } from '../../../../models/channel';
import { CountRequestBuilder } from './count/';
import { GetAllMessagesRequestBuilder } from './getAllMessages/';
import { ChannelItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ChannelsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the channels property of the microsoft.graph.deletedTeam entity.
 */
export declare class ChannelsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to call the getAllMessages method.
     */
    get getAllMessages(): GetAllMessagesRequestBuilder;
    /**
     * Provides operations to manage the channels property of the microsoft.graph.deletedTeam entity.
     * @param channelId The unique identifier of channel
     * @returns a ChannelItemRequestBuilder
     */
    byChannelId(channelId: string): ChannelItemRequestBuilder;
    /**
     * Instantiates a new ChannelsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The channels that are either shared with this deleted team or created in this deleted team.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ChannelCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<ChannelsRequestBuilderGetQueryParameters> | undefined): Promise<ChannelCollectionResponse | undefined>;
    /**
     * Create new navigation property to channels for teamwork
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Channel
     */
    post(body: Channel, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Channel | undefined>;
    /**
     * The channels that are either shared with this deleted team or created in this deleted team.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ChannelsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to channels for teamwork
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: Channel, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a channelsRequestBuilder
     */
    withUrl(rawUrl: string): ChannelsRequestBuilder;
}
