import { type Teamwork } from '../models/teamwork';
import { DeletedTeamsRequestBuilder } from './deletedTeams/';
import { SendActivityNotificationToRecipientsRequestBuilder } from './sendActivityNotificationToRecipients/';
import { TeamsAppSettingsRequestBuilder } from './teamsAppSettings/';
import { WorkforceIntegrationsRequestBuilder } from './workforceIntegrations/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface TeamworkRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the teamwork singleton.
 */
export declare class TeamworkRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the deletedTeams property of the microsoft.graph.teamwork entity.
     */
    get deletedTeams(): DeletedTeamsRequestBuilder;
    /**
     * Provides operations to call the sendActivityNotificationToRecipients method.
     */
    get sendActivityNotificationToRecipients(): SendActivityNotificationToRecipientsRequestBuilder;
    /**
     * Provides operations to manage the teamsAppSettings property of the microsoft.graph.teamwork entity.
     */
    get teamsAppSettings(): TeamsAppSettingsRequestBuilder;
    /**
     * Provides operations to manage the workforceIntegrations property of the microsoft.graph.teamwork entity.
     */
    get workforceIntegrations(): WorkforceIntegrationsRequestBuilder;
    /**
     * Instantiates a new TeamworkRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get teamwork
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Teamwork
     */
    get(requestConfiguration?: RequestConfiguration<TeamworkRequestBuilderGetQueryParameters> | undefined): Promise<Teamwork | undefined>;
    /**
     * Update teamwork
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Teamwork
     */
    patch(body: Teamwork, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Teamwork | undefined>;
    /**
     * Get teamwork
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<TeamworkRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update teamwork
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Teamwork, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a teamworkRequestBuilder
     */
    withUrl(rawUrl: string): TeamworkRequestBuilder;
}
