import { type DelegatedAdminServiceManagementDetailCollectionResponse } from '../../../../models/';
import { type DelegatedAdminServiceManagementDetail } from '../../../../models/delegatedAdminServiceManagementDetail';
import { CountRequestBuilder } from './count/';
import { DelegatedAdminServiceManagementDetailItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ServiceManagementDetailsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the serviceManagementDetails property of the microsoft.graph.delegatedAdminCustomer entity.
 */
export declare class ServiceManagementDetailsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the serviceManagementDetails property of the microsoft.graph.delegatedAdminCustomer entity.
     * @param delegatedAdminServiceManagementDetailId The unique identifier of delegatedAdminServiceManagementDetail
     * @returns a DelegatedAdminServiceManagementDetailItemRequestBuilder
     */
    byDelegatedAdminServiceManagementDetailId(delegatedAdminServiceManagementDetailId: string): DelegatedAdminServiceManagementDetailItemRequestBuilder;
    /**
     * Instantiates a new ServiceManagementDetailsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the delegatedAdminServiceManagementDetail objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DelegatedAdminServiceManagementDetailCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/delegatedadmincustomer-list-servicemanagementdetails?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ServiceManagementDetailsRequestBuilderGetQueryParameters> | undefined): Promise<DelegatedAdminServiceManagementDetailCollectionResponse | undefined>;
    /**
     * Create new navigation property to serviceManagementDetails for tenantRelationships
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DelegatedAdminServiceManagementDetail
     */
    post(body: DelegatedAdminServiceManagementDetail, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DelegatedAdminServiceManagementDetail | undefined>;
    /**
     * Get a list of the delegatedAdminServiceManagementDetail objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ServiceManagementDetailsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to serviceManagementDetails for tenantRelationships
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DelegatedAdminServiceManagementDetail, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a serviceManagementDetailsRequestBuilder
     */
    withUrl(rawUrl: string): ServiceManagementDetailsRequestBuilder;
}
