import { type DelegatedAdminRelationshipCollectionResponse } from '../../models/';
import { type DelegatedAdminRelationship } from '../../models/delegatedAdminRelationship';
import { CountRequestBuilder } from './count/';
import { DelegatedAdminRelationshipItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DelegatedAdminRelationshipsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the delegatedAdminRelationships property of the microsoft.graph.tenantRelationship entity.
 */
export declare class DelegatedAdminRelationshipsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the delegatedAdminRelationships property of the microsoft.graph.tenantRelationship entity.
     * @param delegatedAdminRelationshipId The unique identifier of delegatedAdminRelationship
     * @returns a DelegatedAdminRelationshipItemRequestBuilder
     */
    byDelegatedAdminRelationshipId(delegatedAdminRelationshipId: string): DelegatedAdminRelationshipItemRequestBuilder;
    /**
     * Instantiates a new DelegatedAdminRelationshipsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the delegatedAdminRelationship objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DelegatedAdminRelationshipCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/tenantrelationship-list-delegatedadminrelationships?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<DelegatedAdminRelationshipsRequestBuilderGetQueryParameters> | undefined): Promise<DelegatedAdminRelationshipCollectionResponse | undefined>;
    /**
     * Create a new delegatedAdminRelationship object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DelegatedAdminRelationship
     * @see {@link https://learn.microsoft.com/graph/api/tenantrelationship-post-delegatedadminrelationships?view=graph-rest-1.0|Find more info here}
     */
    post(body: DelegatedAdminRelationship, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DelegatedAdminRelationship | undefined>;
    /**
     * Get a list of the delegatedAdminRelationship objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DelegatedAdminRelationshipsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new delegatedAdminRelationship object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DelegatedAdminRelationship, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a delegatedAdminRelationshipsRequestBuilder
     */
    withUrl(rawUrl: string): DelegatedAdminRelationshipsRequestBuilder;
}
