import { type DelegatedAdminAccessAssignmentCollectionResponse } from '../../../../models/';
import { type DelegatedAdminAccessAssignment } from '../../../../models/delegatedAdminAccessAssignment';
import { CountRequestBuilder } from './count/';
import { DelegatedAdminAccessAssignmentItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AccessAssignmentsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the accessAssignments property of the microsoft.graph.delegatedAdminRelationship entity.
 */
export declare class AccessAssignmentsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the accessAssignments property of the microsoft.graph.delegatedAdminRelationship entity.
     * @param delegatedAdminAccessAssignmentId The unique identifier of delegatedAdminAccessAssignment
     * @returns a DelegatedAdminAccessAssignmentItemRequestBuilder
     */
    byDelegatedAdminAccessAssignmentId(delegatedAdminAccessAssignmentId: string): DelegatedAdminAccessAssignmentItemRequestBuilder;
    /**
     * Instantiates a new AccessAssignmentsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of the delegatedAdminAccessAssignment objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DelegatedAdminAccessAssignmentCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/delegatedadminrelationship-list-accessassignments?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<AccessAssignmentsRequestBuilderGetQueryParameters> | undefined): Promise<DelegatedAdminAccessAssignmentCollectionResponse | undefined>;
    /**
     * Create a new delegatedAdminAccessAssignment object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DelegatedAdminAccessAssignment
     * @see {@link https://learn.microsoft.com/graph/api/delegatedadminrelationship-post-accessassignments?view=graph-rest-1.0|Find more info here}
     */
    post(body: DelegatedAdminAccessAssignment, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DelegatedAdminAccessAssignment | undefined>;
    /**
     * Get a list of the delegatedAdminAccessAssignment objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AccessAssignmentsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new delegatedAdminAccessAssignment object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: DelegatedAdminAccessAssignment, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a accessAssignmentsRequestBuilder
     */
    withUrl(rawUrl: string): AccessAssignmentsRequestBuilder;
}
