import { type TenantRelationship } from '../models/tenantRelationship';
import { DelegatedAdminCustomersRequestBuilder } from './delegatedAdminCustomers/';
import { DelegatedAdminRelationshipsRequestBuilder } from './delegatedAdminRelationships/';
import { FindTenantInformationByDomainNameWithDomainNameRequestBuilder } from './findTenantInformationByDomainNameWithDomainName/';
import { FindTenantInformationByTenantIdWithTenantIdRequestBuilder } from './findTenantInformationByTenantIdWithTenantId/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface TenantRelationshipsRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the tenantRelationship singleton.
 */
export declare class TenantRelationshipsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the delegatedAdminCustomers property of the microsoft.graph.tenantRelationship entity.
     */
    get delegatedAdminCustomers(): DelegatedAdminCustomersRequestBuilder;
    /**
     * Provides operations to manage the delegatedAdminRelationships property of the microsoft.graph.tenantRelationship entity.
     */
    get delegatedAdminRelationships(): DelegatedAdminRelationshipsRequestBuilder;
    /**
     * Instantiates a new TenantRelationshipsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Provides operations to call the findTenantInformationByDomainName method.
     * @param domainName Usage: domainName='{domainName}'
     * @returns a findTenantInformationByDomainNameWithDomainNameRequestBuilder
     */
    findTenantInformationByDomainNameWithDomainName(domainName: string | undefined): FindTenantInformationByDomainNameWithDomainNameRequestBuilder;
    /**
     * Provides operations to call the findTenantInformationByTenantId method.
     * @param tenantId Usage: tenantId='{tenantId}'
     * @returns a findTenantInformationByTenantIdWithTenantIdRequestBuilder
     */
    findTenantInformationByTenantIdWithTenantId(tenantId: string | undefined): FindTenantInformationByTenantIdWithTenantIdRequestBuilder;
    /**
     * Get tenantRelationships
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TenantRelationship
     */
    get(requestConfiguration?: RequestConfiguration<TenantRelationshipsRequestBuilderGetQueryParameters> | undefined): Promise<TenantRelationship | undefined>;
    /**
     * Update tenantRelationships
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TenantRelationship
     */
    patch(body: TenantRelationship, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<TenantRelationship | undefined>;
    /**
     * Get tenantRelationships
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<TenantRelationshipsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update tenantRelationships
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: TenantRelationship, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a tenantRelationshipsRequestBuilder
     */
    withUrl(rawUrl: string): TenantRelationshipsRequestBuilder;
}
