import { type ActivityHistoryItemCollectionResponse } from '../../../../../models/';
import { type ActivityHistoryItem } from '../../../../../models/activityHistoryItem';
import { CountRequestBuilder } from './count/';
import { ActivityHistoryItemItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface HistoryItemsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the historyItems property of the microsoft.graph.userActivity entity.
 */
export declare class HistoryItemsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the historyItems property of the microsoft.graph.userActivity entity.
     * @param activityHistoryItemId The unique identifier of activityHistoryItem
     * @returns a ActivityHistoryItemItemRequestBuilder
     */
    byActivityHistoryItemId(activityHistoryItemId: string): ActivityHistoryItemItemRequestBuilder;
    /**
     * Instantiates a new HistoryItemsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Optional. NavigationProperty/Containment; navigation property to the activity's historyItems.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ActivityHistoryItemCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<HistoryItemsRequestBuilderGetQueryParameters> | undefined): Promise<ActivityHistoryItemCollectionResponse | undefined>;
    /**
     * Create new navigation property to historyItems for users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ActivityHistoryItem
     */
    post(body: ActivityHistoryItem, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ActivityHistoryItem | undefined>;
    /**
     * Optional. NavigationProperty/Containment; navigation property to the activity's historyItems.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<HistoryItemsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to historyItems for users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ActivityHistoryItem, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a historyItemsRequestBuilder
     */
    withUrl(rawUrl: string): HistoryItemsRequestBuilder;
}
