import { type UserActivity } from '../../../../models/userActivity';
import { HistoryItemsRequestBuilder } from './historyItems/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface UserActivityItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the activities property of the microsoft.graph.user entity.
 */
export declare class UserActivityItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the historyItems property of the microsoft.graph.userActivity entity.
     */
    get historyItems(): HistoryItemsRequestBuilder;
    /**
     * Instantiates a new UserActivityItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete an existing user activity for your app.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/projectrome-delete-activity?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * The user's activities across devices. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserActivity
     */
    get(requestConfiguration?: RequestConfiguration<UserActivityItemRequestBuilderGetQueryParameters> | undefined): Promise<UserActivity | undefined>;
    /**
     * Update the navigation property activities in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of UserActivity
     */
    patch(body: UserActivity, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<UserActivity | undefined>;
    /**
     * Delete an existing user activity for your app.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * The user's activities across devices. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<UserActivityItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property activities in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: UserActivity, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a UserActivityItemRequestBuilder
     */
    withUrl(rawUrl: string): UserActivityItemRequestBuilder;
}
