import { type AuthenticationMethod } from '../../../../../models/authenticationMethod';
import { ResetPasswordRequestBuilder } from './resetPassword/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface AuthenticationMethodItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the methods property of the microsoft.graph.authentication entity.
 */
export declare class AuthenticationMethodItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the resetPassword method.
     */
    get resetPassword(): ResetPasswordRequestBuilder;
    /**
     * Instantiates a new AuthenticationMethodItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the properties and relationships of an authenticationMethod object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AuthenticationMethod
     * @see {@link https://learn.microsoft.com/graph/api/authenticationmethod-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<AuthenticationMethodItemRequestBuilderGetQueryParameters> | undefined): Promise<AuthenticationMethod | undefined>;
    /**
     * Update the navigation property methods in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of AuthenticationMethod
     */
    patch(body: AuthenticationMethod, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<AuthenticationMethod | undefined>;
    /**
     * Retrieve the properties and relationships of an authenticationMethod object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<AuthenticationMethodItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property methods in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: AuthenticationMethod, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a AuthenticationMethodItemRequestBuilder
     */
    withUrl(rawUrl: string): AuthenticationMethodItemRequestBuilder;
}
