"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResetPasswordRequestBuilder = exports.serializeResetPasswordPostRequestBody = exports.deserializeIntoResetPasswordPostRequestBody = exports.createResetPasswordPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../../../models/oDataErrors/oDataError");
const passwordResetResponse_1 = require("../../../../../../models/passwordResetResponse");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createResetPasswordPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoResetPasswordPostRequestBody;
}
exports.createResetPasswordPostRequestBodyFromDiscriminatorValue = createResetPasswordPostRequestBodyFromDiscriminatorValue;
function deserializeIntoResetPasswordPostRequestBody(resetPasswordPostRequestBody = {}) {
    return {
        "newPassword": n => { resetPasswordPostRequestBody.newPassword = n.getStringValue(); },
    };
}
exports.deserializeIntoResetPasswordPostRequestBody = deserializeIntoResetPasswordPostRequestBody;
function serializeResetPasswordPostRequestBody(writer, resetPasswordPostRequestBody = {}) {
    writer.writeStringValue("newPassword", resetPasswordPostRequestBody.newPassword);
    writer.writeAdditionalData(resetPasswordPostRequestBody.additionalData);
}
exports.serializeResetPasswordPostRequestBody = serializeResetPasswordPostRequestBody;
/**
 * Provides operations to call the resetPassword method.
 */
class ResetPasswordRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new ResetPasswordRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/users/{user%2Did}/authentication/methods/{authenticationMethod%2Did}/resetPassword");
    }
    ;
    /**
     * Reset a user's password, represented by a password authentication method object. This can only be done by an administrator with appropriate permissions and can't be performed on a user's own account. This flow writes the new password to Microsoft Entra ID and pushes it to on-premises Active Directory if configured using password writeback. The admin can either provide a new password or have the system generate one. The user is prompted to change their password on their next sign in. This reset is a long-running operation and returns a Location header with a link where the caller can periodically check for the status of the reset operation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PasswordResetResponse
     * @see {@link https://learn.microsoft.com/graph/api/authenticationmethod-resetpassword?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, passwordResetResponse_1.createPasswordResetResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Reset a user's password, represented by a password authentication method object. This can only be done by an administrator with appropriate permissions and can't be performed on a user's own account. This flow writes the new password to Microsoft Entra ID and pushes it to on-premises Active Directory if configured using password writeback. The admin can either provide a new password or have the system generate one. The user is prompted to change their password on their next sign in. This reset is a long-running operation and returns a Location header with a link where the caller can periodically check for the status of the reset operation.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeResetPasswordPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a resetPasswordRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new ResetPasswordRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.ResetPasswordRequestBuilder = ResetPasswordRequestBuilder;
// tslint:enable
// eslint-enable
