import { type SoftwareOathAuthenticationMethodCollectionResponse } from '../../../../models/';
import { CountRequestBuilder } from './count/';
import { SoftwareOathAuthenticationMethodItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface SoftwareOathMethodsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the softwareOathMethods property of the microsoft.graph.authentication entity.
 */
export declare class SoftwareOathMethodsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the softwareOathMethods property of the microsoft.graph.authentication entity.
     * @param softwareOathAuthenticationMethodId The unique identifier of softwareOathAuthenticationMethod
     * @returns a SoftwareOathAuthenticationMethodItemRequestBuilder
     */
    bySoftwareOathAuthenticationMethodId(softwareOathAuthenticationMethodId: string): SoftwareOathAuthenticationMethodItemRequestBuilder;
    /**
     * Instantiates a new SoftwareOathMethodsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of a user's software OATH token authentication method objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SoftwareOathAuthenticationMethodCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/authentication-list-softwareoathmethods?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SoftwareOathMethodsRequestBuilderGetQueryParameters> | undefined): Promise<SoftwareOathAuthenticationMethodCollectionResponse | undefined>;
    /**
     * Retrieve a list of a user's software OATH token authentication method objects and their properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SoftwareOathMethodsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a softwareOathMethodsRequestBuilder
     */
    withUrl(rawUrl: string): SoftwareOathMethodsRequestBuilder;
}
