"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AcceptRequestBuilder = exports.serializeAcceptPostRequestBody = exports.deserializeIntoAcceptPostRequestBody = exports.createAcceptPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../../../../../../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createAcceptPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoAcceptPostRequestBody;
}
exports.createAcceptPostRequestBodyFromDiscriminatorValue = createAcceptPostRequestBodyFromDiscriminatorValue;
function deserializeIntoAcceptPostRequestBody(acceptPostRequestBody = {}) {
    return {
        "comment": n => { acceptPostRequestBody.comment = n.getStringValue(); },
        "sendResponse": n => { acceptPostRequestBody.sendResponse = n.getBooleanValue(); },
    };
}
exports.deserializeIntoAcceptPostRequestBody = deserializeIntoAcceptPostRequestBody;
function serializeAcceptPostRequestBody(writer, acceptPostRequestBody = {}) {
    writer.writeStringValue("Comment", acceptPostRequestBody.comment);
    writer.writeBooleanValue("SendResponse", acceptPostRequestBody.sendResponse);
    writer.writeAdditionalData(acceptPostRequestBody.additionalData);
}
exports.serializeAcceptPostRequestBody = serializeAcceptPostRequestBody;
/**
 * Provides operations to call the accept method.
 */
class AcceptRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new AcceptRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/users/{user%2Did}/calendarGroups/{calendarGroup%2Did}/calendars/{calendar%2Did}/calendarView/{event%2Did}/instances/{event%2Did1}/accept");
    }
    ;
    /**
     * Accept the specified event in a user calendar.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/event-accept?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Accept the specified event in a user calendar.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeAcceptPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a acceptRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new AcceptRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.AcceptRequestBuilder = AcceptRequestBuilder;
// tslint:enable
// eslint-enable
