"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeclineRequestBuilder = exports.serializeDeclinePostRequestBody = exports.deserializeIntoDeclinePostRequestBody = exports.createDeclinePostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../../../../models/oDataErrors/oDataError");
const timeSlot_1 = require("../../../../../../../models/timeSlot");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createDeclinePostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoDeclinePostRequestBody;
}
exports.createDeclinePostRequestBodyFromDiscriminatorValue = createDeclinePostRequestBodyFromDiscriminatorValue;
function deserializeIntoDeclinePostRequestBody(declinePostRequestBody = {}) {
    return {
        "comment": n => { declinePostRequestBody.comment = n.getStringValue(); },
        "proposedNewTime": n => { declinePostRequestBody.proposedNewTime = n.getObjectValue(timeSlot_1.createTimeSlotFromDiscriminatorValue); },
        "sendResponse": n => { declinePostRequestBody.sendResponse = n.getBooleanValue(); },
    };
}
exports.deserializeIntoDeclinePostRequestBody = deserializeIntoDeclinePostRequestBody;
function serializeDeclinePostRequestBody(writer, declinePostRequestBody = {}) {
    writer.writeStringValue("Comment", declinePostRequestBody.comment);
    writer.writeObjectValue("ProposedNewTime", declinePostRequestBody.proposedNewTime, timeSlot_1.serializeTimeSlot);
    writer.writeBooleanValue("SendResponse", declinePostRequestBody.sendResponse);
    writer.writeAdditionalData(declinePostRequestBody.additionalData);
}
exports.serializeDeclinePostRequestBody = serializeDeclinePostRequestBody;
/**
 * Provides operations to call the decline method.
 */
class DeclineRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new DeclineRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/users/{user%2Did}/calendarView/{event%2Did}/instances/{event%2Did1}/decline");
    }
    ;
    /**
     * Decline invitation to the specified event in a user calendar. If the event allows proposals for new times, on declining the event, an invitee can choose to suggest an alternative time by including the proposedNewTime parameter. For more information on how to propose a time, and how to receive and accept a new time proposal, see Propose new meeting times.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/event-decline?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Decline invitation to the specified event in a user calendar. If the event allows proposals for new times, on declining the event, an invitee can choose to suggest an alternative time by including the proposedNewTime parameter. For more information on how to propose a time, and how to receive and accept a new time proposal, see Propose new meeting times.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeDeclinePostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a declineRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new DeclineRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.DeclineRequestBuilder = DeclineRequestBuilder;
// tslint:enable
// eslint-enable
