"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChangePasswordRequestBuilder = exports.serializeChangePasswordPostRequestBody = exports.deserializeIntoChangePasswordPostRequestBody = exports.createChangePasswordPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createChangePasswordPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoChangePasswordPostRequestBody;
}
exports.createChangePasswordPostRequestBodyFromDiscriminatorValue = createChangePasswordPostRequestBodyFromDiscriminatorValue;
function deserializeIntoChangePasswordPostRequestBody(changePasswordPostRequestBody = {}) {
    return {
        "currentPassword": n => { changePasswordPostRequestBody.currentPassword = n.getStringValue(); },
        "newPassword": n => { changePasswordPostRequestBody.newPassword = n.getStringValue(); },
    };
}
exports.deserializeIntoChangePasswordPostRequestBody = deserializeIntoChangePasswordPostRequestBody;
function serializeChangePasswordPostRequestBody(writer, changePasswordPostRequestBody = {}) {
    writer.writeStringValue("currentPassword", changePasswordPostRequestBody.currentPassword);
    writer.writeStringValue("newPassword", changePasswordPostRequestBody.newPassword);
    writer.writeAdditionalData(changePasswordPostRequestBody.additionalData);
}
exports.serializeChangePasswordPostRequestBody = serializeChangePasswordPostRequestBody;
/**
 * Provides operations to call the changePassword method.
 */
class ChangePasswordRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new ChangePasswordRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/users/{user%2Did}/changePassword");
    }
    ;
    /**
     * Enable the user to update their password. Any user can update their password without belonging to any administrator role.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/user-changepassword?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Enable the user to update their password. Any user can update their password without belonging to any administrator role.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeChangePasswordPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a changePasswordRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new ChangePasswordRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.ChangePasswordRequestBuilder = ChangePasswordRequestBuilder;
// tslint:enable
// eslint-enable
