"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HideForUserRequestBuilder = exports.serializeHideForUserPostRequestBody = exports.deserializeIntoHideForUserPostRequestBody = exports.createHideForUserPostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../../models/oDataErrors/oDataError");
const teamworkUserIdentity_1 = require("../../../../../models/teamworkUserIdentity");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createHideForUserPostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoHideForUserPostRequestBody;
}
exports.createHideForUserPostRequestBodyFromDiscriminatorValue = createHideForUserPostRequestBodyFromDiscriminatorValue;
function deserializeIntoHideForUserPostRequestBody(hideForUserPostRequestBody = {}) {
    return {
        "user": n => { hideForUserPostRequestBody.user = n.getObjectValue(teamworkUserIdentity_1.createTeamworkUserIdentityFromDiscriminatorValue); },
    };
}
exports.deserializeIntoHideForUserPostRequestBody = deserializeIntoHideForUserPostRequestBody;
function serializeHideForUserPostRequestBody(writer, hideForUserPostRequestBody = {}) {
    writer.writeObjectValue("user", hideForUserPostRequestBody.user, teamworkUserIdentity_1.serializeTeamworkUserIdentity);
    writer.writeAdditionalData(hideForUserPostRequestBody.additionalData);
}
exports.serializeHideForUserPostRequestBody = serializeHideForUserPostRequestBody;
/**
 * Provides operations to call the hideForUser method.
 */
class HideForUserRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new HideForUserRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/users/{user%2Did}/chats/{chat%2Did}/hideForUser");
    }
    ;
    /**
     * Hide a chat for a user.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/chat-hideforuser?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Hide a chat for a user.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeHideForUserPostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a hideForUserRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new HideForUserRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.HideForUserRequestBuilder = HideForUserRequestBuilder;
// tslint:enable
// eslint-enable
