import { type PinnedChatMessageInfo } from '../../../../../../models/pinnedChatMessageInfo';
import { MessageRequestBuilder } from './message/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface PinnedChatMessageInfoItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the pinnedMessages property of the microsoft.graph.chat entity.
 */
export declare class PinnedChatMessageInfoItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the message property of the microsoft.graph.pinnedChatMessageInfo entity.
     */
    get message(): MessageRequestBuilder;
    /**
     * Instantiates a new PinnedChatMessageInfoItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Unpin a message from a chat.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/chat-delete-pinnedmessages?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * A collection of all the pinned messages in the chat. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PinnedChatMessageInfo
     */
    get(requestConfiguration?: RequestConfiguration<PinnedChatMessageInfoItemRequestBuilderGetQueryParameters> | undefined): Promise<PinnedChatMessageInfo | undefined>;
    /**
     * Update the navigation property pinnedMessages in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PinnedChatMessageInfo
     */
    patch(body: PinnedChatMessageInfo, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<PinnedChatMessageInfo | undefined>;
    /**
     * Unpin a message from a chat.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * A collection of all the pinned messages in the chat. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<PinnedChatMessageInfoItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property pinnedMessages in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: PinnedChatMessageInfo, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a PinnedChatMessageInfoItemRequestBuilder
     */
    withUrl(rawUrl: string): PinnedChatMessageInfoItemRequestBuilder;
}
