import { type ContactFolder } from '../../../../models/contactFolder';
import { ChildFoldersRequestBuilder } from './childFolders/';
import { ContactsRequestBuilder } from './contacts/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ContactFolderItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the contactFolders property of the microsoft.graph.user entity.
 */
export declare class ContactFolderItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the childFolders property of the microsoft.graph.contactFolder entity.
     */
    get childFolders(): ChildFoldersRequestBuilder;
    /**
     * Provides operations to manage the contacts property of the microsoft.graph.contactFolder entity.
     */
    get contacts(): ContactsRequestBuilder;
    /**
     * Instantiates a new ContactFolderItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete contactFolder other than the default contactFolder.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/contactfolder-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Get a contact folder by using the contact folder ID. There are two scenarios where an app can get another user's contact folder:
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ContactFolder
     * @see {@link https://learn.microsoft.com/graph/api/contactfolder-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<ContactFolderItemRequestBuilderGetQueryParameters> | undefined): Promise<ContactFolder | undefined>;
    /**
     * Update the properties of contactfolder object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ContactFolder
     * @see {@link https://learn.microsoft.com/graph/api/contactfolder-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: ContactFolder, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ContactFolder | undefined>;
    /**
     * Delete contactFolder other than the default contactFolder.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Get a contact folder by using the contact folder ID. There are two scenarios where an app can get another user's contact folder:
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ContactFolderItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of contactfolder object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: ContactFolder, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a ContactFolderItemRequestBuilder
     */
    withUrl(rawUrl: string): ContactFolderItemRequestBuilder;
}
