import { type AttendeeBase } from '../../../models/attendeeBase';
import { type LocationConstraint } from '../../../models/locationConstraint';
import { type MeetingTimeSuggestionsResult } from '../../../models/meetingTimeSuggestionsResult';
import { type TimeConstraint } from '../../../models/timeConstraint';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Duration, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createFindMeetingTimesPostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoFindMeetingTimesPostRequestBody;
export declare function deserializeIntoFindMeetingTimesPostRequestBody(findMeetingTimesPostRequestBody?: FindMeetingTimesPostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export interface FindMeetingTimesPostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The attendees property
     */
    attendees?: AttendeeBase[];
    /**
     * The isOrganizerOptional property
     */
    isOrganizerOptional?: boolean;
    /**
     * The locationConstraint property
     */
    locationConstraint?: LocationConstraint;
    /**
     * The maxCandidates property
     */
    maxCandidates?: number;
    /**
     * The meetingDuration property
     */
    meetingDuration?: Duration;
    /**
     * The minimumAttendeePercentage property
     */
    minimumAttendeePercentage?: number;
    /**
     * The returnSuggestionReasons property
     */
    returnSuggestionReasons?: boolean;
    /**
     * The timeConstraint property
     */
    timeConstraint?: TimeConstraint;
}
export declare function serializeFindMeetingTimesPostRequestBody(writer: SerializationWriter, findMeetingTimesPostRequestBody?: FindMeetingTimesPostRequestBody | undefined): void;
/**
 * Provides operations to call the findMeetingTimes method.
 */
export declare class FindMeetingTimesRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new FindMeetingTimesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Suggest meeting times and locations based on organizer and attendee availability, and time or location constraints specified as parameters. If findMeetingTimes cannot return any meeting suggestions, the response would indicate a reason in the emptySuggestionsReason property. Based on this value, you can better adjust the parameters and call findMeetingTimes again. The algorithm used to suggest meeting times and locations undergoes fine-tuning from time to time. In scenarios like test environments where the input parameters and calendar data remain static, expect that the suggested results may differ over time.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MeetingTimeSuggestionsResult
     * @see {@link https://learn.microsoft.com/graph/api/user-findmeetingtimes?view=graph-rest-1.0|Find more info here}
     */
    post(body: FindMeetingTimesPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<MeetingTimeSuggestionsResult | undefined>;
    /**
     * Suggest meeting times and locations based on organizer and attendee availability, and time or location constraints specified as parameters. If findMeetingTimes cannot return any meeting suggestions, the response would indicate a reason in the emptySuggestionsReason property. Based on this value, you can better adjust the parameters and call findMeetingTimes again. The algorithm used to suggest meeting times and locations undergoes fine-tuning from time to time. In scenarios like test environments where the input parameters and calendar data remain static, expect that the suggested results may differ over time.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: FindMeetingTimesPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a findMeetingTimesRequestBuilder
     */
    withUrl(rawUrl: string): FindMeetingTimesRequestBuilder;
}
