import { type TimeOffRequestCollectionResponse } from '../../../../../../models/';
import { type TimeOffRequest } from '../../../../../../models/timeOffRequest';
import { CountRequestBuilder } from './count/';
import { TimeOffRequestItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface TimeOffRequestsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the timeOffRequests property of the microsoft.graph.schedule entity.
 */
export declare class TimeOffRequestsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the timeOffRequests property of the microsoft.graph.schedule entity.
     * @param timeOffRequestId The unique identifier of timeOffRequest
     * @returns a TimeOffRequestItemRequestBuilder
     */
    byTimeOffRequestId(timeOffRequestId: string): TimeOffRequestItemRequestBuilder;
    /**
     * Instantiates a new TimeOffRequestsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of timeOffRequest objects in the team.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TimeOffRequestCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/timeoffrequest-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<TimeOffRequestsRequestBuilderGetQueryParameters> | undefined): Promise<TimeOffRequestCollectionResponse | undefined>;
    /**
     * Create new navigation property to timeOffRequests for users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TimeOffRequest
     */
    post(body: TimeOffRequest, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<TimeOffRequest | undefined>;
    /**
     * Retrieve a list of timeOffRequest objects in the team.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<TimeOffRequestsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to timeOffRequests for users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: TimeOffRequest, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a timeOffRequestsRequestBuilder
     */
    withUrl(rawUrl: string): TimeOffRequestsRequestBuilder;
}
