import { type LicenseDetailsCollectionResponse } from '../../../models/';
import { type LicenseDetails } from '../../../models/licenseDetails';
import { CountRequestBuilder } from './count/';
import { LicenseDetailsItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface LicenseDetailsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the licenseDetails property of the microsoft.graph.user entity.
 */
export declare class LicenseDetailsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the licenseDetails property of the microsoft.graph.user entity.
     * @param licenseDetailsId The unique identifier of licenseDetails
     * @returns a LicenseDetailsItemRequestBuilder
     */
    byLicenseDetailsId(licenseDetailsId: string): LicenseDetailsItemRequestBuilder;
    /**
     * Instantiates a new LicenseDetailsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of licenseDetails objects for enterprise users. This API returns details for licenses that are directly assigned and those transitively assigned through memberships in licensed groups.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of LicenseDetailsCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/user-list-licensedetails?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<LicenseDetailsRequestBuilderGetQueryParameters> | undefined): Promise<LicenseDetailsCollectionResponse | undefined>;
    /**
     * Create new navigation property to licenseDetails for users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of LicenseDetails
     */
    post(body: LicenseDetails, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<LicenseDetails | undefined>;
    /**
     * Retrieve a list of licenseDetails objects for enterprise users. This API returns details for licenses that are directly assigned and those transitively assigned through memberships in licensed groups.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<LicenseDetailsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to licenseDetails for users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: LicenseDetails, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a licenseDetailsRequestBuilder
     */
    withUrl(rawUrl: string): LicenseDetailsRequestBuilder;
}
