import { type Message } from '../../../../../../../../models/message';
import { AttachmentsRequestBuilder } from './attachments/';
import { CopyRequestBuilder } from './copy/';
import { CreateForwardRequestBuilder } from './createForward/';
import { CreateReplyRequestBuilder } from './createReply/';
import { CreateReplyAllRequestBuilder } from './createReplyAll/';
import { ExtensionsRequestBuilder } from './extensions/';
import { ForwardRequestBuilder } from './forward/';
import { MoveRequestBuilder } from './move/';
import { ReplyRequestBuilder } from './reply/';
import { ReplyAllRequestBuilder } from './replyAll/';
import { SendRequestBuilder } from './send/';
import { ContentRequestBuilder } from './value/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface MessageItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the messages property of the microsoft.graph.mailFolder entity.
 */
export declare class MessageItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the attachments property of the microsoft.graph.message entity.
     */
    get attachments(): AttachmentsRequestBuilder;
    /**
     * Provides operations to manage the media for the user entity.
     */
    get content(): ContentRequestBuilder;
    /**
     * Provides operations to call the copy method.
     */
    get copy(): CopyRequestBuilder;
    /**
     * Provides operations to call the createForward method.
     */
    get createForward(): CreateForwardRequestBuilder;
    /**
     * Provides operations to call the createReply method.
     */
    get createReply(): CreateReplyRequestBuilder;
    /**
     * Provides operations to call the createReplyAll method.
     */
    get createReplyAll(): CreateReplyAllRequestBuilder;
    /**
     * Provides operations to manage the extensions property of the microsoft.graph.message entity.
     */
    get extensions(): ExtensionsRequestBuilder;
    /**
     * Provides operations to call the forward method.
     */
    get forward(): ForwardRequestBuilder;
    /**
     * Provides operations to call the move method.
     */
    get move(): MoveRequestBuilder;
    /**
     * Provides operations to call the reply method.
     */
    get reply(): ReplyRequestBuilder;
    /**
     * Provides operations to call the replyAll method.
     */
    get replyAll(): ReplyAllRequestBuilder;
    /**
     * Provides operations to call the send method.
     */
    get send(): SendRequestBuilder;
    /**
     * Instantiates a new MessageItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property messages for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * The collection of messages in the mailFolder.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Message
     */
    get(requestConfiguration?: RequestConfiguration<MessageItemRequestBuilderGetQueryParameters> | undefined): Promise<Message | undefined>;
    /**
     * Update the navigation property messages in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Message
     */
    patch(body: Message, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Message | undefined>;
    /**
     * Delete navigation property messages for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * The collection of messages in the mailFolder.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<MessageItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property messages in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Message, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a MessageItemRequestBuilder
     */
    withUrl(rawUrl: string): MessageItemRequestBuilder;
}
