import { type Message } from '../../../../../models/message';
import { BaseRequestBuilder, RequestInformation, type AdditionalDataHolder, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createMovePostRequestBodyFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoMovePostRequestBody;
export declare function deserializeIntoMovePostRequestBody(movePostRequestBody?: MovePostRequestBody | undefined): Record<string, (node: ParseNode) => void>;
export interface MovePostRequestBody extends AdditionalDataHolder, Parsable {
    /**
     * Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     */
    additionalData?: Record<string, unknown>;
    /**
     * The DestinationId property
     */
    destinationId?: string;
}
export declare function serializeMovePostRequestBody(writer: SerializationWriter, movePostRequestBody?: MovePostRequestBody | undefined): void;
/**
 * Provides operations to call the move method.
 */
export declare class MoveRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new MoveRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Move a message to another folder within the specified user's mailbox. This creates a new copy of the message in the destination folder and removes the original message.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Message
     * @see {@link https://learn.microsoft.com/graph/api/message-move?view=graph-rest-1.0|Find more info here}
     */
    post(body: MovePostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Message | undefined>;
    /**
     * Move a message to another folder within the specified user's mailbox. This creates a new copy of the message in the destination folder and removes the original message.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: MovePostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a moveRequestBuilder
     */
    withUrl(rawUrl: string): MoveRequestBuilder;
}
