import { type OnenoteSection } from '../../../../../../../models/onenoteSection';
import { CopyToNotebookRequestBuilder } from './copyToNotebook/';
import { CopyToSectionGroupRequestBuilder } from './copyToSectionGroup/';
import { PagesRequestBuilder } from './pages/';
import { ParentNotebookRequestBuilder } from './parentNotebook/';
import { ParentSectionGroupRequestBuilder } from './parentSectionGroup/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface OnenoteSectionItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the sections property of the microsoft.graph.sectionGroup entity.
 */
export declare class OnenoteSectionItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to call the copyToNotebook method.
     */
    get copyToNotebook(): CopyToNotebookRequestBuilder;
    /**
     * Provides operations to call the copyToSectionGroup method.
     */
    get copyToSectionGroup(): CopyToSectionGroupRequestBuilder;
    /**
     * Provides operations to manage the pages property of the microsoft.graph.onenoteSection entity.
     */
    get pages(): PagesRequestBuilder;
    /**
     * Provides operations to manage the parentNotebook property of the microsoft.graph.onenoteSection entity.
     */
    get parentNotebook(): ParentNotebookRequestBuilder;
    /**
     * Provides operations to manage the parentSectionGroup property of the microsoft.graph.onenoteSection entity.
     */
    get parentSectionGroup(): ParentSectionGroupRequestBuilder;
    /**
     * Instantiates a new OnenoteSectionItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property sections for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * The sections in the section group. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OnenoteSection
     */
    get(requestConfiguration?: RequestConfiguration<OnenoteSectionItemRequestBuilderGetQueryParameters> | undefined): Promise<OnenoteSection | undefined>;
    /**
     * Update the navigation property sections in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OnenoteSection
     */
    patch(body: OnenoteSection, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<OnenoteSection | undefined>;
    /**
     * Delete navigation property sections for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * The sections in the section group. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<OnenoteSectionItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property sections in users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: OnenoteSection, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a OnenoteSectionItemRequestBuilder
     */
    withUrl(rawUrl: string): OnenoteSectionItemRequestBuilder;
}
