import { type OnlineMeetingCollectionResponse } from '../../../models/';
import { type OnlineMeeting } from '../../../models/onlineMeeting';
import { CountRequestBuilder } from './count/';
import { CreateOrGetRequestBuilder } from './createOrGet/';
import { OnlineMeetingItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface OnlineMeetingsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the onlineMeetings property of the microsoft.graph.user entity.
 */
export declare class OnlineMeetingsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to call the createOrGet method.
     */
    get createOrGet(): CreateOrGetRequestBuilder;
    /**
     * Provides operations to manage the onlineMeetings property of the microsoft.graph.user entity.
     * @param onlineMeetingId The unique identifier of onlineMeeting
     * @returns a OnlineMeetingItemRequestBuilder
     */
    byOnlineMeetingId(onlineMeetingId: string): OnlineMeetingItemRequestBuilder;
    /**
     * Instantiates a new OnlineMeetingsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve the properties and relationships of an onlineMeeting object. For example, you can: Teams live event attendee report (deprecated) is an online meeting artifact. For details, see Online meeting artifacts and permissions.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OnlineMeetingCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/onlinemeeting-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<OnlineMeetingsRequestBuilderGetQueryParameters> | undefined): Promise<OnlineMeetingCollectionResponse | undefined>;
    /**
     * Create an online meeting on behalf of a user.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OnlineMeeting
     * @see {@link https://learn.microsoft.com/graph/api/application-post-onlinemeetings?view=graph-rest-1.0|Find more info here}
     */
    post(body: OnlineMeeting, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<OnlineMeeting | undefined>;
    /**
     * Retrieve the properties and relationships of an onlineMeeting object. For example, you can: Teams live event attendee report (deprecated) is an online meeting artifact. For details, see Online meeting artifacts and permissions.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<OnlineMeetingsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create an online meeting on behalf of a user.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: OnlineMeeting, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a onlineMeetingsRequestBuilder
     */
    withUrl(rawUrl: string): OnlineMeetingsRequestBuilder;
}
