import { type OutlookUser } from '../../../models/';
import { MasterCategoriesRequestBuilder } from './masterCategories/';
import { SupportedLanguagesRequestBuilder } from './supportedLanguages/';
import { SupportedTimeZonesRequestBuilder } from './supportedTimeZones/';
import { SupportedTimeZonesWithTimeZoneStandardRequestBuilder } from './supportedTimeZonesWithTimeZoneStandard/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface OutlookRequestBuilderGetQueryParameters {
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the outlook property of the microsoft.graph.user entity.
 */
export declare class OutlookRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the masterCategories property of the microsoft.graph.outlookUser entity.
     */
    get masterCategories(): MasterCategoriesRequestBuilder;
    /**
     * Provides operations to call the supportedLanguages method.
     */
    get supportedLanguages(): SupportedLanguagesRequestBuilder;
    /**
     * Provides operations to call the supportedTimeZones method.
     */
    get supportedTimeZones(): SupportedTimeZonesRequestBuilder;
    /**
     * Instantiates a new OutlookRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get outlook from users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OutlookUser
     */
    get(requestConfiguration?: RequestConfiguration<OutlookRequestBuilderGetQueryParameters> | undefined): Promise<OutlookUser | undefined>;
    /**
     * Provides operations to call the supportedTimeZones method.
     * @param TimeZoneStandard Usage: TimeZoneStandard='{TimeZoneStandard}'
     * @returns a supportedTimeZonesWithTimeZoneStandardRequestBuilder
     */
    supportedTimeZonesWithTimeZoneStandard(timeZoneStandard: string | undefined): SupportedTimeZonesWithTimeZoneStandardRequestBuilder;
    /**
     * Get outlook from users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<OutlookRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a outlookRequestBuilder
     */
    withUrl(rawUrl: string): OutlookRequestBuilder;
}
