"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OutlookRequestBuilder = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const outlookUser_1 = require("../../../models/outlookUser");
const masterCategories_1 = require("./masterCategories/");
const supportedLanguages_1 = require("./supportedLanguages/");
const supportedTimeZones_1 = require("./supportedTimeZones/");
const supportedTimeZonesWithTimeZoneStandard_1 = require("./supportedTimeZonesWithTimeZoneStandard/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the outlook property of the microsoft.graph.user entity.
 */
class OutlookRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to manage the masterCategories property of the microsoft.graph.outlookUser entity.
     */
    get masterCategories() {
        return new masterCategories_1.MasterCategoriesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the supportedLanguages method.
     */
    get supportedLanguages() {
        return new supportedLanguages_1.SupportedLanguagesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the supportedTimeZones method.
     */
    get supportedTimeZones() {
        return new supportedTimeZones_1.SupportedTimeZonesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new OutlookRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/users/{user%2Did}/outlook{?%24select}");
    }
    ;
    /**
     * Get outlook from users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OutlookUser
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, outlookUser_1.createOutlookUserFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Provides operations to call the supportedTimeZones method.
     * @param TimeZoneStandard Usage: TimeZoneStandard='{TimeZoneStandard}'
     * @returns a supportedTimeZonesWithTimeZoneStandardRequestBuilder
     */
    supportedTimeZonesWithTimeZoneStandard(timeZoneStandard) {
        if (!timeZoneStandard)
            throw new Error("timeZoneStandard cannot be undefined");
        return new supportedTimeZonesWithTimeZoneStandard_1.SupportedTimeZonesWithTimeZoneStandardRequestBuilder(this.pathParameters, this.requestAdapter, timeZoneStandard);
    }
    ;
    /**
     * Get outlook from users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, outlookRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a outlookRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new OutlookRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.OutlookRequestBuilder = OutlookRequestBuilder;
const outlookRequestBuilderGetQueryParametersMapper = {
    "select": "%24select",
};
// tslint:enable
// eslint-enable
