import { type OutlookCategory } from '../../../../../models/outlookCategory';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface OutlookCategoryItemRequestBuilderGetQueryParameters {
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the masterCategories property of the microsoft.graph.outlookUser entity.
 */
export declare class OutlookCategoryItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new OutlookCategoryItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete the specified outlookCategory object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/outlookcategory-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Get the properties and relationships of the specified outlookCategory object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OutlookCategory
     * @see {@link https://learn.microsoft.com/graph/api/outlookcategory-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<OutlookCategoryItemRequestBuilderGetQueryParameters> | undefined): Promise<OutlookCategory | undefined>;
    /**
     * Update the writable property, color, of the specified outlookCategory object. You can't modify the displayName propertyonce you have created the category.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of OutlookCategory
     * @see {@link https://learn.microsoft.com/graph/api/outlookcategory-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: OutlookCategory, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<OutlookCategory | undefined>;
    /**
     * Delete the specified outlookCategory object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Get the properties and relationships of the specified outlookCategory object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<OutlookCategoryItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the writable property, color, of the specified outlookCategory object. You can't modify the displayName propertyonce you have created the category.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: OutlookCategory, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a OutlookCategoryItemRequestBuilder
     */
    withUrl(rawUrl: string): OutlookCategoryItemRequestBuilder;
}
