import { type BaseCollectionPaginationCountResponse } from '../../../../models/baseCollectionPaginationCountResponse';
import { type LocaleInfo } from '../../../../models/localeInfo';
import { BaseRequestBuilder, RequestInformation, type Parsable, type ParseNode, type RequestAdapter, type RequestConfiguration, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createSupportedLanguagesGetResponseFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoSupportedLanguagesGetResponse;
export declare function deserializeIntoSupportedLanguagesGetResponse(supportedLanguagesGetResponse?: SupportedLanguagesGetResponse | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeSupportedLanguagesGetResponse(writer: SerializationWriter, supportedLanguagesGetResponse?: SupportedLanguagesGetResponse | undefined): void;
export interface SupportedLanguagesGetResponse extends BaseCollectionPaginationCountResponse, Parsable {
    /**
     * The value property
     */
    value?: LocaleInfo[];
}
export interface SupportedLanguagesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to call the supportedLanguages method.
 */
export declare class SupportedLanguagesRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new SupportedLanguagesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get the list of locales and languages that are supported for the user, as configured on the user's mailbox server. When setting up an Outlook client, the user selects the preferred language from this supported list. You can subsequently get the preferred language bygetting the user's mailbox settings.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SupportedLanguagesGetResponse
     * @see {@link https://learn.microsoft.com/graph/api/outlookuser-supportedlanguages?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<SupportedLanguagesRequestBuilderGetQueryParameters> | undefined): Promise<SupportedLanguagesGetResponse | undefined>;
    /**
     * Get the list of locales and languages that are supported for the user, as configured on the user's mailbox server. When setting up an Outlook client, the user selects the preferred language from this supported list. You can subsequently get the preferred language bygetting the user's mailbox settings.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<SupportedLanguagesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a supportedLanguagesRequestBuilder
     */
    withUrl(rawUrl: string): SupportedLanguagesRequestBuilder;
}
