import { type ProfilePhotoCollectionResponse } from '../../../models/';
import { ProfilePhotoItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface PhotosRequestBuilderGetQueryParameters {
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the photos property of the microsoft.graph.user entity.
 */
export declare class PhotosRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the photos property of the microsoft.graph.user entity.
     * @param profilePhotoId The unique identifier of profilePhoto
     * @returns a ProfilePhotoItemRequestBuilder
     */
    byProfilePhotoId(profilePhotoId: string): ProfilePhotoItemRequestBuilder;
    /**
     * Instantiates a new PhotosRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The collection of the user's profile photos in different sizes. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ProfilePhotoCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<PhotosRequestBuilderGetQueryParameters> | undefined): Promise<ProfilePhotoCollectionResponse | undefined>;
    /**
     * The collection of the user's profile photos in different sizes. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<PhotosRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a photosRequestBuilder
     */
    withUrl(rawUrl: string): PhotosRequestBuilder;
}
