"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PhotosRequestBuilder = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const profilePhotoCollectionResponse_1 = require("../../../models/profilePhotoCollectionResponse");
const item_1 = require("./item/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the photos property of the microsoft.graph.user entity.
 */
class PhotosRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to manage the photos property of the microsoft.graph.user entity.
     * @param profilePhotoId The unique identifier of profilePhoto
     * @returns a ProfilePhotoItemRequestBuilder
     */
    byProfilePhotoId(profilePhotoId) {
        if (!profilePhotoId)
            throw new Error("profilePhotoId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["profilePhoto%2Did"] = profilePhotoId;
        return new item_1.ProfilePhotoItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new PhotosRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/users/{user%2Did}/photos{?%24top,%24skip,%24filter,%24orderby,%24select}");
    }
    ;
    /**
     * The collection of the user's profile photos in different sizes. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ProfilePhotoCollectionResponse
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, profilePhotoCollectionResponse_1.createProfilePhotoCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * The collection of the user's profile photos in different sizes. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, photosRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a photosRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new PhotosRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.PhotosRequestBuilder = PhotosRequestBuilder;
const photosRequestBuilderGetQueryParametersMapper = {
    "filter": "%24filter",
    "orderby": "%24orderby",
    "select": "%24select",
    "skip": "%24skip",
    "top": "%24top",
};
// tslint:enable
// eslint-enable
