import { type PlannerBucketCollectionResponse } from '../../../../../../models/';
import { type PlannerBucket } from '../../../../../../models/plannerBucket';
import { CountRequestBuilder } from './count/';
import { PlannerBucketItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface BucketsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the buckets property of the microsoft.graph.plannerPlan entity.
 */
export declare class BucketsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the buckets property of the microsoft.graph.plannerPlan entity.
     * @param plannerBucketId The unique identifier of plannerBucket
     * @returns a PlannerBucketItemRequestBuilder
     */
    byPlannerBucketId(plannerBucketId: string): PlannerBucketItemRequestBuilder;
    /**
     * Instantiates a new BucketsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of plannerBucket objects contained by a plannerPlan object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PlannerBucketCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/plannerplan-list-buckets?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<BucketsRequestBuilderGetQueryParameters> | undefined): Promise<PlannerBucketCollectionResponse | undefined>;
    /**
     * Create new navigation property to buckets for users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PlannerBucket
     */
    post(body: PlannerBucket, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<PlannerBucket | undefined>;
    /**
     * Retrieve a list of plannerBucket objects contained by a plannerPlan object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<BucketsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to buckets for users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: PlannerBucket, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a bucketsRequestBuilder
     */
    withUrl(rawUrl: string): BucketsRequestBuilder;
}
