"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClearPresenceRequestBuilder = exports.serializeClearPresencePostRequestBody = exports.deserializeIntoClearPresencePostRequestBody = exports.createClearPresencePostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createClearPresencePostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoClearPresencePostRequestBody;
}
exports.createClearPresencePostRequestBodyFromDiscriminatorValue = createClearPresencePostRequestBodyFromDiscriminatorValue;
function deserializeIntoClearPresencePostRequestBody(clearPresencePostRequestBody = {}) {
    return {
        "sessionId": n => { clearPresencePostRequestBody.sessionId = n.getStringValue(); },
    };
}
exports.deserializeIntoClearPresencePostRequestBody = deserializeIntoClearPresencePostRequestBody;
function serializeClearPresencePostRequestBody(writer, clearPresencePostRequestBody = {}) {
    writer.writeStringValue("sessionId", clearPresencePostRequestBody.sessionId);
    writer.writeAdditionalData(clearPresencePostRequestBody.additionalData);
}
exports.serializeClearPresencePostRequestBody = serializeClearPresencePostRequestBody;
/**
 * Provides operations to call the clearPresence method.
 */
class ClearPresenceRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new ClearPresenceRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/users/{user%2Did}/presence/clearPresence");
    }
    ;
    /**
     * Clear the application's presence session for a user. If it is the user's only presence session, the user's presence will change to Offline/Offline. For details about presences sessions, see presence: setPresence.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/presence-clearpresence?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Clear the application's presence session for a user. If it is the user's only presence session, the user's presence will change to Offline/Offline. For details about presences sessions, see presence: setPresence.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeClearPresencePostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a clearPresenceRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new ClearPresenceRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.ClearPresenceRequestBuilder = ClearPresenceRequestBuilder;
// tslint:enable
// eslint-enable
