"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SetPresenceRequestBuilder = exports.serializeSetPresencePostRequestBody = exports.deserializeIntoSetPresencePostRequestBody = exports.createSetPresencePostRequestBodyFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createSetPresencePostRequestBodyFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoSetPresencePostRequestBody;
}
exports.createSetPresencePostRequestBodyFromDiscriminatorValue = createSetPresencePostRequestBodyFromDiscriminatorValue;
function deserializeIntoSetPresencePostRequestBody(setPresencePostRequestBody = {}) {
    return {
        "activity": n => { setPresencePostRequestBody.activity = n.getStringValue(); },
        "availability": n => { setPresencePostRequestBody.availability = n.getStringValue(); },
        "expirationDuration": n => { setPresencePostRequestBody.expirationDuration = n.getDurationValue(); },
        "sessionId": n => { setPresencePostRequestBody.sessionId = n.getStringValue(); },
    };
}
exports.deserializeIntoSetPresencePostRequestBody = deserializeIntoSetPresencePostRequestBody;
function serializeSetPresencePostRequestBody(writer, setPresencePostRequestBody = {}) {
    writer.writeStringValue("activity", setPresencePostRequestBody.activity);
    writer.writeStringValue("availability", setPresencePostRequestBody.availability);
    writer.writeDurationValue("expirationDuration", setPresencePostRequestBody.expirationDuration);
    writer.writeStringValue("sessionId", setPresencePostRequestBody.sessionId);
    writer.writeAdditionalData(setPresencePostRequestBody.additionalData);
}
exports.serializeSetPresencePostRequestBody = serializeSetPresencePostRequestBody;
/**
 * Provides operations to call the setPresence method.
 */
class SetPresenceRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new SetPresenceRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/users/{user%2Did}/presence/setPresence");
    }
    ;
    /**
     * Set the state of a user's presence session as an application.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/presence-setpresence?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Set the state of a user's presence session as an application.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, serializeSetPresencePostRequestBody);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a setPresenceRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new SetPresenceRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.SetPresenceRequestBuilder = SetPresenceRequestBuilder;
// tslint:enable
// eslint-enable
