import { type DirectoryObjectCollectionResponse } from '../../../models/';
import { CountRequestBuilder } from './count/';
import { GraphAppRoleAssignmentRequestBuilder } from './graphAppRoleAssignment/';
import { GraphDeviceRequestBuilder } from './graphDevice/';
import { GraphEndpointRequestBuilder } from './graphEndpoint/';
import { DirectoryObjectItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface RegisteredDevicesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the registeredDevices property of the microsoft.graph.user entity.
 */
export declare class RegisteredDevicesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Casts the previous resource to appRoleAssignment.
     */
    get graphAppRoleAssignment(): GraphAppRoleAssignmentRequestBuilder;
    /**
     * Casts the previous resource to device.
     */
    get graphDevice(): GraphDeviceRequestBuilder;
    /**
     * Casts the previous resource to endpoint.
     */
    get graphEndpoint(): GraphEndpointRequestBuilder;
    /**
     * Provides operations to manage the registeredDevices property of the microsoft.graph.user entity.
     * @param directoryObjectId The unique identifier of directoryObject
     * @returns a DirectoryObjectItemRequestBuilder
     */
    byDirectoryObjectId(directoryObjectId: string): DirectoryObjectItemRequestBuilder;
    /**
     * Instantiates a new RegisteredDevicesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Devices that are registered for the user. Read-only. Nullable. Supports $expand and returns up to 100 objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DirectoryObjectCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/user-list-registereddevices?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<RegisteredDevicesRequestBuilderGetQueryParameters> | undefined): Promise<DirectoryObjectCollectionResponse | undefined>;
    /**
     * Devices that are registered for the user. Read-only. Nullable. Supports $expand and returns up to 100 objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<RegisteredDevicesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a registeredDevicesRequestBuilder
     */
    withUrl(rawUrl: string): RegisteredDevicesRequestBuilder;
}
