"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RevokeSignInSessionsRequestBuilder = exports.serializeRevokeSignInSessionsPostResponse = exports.deserializeIntoRevokeSignInSessionsPostResponse = exports.createRevokeSignInSessionsPostResponseFromDiscriminatorValue = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
function createRevokeSignInSessionsPostResponseFromDiscriminatorValue(parseNode) {
    if (!parseNode)
        throw new Error("parseNode cannot be undefined");
    return deserializeIntoRevokeSignInSessionsPostResponse;
}
exports.createRevokeSignInSessionsPostResponseFromDiscriminatorValue = createRevokeSignInSessionsPostResponseFromDiscriminatorValue;
function deserializeIntoRevokeSignInSessionsPostResponse(revokeSignInSessionsPostResponse = {}) {
    return {
        "value": n => { revokeSignInSessionsPostResponse.value = n.getBooleanValue(); },
    };
}
exports.deserializeIntoRevokeSignInSessionsPostResponse = deserializeIntoRevokeSignInSessionsPostResponse;
function serializeRevokeSignInSessionsPostResponse(writer, revokeSignInSessionsPostResponse = {}) {
    writer.writeBooleanValue("value", revokeSignInSessionsPostResponse.value);
    writer.writeAdditionalData(revokeSignInSessionsPostResponse.additionalData);
}
exports.serializeRevokeSignInSessionsPostResponse = serializeRevokeSignInSessionsPostResponse;
/**
 * Provides operations to call the revokeSignInSessions method.
 */
class RevokeSignInSessionsRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new RevokeSignInSessionsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/users/{user%2Did}/revokeSignInSessions");
    }
    ;
    /**
     * Invalidates all the refresh tokens issued to applications for a user (as well as session cookies in a user's browser), by resetting the signInSessionsValidFromDateTime user property to the current date-time. Typically, this operation is performed (by the user or an administrator) if the user has a lost or stolen device. This operation prevents access to the organization's data through applications on the device by requiring the user to sign in again to all applications that they have previously consented to, independent of device.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of RevokeSignInSessionsPostResponse
     * @see {@link https://learn.microsoft.com/graph/api/user-revokesigninsessions?view=graph-rest-1.0|Find more info here}
     */
    post(requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, createRevokeSignInSessionsPostResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Invalidates all the refresh tokens issued to applications for a user (as well as session cookies in a user's browser), by resetting the signInSessionsValidFromDateTime user property to the current date-time. Typically, this operation is performed (by the user or an administrator) if the user has a lost or stolen device. This operation prevents access to the organization's data through applications on the device by requiring the user to sign in again to all applications that they have previously consented to, independent of device.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a revokeSignInSessionsRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new RevokeSignInSessionsRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.RevokeSignInSessionsRequestBuilder = RevokeSignInSessionsRequestBuilder;
// tslint:enable
// eslint-enable
