import { type ScopedRoleMembershipCollectionResponse } from '../../../models/';
import { type ScopedRoleMembership } from '../../../models/scopedRoleMembership';
import { CountRequestBuilder } from './count/';
import { ScopedRoleMembershipItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface ScopedRoleMemberOfRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the scopedRoleMemberOf property of the microsoft.graph.user entity.
 */
export declare class ScopedRoleMemberOfRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the scopedRoleMemberOf property of the microsoft.graph.user entity.
     * @param scopedRoleMembershipId The unique identifier of scopedRoleMembership
     * @returns a ScopedRoleMembershipItemRequestBuilder
     */
    byScopedRoleMembershipId(scopedRoleMembershipId: string): ScopedRoleMembershipItemRequestBuilder;
    /**
     * Instantiates a new ScopedRoleMemberOfRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get scopedRoleMemberOf from users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ScopedRoleMembershipCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<ScopedRoleMemberOfRequestBuilderGetQueryParameters> | undefined): Promise<ScopedRoleMembershipCollectionResponse | undefined>;
    /**
     * Create new navigation property to scopedRoleMemberOf for users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of ScopedRoleMembership
     */
    post(body: ScopedRoleMembership, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<ScopedRoleMembership | undefined>;
    /**
     * Get scopedRoleMemberOf from users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<ScopedRoleMemberOfRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to scopedRoleMemberOf for users
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ScopedRoleMembership, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a scopedRoleMemberOfRequestBuilder
     */
    withUrl(rawUrl: string): ScopedRoleMemberOfRequestBuilder;
}
