import { type TodoTask } from '../../../../../../../models/todoTask';
import { AttachmentsRequestBuilder } from './attachments/';
import { AttachmentSessionsRequestBuilder } from './attachmentSessions/';
import { ChecklistItemsRequestBuilder } from './checklistItems/';
import { ExtensionsRequestBuilder } from './extensions/';
import { LinkedResourcesRequestBuilder } from './linkedResources/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface TodoTaskItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the tasks property of the microsoft.graph.todoTaskList entity.
 */
export declare class TodoTaskItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the attachments property of the microsoft.graph.todoTask entity.
     */
    get attachments(): AttachmentsRequestBuilder;
    /**
     * Provides operations to manage the attachmentSessions property of the microsoft.graph.todoTask entity.
     */
    get attachmentSessions(): AttachmentSessionsRequestBuilder;
    /**
     * Provides operations to manage the checklistItems property of the microsoft.graph.todoTask entity.
     */
    get checklistItems(): ChecklistItemsRequestBuilder;
    /**
     * Provides operations to manage the extensions property of the microsoft.graph.todoTask entity.
     */
    get extensions(): ExtensionsRequestBuilder;
    /**
     * Provides operations to manage the linkedResources property of the microsoft.graph.todoTask entity.
     */
    get linkedResources(): LinkedResourcesRequestBuilder;
    /**
     * Instantiates a new TodoTaskItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Deletes a todoTask object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/todotask-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of a todoTask object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TodoTask
     * @see {@link https://learn.microsoft.com/graph/api/todotask-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<TodoTaskItemRequestBuilderGetQueryParameters> | undefined): Promise<TodoTask | undefined>;
    /**
     * Update the properties of a todoTask object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of TodoTask
     * @see {@link https://learn.microsoft.com/graph/api/todotask-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: TodoTask, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<TodoTask | undefined>;
    /**
     * Deletes a todoTask object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of a todoTask object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<TodoTaskItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the properties of a todoTask object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: TodoTask, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a TodoTaskItemRequestBuilder
     */
    withUrl(rawUrl: string): TodoTaskItemRequestBuilder;
}
