import { type WindowsMalwareInformationCollectionResponse } from '../../models/';
import { type WindowsMalwareInformation } from '../../models/windowsMalwareInformation';
import { CountRequestBuilder } from './count/';
import { WindowsMalwareInformationItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface WindowsMalwareInformationRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the windowsMalwareInformation property of the microsoft.graph.deviceManagement entity.
 */
export declare class WindowsMalwareInformationRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the windowsMalwareInformation property of the microsoft.graph.deviceManagement entity.
     * @param windowsMalwareInformationId The unique identifier of windowsMalwareInformation
     * @returns a WindowsMalwareInformationItemRequestBuilder
     */
    byWindowsMalwareInformationId(windowsMalwareInformationId: string): WindowsMalwareInformationItemRequestBuilder;
    /**
     * Instantiates a new WindowsMalwareInformationRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the windowsMalwareInformation objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WindowsMalwareInformationCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-windowsmalwareinformation-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<WindowsMalwareInformationRequestBuilderGetQueryParameters> | undefined): Promise<WindowsMalwareInformationCollectionResponse | undefined>;
    /**
     * Create a new windowsMalwareInformation object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WindowsMalwareInformation
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-windowsmalwareinformation-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: WindowsMalwareInformation, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WindowsMalwareInformation | undefined>;
    /**
     * List properties and relationships of the windowsMalwareInformation objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<WindowsMalwareInformationRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new windowsMalwareInformation object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: WindowsMalwareInformation, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a windowsMalwareInformationRequestBuilder
     */
    withUrl(rawUrl: string): WindowsMalwareInformationRequestBuilder;
}
