"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WindowsMalwareInformationRequestBuilder = void 0;
const oDataError_1 = require("../../models/oDataErrors/oDataError");
const windowsMalwareInformation_1 = require("../../models/windowsMalwareInformation");
const windowsMalwareInformationCollectionResponse_1 = require("../../models/windowsMalwareInformationCollectionResponse");
const count_1 = require("./count/");
const item_1 = require("./item/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the windowsMalwareInformation property of the microsoft.graph.deviceManagement entity.
 */
class WindowsMalwareInformationRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new count_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the windowsMalwareInformation property of the microsoft.graph.deviceManagement entity.
     * @param windowsMalwareInformationId The unique identifier of windowsMalwareInformation
     * @returns a WindowsMalwareInformationItemRequestBuilder
     */
    byWindowsMalwareInformationId(windowsMalwareInformationId) {
        if (!windowsMalwareInformationId)
            throw new Error("windowsMalwareInformationId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["windowsMalwareInformation%2Did"] = windowsMalwareInformationId;
        return new item_1.WindowsMalwareInformationItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new WindowsMalwareInformationRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/deviceManagement/windowsMalwareInformation{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * List properties and relationships of the windowsMalwareInformation objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WindowsMalwareInformationCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-windowsmalwareinformation-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, windowsMalwareInformationCollectionResponse_1.createWindowsMalwareInformationCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Create a new windowsMalwareInformation object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WindowsMalwareInformation
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-windowsmalwareinformation-create?view=graph-rest-1.0|Find more info here}
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, windowsMalwareInformation_1.createWindowsMalwareInformationFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * List properties and relationships of the windowsMalwareInformation objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, windowsMalwareInformationRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Create a new windowsMalwareInformation object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, windowsMalwareInformation_1.serializeWindowsMalwareInformation);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a windowsMalwareInformationRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new WindowsMalwareInformationRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.WindowsMalwareInformationRequestBuilder = WindowsMalwareInformationRequestBuilder;
const windowsMalwareInformationRequestBuilderGetQueryParametersMapper = {
    "count": "%24count",
    "expand": "%24expand",
    "filter": "%24filter",
    "orderby": "%24orderby",
    "search": "%24search",
    "select": "%24select",
    "skip": "%24skip",
    "top": "%24top",
};
// tslint:enable
// eslint-enable
