import { type MalwareStateForWindowsDeviceCollectionResponse } from '../../../../models/';
import { type MalwareStateForWindowsDevice } from '../../../../models/malwareStateForWindowsDevice';
import { CountRequestBuilder } from './count/';
import { MalwareStateForWindowsDeviceItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DeviceMalwareStatesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the deviceMalwareStates property of the microsoft.graph.windowsMalwareInformation entity.
 */
export declare class DeviceMalwareStatesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the deviceMalwareStates property of the microsoft.graph.windowsMalwareInformation entity.
     * @param malwareStateForWindowsDeviceId The unique identifier of malwareStateForWindowsDevice
     * @returns a MalwareStateForWindowsDeviceItemRequestBuilder
     */
    byMalwareStateForWindowsDeviceId(malwareStateForWindowsDeviceId: string): MalwareStateForWindowsDeviceItemRequestBuilder;
    /**
     * Instantiates a new DeviceMalwareStatesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the malwareStateForWindowsDevice objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MalwareStateForWindowsDeviceCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-malwarestateforwindowsdevice-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<DeviceMalwareStatesRequestBuilderGetQueryParameters> | undefined): Promise<MalwareStateForWindowsDeviceCollectionResponse | undefined>;
    /**
     * Create a new malwareStateForWindowsDevice object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of MalwareStateForWindowsDevice
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-malwarestateforwindowsdevice-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: MalwareStateForWindowsDevice, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<MalwareStateForWindowsDevice | undefined>;
    /**
     * List properties and relationships of the malwareStateForWindowsDevice objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DeviceMalwareStatesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new malwareStateForWindowsDevice object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: MalwareStateForWindowsDevice, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a deviceMalwareStatesRequestBuilder
     */
    withUrl(rawUrl: string): DeviceMalwareStatesRequestBuilder;
}
