import { type EmailIdentity } from './emailIdentity';
import { type Entity } from './entity';
import { PayloadBrand } from './payloadBrand';
import { PayloadComplexity } from './payloadComplexity';
import { PayloadDeliveryPlatform } from './payloadDeliveryPlatform';
import { type PayloadDetail } from './payloadDetail';
import { PayloadIndustry } from './payloadIndustry';
import { PayloadTheme } from './payloadTheme';
import { SimulationAttackTechnique } from './simulationAttackTechnique';
import { SimulationAttackType } from './simulationAttackType';
import { SimulationContentSource } from './simulationContentSource';
import { SimulationContentStatus } from './simulationContentStatus';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createPayloadFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoPayload;
export declare function deserializeIntoPayload(payload?: Payload | undefined): Record<string, (node: ParseNode) => void>;
export interface Payload extends Entity, Parsable {
    /**
     * The branch of a payload. Possible values are: unknown, other, americanExpress, capitalOne, dhl, docuSign, dropbox, facebook, firstAmerican, microsoft, netflix, scotiabank, sendGrid, stewartTitle, tesco, wellsFargo, syrinxCloud, adobe, teams, zoom, unknownFutureValue.
     */
    brand?: PayloadBrand;
    /**
     * The complexity of a payload. Possible values are: unknown, low, medium, high, unknownFutureValue.
     */
    complexity?: PayloadComplexity;
    /**
     * Identity of the user who created the attack simulation and training campaign payload.
     */
    createdBy?: EmailIdentity;
    /**
     * Date and time when the attack simulation and training campaign payload. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    createdDateTime?: Date;
    /**
     * Description of the attack simulation and training campaign payload.
     */
    description?: string;
    /**
     * Additional details about the payload.
     */
    detail?: PayloadDetail;
    /**
     * Display name of the attack simulation and training campaign payload. Supports $filter and $orderby.
     */
    displayName?: string;
    /**
     * Industry of a payload. Possible values are: unknown, other, banking, businessServices, consumerServices, education, energy, construction, consulting, financialServices, government, hospitality, insurance, legal, courierServices, IT, healthcare, manufacturing, retail, telecom, realEstate, unknownFutureValue.
     */
    industry?: PayloadIndustry;
    /**
     * Indicates whether the attack simulation and training campaign payload was created from an automation flow. Supports $filter and $orderby.
     */
    isAutomated?: boolean;
    /**
     * Indicates whether the payload is controversial.
     */
    isControversial?: boolean;
    /**
     * Indicates whether the payload is from any recent event.
     */
    isCurrentEvent?: boolean;
    /**
     * Payload language.
     */
    language?: string;
    /**
     * Identity of the user who most recently modified the attack simulation and training campaign payload.
     */
    lastModifiedBy?: EmailIdentity;
    /**
     * Date and time when the attack simulation and training campaign payload was last modified. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     */
    lastModifiedDateTime?: Date;
    /**
     * Free text tags for a payload.
     */
    payloadTags?: string[];
    /**
     * The payload delivery platform for a simulation. Possible values are: unknown, sms, email, teams, unknownFutureValue.
     */
    platform?: PayloadDeliveryPlatform;
    /**
     * Predicted probability for a payload to phish a targeted user.
     */
    predictedCompromiseRate?: number;
    /**
     * Attack type of the attack simulation and training campaign. Supports $filter and $orderby. Possible values are: unknown, social, cloud, endpoint, unknownFutureValue.
     */
    simulationAttackType?: SimulationAttackType;
    /**
     * The source property
     */
    source?: SimulationContentSource;
    /**
     * Simulation content status. Supports $filter and $orderby. Possible values are: unknown, draft, ready, archive, delete, unknownFutureValue.
     */
    status?: SimulationContentStatus;
    /**
     * The social engineering technique used in the attack simulation and training campaign. Supports $filter and $orderby. Possible values are: unknown, credentialHarvesting, attachmentMalware, driveByUrl, linkInAttachment, linkToMalwareFile, unknownFutureValue, oAuthConsentGrant. Note that you must use the Prefer: include-unknown-enum-members request header to get the following values from this evolvable enum: oAuthConsentGrant. For more information on the types of social engineering attack techniques, see simulations.
     */
    technique?: SimulationAttackTechnique;
    /**
     * The theme of a payload. Possible values are: unknown, other, accountActivation, accountVerification, billing, cleanUpMail, controversial, documentReceived, expense, fax, financeReport, incomingMessages, invoice, itemReceived, loginAlert, mailReceived, password, payment, payroll, personalizedOffer, quarantine, remoteWork, reviewMessage, securityUpdate, serviceSuspended, signatureRequired, upgradeMailboxStorage, verifyMailbox, voicemail, advertisement, employeeEngagement, unknownFutureValue.
     */
    theme?: PayloadTheme;
}
export declare function serializePayload(writer: SerializationWriter, payload?: Payload | undefined): void;
