import { type Entity } from '../entity';
import { type Article } from './article';
import { type CvssSummary } from './cvssSummary';
import { type FormattedContent } from './formattedContent';
import { type Hyperlink } from './hyperlink';
import { type VulnerabilityComponent } from './vulnerabilityComponent';
import { VulnerabilitySeverity } from './vulnerabilitySeverity';
import { type Parsable, type ParseNode, type SerializationWriter } from '@microsoft/kiota-abstractions';
export declare function createVulnerabilityFromDiscriminatorValue(parseNode: ParseNode | undefined): typeof deserializeIntoVulnerability;
export declare function deserializeIntoVulnerability(vulnerability?: Vulnerability | undefined): Record<string, (node: ParseNode) => void>;
export declare function serializeVulnerability(writer: SerializationWriter, vulnerability?: Vulnerability | undefined): void;
export interface Vulnerability extends Entity, Parsable {
    /**
     * Indicates whether this vulnerability has any known exploits associated to known bad actors.
     */
    activeExploitsObserved?: boolean;
    /**
     * Articles related to this vulnerability.
     */
    articles?: Article[];
    /**
     * Community-defined common weakness enumerations (CWE).
     */
    commonWeaknessEnumerationIds?: string[];
    /**
     * Components related to this vulnerability article.
     */
    components?: VulnerabilityComponent[];
    /**
     * The date and time when this vulnerability article was first created.
     */
    createdDateTime?: Date;
    /**
     * The cvss2Summary property
     */
    cvss2Summary?: CvssSummary;
    /**
     * The cvss3Summary property
     */
    cvss3Summary?: CvssSummary;
    /**
     * The description property
     */
    description?: FormattedContent;
    /**
     * Known exploits for this vulnerability.
     */
    exploits?: Hyperlink[];
    /**
     * Indicates whether this vulnerability has exploits in public sources (such as Packetstorm or Exploit-DB) online.
     */
    exploitsAvailable?: boolean;
    /**
     * Indicates whether chatter about this vulnerability has been discovered online.
     */
    hasChatter?: boolean;
    /**
     * The date and time when this vulnerability article was most recently updated.
     */
    lastModifiedDateTime?: Date;
    /**
     * A unique algorithm that reflects the priority of a vulnerability based on the CVSS score, exploits, chatter, and linkage to malware. This property also evaluates the recency of these components so users can understand which vulnerability should be remediated first.
     */
    priorityScore?: number;
    /**
     * The date and time when this vulnerability article was published.
     */
    publishedDateTime?: Date;
    /**
     * Reference links where further information can be learned about this vulnerability.
     */
    references?: Hyperlink[];
    /**
     * Any known remediation steps.
     */
    remediation?: FormattedContent;
    /**
     * The severity property
     */
    severity?: VulnerabilitySeverity;
}
