import { type PayloadCollectionResponse } from '../../../models/';
import { type Payload } from '../../../models/payload';
import { CountRequestBuilder } from './count/';
import { PayloadItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface PayloadsRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the payloads property of the microsoft.graph.attackSimulationRoot entity.
 */
export declare class PayloadsRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the payloads property of the microsoft.graph.attackSimulationRoot entity.
     * @param payloadId The unique identifier of payload
     * @returns a PayloadItemRequestBuilder
     */
    byPayloadId(payloadId: string): PayloadItemRequestBuilder;
    /**
     * Instantiates a new PayloadsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get a list of payloads for attack simulation campaigns. This operation expects the mandatory parameter source to filter and query the respective data source.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PayloadCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/attacksimulationroot-list-payloads?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<PayloadsRequestBuilderGetQueryParameters> | undefined): Promise<PayloadCollectionResponse | undefined>;
    /**
     * Create new navigation property to payloads for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Payload
     */
    post(body: Payload, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Payload | undefined>;
    /**
     * Get a list of payloads for attack simulation campaigns. This operation expects the mandatory parameter source to filter and query the respective data source.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<PayloadsRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to payloads for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: Payload, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a payloadsRequestBuilder
     */
    withUrl(rawUrl: string): PayloadsRequestBuilder;
}
