"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PayloadItemRequestBuilder = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const payload_1 = require("../../../../models/payload");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the payloads property of the microsoft.graph.attackSimulationRoot entity.
 */
class PayloadItemRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new PayloadItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/security/attackSimulation/payloads/{payload%2Did}{?%24select,%24expand}");
    }
    ;
    /**
     * Delete navigation property payloads for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration) {
        const requestInfo = this.toDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Represents an attack simulation training campaign payload in a tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Payload
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, payload_1.createPayloadFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Update the navigation property payloads in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Payload
     */
    patch(body, requestConfiguration) {
        const requestInfo = this.toPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, payload_1.createPayloadFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Delete navigation property payloads for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.DELETE, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Represents an attack simulation training campaign payload in a tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, payloadItemRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property payloads in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.PATCH, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, payload_1.serializePayload);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a PayloadItemRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new PayloadItemRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.PayloadItemRequestBuilder = PayloadItemRequestBuilder;
const payloadItemRequestBuilderGetQueryParametersMapper = {
    "expand": "%24expand",
    "select": "%24select",
};
// tslint:enable
// eslint-enable
