import { type VulnerabilityCollectionResponse } from '../../../models/security/';
import { type Vulnerability } from '../../../models/security/vulnerability';
import { CountRequestBuilder } from './count/';
import { VulnerabilityItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface VulnerabilitiesRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the vulnerabilities property of the microsoft.graph.security.threatIntelligence entity.
 */
export declare class VulnerabilitiesRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the vulnerabilities property of the microsoft.graph.security.threatIntelligence entity.
     * @param vulnerabilityId The unique identifier of vulnerability
     * @returns a VulnerabilityItemRequestBuilder
     */
    byVulnerabilityId(vulnerabilityId: string): VulnerabilityItemRequestBuilder;
    /**
     * Instantiates a new VulnerabilitiesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Read the properties and relationships of a vulnerability object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VulnerabilityCollectionResponse
     */
    get(requestConfiguration?: RequestConfiguration<VulnerabilitiesRequestBuilderGetQueryParameters> | undefined): Promise<VulnerabilityCollectionResponse | undefined>;
    /**
     * Create new navigation property to vulnerabilities for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Vulnerability
     */
    post(body: Vulnerability, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Vulnerability | undefined>;
    /**
     * Read the properties and relationships of a vulnerability object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<VulnerabilitiesRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create new navigation property to vulnerabilities for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: Vulnerability, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a vulnerabilitiesRequestBuilder
     */
    withUrl(rawUrl: string): VulnerabilitiesRequestBuilder;
}
