"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VulnerabilitiesRequestBuilder = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const vulnerability_1 = require("../../../models/security/vulnerability");
const vulnerabilityCollectionResponse_1 = require("../../../models/security/vulnerabilityCollectionResponse");
const count_1 = require("./count/");
const item_1 = require("./item/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the vulnerabilities property of the microsoft.graph.security.threatIntelligence entity.
 */
class VulnerabilitiesRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new count_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the vulnerabilities property of the microsoft.graph.security.threatIntelligence entity.
     * @param vulnerabilityId The unique identifier of vulnerability
     * @returns a VulnerabilityItemRequestBuilder
     */
    byVulnerabilityId(vulnerabilityId) {
        if (!vulnerabilityId)
            throw new Error("vulnerabilityId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["vulnerability%2Did"] = vulnerabilityId;
        return new item_1.VulnerabilityItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new VulnerabilitiesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/security/threatIntelligence/vulnerabilities{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * Read the properties and relationships of a vulnerability object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of VulnerabilityCollectionResponse
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, vulnerabilityCollectionResponse_1.createVulnerabilityCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Create new navigation property to vulnerabilities for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Vulnerability
     */
    post(body, requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, vulnerability_1.createVulnerabilityFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Read the properties and relationships of a vulnerability object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, vulnerabilitiesRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Create new navigation property to vulnerabilities for security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, vulnerability_1.serializeVulnerability);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a vulnerabilitiesRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new VulnerabilitiesRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.VulnerabilitiesRequestBuilder = VulnerabilitiesRequestBuilder;
const vulnerabilitiesRequestBuilderGetQueryParametersMapper = {
    "count": "%24count",
    "expand": "%24expand",
    "filter": "%24filter",
    "orderby": "%24orderby",
    "search": "%24search",
    "select": "%24select",
    "skip": "%24skip",
    "top": "%24top",
};
// tslint:enable
// eslint-enable
