import { type Vulnerability } from '../../../../models/security/vulnerability';
import { ArticlesRequestBuilder } from './articles/';
import { ComponentsRequestBuilder } from './components/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface VulnerabilityItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the vulnerabilities property of the microsoft.graph.security.threatIntelligence entity.
 */
export declare class VulnerabilityItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the articles property of the microsoft.graph.security.vulnerability entity.
     */
    get articles(): ArticlesRequestBuilder;
    /**
     * Provides operations to manage the components property of the microsoft.graph.security.vulnerability entity.
     */
    get components(): ComponentsRequestBuilder;
    /**
     * Instantiates a new VulnerabilityItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property vulnerabilities for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Read the properties and relationships of a vulnerability object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Vulnerability
     * @see {@link https://learn.microsoft.com/graph/api/security-vulnerability-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<VulnerabilityItemRequestBuilderGetQueryParameters> | undefined): Promise<Vulnerability | undefined>;
    /**
     * Update the navigation property vulnerabilities in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Vulnerability
     */
    patch(body: Vulnerability, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<Vulnerability | undefined>;
    /**
     * Delete navigation property vulnerabilities for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Read the properties and relationships of a vulnerability object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<VulnerabilityItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the navigation property vulnerabilities in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: Vulnerability, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a VulnerabilityItemRequestBuilder
     */
    withUrl(rawUrl: string): VulnerabilityItemRequestBuilder;
}
