"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VulnerabilityItemRequestBuilder = void 0;
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const vulnerability_1 = require("../../../../models/security/vulnerability");
const articles_1 = require("./articles/");
const components_1 = require("./components/");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the vulnerabilities property of the microsoft.graph.security.threatIntelligence entity.
 */
class VulnerabilityItemRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to manage the articles property of the microsoft.graph.security.vulnerability entity.
     */
    get articles() {
        return new articles_1.ArticlesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the components property of the microsoft.graph.security.vulnerability entity.
     */
    get components() {
        return new components_1.ComponentsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new VulnerabilityItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/security/threatIntelligence/vulnerabilities/{vulnerability%2Did}{?%24select,%24expand}");
    }
    ;
    /**
     * Delete navigation property vulnerabilities for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     */
    delete(requestConfiguration) {
        const requestInfo = this.toDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Read the properties and relationships of a vulnerability object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Vulnerability
     * @see {@link https://learn.microsoft.com/graph/api/security-vulnerability-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, vulnerability_1.createVulnerabilityFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Update the navigation property vulnerabilities in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of Vulnerability
     */
    patch(body, requestConfiguration) {
        const requestInfo = this.toPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, vulnerability_1.createVulnerabilityFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Delete navigation property vulnerabilities for security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.DELETE, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Read the properties and relationships of a vulnerability object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, vulnerabilityItemRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property vulnerabilities in security
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.PATCH, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, vulnerability_1.serializeVulnerability);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a VulnerabilityItemRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new VulnerabilityItemRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.VulnerabilityItemRequestBuilder = VulnerabilityItemRequestBuilder;
const vulnerabilityItemRequestBuilderGetQueryParametersMapper = {
    "expand": "%24expand",
    "select": "%24select",
};
// tslint:enable
// eslint-enable
