import { type WindowsDeviceMalwareStateCollectionResponse } from '../../../../../../models/';
import { type WindowsDeviceMalwareState } from '../../../../../../models/windowsDeviceMalwareState';
import { CountRequestBuilder } from './count/';
import { WindowsDeviceMalwareStateItemRequestBuilder } from './item/';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DetectedMalwareStateRequestBuilderGetQueryParameters {
    /**
     * Include count of items
     */
    count?: boolean;
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Filter items by property values
     */
    filter?: string;
    /**
     * Order items by property values
     */
    orderby?: string[];
    /**
     * Search items by search phrases
     */
    search?: string;
    /**
     * Select properties to be returned
     */
    select?: string[];
    /**
     * Skip the first n items
     */
    skip?: number;
    /**
     * Show only the first n items
     */
    top?: number;
}
/**
 * Provides operations to manage the detectedMalwareState property of the microsoft.graph.windowsProtectionState entity.
 */
export declare class DetectedMalwareStateRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to count the resources in the collection.
     */
    get count(): CountRequestBuilder;
    /**
     * Provides operations to manage the detectedMalwareState property of the microsoft.graph.windowsProtectionState entity.
     * @param windowsDeviceMalwareStateId The unique identifier of windowsDeviceMalwareState
     * @returns a WindowsDeviceMalwareStateItemRequestBuilder
     */
    byWindowsDeviceMalwareStateId(windowsDeviceMalwareStateId: string): WindowsDeviceMalwareStateItemRequestBuilder;
    /**
     * Instantiates a new DetectedMalwareStateRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List properties and relationships of the windowsDeviceMalwareState objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WindowsDeviceMalwareStateCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-windowsdevicemalwarestate-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration?: RequestConfiguration<DetectedMalwareStateRequestBuilderGetQueryParameters> | undefined): Promise<WindowsDeviceMalwareStateCollectionResponse | undefined>;
    /**
     * Create a new windowsDeviceMalwareState object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WindowsDeviceMalwareState
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-windowsdevicemalwarestate-create?view=graph-rest-1.0|Find more info here}
     */
    post(body: WindowsDeviceMalwareState, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<WindowsDeviceMalwareState | undefined>;
    /**
     * List properties and relationships of the windowsDeviceMalwareState objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DetectedMalwareStateRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Create a new windowsDeviceMalwareState object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: WindowsDeviceMalwareState, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a detectedMalwareStateRequestBuilder
     */
    withUrl(rawUrl: string): DetectedMalwareStateRequestBuilder;
}
