"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WindowsDeviceMalwareStateItemRequestBuilder = void 0;
const oDataError_1 = require("../../../../../../../models/oDataErrors/oDataError");
const windowsDeviceMalwareState_1 = require("../../../../../../../models/windowsDeviceMalwareState");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the detectedMalwareState property of the microsoft.graph.windowsProtectionState entity.
 */
class WindowsDeviceMalwareStateItemRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new WindowsDeviceMalwareStateItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/users/{user%2Did}/managedDevices/{managedDevice%2Did}/windowsProtectionState/detectedMalwareState/{windowsDeviceMalwareState%2Did}{?%24select,%24expand}");
    }
    ;
    /**
     * Deletes a windowsDeviceMalwareState.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-windowsdevicemalwarestate-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration) {
        const requestInfo = this.toDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Read properties and relationships of the windowsDeviceMalwareState object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WindowsDeviceMalwareState
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-windowsdevicemalwarestate-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, windowsDeviceMalwareState_1.createWindowsDeviceMalwareStateFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Update the properties of a windowsDeviceMalwareState object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WindowsDeviceMalwareState
     * @see {@link https://learn.microsoft.com/graph/api/intune-devices-windowsdevicemalwarestate-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body, requestConfiguration) {
        const requestInfo = this.toPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, windowsDeviceMalwareState_1.createWindowsDeviceMalwareStateFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Deletes a windowsDeviceMalwareState.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.DELETE, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Read properties and relationships of the windowsDeviceMalwareState object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, windowsDeviceMalwareStateItemRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Update the properties of a windowsDeviceMalwareState object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.PATCH, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, windowsDeviceMalwareState_1.serializeWindowsDeviceMalwareState);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a WindowsDeviceMalwareStateItemRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new WindowsDeviceMalwareStateItemRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.WindowsDeviceMalwareStateItemRequestBuilder = WindowsDeviceMalwareStateItemRequestBuilder;
const windowsDeviceMalwareStateItemRequestBuilderGetQueryParametersMapper = {
    "expand": "%24expand",
    "select": "%24select",
};
// tslint:enable
// eslint-enable
